import{r as x,g as at,_ as lc,a as Tp,b as H,c as Dp,d as ke,u as te,S as cc,e as uc,m as _p,T as ts,f as fc,h as $p,i as Bp,Q as Pp,j as kp,k as Lp}from"./@libs-DsDdirnI.js";import{u as Mp,a as ie,L as ge,O as dc,B as Up,R as Vp,b as W,N as Ro}from"./@react-router-DqDt1vCS.js";(function(){const t=document.createElement("link").relList;if(t&&t.supports&&t.supports("modulepreload"))return;for(const o of document.querySelectorAll('link[rel="modulepreload"]'))r(o);new MutationObserver(o=>{for(const i of o)if(i.type==="childList")for(const s of i.addedNodes)s.tagName==="LINK"&&s.rel==="modulepreload"&&r(s)}).observe(document,{childList:!0,subtree:!0});function n(o){const i={};return o.integrity&&(i.integrity=o.integrity),o.referrerPolicy&&(i.referrerPolicy=o.referrerPolicy),o.crossOrigin==="use-credentials"?i.credentials="include":o.crossOrigin==="anonymous"?i.credentials="omit":i.credentials="same-origin",i}function r(o){if(o.ep)return;o.ep=!0;const i=n(o);fetch(o.href,i)}})();var pc={exports:{}},Qr={};/**
 * @license React
 * react-jsx-runtime.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Hp=x,Gp=Symbol.for("react.element"),Wp=Symbol.for("react.fragment"),zp=Object.prototype.hasOwnProperty,Qp=Hp.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED.ReactCurrentOwner,qp={key:!0,ref:!0,__self:!0,__source:!0};function hc(e,t,n){var r,o={},i=null,s=null;n!==void 0&&(i=""+n),t.key!==void 0&&(i=""+t.key),t.ref!==void 0&&(s=t.ref);for(r in t)zp.call(t,r)&&!qp.hasOwnProperty(r)&&(o[r]=t[r]);if(e&&e.defaultProps)for(r in t=e.defaultProps,t)o[r]===void 0&&(o[r]=t[r]);return{$$typeof:Gp,type:e,key:i,ref:s,props:o,_owner:Qp.current}}Qr.Fragment=Wp;Qr.jsx=hc;Qr.jsxs=hc;pc.exports=Qr;var a=pc.exports,gc={exports:{}};/*!
	Copyright (c) 2018 Jed Watson.
	Licensed under the MIT License (MIT), see
	http://jedwatson.github.io/classnames
*/(function(e){(function(){var t={}.hasOwnProperty;function n(){for(var i="",s=0;s<arguments.length;s++){var l=arguments[s];l&&(i=o(i,r(l)))}return i}function r(i){if(typeof i=="string"||typeof i=="number")return i;if(typeof i!="object")return"";if(Array.isArray(i))return n.apply(null,i);if(i.toString!==Object.prototype.toString&&!i.toString.toString().includes("[native code]"))return i.toString();var s="";for(var l in i)t.call(i,l)&&i[l]&&(s=o(s,l));return s}function o(i,s){return s?i?i+" "+s:i+s:i}e.exports?(n.default=n,e.exports=n):window.classNames=n})()})(gc);var Kp=gc.exports;const _=at(Kp);var Yp=function(e,t,n,r,o,i,s,l){if(!e){var c;if(t===void 0)c=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var u=[n,r,o,i,s,l],f=0;c=new Error(t.replace(/%s/g,function(){return u[f++]})),c.name="Invariant Violation"}throw c.framesToPop=1,c}},Jp=Yp;const Zp=at(Jp);function Js(e){return"default"+e.charAt(0).toUpperCase()+e.substr(1)}function Xp(e){var t=eh(e,"string");return typeof t=="symbol"?t:String(t)}function eh(e,t){if(typeof e!="object"||e===null)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t||"default");if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function mc(e,t,n){var r=x.useRef(e!==void 0),o=x.useState(t),i=o[0],s=o[1],l=e!==void 0,c=r.current;return r.current=l,!l&&c&&i!==t&&s(t),[l?e:i,x.useCallback(function(u){for(var f=arguments.length,d=new Array(f>1?f-1:0),p=1;p<f;p++)d[p-1]=arguments[p];n&&n.apply(void 0,[u].concat(d)),s(u)},[n])]}function ns(e,t){return Object.keys(t).reduce(function(n,r){var o,i=n,s=i[Js(r)],l=i[r],c=lc(i,[Js(r),r].map(Xp)),u=t[r],f=mc(l,s,e[u]),d=f[0],p=f[1];return Tp({},c,(o={},o[r]=d,o[u]=p,o))},e)}const th=["xxl","xl","lg","md","sm","xs"],nh="xs",qr=x.createContext({prefixes:{},breakpoints:th,minBreakpoint:nh});function $(e,t){const{prefixes:n}=x.useContext(qr);return e||n[t]||t}function xc(){const{breakpoints:e}=x.useContext(qr);return e}function vc(){const{minBreakpoint:e}=x.useContext(qr);return e}function Kr(){const{dir:e}=x.useContext(qr);return e==="rtl"}function yc(e){return e&&e.ownerDocument||document}function rh(e){var t=yc(e);return t&&t.defaultView||window}function oh(e,t){return rh(e).getComputedStyle(e,t)}var ih=/([A-Z])/g;function sh(e){return e.replace(ih,"-$1").toLowerCase()}var ah=/^ms-/;function Qn(e){return sh(e).replace(ah,"-ms-")}var lh=/^((translate|rotate|scale)(X|Y|Z|3d)?|matrix(3d)?|perspective|skew(X|Y)?)$/i;function ch(e){return!!(e&&lh.test(e))}function Nt(e,t){var n="",r="";if(typeof t=="string")return e.style.getPropertyValue(Qn(t))||oh(e).getPropertyValue(Qn(t));Object.keys(t).forEach(function(o){var i=t[o];!i&&i!==0?e.style.removeProperty(Qn(o)):ch(o)?r+=o+"("+i+") ":n+=Qn(o)+": "+i+";"}),r&&(n+="transform: "+r+";"),e.style.cssText+=";"+n}var wc={exports:{}},uh="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED",fh=uh,dh=fh;function bc(){}function Cc(){}Cc.resetWarningCache=bc;var ph=function(){function e(r,o,i,s,l,c){if(c!==dh){var u=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw u.name="Invariant Violation",u}}e.isRequired=e;function t(){return e}var n={array:e,bigint:e,bool:e,func:e,number:e,object:e,string:e,symbol:e,any:e,arrayOf:t,element:e,elementType:e,instanceOf:t,node:e,objectOf:t,oneOf:t,oneOfType:t,shape:t,exact:t,checkPropTypes:Cc,resetWarningCache:bc};return n.PropTypes=n,n};wc.exports=ph();var hh=wc.exports;const I=at(hh),Zs={disabled:!1},Sc=H.createContext(null);var gh=function(t){return t.scrollTop},yn="unmounted",xt="exited",et="entering",vt="entered",br="exiting",lt=function(e){Dp(t,e);function t(r,o){var i;i=e.call(this,r,o)||this;var s=o,l=s&&!s.isMounting?r.enter:r.appear,c;return i.appearStatus=null,r.in?l?(c=xt,i.appearStatus=et):c=vt:r.unmountOnExit||r.mountOnEnter?c=yn:c=xt,i.state={status:c},i.nextCallback=null,i}t.getDerivedStateFromProps=function(o,i){var s=o.in;return s&&i.status===yn?{status:xt}:null};var n=t.prototype;return n.componentDidMount=function(){this.updateStatus(!0,this.appearStatus)},n.componentDidUpdate=function(o){var i=null;if(o!==this.props){var s=this.state.status;this.props.in?s!==et&&s!==vt&&(i=et):(s===et||s===vt)&&(i=br)}this.updateStatus(!1,i)},n.componentWillUnmount=function(){this.cancelNextCallback()},n.getTimeouts=function(){var o=this.props.timeout,i,s,l;return i=s=l=o,o!=null&&typeof o!="number"&&(i=o.exit,s=o.enter,l=o.appear!==void 0?o.appear:s),{exit:i,enter:s,appear:l}},n.updateStatus=function(o,i){if(o===void 0&&(o=!1),i!==null)if(this.cancelNextCallback(),i===et){if(this.props.unmountOnExit||this.props.mountOnEnter){var s=this.props.nodeRef?this.props.nodeRef.current:ke.findDOMNode(this);s&&gh(s)}this.performEnter(o)}else this.performExit();else this.props.unmountOnExit&&this.state.status===xt&&this.setState({status:yn})},n.performEnter=function(o){var i=this,s=this.props.enter,l=this.context?this.context.isMounting:o,c=this.props.nodeRef?[l]:[ke.findDOMNode(this),l],u=c[0],f=c[1],d=this.getTimeouts(),p=l?d.appear:d.enter;if(!o&&!s||Zs.disabled){this.safeSetState({status:vt},function(){i.props.onEntered(u)});return}this.props.onEnter(u,f),this.safeSetState({status:et},function(){i.props.onEntering(u,f),i.onTransitionEnd(p,function(){i.safeSetState({status:vt},function(){i.props.onEntered(u,f)})})})},n.performExit=function(){var o=this,i=this.props.exit,s=this.getTimeouts(),l=this.props.nodeRef?void 0:ke.findDOMNode(this);if(!i||Zs.disabled){this.safeSetState({status:xt},function(){o.props.onExited(l)});return}this.props.onExit(l),this.safeSetState({status:br},function(){o.props.onExiting(l),o.onTransitionEnd(s.exit,function(){o.safeSetState({status:xt},function(){o.props.onExited(l)})})})},n.cancelNextCallback=function(){this.nextCallback!==null&&(this.nextCallback.cancel(),this.nextCallback=null)},n.safeSetState=function(o,i){i=this.setNextCallback(i),this.setState(o,i)},n.setNextCallback=function(o){var i=this,s=!0;return this.nextCallback=function(l){s&&(s=!1,i.nextCallback=null,o(l))},this.nextCallback.cancel=function(){s=!1},this.nextCallback},n.onTransitionEnd=function(o,i){this.setNextCallback(i);var s=this.props.nodeRef?this.props.nodeRef.current:ke.findDOMNode(this),l=o==null&&!this.props.addEndListener;if(!s||l){setTimeout(this.nextCallback,0);return}if(this.props.addEndListener){var c=this.props.nodeRef?[this.nextCallback]:[s,this.nextCallback],u=c[0],f=c[1];this.props.addEndListener(u,f)}o!=null&&setTimeout(this.nextCallback,o)},n.render=function(){var o=this.state.status;if(o===yn)return null;var i=this.props,s=i.children;i.in,i.mountOnEnter,i.unmountOnExit,i.appear,i.enter,i.exit,i.timeout,i.addEndListener,i.onEnter,i.onEntering,i.onEntered,i.onExit,i.onExiting,i.onExited,i.nodeRef;var l=lc(i,["children","in","mountOnEnter","unmountOnExit","appear","enter","exit","timeout","addEndListener","onEnter","onEntering","onEntered","onExit","onExiting","onExited","nodeRef"]);return H.createElement(Sc.Provider,{value:null},typeof s=="function"?s(o,l):H.cloneElement(H.Children.only(s),l))},t}(H.Component);lt.contextType=Sc;lt.propTypes={};function Mt(){}lt.defaultProps={in:!1,mountOnEnter:!1,unmountOnExit:!1,appear:!1,enter:!0,exit:!0,onEnter:Mt,onEntering:Mt,onEntered:Mt,onExit:Mt,onExiting:Mt,onExited:Mt};lt.UNMOUNTED=yn;lt.EXITED=xt;lt.ENTERING=et;lt.ENTERED=vt;lt.EXITING=br;const mh=lt,rs=!!(typeof window<"u"&&window.document&&window.document.createElement);var fi=!1,di=!1;try{var Fo={get passive(){return fi=!0},get once(){return di=fi=!0}};rs&&(window.addEventListener("test",Fo,Fo),window.removeEventListener("test",Fo,!0))}catch{}function Ac(e,t,n,r){if(r&&typeof r!="boolean"&&!di){var o=r.once,i=r.capture,s=n;!di&&o&&(s=n.__once||function l(c){this.removeEventListener(t,l,i),n.call(this,c)},n.__once=s),e.addEventListener(t,s,fi?r:i)}e.addEventListener(t,n,r)}function pi(e,t,n,r){var o=r&&typeof r!="boolean"?r.capture:r;e.removeEventListener(t,n,o),n.__once&&e.removeEventListener(t,n.__once,o)}function jc(e,t,n,r){return Ac(e,t,n,r),function(){pi(e,t,n,r)}}function xh(e,t,n,r){if(n===void 0&&(n=!1),r===void 0&&(r=!0),e){var o=document.createEvent("HTMLEvents");o.initEvent(t,n,r),e.dispatchEvent(o)}}function vh(e){var t=Nt(e,"transitionDuration")||"",n=t.indexOf("ms")===-1?1e3:1;return parseFloat(t)*n}function yh(e,t,n){n===void 0&&(n=5);var r=!1,o=setTimeout(function(){r||xh(e,"transitionend",!0)},t+n),i=jc(e,"transitionend",function(){r=!0},{once:!0});return function(){clearTimeout(o),i()}}function Rc(e,t,n,r){n==null&&(n=vh(e)||0);var o=yh(e,n,r),i=jc(e,"transitionend",t);return function(){o(),i()}}function Xs(e,t){const n=Nt(e,t)||"",r=n.indexOf("ms")===-1?1e3:1;return parseFloat(n)*r}function Fc(e,t){const n=Xs(e,"transitionDuration"),r=Xs(e,"transitionDelay"),o=Rc(e,i=>{i.target===e&&(o(),t(i))},n+r)}function fn(...e){return e.filter(t=>t!=null).reduce((t,n)=>{if(typeof n!="function")throw new Error("Invalid Argument Type, must only provide functions, undefined, or null.");return t===null?n:function(...o){t.apply(this,o),n.apply(this,o)}},null)}function Oc(e){e.offsetHeight}const ea=e=>!e||typeof e=="function"?e:t=>{e.current=t};function wh(e,t){const n=ea(e),r=ea(t);return o=>{n&&n(o),r&&r(o)}}function ze(e,t){return x.useMemo(()=>wh(e,t),[e,t])}function Cr(e){return e&&"setState"in e?ke.findDOMNode(e):e??null}const bh=H.forwardRef(({onEnter:e,onEntering:t,onEntered:n,onExit:r,onExiting:o,onExited:i,addEndListener:s,children:l,childRef:c,...u},f)=>{const d=x.useRef(null),p=ze(d,c),h=C=>{p(Cr(C))},g=C=>A=>{C&&d.current&&C(d.current,A)},m=x.useCallback(g(e),[e]),v=x.useCallback(g(t),[t]),y=x.useCallback(g(n),[n]),b=x.useCallback(g(r),[r]),w=x.useCallback(g(o),[o]),S=x.useCallback(g(i),[i]),F=x.useCallback(g(s),[s]);return a.jsx(mh,{ref:f,...u,onEnter:m,onEntered:y,onEntering:v,onExit:b,onExited:S,onExiting:w,addEndListener:F,nodeRef:d,children:typeof l=="function"?(C,A)=>l(C,{...A,ref:h}):H.cloneElement(l,{ref:h})})}),Ec=bh,Ch={height:["marginTop","marginBottom"],width:["marginLeft","marginRight"]};function Sh(e,t){const n=`offset${e[0].toUpperCase()}${e.slice(1)}`,r=t[n],o=Ch[e];return r+parseInt(Nt(t,o[0]),10)+parseInt(Nt(t,o[1]),10)}const Ah={[xt]:"collapse",[br]:"collapsing",[et]:"collapsing",[vt]:"collapse show"},jh=H.forwardRef(({onEnter:e,onEntering:t,onEntered:n,onExit:r,onExiting:o,className:i,children:s,dimension:l="height",in:c=!1,timeout:u=300,mountOnEnter:f=!1,unmountOnExit:d=!1,appear:p=!1,getDimensionValue:h=Sh,...g},m)=>{const v=typeof l=="function"?l():l,y=x.useMemo(()=>fn(C=>{C.style[v]="0"},e),[v,e]),b=x.useMemo(()=>fn(C=>{const A=`scroll${v[0].toUpperCase()}${v.slice(1)}`;C.style[v]=`${C[A]}px`},t),[v,t]),w=x.useMemo(()=>fn(C=>{C.style[v]=null},n),[v,n]),S=x.useMemo(()=>fn(C=>{C.style[v]=`${h(v,C)}px`,Oc(C)},r),[r,h,v]),F=x.useMemo(()=>fn(C=>{C.style[v]=null},o),[v,o]);return a.jsx(Ec,{ref:m,addEndListener:Fc,...g,"aria-expanded":g.role?c:null,onEnter:y,onEntering:b,onEntered:w,onExit:S,onExiting:F,childRef:s.ref,in:c,timeout:u,mountOnEnter:f,unmountOnExit:d,appear:p,children:(C,A)=>H.cloneElement(s,{...A,className:_(i,s.props.className,Ah[C],v==="width"&&"collapse-horizontal")})})}),Rh=jh;function Ic(e,t){return Array.isArray(e)?e.includes(t):e===t}const Nc=x.createContext({});Nc.displayName="AccordionContext";const Yr=Nc,Tc=x.forwardRef(({as:e="div",bsPrefix:t,className:n,children:r,eventKey:o,...i},s)=>{const{activeEventKey:l}=x.useContext(Yr);return t=$(t,"accordion-collapse"),a.jsx(Rh,{ref:s,in:Ic(l,o),...i,className:_(n,t),children:a.jsx(e,{children:x.Children.only(r)})})});Tc.displayName="AccordionCollapse";const Dc=Tc,_c=x.createContext({eventKey:""});_c.displayName="AccordionItemContext";const os=_c,$c=x.forwardRef(({as:e="div",bsPrefix:t,className:n,onEnter:r,onEntering:o,onEntered:i,onExit:s,onExiting:l,onExited:c,...u},f)=>{t=$(t,"accordion-body");const{eventKey:d}=x.useContext(os);return a.jsx(Dc,{eventKey:d,onEnter:r,onEntering:o,onEntered:i,onExit:s,onExiting:l,onExited:c,children:a.jsx(e,{ref:f,...u,className:_(n,t)})})});$c.displayName="AccordionBody";const Fh=$c;function Oh(e,t){const{activeEventKey:n,onSelect:r,alwaysOpen:o}=x.useContext(Yr);return i=>{let s=e===n?null:e;o&&(Array.isArray(n)?n.includes(e)?s=n.filter(l=>l!==e):s=[...n,e]:s=[e]),r==null||r(s,i),t==null||t(i)}}const Bc=x.forwardRef(({as:e="button",bsPrefix:t,className:n,onClick:r,...o},i)=>{t=$(t,"accordion-button");const{eventKey:s}=x.useContext(os),l=Oh(s,r),{activeEventKey:c}=x.useContext(Yr);return e==="button"&&(o.type="button"),a.jsx(e,{ref:i,onClick:l,...o,"aria-expanded":Array.isArray(c)?c.includes(s):s===c,className:_(n,t,!Ic(c,s)&&"collapsed")})});Bc.displayName="AccordionButton";const Pc=Bc,kc=x.forwardRef(({as:e="h2",bsPrefix:t,className:n,children:r,onClick:o,...i},s)=>(t=$(t,"accordion-header"),a.jsx(e,{ref:s,...i,className:_(n,t),children:a.jsx(Pc,{onClick:o,children:r})})));kc.displayName="AccordionHeader";const Eh=kc,Lc=x.forwardRef(({as:e="div",bsPrefix:t,className:n,eventKey:r,...o},i)=>{t=$(t,"accordion-item");const s=x.useMemo(()=>({eventKey:r}),[r]);return a.jsx(os.Provider,{value:s,children:a.jsx(e,{ref:i,...o,className:_(n,t)})})});Lc.displayName="AccordionItem";const Ih=Lc,Mc=x.forwardRef((e,t)=>{const{as:n="div",activeKey:r,bsPrefix:o,className:i,onSelect:s,flush:l,alwaysOpen:c,...u}=ns(e,{activeKey:"onSelect"}),f=$(o,"accordion"),d=x.useMemo(()=>({activeEventKey:r,onSelect:s,alwaysOpen:c}),[r,s,c]);return a.jsx(Yr.Provider,{value:d,children:a.jsx(n,{ref:t,...u,className:_(i,f,l&&`${f}-flush`)})})});Mc.displayName="Accordion";const gr=Object.assign(Mc,{Button:Pc,Collapse:Dc,Item:Ih,Header:Eh,Body:Fh});function Nh(e){const t=x.useRef(e);return x.useEffect(()=>{t.current=e},[e]),t}function ce(e){const t=Nh(e);return x.useCallback(function(...n){return t.current&&t.current(...n)},[t])}const is=e=>x.forwardRef((t,n)=>a.jsx("div",{...t,ref:n,className:_(t.className,e)}));function Sr(){return x.useState(null)}function Th(e,t,n,r=!1){const o=ce(n);x.useEffect(()=>{const i=typeof e=="function"?e():e;return i.addEventListener(t,o,r),()=>i.removeEventListener(t,o,r)},[e])}function ss(){const e=x.useRef(!0),t=x.useRef(()=>e.current);return x.useEffect(()=>(e.current=!0,()=>{e.current=!1}),[]),t.current}function Uc(e){const t=x.useRef(null);return x.useEffect(()=>{t.current=e}),t.current}const Dh=typeof global<"u"&&global.navigator&&global.navigator.product==="ReactNative",_h=typeof document<"u",Ar=_h||Dh?x.useLayoutEffect:x.useEffect,$h=["as","disabled"];function Bh(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}function Ph(e){return!e||e.trim()==="#"}function as({tagName:e,disabled:t,href:n,target:r,rel:o,role:i,onClick:s,tabIndex:l=0,type:c}){e||(n!=null||r!=null||o!=null?e="a":e="button");const u={tagName:e};if(e==="button")return[{type:c||"button",disabled:t},u];const f=p=>{if((t||e==="a"&&Ph(n))&&p.preventDefault(),t){p.stopPropagation();return}s==null||s(p)},d=p=>{p.key===" "&&(p.preventDefault(),f(p))};return e==="a"&&(n||(n="#"),t&&(n=void 0)),[{role:i??"button",disabled:void 0,tabIndex:t?void 0:l,href:n,target:e==="a"?r:void 0,"aria-disabled":t||void 0,rel:e==="a"?o:void 0,onClick:f,onKeyDown:d},u]}const ls=x.forwardRef((e,t)=>{let{as:n,disabled:r}=e,o=Bh(e,$h);const[i,{tagName:s}]=as(Object.assign({tagName:n,disabled:r},o));return a.jsx(s,Object.assign({},o,i,{ref:t}))});ls.displayName="Button";const kh=["onKeyDown"];function Lh(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}function Mh(e){return!e||e.trim()==="#"}const Vc=x.forwardRef((e,t)=>{let{onKeyDown:n}=e,r=Lh(e,kh);const[o]=as(Object.assign({tagName:"a"},r)),i=ce(s=>{o.onKeyDown(s),n==null||n(s)});return Mh(r.href)||r.role==="button"?a.jsx("a",Object.assign({ref:t},r,o,{onKeyDown:i})):a.jsx("a",Object.assign({ref:t},r,{onKeyDown:n}))});Vc.displayName="Anchor";const Hc=Vc,Uh={[et]:"show",[vt]:"show"},Gc=x.forwardRef(({className:e,children:t,transitionClasses:n={},onEnter:r,...o},i)=>{const s={in:!1,timeout:300,mountOnEnter:!1,unmountOnExit:!1,appear:!1,...o},l=x.useCallback((c,u)=>{Oc(c),r==null||r(c,u)},[r]);return a.jsx(Ec,{ref:i,addEndListener:Fc,...s,onEnter:l,childRef:t.ref,children:(c,u)=>x.cloneElement(t,{...u,className:_("fade",e,t.props.className,Uh[c],n[c])})})});Gc.displayName="Fade";const jr=Gc,Vh={"aria-label":I.string,onClick:I.func,variant:I.oneOf(["white"])},cs=x.forwardRef(({className:e,variant:t,"aria-label":n="Close",...r},o)=>a.jsx("button",{ref:o,type:"button",className:_("btn-close",t&&`btn-close-${t}`,e),"aria-label":n,...r}));cs.displayName="CloseButton";cs.propTypes=Vh;const Hh=cs,Wc=x.forwardRef(({bsPrefix:e,bg:t="primary",pill:n=!1,text:r,className:o,as:i="span",...s},l)=>{const c=$(e,"badge");return a.jsx(i,{ref:l,...s,className:_(o,c,n&&"rounded-pill",r&&`text-${r}`,t&&`bg-${t}`)})});Wc.displayName="Badge";const Re=Wc,zc=x.forwardRef(({as:e,bsPrefix:t,variant:n="primary",size:r,active:o=!1,disabled:i=!1,className:s,...l},c)=>{const u=$(t,"btn"),[f,{tagName:d}]=as({tagName:e,disabled:i,...l}),p=d;return a.jsx(p,{...f,...l,ref:c,disabled:i,className:_(s,u,o&&"active",n&&`${u}-${n}`,r&&`${u}-${r}`,l.href&&i&&"disabled")})});zc.displayName="Button";const z=zc,Qc=x.forwardRef(({bsPrefix:e,size:t,vertical:n=!1,className:r,role:o="group",as:i="div",...s},l)=>{const c=$(e,"btn-group");let u=c;return n&&(u=`${c}-vertical`),a.jsx(i,{...s,ref:l,role:o,className:_(r,u,t&&`${c}-${t}`)})});Qc.displayName="ButtonGroup";const wt=Qc,qc=x.forwardRef(({bsPrefix:e,className:t,role:n="toolbar",...r},o)=>{const i=$(e,"btn-toolbar");return a.jsx("div",{...r,ref:o,className:_(t,i),role:n})});qc.displayName="ButtonToolbar";const Gh=qc,Kc=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"card-body"),a.jsx(n,{ref:o,className:_(e,t),...r})));Kc.displayName="CardBody";const Yc=Kc,Jc=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"card-footer"),a.jsx(n,{ref:o,className:_(e,t),...r})));Jc.displayName="CardFooter";const Wh=Jc,Zc=x.createContext(null);Zc.displayName="CardHeaderContext";const Xc=Zc,eu=x.forwardRef(({bsPrefix:e,className:t,as:n="div",...r},o)=>{const i=$(e,"card-header"),s=x.useMemo(()=>({cardHeaderBsPrefix:i}),[i]);return a.jsx(Xc.Provider,{value:s,children:a.jsx(n,{ref:o,...r,className:_(t,i)})})});eu.displayName="CardHeader";const zh=eu,tu=x.forwardRef(({bsPrefix:e,className:t,variant:n,as:r="img",...o},i)=>{const s=$(e,"card-img");return a.jsx(r,{ref:i,className:_(n?`${s}-${n}`:s,t),...o})});tu.displayName="CardImg";const Qh=tu,nu=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"card-img-overlay"),a.jsx(n,{ref:o,className:_(e,t),...r})));nu.displayName="CardImgOverlay";const qh=nu,ru=x.forwardRef(({className:e,bsPrefix:t,as:n="a",...r},o)=>(t=$(t,"card-link"),a.jsx(n,{ref:o,className:_(e,t),...r})));ru.displayName="CardLink";const Kh=ru,Yh=is("h6"),ou=x.forwardRef(({className:e,bsPrefix:t,as:n=Yh,...r},o)=>(t=$(t,"card-subtitle"),a.jsx(n,{ref:o,className:_(e,t),...r})));ou.displayName="CardSubtitle";const Jh=ou,iu=x.forwardRef(({className:e,bsPrefix:t,as:n="p",...r},o)=>(t=$(t,"card-text"),a.jsx(n,{ref:o,className:_(e,t),...r})));iu.displayName="CardText";const Zh=iu,Xh=is("h5"),su=x.forwardRef(({className:e,bsPrefix:t,as:n=Xh,...r},o)=>(t=$(t,"card-title"),a.jsx(n,{ref:o,className:_(e,t),...r})));su.displayName="CardTitle";const eg=su,au=x.forwardRef(({bsPrefix:e,className:t,bg:n,text:r,border:o,body:i=!1,children:s,as:l="div",...c},u)=>{const f=$(e,"card");return a.jsx(l,{ref:u,...c,className:_(t,f,n&&`bg-${n}`,r&&`text-${r}`,o&&`border-${o}`),children:i?a.jsx(Yc,{children:s}):s})});au.displayName="Card";const D=Object.assign(au,{Img:Qh,Title:eg,Subtitle:Jh,Body:Yc,Link:Kh,Text:Zh,Header:zh,Footer:Wh,ImgOverlay:qh});function tg(e){const t=x.useRef(e);return t.current=e,t}function us(e){const t=tg(e);x.useEffect(()=>()=>t.current(),[])}const hi=2**31-1;function lu(e,t,n){const r=n-Date.now();e.current=r<=hi?setTimeout(t,r):setTimeout(()=>lu(e,t,n),hi)}function ng(){const e=ss(),t=x.useRef();return us(()=>clearTimeout(t.current)),x.useMemo(()=>{const n=()=>clearTimeout(t.current);function r(o,i=0){e()&&(n(),i<=hi?t.current=setTimeout(o,i):lu(t,o,Date.now()+i))}return{set:r,clear:n,handleRef:t}},[])}function rg(e,t){return x.Children.toArray(e).some(n=>x.isValidElement(n)&&n.type===t)}function og({as:e,bsPrefix:t,className:n,...r}){t=$(t,"col");const o=xc(),i=vc(),s=[],l=[];return o.forEach(c=>{const u=r[c];delete r[c];let f,d,p;typeof u=="object"&&u!=null?{span:f,offset:d,order:p}=u:f=u;const h=c!==i?`-${c}`:"";f&&s.push(f===!0?`${t}${h}`:`${t}${h}-${f}`),p!=null&&l.push(`order${h}-${p}`),d!=null&&l.push(`offset${h}-${d}`)}),[{...r,className:_(n,...s,...l)},{as:e,bsPrefix:t,spans:s}]}const cu=x.forwardRef((e,t)=>{const[{className:n,...r},{as:o="div",bsPrefix:i,spans:s}]=og(e);return a.jsx(o,{...r,ref:t,className:_(n,!s.length&&i)})});cu.displayName="Col";const fs=cu;var ig=Function.prototype.bind.call(Function.prototype.call,[].slice);function gi(e,t){return ig(e.querySelectorAll(t))}const Jr=!!(typeof window<"u"&&window.document&&window.document.createElement);var mi=!1,xi=!1;try{var Oo={get passive(){return mi=!0},get once(){return xi=mi=!0}};Jr&&(window.addEventListener("test",Oo,Oo),window.removeEventListener("test",Oo,!0))}catch{}function uu(e,t,n,r){if(r&&typeof r!="boolean"&&!xi){var o=r.once,i=r.capture,s=n;!xi&&o&&(s=n.__once||function l(c){this.removeEventListener(t,l,i),n.call(this,c)},n.__once=s),e.addEventListener(t,s,mi?r:i)}e.addEventListener(t,n,r)}function sg(e,t,n){const r=x.useRef(e!==void 0),[o,i]=x.useState(t),s=e!==void 0,l=r.current;return r.current=s,!s&&l&&o!==t&&i(t),[s?e:o,x.useCallback((...c)=>{const[u,...f]=c;let d=n==null?void 0:n(u,...f);return i(u),d},[n])]}function fu(){const[,e]=x.useReducer(t=>!t,!1);return e}const ag=x.createContext(null),Zr=ag;var ta=Object.prototype.hasOwnProperty;function na(e,t,n){for(n of e.keys())if(jn(n,t))return n}function jn(e,t){var n,r,o;if(e===t)return!0;if(e&&t&&(n=e.constructor)===t.constructor){if(n===Date)return e.getTime()===t.getTime();if(n===RegExp)return e.toString()===t.toString();if(n===Array){if((r=e.length)===t.length)for(;r--&&jn(e[r],t[r]););return r===-1}if(n===Set){if(e.size!==t.size)return!1;for(r of e)if(o=r,o&&typeof o=="object"&&(o=na(t,o),!o)||!t.has(o))return!1;return!0}if(n===Map){if(e.size!==t.size)return!1;for(r of e)if(o=r[0],o&&typeof o=="object"&&(o=na(t,o),!o)||!jn(r[1],t.get(o)))return!1;return!0}if(n===ArrayBuffer)e=new Uint8Array(e),t=new Uint8Array(t);else if(n===DataView){if((r=e.byteLength)===t.byteLength)for(;r--&&e.getInt8(r)===t.getInt8(r););return r===-1}if(ArrayBuffer.isView(e)){if((r=e.byteLength)===t.byteLength)for(;r--&&e[r]===t[r];);return r===-1}if(!n||typeof e=="object"){r=0;for(n in e)if(ta.call(e,n)&&++r&&!ta.call(t,n)||!(n in t)||!jn(e[n],t[n]))return!1;return Object.keys(t).length===r}}return e!==e&&t!==t}function lg(e){const t=ss();return[e[0],x.useCallback(n=>{if(t())return e[1](n)},[t,e[1]])]}var Ce="top",_e="bottom",$e="right",Se="left",ds="auto",Pn=[Ce,_e,$e,Se],Jt="start",In="end",cg="clippingParents",du="viewport",dn="popper",ug="reference",ra=Pn.reduce(function(e,t){return e.concat([t+"-"+Jt,t+"-"+In])},[]),pu=[].concat(Pn,[ds]).reduce(function(e,t){return e.concat([t,t+"-"+Jt,t+"-"+In])},[]),fg="beforeRead",dg="read",pg="afterRead",hg="beforeMain",gg="main",mg="afterMain",xg="beforeWrite",vg="write",yg="afterWrite",wg=[fg,dg,pg,hg,gg,mg,xg,vg,yg];function He(e){return e.split("-")[0]}function Fe(e){if(e==null)return window;if(e.toString()!=="[object Window]"){var t=e.ownerDocument;return t&&t.defaultView||window}return e}function _t(e){var t=Fe(e).Element;return e instanceof t||e instanceof Element}function Ge(e){var t=Fe(e).HTMLElement;return e instanceof t||e instanceof HTMLElement}function ps(e){if(typeof ShadowRoot>"u")return!1;var t=Fe(e).ShadowRoot;return e instanceof t||e instanceof ShadowRoot}var Tt=Math.max,Rr=Math.min,Zt=Math.round;function vi(){var e=navigator.userAgentData;return e!=null&&e.brands&&Array.isArray(e.brands)?e.brands.map(function(t){return t.brand+"/"+t.version}).join(" "):navigator.userAgent}function hu(){return!/^((?!chrome|android).)*safari/i.test(vi())}function Xt(e,t,n){t===void 0&&(t=!1),n===void 0&&(n=!1);var r=e.getBoundingClientRect(),o=1,i=1;t&&Ge(e)&&(o=e.offsetWidth>0&&Zt(r.width)/e.offsetWidth||1,i=e.offsetHeight>0&&Zt(r.height)/e.offsetHeight||1);var s=_t(e)?Fe(e):window,l=s.visualViewport,c=!hu()&&n,u=(r.left+(c&&l?l.offsetLeft:0))/o,f=(r.top+(c&&l?l.offsetTop:0))/i,d=r.width/o,p=r.height/i;return{width:d,height:p,top:f,right:u+d,bottom:f+p,left:u,x:u,y:f}}function hs(e){var t=Xt(e),n=e.offsetWidth,r=e.offsetHeight;return Math.abs(t.width-n)<=1&&(n=t.width),Math.abs(t.height-r)<=1&&(r=t.height),{x:e.offsetLeft,y:e.offsetTop,width:n,height:r}}function gu(e,t){var n=t.getRootNode&&t.getRootNode();if(e.contains(t))return!0;if(n&&ps(n)){var r=t;do{if(r&&e.isSameNode(r))return!0;r=r.parentNode||r.host}while(r)}return!1}function bt(e){return e?(e.nodeName||"").toLowerCase():null}function ot(e){return Fe(e).getComputedStyle(e)}function bg(e){return["table","td","th"].indexOf(bt(e))>=0}function jt(e){return((_t(e)?e.ownerDocument:e.document)||window.document).documentElement}function Xr(e){return bt(e)==="html"?e:e.assignedSlot||e.parentNode||(ps(e)?e.host:null)||jt(e)}function oa(e){return!Ge(e)||ot(e).position==="fixed"?null:e.offsetParent}function Cg(e){var t=/firefox/i.test(vi()),n=/Trident/i.test(vi());if(n&&Ge(e)){var r=ot(e);if(r.position==="fixed")return null}var o=Xr(e);for(ps(o)&&(o=o.host);Ge(o)&&["html","body"].indexOf(bt(o))<0;){var i=ot(o);if(i.transform!=="none"||i.perspective!=="none"||i.contain==="paint"||["transform","perspective"].indexOf(i.willChange)!==-1||t&&i.willChange==="filter"||t&&i.filter&&i.filter!=="none")return o;o=o.parentNode}return null}function kn(e){for(var t=Fe(e),n=oa(e);n&&bg(n)&&ot(n).position==="static";)n=oa(n);return n&&(bt(n)==="html"||bt(n)==="body"&&ot(n).position==="static")?t:n||Cg(e)||t}function gs(e){return["top","bottom"].indexOf(e)>=0?"x":"y"}function Rn(e,t,n){return Tt(e,Rr(t,n))}function Sg(e,t,n){var r=Rn(e,t,n);return r>n?n:r}function mu(){return{top:0,right:0,bottom:0,left:0}}function xu(e){return Object.assign({},mu(),e)}function vu(e,t){return t.reduce(function(n,r){return n[r]=e,n},{})}var Ag=function(t,n){return t=typeof t=="function"?t(Object.assign({},n.rects,{placement:n.placement})):t,xu(typeof t!="number"?t:vu(t,Pn))};function jg(e){var t,n=e.state,r=e.name,o=e.options,i=n.elements.arrow,s=n.modifiersData.popperOffsets,l=He(n.placement),c=gs(l),u=[Se,$e].indexOf(l)>=0,f=u?"height":"width";if(!(!i||!s)){var d=Ag(o.padding,n),p=hs(i),h=c==="y"?Ce:Se,g=c==="y"?_e:$e,m=n.rects.reference[f]+n.rects.reference[c]-s[c]-n.rects.popper[f],v=s[c]-n.rects.reference[c],y=kn(i),b=y?c==="y"?y.clientHeight||0:y.clientWidth||0:0,w=m/2-v/2,S=d[h],F=b-p[f]-d[g],C=b/2-p[f]/2+w,A=Rn(S,C,F),O=c;n.modifiersData[r]=(t={},t[O]=A,t.centerOffset=A-C,t)}}function Rg(e){var t=e.state,n=e.options,r=n.element,o=r===void 0?"[data-popper-arrow]":r;o!=null&&(typeof o=="string"&&(o=t.elements.popper.querySelector(o),!o)||gu(t.elements.popper,o)&&(t.elements.arrow=o))}const Fg={name:"arrow",enabled:!0,phase:"main",fn:jg,effect:Rg,requires:["popperOffsets"],requiresIfExists:["preventOverflow"]};function en(e){return e.split("-")[1]}var Og={top:"auto",right:"auto",bottom:"auto",left:"auto"};function Eg(e,t){var n=e.x,r=e.y,o=t.devicePixelRatio||1;return{x:Zt(n*o)/o||0,y:Zt(r*o)/o||0}}function ia(e){var t,n=e.popper,r=e.popperRect,o=e.placement,i=e.variation,s=e.offsets,l=e.position,c=e.gpuAcceleration,u=e.adaptive,f=e.roundOffsets,d=e.isFixed,p=s.x,h=p===void 0?0:p,g=s.y,m=g===void 0?0:g,v=typeof f=="function"?f({x:h,y:m}):{x:h,y:m};h=v.x,m=v.y;var y=s.hasOwnProperty("x"),b=s.hasOwnProperty("y"),w=Se,S=Ce,F=window;if(u){var C=kn(n),A="clientHeight",O="clientWidth";if(C===Fe(n)&&(C=jt(n),ot(C).position!=="static"&&l==="absolute"&&(A="scrollHeight",O="scrollWidth")),C=C,o===Ce||(o===Se||o===$e)&&i===In){S=_e;var T=d&&C===F&&F.visualViewport?F.visualViewport.height:C[A];m-=T-r.height,m*=c?1:-1}if(o===Se||(o===Ce||o===_e)&&i===In){w=$e;var N=d&&C===F&&F.visualViewport?F.visualViewport.width:C[O];h-=N-r.width,h*=c?1:-1}}var E=Object.assign({position:l},u&&Og),B=f===!0?Eg({x:h,y:m},Fe(n)):{x:h,y:m};if(h=B.x,m=B.y,c){var P;return Object.assign({},E,(P={},P[S]=b?"0":"",P[w]=y?"0":"",P.transform=(F.devicePixelRatio||1)<=1?"translate("+h+"px, "+m+"px)":"translate3d("+h+"px, "+m+"px, 0)",P))}return Object.assign({},E,(t={},t[S]=b?m+"px":"",t[w]=y?h+"px":"",t.transform="",t))}function Ig(e){var t=e.state,n=e.options,r=n.gpuAcceleration,o=r===void 0?!0:r,i=n.adaptive,s=i===void 0?!0:i,l=n.roundOffsets,c=l===void 0?!0:l,u={placement:He(t.placement),variation:en(t.placement),popper:t.elements.popper,popperRect:t.rects.popper,gpuAcceleration:o,isFixed:t.options.strategy==="fixed"};t.modifiersData.popperOffsets!=null&&(t.styles.popper=Object.assign({},t.styles.popper,ia(Object.assign({},u,{offsets:t.modifiersData.popperOffsets,position:t.options.strategy,adaptive:s,roundOffsets:c})))),t.modifiersData.arrow!=null&&(t.styles.arrow=Object.assign({},t.styles.arrow,ia(Object.assign({},u,{offsets:t.modifiersData.arrow,position:"absolute",adaptive:!1,roundOffsets:c})))),t.attributes.popper=Object.assign({},t.attributes.popper,{"data-popper-placement":t.placement})}const Ng={name:"computeStyles",enabled:!0,phase:"beforeWrite",fn:Ig,data:{}};var qn={passive:!0};function Tg(e){var t=e.state,n=e.instance,r=e.options,o=r.scroll,i=o===void 0?!0:o,s=r.resize,l=s===void 0?!0:s,c=Fe(t.elements.popper),u=[].concat(t.scrollParents.reference,t.scrollParents.popper);return i&&u.forEach(function(f){f.addEventListener("scroll",n.update,qn)}),l&&c.addEventListener("resize",n.update,qn),function(){i&&u.forEach(function(f){f.removeEventListener("scroll",n.update,qn)}),l&&c.removeEventListener("resize",n.update,qn)}}const Dg={name:"eventListeners",enabled:!0,phase:"write",fn:function(){},effect:Tg,data:{}};var _g={left:"right",right:"left",bottom:"top",top:"bottom"};function mr(e){return e.replace(/left|right|bottom|top/g,function(t){return _g[t]})}var $g={start:"end",end:"start"};function sa(e){return e.replace(/start|end/g,function(t){return $g[t]})}function ms(e){var t=Fe(e),n=t.pageXOffset,r=t.pageYOffset;return{scrollLeft:n,scrollTop:r}}function xs(e){return Xt(jt(e)).left+ms(e).scrollLeft}function Bg(e,t){var n=Fe(e),r=jt(e),o=n.visualViewport,i=r.clientWidth,s=r.clientHeight,l=0,c=0;if(o){i=o.width,s=o.height;var u=hu();(u||!u&&t==="fixed")&&(l=o.offsetLeft,c=o.offsetTop)}return{width:i,height:s,x:l+xs(e),y:c}}function Pg(e){var t,n=jt(e),r=ms(e),o=(t=e.ownerDocument)==null?void 0:t.body,i=Tt(n.scrollWidth,n.clientWidth,o?o.scrollWidth:0,o?o.clientWidth:0),s=Tt(n.scrollHeight,n.clientHeight,o?o.scrollHeight:0,o?o.clientHeight:0),l=-r.scrollLeft+xs(e),c=-r.scrollTop;return ot(o||n).direction==="rtl"&&(l+=Tt(n.clientWidth,o?o.clientWidth:0)-i),{width:i,height:s,x:l,y:c}}function vs(e){var t=ot(e),n=t.overflow,r=t.overflowX,o=t.overflowY;return/auto|scroll|overlay|hidden/.test(n+o+r)}function yu(e){return["html","body","#document"].indexOf(bt(e))>=0?e.ownerDocument.body:Ge(e)&&vs(e)?e:yu(Xr(e))}function Fn(e,t){var n;t===void 0&&(t=[]);var r=yu(e),o=r===((n=e.ownerDocument)==null?void 0:n.body),i=Fe(r),s=o?[i].concat(i.visualViewport||[],vs(r)?r:[]):r,l=t.concat(s);return o?l:l.concat(Fn(Xr(s)))}function yi(e){return Object.assign({},e,{left:e.x,top:e.y,right:e.x+e.width,bottom:e.y+e.height})}function kg(e,t){var n=Xt(e,!1,t==="fixed");return n.top=n.top+e.clientTop,n.left=n.left+e.clientLeft,n.bottom=n.top+e.clientHeight,n.right=n.left+e.clientWidth,n.width=e.clientWidth,n.height=e.clientHeight,n.x=n.left,n.y=n.top,n}function aa(e,t,n){return t===du?yi(Bg(e,n)):_t(t)?kg(t,n):yi(Pg(jt(e)))}function Lg(e){var t=Fn(Xr(e)),n=["absolute","fixed"].indexOf(ot(e).position)>=0,r=n&&Ge(e)?kn(e):e;return _t(r)?t.filter(function(o){return _t(o)&&gu(o,r)&&bt(o)!=="body"}):[]}function Mg(e,t,n,r){var o=t==="clippingParents"?Lg(e):[].concat(t),i=[].concat(o,[n]),s=i[0],l=i.reduce(function(c,u){var f=aa(e,u,r);return c.top=Tt(f.top,c.top),c.right=Rr(f.right,c.right),c.bottom=Rr(f.bottom,c.bottom),c.left=Tt(f.left,c.left),c},aa(e,s,r));return l.width=l.right-l.left,l.height=l.bottom-l.top,l.x=l.left,l.y=l.top,l}function wu(e){var t=e.reference,n=e.element,r=e.placement,o=r?He(r):null,i=r?en(r):null,s=t.x+t.width/2-n.width/2,l=t.y+t.height/2-n.height/2,c;switch(o){case Ce:c={x:s,y:t.y-n.height};break;case _e:c={x:s,y:t.y+t.height};break;case $e:c={x:t.x+t.width,y:l};break;case Se:c={x:t.x-n.width,y:l};break;default:c={x:t.x,y:t.y}}var u=o?gs(o):null;if(u!=null){var f=u==="y"?"height":"width";switch(i){case Jt:c[u]=c[u]-(t[f]/2-n[f]/2);break;case In:c[u]=c[u]+(t[f]/2-n[f]/2);break}}return c}function Nn(e,t){t===void 0&&(t={});var n=t,r=n.placement,o=r===void 0?e.placement:r,i=n.strategy,s=i===void 0?e.strategy:i,l=n.boundary,c=l===void 0?cg:l,u=n.rootBoundary,f=u===void 0?du:u,d=n.elementContext,p=d===void 0?dn:d,h=n.altBoundary,g=h===void 0?!1:h,m=n.padding,v=m===void 0?0:m,y=xu(typeof v!="number"?v:vu(v,Pn)),b=p===dn?ug:dn,w=e.rects.popper,S=e.elements[g?b:p],F=Mg(_t(S)?S:S.contextElement||jt(e.elements.popper),c,f,s),C=Xt(e.elements.reference),A=wu({reference:C,element:w,strategy:"absolute",placement:o}),O=yi(Object.assign({},w,A)),T=p===dn?O:C,N={top:F.top-T.top+y.top,bottom:T.bottom-F.bottom+y.bottom,left:F.left-T.left+y.left,right:T.right-F.right+y.right},E=e.modifiersData.offset;if(p===dn&&E){var B=E[o];Object.keys(N).forEach(function(P){var M=[$e,_e].indexOf(P)>=0?1:-1,V=[Ce,_e].indexOf(P)>=0?"y":"x";N[P]+=B[V]*M})}return N}function Ug(e,t){t===void 0&&(t={});var n=t,r=n.placement,o=n.boundary,i=n.rootBoundary,s=n.padding,l=n.flipVariations,c=n.allowedAutoPlacements,u=c===void 0?pu:c,f=en(r),d=f?l?ra:ra.filter(function(g){return en(g)===f}):Pn,p=d.filter(function(g){return u.indexOf(g)>=0});p.length===0&&(p=d);var h=p.reduce(function(g,m){return g[m]=Nn(e,{placement:m,boundary:o,rootBoundary:i,padding:s})[He(m)],g},{});return Object.keys(h).sort(function(g,m){return h[g]-h[m]})}function Vg(e){if(He(e)===ds)return[];var t=mr(e);return[sa(e),t,sa(t)]}function Hg(e){var t=e.state,n=e.options,r=e.name;if(!t.modifiersData[r]._skip){for(var o=n.mainAxis,i=o===void 0?!0:o,s=n.altAxis,l=s===void 0?!0:s,c=n.fallbackPlacements,u=n.padding,f=n.boundary,d=n.rootBoundary,p=n.altBoundary,h=n.flipVariations,g=h===void 0?!0:h,m=n.allowedAutoPlacements,v=t.options.placement,y=He(v),b=y===v,w=c||(b||!g?[mr(v)]:Vg(v)),S=[v].concat(w).reduce(function(ye,be){return ye.concat(He(be)===ds?Ug(t,{placement:be,boundary:f,rootBoundary:d,padding:u,flipVariations:g,allowedAutoPlacements:m}):be)},[]),F=t.rects.reference,C=t.rects.popper,A=new Map,O=!0,T=S[0],N=0;N<S.length;N++){var E=S[N],B=He(E),P=en(E)===Jt,M=[Ce,_e].indexOf(B)>=0,V=M?"width":"height",J=Nn(t,{placement:E,boundary:f,rootBoundary:d,altBoundary:p,padding:u}),Q=M?P?$e:Se:P?_e:Ce;F[V]>C[V]&&(Q=mr(Q));var X=mr(Q),K=[];if(i&&K.push(J[B]<=0),l&&K.push(J[Q]<=0,J[X]<=0),K.every(function(ye){return ye})){T=E,O=!1;break}A.set(E,K)}if(O)for(var ee=g?3:1,se=function(be){var qe=S.find(function(Ke){var Pe=A.get(Ke);if(Pe)return Pe.slice(0,be).every(function(Ye){return Ye})});if(qe)return T=qe,"break"},he=ee;he>0;he--){var ae=se(he);if(ae==="break")break}t.placement!==T&&(t.modifiersData[r]._skip=!0,t.placement=T,t.reset=!0)}}const Gg={name:"flip",enabled:!0,phase:"main",fn:Hg,requiresIfExists:["offset"],data:{_skip:!1}};function la(e,t,n){return n===void 0&&(n={x:0,y:0}),{top:e.top-t.height-n.y,right:e.right-t.width+n.x,bottom:e.bottom-t.height+n.y,left:e.left-t.width-n.x}}function ca(e){return[Ce,$e,_e,Se].some(function(t){return e[t]>=0})}function Wg(e){var t=e.state,n=e.name,r=t.rects.reference,o=t.rects.popper,i=t.modifiersData.preventOverflow,s=Nn(t,{elementContext:"reference"}),l=Nn(t,{altBoundary:!0}),c=la(s,r),u=la(l,o,i),f=ca(c),d=ca(u);t.modifiersData[n]={referenceClippingOffsets:c,popperEscapeOffsets:u,isReferenceHidden:f,hasPopperEscaped:d},t.attributes.popper=Object.assign({},t.attributes.popper,{"data-popper-reference-hidden":f,"data-popper-escaped":d})}const zg={name:"hide",enabled:!0,phase:"main",requiresIfExists:["preventOverflow"],fn:Wg};function Qg(e,t,n){var r=He(e),o=[Se,Ce].indexOf(r)>=0?-1:1,i=typeof n=="function"?n(Object.assign({},t,{placement:e})):n,s=i[0],l=i[1];return s=s||0,l=(l||0)*o,[Se,$e].indexOf(r)>=0?{x:l,y:s}:{x:s,y:l}}function qg(e){var t=e.state,n=e.options,r=e.name,o=n.offset,i=o===void 0?[0,0]:o,s=pu.reduce(function(f,d){return f[d]=Qg(d,t.rects,i),f},{}),l=s[t.placement],c=l.x,u=l.y;t.modifiersData.popperOffsets!=null&&(t.modifiersData.popperOffsets.x+=c,t.modifiersData.popperOffsets.y+=u),t.modifiersData[r]=s}const Kg={name:"offset",enabled:!0,phase:"main",requires:["popperOffsets"],fn:qg};function Yg(e){var t=e.state,n=e.name;t.modifiersData[n]=wu({reference:t.rects.reference,element:t.rects.popper,strategy:"absolute",placement:t.placement})}const Jg={name:"popperOffsets",enabled:!0,phase:"read",fn:Yg,data:{}};function Zg(e){return e==="x"?"y":"x"}function Xg(e){var t=e.state,n=e.options,r=e.name,o=n.mainAxis,i=o===void 0?!0:o,s=n.altAxis,l=s===void 0?!1:s,c=n.boundary,u=n.rootBoundary,f=n.altBoundary,d=n.padding,p=n.tether,h=p===void 0?!0:p,g=n.tetherOffset,m=g===void 0?0:g,v=Nn(t,{boundary:c,rootBoundary:u,padding:d,altBoundary:f}),y=He(t.placement),b=en(t.placement),w=!b,S=gs(y),F=Zg(S),C=t.modifiersData.popperOffsets,A=t.rects.reference,O=t.rects.popper,T=typeof m=="function"?m(Object.assign({},t.rects,{placement:t.placement})):m,N=typeof T=="number"?{mainAxis:T,altAxis:T}:Object.assign({mainAxis:0,altAxis:0},T),E=t.modifiersData.offset?t.modifiersData.offset[t.placement]:null,B={x:0,y:0};if(C){if(i){var P,M=S==="y"?Ce:Se,V=S==="y"?_e:$e,J=S==="y"?"height":"width",Q=C[S],X=Q+v[M],K=Q-v[V],ee=h?-O[J]/2:0,se=b===Jt?A[J]:O[J],he=b===Jt?-O[J]:-A[J],ae=t.elements.arrow,ye=h&&ae?hs(ae):{width:0,height:0},be=t.modifiersData["arrow#persistent"]?t.modifiersData["arrow#persistent"].padding:mu(),qe=be[M],Ke=be[V],Pe=Rn(0,A[J],ye[J]),Ye=w?A[J]/2-ee-Pe-qe-N.mainAxis:se-Pe-qe-N.mainAxis,ct=w?-A[J]/2+ee+Pe+Ke+N.mainAxis:he+Pe+Ke+N.mainAxis,ut=t.elements.arrow&&kn(t.elements.arrow),ft=ut?S==="y"?ut.clientTop||0:ut.clientLeft||0:0,dt=(P=E==null?void 0:E[S])!=null?P:0,pt=Q+Ye-dt-ft,re=Q+ct-dt,Rt=Rn(h?Rr(X,pt):X,Q,h?Tt(K,re):K);C[S]=Rt,B[S]=Rt-Q}if(l){var ht,Ao=S==="x"?Ce:Se,jo=S==="x"?_e:$e,Je=C[F],kt=F==="y"?"height":"width",Gn=Je+v[Ao],Wn=Je-v[jo],Lt=[Ce,Se].indexOf(y)!==-1,zn=(ht=E==null?void 0:E[F])!=null?ht:0,Z=Lt?Gn:Je-A[kt]-O[kt]-zn+N.altAxis,Ze=Lt?Je+A[kt]+O[kt]-zn-N.altAxis:Wn,un=h&&Lt?Sg(Z,Je,Ze):Rn(h?Z:Gn,Je,h?Ze:Wn);C[F]=un,B[F]=un-Je}t.modifiersData[r]=B}}const em={name:"preventOverflow",enabled:!0,phase:"main",fn:Xg,requiresIfExists:["offset"]};function tm(e){return{scrollLeft:e.scrollLeft,scrollTop:e.scrollTop}}function nm(e){return e===Fe(e)||!Ge(e)?ms(e):tm(e)}function rm(e){var t=e.getBoundingClientRect(),n=Zt(t.width)/e.offsetWidth||1,r=Zt(t.height)/e.offsetHeight||1;return n!==1||r!==1}function om(e,t,n){n===void 0&&(n=!1);var r=Ge(t),o=Ge(t)&&rm(t),i=jt(t),s=Xt(e,o,n),l={scrollLeft:0,scrollTop:0},c={x:0,y:0};return(r||!r&&!n)&&((bt(t)!=="body"||vs(i))&&(l=nm(t)),Ge(t)?(c=Xt(t,!0),c.x+=t.clientLeft,c.y+=t.clientTop):i&&(c.x=xs(i))),{x:s.left+l.scrollLeft-c.x,y:s.top+l.scrollTop-c.y,width:s.width,height:s.height}}function im(e){var t=new Map,n=new Set,r=[];e.forEach(function(i){t.set(i.name,i)});function o(i){n.add(i.name);var s=[].concat(i.requires||[],i.requiresIfExists||[]);s.forEach(function(l){if(!n.has(l)){var c=t.get(l);c&&o(c)}}),r.push(i)}return e.forEach(function(i){n.has(i.name)||o(i)}),r}function sm(e){var t=im(e);return wg.reduce(function(n,r){return n.concat(t.filter(function(o){return o.phase===r}))},[])}function am(e){var t;return function(){return t||(t=new Promise(function(n){Promise.resolve().then(function(){t=void 0,n(e())})})),t}}function lm(e){var t=e.reduce(function(n,r){var o=n[r.name];return n[r.name]=o?Object.assign({},o,r,{options:Object.assign({},o.options,r.options),data:Object.assign({},o.data,r.data)}):r,n},{});return Object.keys(t).map(function(n){return t[n]})}var ua={placement:"bottom",modifiers:[],strategy:"absolute"};function fa(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return!t.some(function(r){return!(r&&typeof r.getBoundingClientRect=="function")})}function cm(e){e===void 0&&(e={});var t=e,n=t.defaultModifiers,r=n===void 0?[]:n,o=t.defaultOptions,i=o===void 0?ua:o;return function(l,c,u){u===void 0&&(u=i);var f={placement:"bottom",orderedModifiers:[],options:Object.assign({},ua,i),modifiersData:{},elements:{reference:l,popper:c},attributes:{},styles:{}},d=[],p=!1,h={state:f,setOptions:function(y){var b=typeof y=="function"?y(f.options):y;m(),f.options=Object.assign({},i,f.options,b),f.scrollParents={reference:_t(l)?Fn(l):l.contextElement?Fn(l.contextElement):[],popper:Fn(c)};var w=sm(lm([].concat(r,f.options.modifiers)));return f.orderedModifiers=w.filter(function(S){return S.enabled}),g(),h.update()},forceUpdate:function(){if(!p){var y=f.elements,b=y.reference,w=y.popper;if(fa(b,w)){f.rects={reference:om(b,kn(w),f.options.strategy==="fixed"),popper:hs(w)},f.reset=!1,f.placement=f.options.placement,f.orderedModifiers.forEach(function(N){return f.modifiersData[N.name]=Object.assign({},N.data)});for(var S=0;S<f.orderedModifiers.length;S++){if(f.reset===!0){f.reset=!1,S=-1;continue}var F=f.orderedModifiers[S],C=F.fn,A=F.options,O=A===void 0?{}:A,T=F.name;typeof C=="function"&&(f=C({state:f,options:O,name:T,instance:h})||f)}}}},update:am(function(){return new Promise(function(v){h.forceUpdate(),v(f)})}),destroy:function(){m(),p=!0}};if(!fa(l,c))return h;h.setOptions(u).then(function(v){!p&&u.onFirstUpdate&&u.onFirstUpdate(v)});function g(){f.orderedModifiers.forEach(function(v){var y=v.name,b=v.options,w=b===void 0?{}:b,S=v.effect;if(typeof S=="function"){var F=S({state:f,name:y,instance:h,options:w}),C=function(){};d.push(F||C)}})}function m(){d.forEach(function(v){return v()}),d=[]}return h}}const um=cm({defaultModifiers:[zg,Jg,Ng,Dg,Kg,Gg,em,Fg]}),fm=["enabled","placement","strategy","modifiers"];function dm(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}const pm={name:"applyStyles",enabled:!1,phase:"afterWrite",fn:()=>{}},hm={name:"ariaDescribedBy",enabled:!0,phase:"afterWrite",effect:({state:e})=>()=>{const{reference:t,popper:n}=e.elements;if("removeAttribute"in t){const r=(t.getAttribute("aria-describedby")||"").split(",").filter(o=>o.trim()!==n.id);r.length?t.setAttribute("aria-describedby",r.join(",")):t.removeAttribute("aria-describedby")}},fn:({state:e})=>{var t;const{popper:n,reference:r}=e.elements,o=(t=n.getAttribute("role"))==null?void 0:t.toLowerCase();if(n.id&&o==="tooltip"&&"setAttribute"in r){const i=r.getAttribute("aria-describedby");if(i&&i.split(",").indexOf(n.id)!==-1)return;r.setAttribute("aria-describedby",i?`${i},${n.id}`:n.id)}}},gm=[];function bu(e,t,n={}){let{enabled:r=!0,placement:o="bottom",strategy:i="absolute",modifiers:s=gm}=n,l=dm(n,fm);const c=x.useRef(s),u=x.useRef(),f=x.useCallback(()=>{var v;(v=u.current)==null||v.update()},[]),d=x.useCallback(()=>{var v;(v=u.current)==null||v.forceUpdate()},[]),[p,h]=lg(x.useState({placement:o,update:f,forceUpdate:d,attributes:{},styles:{popper:{},arrow:{}}})),g=x.useMemo(()=>({name:"updateStateModifier",enabled:!0,phase:"write",requires:["computeStyles"],fn:({state:v})=>{const y={},b={};Object.keys(v.elements).forEach(w=>{y[w]=v.styles[w],b[w]=v.attributes[w]}),h({state:v,styles:y,attributes:b,update:f,forceUpdate:d,placement:v.placement})}}),[f,d,h]),m=x.useMemo(()=>(jn(c.current,s)||(c.current=s),c.current),[s]);return x.useEffect(()=>{!u.current||!r||u.current.setOptions({placement:o,strategy:i,modifiers:[...m,g,pm]})},[i,o,g,r,m]),x.useEffect(()=>{if(!(!r||e==null||t==null))return u.current=um(e,t,Object.assign({},l,{placement:o,strategy:i,modifiers:[...m,hm,g]})),()=>{u.current!=null&&(u.current.destroy(),u.current=void 0,h(v=>Object.assign({},v,{attributes:{},styles:{popper:{}}})))}},[r,e,t]),p}function Fr(e,t){if(e.contains)return e.contains(t);if(e.compareDocumentPosition)return e===t||!!(e.compareDocumentPosition(t)&16)}function mm(e,t,n,r){var o=r&&typeof r!="boolean"?r.capture:r;e.removeEventListener(t,n,o),n.__once&&e.removeEventListener(t,n.__once,o)}function Ot(e,t,n,r){return uu(e,t,n,r),function(){mm(e,t,n,r)}}function Ln(e){return e&&e.ownerDocument||document}var xm=function(){},vm=xm;const ym=at(vm),da=()=>{};function wm(e){return e.button===0}function bm(e){return!!(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey)}const xr=e=>e&&("current"in e?e.current:e),pa={click:"mousedown",mouseup:"mousedown",pointerup:"pointerdown"};function Cu(e,t=da,{disabled:n,clickTrigger:r="click"}={}){const o=x.useRef(!1),i=x.useRef(!1),s=x.useCallback(u=>{const f=xr(e);ym(!!f,"ClickOutside captured a close event but does not have a ref to compare it to. useClickOutside(), should be passed a ref that resolves to a DOM node"),o.current=!f||bm(u)||!wm(u)||!!Fr(f,u.target)||i.current,i.current=!1},[e]),l=ce(u=>{const f=xr(e);f&&Fr(f,u.target)&&(i.current=!0)}),c=ce(u=>{o.current||t(u)});x.useEffect(()=>{var u,f;if(n||e==null)return;const d=Ln(xr(e)),p=d.defaultView||window;let h=(u=p.event)!=null?u:(f=p.parent)==null?void 0:f.event,g=null;pa[r]&&(g=Ot(d,pa[r],l,!0));const m=Ot(d,r,s,!0),v=Ot(d,r,b=>{if(b===h){h=void 0;return}c(b)});let y=[];return"ontouchstart"in d.documentElement&&(y=[].slice.call(d.body.children).map(b=>Ot(b,"mousemove",da))),()=>{g==null||g(),m(),v(),y.forEach(b=>b())}},[e,n,r,s,l,c])}function Cm(e){const t={};return Array.isArray(e)?(e==null||e.forEach(n=>{t[n.name]=n}),t):e||t}function Sm(e={}){return Array.isArray(e)?e:Object.keys(e).map(t=>(e[t].name=t,e[t]))}function Su({enabled:e,enableEvents:t,placement:n,flip:r,offset:o,fixed:i,containerPadding:s,arrowElement:l,popperConfig:c={}}){var u,f,d,p,h;const g=Cm(c.modifiers);return Object.assign({},c,{placement:n,enabled:e,strategy:i?"fixed":c.strategy,modifiers:Sm(Object.assign({},g,{eventListeners:{enabled:t,options:(u=g.eventListeners)==null?void 0:u.options},preventOverflow:Object.assign({},g.preventOverflow,{options:s?Object.assign({padding:s},(f=g.preventOverflow)==null?void 0:f.options):(d=g.preventOverflow)==null?void 0:d.options}),offset:{options:Object.assign({offset:o},(p=g.offset)==null?void 0:p.options)},arrow:Object.assign({},g.arrow,{enabled:!!l,options:Object.assign({},(h=g.arrow)==null?void 0:h.options,{element:l})}),flip:Object.assign({enabled:!!r},g.flip)}))})}const Am=["children"];function jm(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}const Rm=()=>{};function Au(e={}){const t=x.useContext(Zr),[n,r]=Sr(),o=x.useRef(!1),{flip:i,offset:s,rootCloseEvent:l,fixed:c=!1,placement:u,popperConfig:f={},enableEventListeners:d=!0,usePopper:p=!!t}=e,h=(t==null?void 0:t.show)==null?!!e.show:t.show;h&&!o.current&&(o.current=!0);const g=C=>{t==null||t.toggle(!1,C)},{placement:m,setMenu:v,menuElement:y,toggleElement:b}=t||{},w=bu(b,y,Su({placement:u||m||"bottom-start",enabled:p,enableEvents:d??h,offset:s,flip:i,fixed:c,arrowElement:n,popperConfig:f})),S=Object.assign({ref:v||Rm,"aria-labelledby":b==null?void 0:b.id},w.attributes.popper,{style:w.styles.popper}),F={show:h,placement:m,hasShown:o.current,toggle:t==null?void 0:t.toggle,popper:p?w:null,arrowProps:p?Object.assign({ref:r},w.attributes.arrow,{style:w.styles.arrow}):{}};return Cu(y,g,{clickTrigger:l,disabled:!h}),[S,F]}const Fm={usePopper:!0};function ys(e){let{children:t}=e,n=jm(e,Am);const[r,o]=Au(n);return a.jsx(a.Fragment,{children:t(r,o)})}ys.displayName="DropdownMenu";ys.defaultProps=Fm;const Or={prefix:String(Math.round(Math.random()*1e10)),current:0},ju=H.createContext(Or),Om=H.createContext(!1);let Em=!!(typeof window<"u"&&window.document&&window.document.createElement),Eo=new WeakMap;function Im(e=!1){let t=x.useContext(ju),n=x.useRef(null);if(n.current===null&&!e){var r,o;let i=(o=H.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED)===null||o===void 0||(r=o.ReactCurrentOwner)===null||r===void 0?void 0:r.current;if(i){let s=Eo.get(i);s==null?Eo.set(i,{id:t.current,state:i.memoizedState}):i.memoizedState!==s.state&&(t.current=s.id,Eo.delete(i))}n.current=++t.current}return n.current}function Nm(e){let t=x.useContext(ju);t===Or&&!Em&&console.warn("When server rendering, you must wrap your application in an <SSRProvider> to ensure consistent ids are generated between the client and server.");let n=Im(!!e),r=`react-aria${t.prefix}`;return e||`${r}-${n}`}function Tm(e){let t=H.useId(),[n]=x.useState(Pm()),r=n?"react-aria":`react-aria${Or.prefix}`;return e||`${r}-${t}`}const Dm=typeof H.useId=="function"?Tm:Nm;function _m(){return!1}function $m(){return!0}function Bm(e){return()=>{}}function Pm(){return typeof H.useSyncExternalStore=="function"?H.useSyncExternalStore(Bm,_m,$m):x.useContext(Om)}const Ru=e=>{var t;return((t=e.getAttribute("role"))==null?void 0:t.toLowerCase())==="menu"},ha=()=>{};function Fu(){const e=Dm(),{show:t=!1,toggle:n=ha,setToggle:r,menuElement:o}=x.useContext(Zr)||{},i=x.useCallback(l=>{n(!t,l)},[t,n]),s={id:e,ref:r||ha,onClick:i,"aria-expanded":!!t};return o&&Ru(o)&&(s["aria-haspopup"]=!0),[s,{show:t,toggle:n}]}function Ou({children:e}){const[t,n]=Fu();return a.jsx(a.Fragment,{children:e(t,n)})}Ou.displayName="DropdownToggle";const tn=x.createContext(null),Tn=(e,t=null)=>e!=null?String(e):t||null,Eu=x.createContext(null);Eu.displayName="NavContext";const ws=Eu,km="data-rr-ui-",Lm="rrUi";function sn(e){return`${km}${e}`}function Mm(e){return`${Lm}${e}`}const Um=["eventKey","disabled","onClick","active","as"];function Vm(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}function Iu({key:e,href:t,active:n,disabled:r,onClick:o}){const i=x.useContext(tn),s=x.useContext(ws),{activeKey:l}=s||{},c=Tn(e,t),u=n==null&&e!=null?Tn(l)===c:n;return[{onClick:ce(d=>{r||(o==null||o(d),i&&!d.isPropagationStopped()&&i(c,d))}),"aria-disabled":r||void 0,"aria-selected":u,[sn("dropdown-item")]:""},{isActive:u}]}const Nu=x.forwardRef((e,t)=>{let{eventKey:n,disabled:r,onClick:o,active:i,as:s=ls}=e,l=Vm(e,Um);const[c]=Iu({key:n,href:l.href,disabled:r,onClick:o,active:i});return a.jsx(s,Object.assign({},l,{ref:t},c))});Nu.displayName="DropdownItem";const Tu=x.createContext(Jr?window:void 0);Tu.Provider;function eo(){return x.useContext(Tu)}function ga(){const e=fu(),t=x.useRef(null),n=x.useCallback(r=>{t.current=r,e()},[e]);return[t,n]}function Mn({defaultShow:e,show:t,onSelect:n,onToggle:r,itemSelector:o=`* [${sn("dropdown-item")}]`,focusFirstItemOnShow:i,placement:s="bottom-start",children:l}){const c=eo(),[u,f]=sg(t,e,r),[d,p]=ga(),h=d.current,[g,m]=ga(),v=g.current,y=Uc(u),b=x.useRef(null),w=x.useRef(!1),S=x.useContext(tn),F=x.useCallback((E,B,P=B==null?void 0:B.type)=>{f(E,{originalEvent:B,source:P})},[f]),C=ce((E,B)=>{n==null||n(E,B),F(!1,B,"select"),B.isPropagationStopped()||S==null||S(E,B)}),A=x.useMemo(()=>({toggle:F,placement:s,show:u,menuElement:h,toggleElement:v,setMenu:p,setToggle:m}),[F,s,u,h,v,p,m]);h&&y&&!u&&(w.current=h.contains(h.ownerDocument.activeElement));const O=ce(()=>{v&&v.focus&&v.focus()}),T=ce(()=>{const E=b.current;let B=i;if(B==null&&(B=d.current&&Ru(d.current)?"keyboard":!1),B===!1||B==="keyboard"&&!/^key.+$/.test(E))return;const P=gi(d.current,o)[0];P&&P.focus&&P.focus()});x.useEffect(()=>{u?T():w.current&&(w.current=!1,O())},[u,w,O,T]),x.useEffect(()=>{b.current=null});const N=(E,B)=>{if(!d.current)return null;const P=gi(d.current,o);let M=P.indexOf(E)+B;return M=Math.max(0,Math.min(M,P.length)),P[M]};return Th(x.useCallback(()=>c.document,[c]),"keydown",E=>{var B,P;const{key:M}=E,V=E.target,J=(B=d.current)==null?void 0:B.contains(V),Q=(P=g.current)==null?void 0:P.contains(V);if(/input|textarea/i.test(V.tagName)&&(M===" "||M!=="Escape"&&J||M==="Escape"&&V.type==="search")||!J&&!Q||M==="Tab"&&(!d.current||!u))return;b.current=E.type;const K={originalEvent:E,source:E.type};switch(M){case"ArrowUp":{const ee=N(V,-1);ee&&ee.focus&&ee.focus(),E.preventDefault();return}case"ArrowDown":if(E.preventDefault(),!u)f(!0,K);else{const ee=N(V,1);ee&&ee.focus&&ee.focus()}return;case"Tab":uu(V.ownerDocument,"keyup",ee=>{var se;(ee.key==="Tab"&&!ee.target||!((se=d.current)!=null&&se.contains(ee.target)))&&f(!1,K)},{once:!0});break;case"Escape":M==="Escape"&&(E.preventDefault(),E.stopPropagation()),f(!1,K);break}}),a.jsx(tn.Provider,{value:C,children:a.jsx(Zr.Provider,{value:A,children:l})})}Mn.displayName="Dropdown";Mn.Menu=ys;Mn.Toggle=Ou;Mn.Item=Nu;const Du=x.createContext({});Du.displayName="DropdownContext";const _u=Du,$u=x.forwardRef(({className:e,bsPrefix:t,as:n="hr",role:r="separator",...o},i)=>(t=$(t,"dropdown-divider"),a.jsx(n,{ref:i,className:_(e,t),role:r,...o})));$u.displayName="DropdownDivider";const Hm=$u,Bu=x.forwardRef(({className:e,bsPrefix:t,as:n="div",role:r="heading",...o},i)=>(t=$(t,"dropdown-header"),a.jsx(n,{ref:i,className:_(e,t),role:r,...o})));Bu.displayName="DropdownHeader";const Gm=Bu,Pu=x.forwardRef(({bsPrefix:e,className:t,eventKey:n,disabled:r=!1,onClick:o,active:i,as:s=Hc,...l},c)=>{const u=$(e,"dropdown-item"),[f,d]=Iu({key:n,href:l.href,disabled:r,onClick:o,active:i});return a.jsx(s,{...l,...f,ref:c,className:_(t,u,d.isActive&&"active",r&&"disabled")})});Pu.displayName="DropdownItem";const Wm=Pu,ku=x.forwardRef(({className:e,bsPrefix:t,as:n="span",...r},o)=>(t=$(t,"dropdown-item-text"),a.jsx(n,{ref:o,className:_(e,t),...r})));ku.displayName="DropdownItemText";const zm=ku,Lu=x.createContext(null);Lu.displayName="InputGroupContext";const Mu=Lu,Uu=x.createContext(null);Uu.displayName="NavbarContext";const Vu=Uu;function Hu(e,t){return e}const Ut=I.oneOf(["start","end"]),Qm=I.oneOfType([Ut,I.shape({sm:Ut}),I.shape({md:Ut}),I.shape({lg:Ut}),I.shape({xl:Ut}),I.shape({xxl:Ut}),I.object]);function Gu(e,t,n){const r=n?"top-end":"top-start",o=n?"top-start":"top-end",i=n?"bottom-end":"bottom-start",s=n?"bottom-start":"bottom-end",l=n?"right-start":"left-start",c=n?"right-end":"left-end",u=n?"left-start":"right-start",f=n?"left-end":"right-end";let d=e?s:i;return t==="up"?d=e?o:r:t==="end"?d=e?f:u:t==="start"?d=e?c:l:t==="down-centered"?d="bottom":t==="up-centered"&&(d="top"),d}const Wu=x.forwardRef(({bsPrefix:e,className:t,align:n,rootCloseEvent:r,flip:o=!0,show:i,renderOnMount:s,as:l="div",popperConfig:c,variant:u,...f},d)=>{let p=!1;const h=x.useContext(Vu),g=$(e,"dropdown-menu"),{align:m,drop:v,isRTL:y}=x.useContext(_u);n=n||m;const b=x.useContext(Mu),w=[];if(n)if(typeof n=="object"){const E=Object.keys(n);if(E.length){const B=E[0],P=n[B];p=P==="start",w.push(`${g}-${B}-${P}`)}}else n==="end"&&(p=!0);const S=Gu(p,v,y),[F,{hasShown:C,popper:A,show:O,toggle:T}]=Au({flip:o,rootCloseEvent:r,show:i,usePopper:!h&&w.length===0,offset:[0,2],popperConfig:c,placement:S});if(F.ref=ze(Hu(d),F.ref),Ar(()=>{O&&(A==null||A.update())},[O]),!C&&!s&&!b)return null;typeof l!="string"&&(F.show=O,F.close=()=>T==null?void 0:T(!1),F.align=n);let N=f.style;return A!=null&&A.placement&&(N={...f.style,...F.style},f["x-placement"]=A.placement),a.jsx(l,{...f,...F,style:N,...(w.length||h)&&{"data-bs-popper":"static"},className:_(t,g,O&&"show",p&&`${g}-end`,u&&`${g}-${u}`,...w)})});Wu.displayName="DropdownMenu";const qm=Wu,zu=x.forwardRef(({bsPrefix:e,split:t,className:n,childBsPrefix:r,as:o=z,...i},s)=>{const l=$(e,"dropdown-toggle"),c=x.useContext(Zr);r!==void 0&&(i.bsPrefix=r);const[u]=Fu();return u.ref=ze(u.ref,Hu(s)),a.jsx(o,{className:_(n,l,t&&`${l}-split`,(c==null?void 0:c.show)&&"show"),...u,...i})});zu.displayName="DropdownToggle";const Km=zu,Qu=x.forwardRef((e,t)=>{const{bsPrefix:n,drop:r="down",show:o,className:i,align:s="start",onSelect:l,onToggle:c,focusFirstItemOnShow:u,as:f="div",navbar:d,autoClose:p=!0,...h}=ns(e,{show:"onToggle"}),g=x.useContext(Mu),m=$(n,"dropdown"),v=Kr(),y=A=>p===!1?A==="click":p==="inside"?A!=="rootClose":p==="outside"?A!=="select":!0,b=ce((A,O)=>{var T,N;!((T=O.originalEvent)==null||(N=T.target)==null)&&N.classList.contains("dropdown-toggle")&&O.source==="mousedown"||(O.originalEvent.currentTarget===document&&(O.source!=="keydown"||O.originalEvent.key==="Escape")&&(O.source="rootClose"),y(O.source)&&(c==null||c(A,O)))}),S=Gu(s==="end",r,v),F=x.useMemo(()=>({align:s,drop:r,isRTL:v}),[s,r,v]),C={down:m,"down-centered":`${m}-center`,up:"dropup","up-centered":"dropup-center dropup",end:"dropend",start:"dropstart"};return a.jsx(_u.Provider,{value:F,children:a.jsx(Mn,{placement:S,show:o,onSelect:l,onToggle:b,focusFirstItemOnShow:u,itemSelector:`.${m}-item:not(.disabled):not(:disabled)`,children:g?h.children:a.jsx(f,{...h,ref:t,className:_(i,o&&"show",C[r])})})})});Qu.displayName="Dropdown";const we=Object.assign(Qu,{Toggle:Km,Menu:qm,Item:Wm,ItemText:zm,Divider:Hm,Header:Gm}),Ym={bsPrefix:I.string,fluid:I.bool,rounded:I.bool,roundedCircle:I.bool,thumbnail:I.bool},qu=x.forwardRef(({bsPrefix:e,className:t,fluid:n=!1,rounded:r=!1,roundedCircle:o=!1,thumbnail:i=!1,...s},l)=>(e=$(e,"img"),a.jsx("img",{ref:l,...s,className:_(t,n&&`${e}-fluid`,r&&"rounded",o&&"rounded-circle",i&&`${e}-thumbnail`)})));qu.displayName="Image";const Un=qu,bs=x.forwardRef(({className:e,fluid:t=!0,...n},r)=>a.jsx(Un,{ref:r,...n,fluid:t,className:_(e,"figure-img")}));bs.displayName="FigureImage";bs.propTypes=Ym;const Jm=bs,Ku=x.forwardRef(({className:e,bsPrefix:t,as:n="figcaption",...r},o)=>(t=$(t,"figure-caption"),a.jsx(n,{ref:o,className:_(e,t),...r})));Ku.displayName="FigureCaption";const Zm=Ku,Yu=x.forwardRef(({className:e,bsPrefix:t,as:n="figure",...r},o)=>(t=$(t,"figure"),a.jsx(n,{ref:o,className:_(e,t),...r})));Yu.displayName="Figure";const Xm=Object.assign(Yu,{Image:Jm,Caption:Zm}),ex={type:I.string,tooltip:I.bool,as:I.elementType},Cs=x.forwardRef(({as:e="div",className:t,type:n="valid",tooltip:r=!1,...o},i)=>a.jsx(e,{...o,ref:i,className:_(t,`${n}-${r?"tooltip":"feedback"}`)}));Cs.displayName="Feedback";Cs.propTypes=ex;const Ju=Cs,tx=x.createContext({}),it=tx,Zu=x.forwardRef(({id:e,bsPrefix:t,className:n,type:r="checkbox",isValid:o=!1,isInvalid:i=!1,as:s="input",...l},c)=>{const{controlId:u}=x.useContext(it);return t=$(t,"form-check-input"),a.jsx(s,{...l,ref:c,type:r,id:e||u,className:_(n,t,o&&"is-valid",i&&"is-invalid")})});Zu.displayName="FormCheckInput";const Xu=Zu,ef=x.forwardRef(({bsPrefix:e,className:t,htmlFor:n,...r},o)=>{const{controlId:i}=x.useContext(it);return e=$(e,"form-check-label"),a.jsx("label",{...r,ref:o,htmlFor:n||i,className:_(t,e)})});ef.displayName="FormCheckLabel";const wi=ef,tf=x.forwardRef(({id:e,bsPrefix:t,bsSwitchPrefix:n,inline:r=!1,reverse:o=!1,disabled:i=!1,isValid:s=!1,isInvalid:l=!1,feedbackTooltip:c=!1,feedback:u,feedbackType:f,className:d,style:p,title:h="",type:g="checkbox",label:m,children:v,as:y="input",...b},w)=>{t=$(t,"form-check"),n=$(n,"form-switch");const{controlId:S}=x.useContext(it),F=x.useMemo(()=>({controlId:e||S}),[S,e]),C=!v&&m!=null&&m!==!1||rg(v,wi),A=a.jsx(Xu,{...b,type:g==="switch"?"checkbox":g,ref:w,isValid:s,isInvalid:l,disabled:i,as:y});return a.jsx(it.Provider,{value:F,children:a.jsx("div",{style:p,className:_(d,C&&t,r&&`${t}-inline`,o&&`${t}-reverse`,g==="switch"&&n),children:v||a.jsxs(a.Fragment,{children:[A,C&&a.jsx(wi,{title:h,children:m}),u&&a.jsx(Ju,{type:f,tooltip:c,children:u})]})})})});tf.displayName="FormCheck";const Er=Object.assign(tf,{Input:Xu,Label:wi}),nf=x.forwardRef(({bsPrefix:e,type:t,size:n,htmlSize:r,id:o,className:i,isValid:s=!1,isInvalid:l=!1,plaintext:c,readOnly:u,as:f="input",...d},p)=>{const{controlId:h}=x.useContext(it);return e=$(e,"form-control"),a.jsx(f,{...d,type:t,size:r,ref:p,readOnly:u,id:o||h,className:_(i,c?`${e}-plaintext`:e,n&&`${e}-${n}`,t==="color"&&`${e}-color`,s&&"is-valid",l&&"is-invalid")})});nf.displayName="FormControl";const rf=Object.assign(nf,{Feedback:Ju}),of=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"form-floating"),a.jsx(n,{ref:o,className:_(e,t),...r})));of.displayName="FormFloating";const nx=of,sf=x.forwardRef(({controlId:e,as:t="div",...n},r)=>{const o=x.useMemo(()=>({controlId:e}),[e]);return a.jsx(it.Provider,{value:o,children:a.jsx(t,{...n,ref:r})})});sf.displayName="FormGroup";const Ss=sf,af=x.forwardRef(({as:e="label",bsPrefix:t,column:n=!1,visuallyHidden:r=!1,className:o,htmlFor:i,...s},l)=>{const{controlId:c}=x.useContext(it);t=$(t,"form-label");let u="col-form-label";typeof n=="string"&&(u=`${u} ${u}-${n}`);const f=_(o,t,r&&"visually-hidden",n&&u);return i=i||c,n?a.jsx(fs,{ref:l,as:"label",className:f,htmlFor:i,...s}):a.jsx(e,{ref:l,className:f,htmlFor:i,...s})});af.displayName="FormLabel";const rx=af,lf=x.forwardRef(({bsPrefix:e,className:t,id:n,...r},o)=>{const{controlId:i}=x.useContext(it);return e=$(e,"form-range"),a.jsx("input",{...r,type:"range",ref:o,className:_(t,e),id:n||i})});lf.displayName="FormRange";const ox=lf,cf=x.forwardRef(({bsPrefix:e,size:t,htmlSize:n,className:r,isValid:o=!1,isInvalid:i=!1,id:s,...l},c)=>{const{controlId:u}=x.useContext(it);return e=$(e,"form-select"),a.jsx("select",{...l,size:n,ref:c,className:_(r,e,t&&`${e}-${t}`,o&&"is-valid",i&&"is-invalid"),id:s||u})});cf.displayName="FormSelect";const ix=cf,uf=x.forwardRef(({bsPrefix:e,className:t,as:n="small",muted:r,...o},i)=>(e=$(e,"form-text"),a.jsx(n,{...o,ref:i,className:_(t,e,r&&"text-muted")})));uf.displayName="FormText";const sx=uf,ff=x.forwardRef((e,t)=>a.jsx(Er,{...e,ref:t,type:"switch"}));ff.displayName="Switch";const ax=Object.assign(ff,{Input:Er.Input,Label:Er.Label}),df=x.forwardRef(({bsPrefix:e,className:t,children:n,controlId:r,label:o,...i},s)=>(e=$(e,"form-floating"),a.jsxs(Ss,{ref:s,className:_(t,e),controlId:r,...i,children:[n,a.jsx("label",{htmlFor:r,children:o})]})));df.displayName="FloatingLabel";const lx=df,cx={_ref:I.any,validated:I.bool,as:I.elementType},As=x.forwardRef(({className:e,validated:t,as:n="form",...r},o)=>a.jsx(n,{...r,ref:o,className:_(e,t&&"was-validated")}));As.displayName="Form";As.propTypes=cx;const fe=Object.assign(As,{Group:Ss,Control:rf,Floating:nx,Check:Er,Switch:ax,Label:rx,Text:sx,Range:ox,Select:ix,FloatingLabel:lx}),ux=x.createContext(null),pf=ux,fx=["as","active","eventKey"];function dx(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}function hf({key:e,onClick:t,active:n,id:r,role:o,disabled:i}){const s=x.useContext(tn),l=x.useContext(ws),c=x.useContext(pf);let u=n;const f={role:o};if(l){!o&&l.role==="tablist"&&(f.role="tab");const d=l.getControllerId(e??null),p=l.getControlledId(e??null);f[sn("event-key")]=e,f.id=d||r,u=n==null&&e!=null?l.activeKey===e:n,(u||!(c!=null&&c.unmountOnExit)&&!(c!=null&&c.mountOnEnter))&&(f["aria-controls"]=p)}return f.role==="tab"&&(f["aria-selected"]=u,u||(f.tabIndex=-1),i&&(f.tabIndex=-1,f["aria-disabled"]=!0)),f.onClick=ce(d=>{i||(t==null||t(d),e!=null&&s&&!d.isPropagationStopped()&&s(e,d))}),[f,{isActive:u}]}const gf=x.forwardRef((e,t)=>{let{as:n=ls,active:r,eventKey:o}=e,i=dx(e,fx);const[s,l]=hf(Object.assign({key:Tn(o,i.href),active:r},i));return s[sn("active")]=l.isActive,a.jsx(n,Object.assign({},i,s,{ref:t}))});gf.displayName="NavItem";const px=gf,hx=["as","onSelect","activeKey","role","onKeyDown"];function gx(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}const ma=()=>{},xa=sn("event-key"),mf=x.forwardRef((e,t)=>{let{as:n="div",onSelect:r,activeKey:o,role:i,onKeyDown:s}=e,l=gx(e,hx);const c=fu(),u=x.useRef(!1),f=x.useContext(tn),d=x.useContext(pf);let p,h;d&&(i=i||"tablist",o=d.activeKey,p=d.getControlledId,h=d.getControllerId);const g=x.useRef(null),m=w=>{const S=g.current;if(!S)return null;const F=gi(S,`[${xa}]:not([aria-disabled=true])`),C=S.querySelector("[aria-selected=true]");if(!C||C!==document.activeElement)return null;const A=F.indexOf(C);if(A===-1)return null;let O=A+w;return O>=F.length&&(O=0),O<0&&(O=F.length-1),F[O]},v=(w,S)=>{w!=null&&(r==null||r(w,S),f==null||f(w,S))},y=w=>{if(s==null||s(w),!d)return;let S;switch(w.key){case"ArrowLeft":case"ArrowUp":S=m(-1);break;case"ArrowRight":case"ArrowDown":S=m(1);break;default:return}S&&(w.preventDefault(),v(S.dataset[Mm("EventKey")]||null,w),u.current=!0,c())};x.useEffect(()=>{if(g.current&&u.current){const w=g.current.querySelector(`[${xa}][aria-selected=true]`);w==null||w.focus()}u.current=!1});const b=ze(t,g);return a.jsx(tn.Provider,{value:v,children:a.jsx(ws.Provider,{value:{role:i,activeKey:Tn(o),getControlledId:p||ma,getControllerId:h||ma},children:a.jsx(n,Object.assign({},l,{onKeyDown:y,ref:b,role:i}))})})});mf.displayName="Nav";const mx=Object.assign(mf,{Item:px});var Kn;function va(e){if((!Kn&&Kn!==0||e)&&rs){var t=document.createElement("div");t.style.position="absolute",t.style.top="-9999px",t.style.width="50px",t.style.height="50px",t.style.overflow="scroll",document.body.appendChild(t),Kn=t.offsetWidth-t.clientWidth,document.body.removeChild(t)}return Kn}function Io(e){e===void 0&&(e=Ln());try{var t=e.activeElement;return!t||!t.nodeName?null:t}catch{return e.body}}function xx(e){var t=Ln(e);return t&&t.defaultView||window}function vx(e,t){return xx(e).getComputedStyle(e,t)}var yx=/([A-Z])/g;function wx(e){return e.replace(yx,"-$1").toLowerCase()}var bx=/^ms-/;function Yn(e){return wx(e).replace(bx,"-ms-")}var Cx=/^((translate|rotate|scale)(X|Y|Z|3d)?|matrix(3d)?|perspective|skew(X|Y)?)$/i;function Sx(e){return!!(e&&Cx.test(e))}function ya(e,t){var n="",r="";if(typeof t=="string")return e.style.getPropertyValue(Yn(t))||vx(e).getPropertyValue(Yn(t));Object.keys(t).forEach(function(o){var i=t[o];!i&&i!==0?e.style.removeProperty(Yn(o)):Sx(o)?r+=o+"("+i+") ":n+=Yn(o)+": "+i+";"}),r&&(n+="transform: "+r+";"),e.style.cssText+=";"+n}function Ax(e=document){const t=e.defaultView;return Math.abs(t.innerWidth-e.documentElement.clientWidth)}const wa=sn("modal-open");class jx{constructor({ownerDocument:t,handleContainerOverflow:n=!0,isRTL:r=!1}={}){this.handleContainerOverflow=n,this.isRTL=r,this.modals=[],this.ownerDocument=t}getScrollbarWidth(){return Ax(this.ownerDocument)}getElement(){return(this.ownerDocument||document).body}setModalAttributes(t){}removeModalAttributes(t){}setContainerStyle(t){const n={overflow:"hidden"},r=this.isRTL?"paddingLeft":"paddingRight",o=this.getElement();t.style={overflow:o.style.overflow,[r]:o.style[r]},t.scrollBarWidth&&(n[r]=`${parseInt(ya(o,r)||"0",10)+t.scrollBarWidth}px`),o.setAttribute(wa,""),ya(o,n)}reset(){[...this.modals].forEach(t=>this.remove(t))}removeContainerStyle(t){const n=this.getElement();n.removeAttribute(wa),Object.assign(n.style,t.style)}add(t){let n=this.modals.indexOf(t);return n!==-1||(n=this.modals.length,this.modals.push(t),this.setModalAttributes(t),n!==0)||(this.state={scrollBarWidth:this.getScrollbarWidth(),style:{}},this.handleContainerOverflow&&this.setContainerStyle(this.state)),n}remove(t){const n=this.modals.indexOf(t);n!==-1&&(this.modals.splice(n,1),!this.modals.length&&this.handleContainerOverflow&&this.removeContainerStyle(this.state),this.removeModalAttributes(t))}isTopModal(t){return!!this.modals.length&&this.modals[this.modals.length-1]===t}}const js=jx,No=(e,t)=>Jr?e==null?(t||Ln()).body:(typeof e=="function"&&(e=e()),e&&"current"in e&&(e=e.current),e&&("nodeType"in e||e.getBoundingClientRect)?e:null):null;function bi(e,t){const n=eo(),[r,o]=x.useState(()=>No(e,n==null?void 0:n.document));if(!r){const i=No(e);i&&o(i)}return x.useEffect(()=>{t&&r&&t(r)},[t,r]),x.useEffect(()=>{const i=No(e);i!==r&&o(i)},[e,r]),r}function Rx({children:e,in:t,onExited:n,mountOnEnter:r,unmountOnExit:o}){const i=x.useRef(null),s=x.useRef(t),l=ce(n);x.useEffect(()=>{t?s.current=!0:l(i.current)},[t,l]);const c=ze(i,e.ref),u=x.cloneElement(e,{ref:c});return t?u:o||!s.current&&r?null:u}function Fx({in:e,onTransition:t}){const n=x.useRef(null),r=x.useRef(!0),o=ce(t);return Ar(()=>{if(!n.current)return;let i=!1;return o({in:e,element:n.current,initial:r.current,isStale:()=>i}),()=>{i=!0}},[e,o]),Ar(()=>(r.current=!1,()=>{r.current=!0}),[]),n}function Ox({children:e,in:t,onExited:n,onEntered:r,transition:o}){const[i,s]=x.useState(!t);t&&i&&s(!1);const l=Fx({in:!!t,onTransition:u=>{const f=()=>{u.isStale()||(u.in?r==null||r(u.element,u.initial):(s(!0),n==null||n(u.element)))};Promise.resolve(o(u)).then(f,d=>{throw u.in||s(!0),d})}}),c=ze(l,e.ref);return i&&!t?null:x.cloneElement(e,{ref:c})}function Ci(e,t,n){return e?a.jsx(e,Object.assign({},n)):t?a.jsx(Ox,Object.assign({},n,{transition:t})):a.jsx(Rx,Object.assign({},n))}function xf(e){return e.code==="Escape"||e.keyCode===27}const Ex=["show","role","className","style","children","backdrop","keyboard","onBackdropClick","onEscapeKeyDown","transition","runTransition","backdropTransition","runBackdropTransition","autoFocus","enforceFocus","restoreFocus","restoreFocusOptions","renderDialog","renderBackdrop","manager","container","onShow","onHide","onExit","onExited","onExiting","onEnter","onEntering","onEntered"];function Ix(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}let To;function Nx(e){return To||(To=new js({ownerDocument:e==null?void 0:e.document})),To}function Tx(e){const t=eo(),n=e||Nx(t),r=x.useRef({dialog:null,backdrop:null});return Object.assign(r.current,{add:()=>n.add(r.current),remove:()=>n.remove(r.current),isTopModal:()=>n.isTopModal(r.current),setDialogRef:x.useCallback(o=>{r.current.dialog=o},[]),setBackdropRef:x.useCallback(o=>{r.current.backdrop=o},[])})}const vf=x.forwardRef((e,t)=>{let{show:n=!1,role:r="dialog",className:o,style:i,children:s,backdrop:l=!0,keyboard:c=!0,onBackdropClick:u,onEscapeKeyDown:f,transition:d,runTransition:p,backdropTransition:h,runBackdropTransition:g,autoFocus:m=!0,enforceFocus:v=!0,restoreFocus:y=!0,restoreFocusOptions:b,renderDialog:w,renderBackdrop:S=re=>a.jsx("div",Object.assign({},re)),manager:F,container:C,onShow:A,onHide:O=()=>{},onExit:T,onExited:N,onExiting:E,onEnter:B,onEntering:P,onEntered:M}=e,V=Ix(e,Ex);const J=eo(),Q=bi(C),X=Tx(F),K=ss(),ee=Uc(n),[se,he]=x.useState(!n),ae=x.useRef(null);x.useImperativeHandle(t,()=>X,[X]),Jr&&!ee&&n&&(ae.current=Io(J==null?void 0:J.document)),n&&se&&he(!1);const ye=ce(()=>{if(X.add(),ct.current=Ot(document,"keydown",Pe),Ye.current=Ot(document,"focus",()=>setTimeout(qe),!0),A&&A(),m){var re,Rt;const ht=Io((re=(Rt=X.dialog)==null?void 0:Rt.ownerDocument)!=null?re:J==null?void 0:J.document);X.dialog&&ht&&!Fr(X.dialog,ht)&&(ae.current=ht,X.dialog.focus())}}),be=ce(()=>{if(X.remove(),ct.current==null||ct.current(),Ye.current==null||Ye.current(),y){var re;(re=ae.current)==null||re.focus==null||re.focus(b),ae.current=null}});x.useEffect(()=>{!n||!Q||ye()},[n,Q,ye]),x.useEffect(()=>{se&&be()},[se,be]),us(()=>{be()});const qe=ce(()=>{if(!v||!K()||!X.isTopModal())return;const re=Io(J==null?void 0:J.document);X.dialog&&re&&!Fr(X.dialog,re)&&X.dialog.focus()}),Ke=ce(re=>{re.target===re.currentTarget&&(u==null||u(re),l===!0&&O())}),Pe=ce(re=>{c&&xf(re)&&X.isTopModal()&&(f==null||f(re),re.defaultPrevented||O())}),Ye=x.useRef(),ct=x.useRef(),ut=(...re)=>{he(!0),N==null||N(...re)};if(!Q)return null;const ft=Object.assign({role:r,ref:X.setDialogRef,"aria-modal":r==="dialog"?!0:void 0},V,{style:i,className:o,tabIndex:-1});let dt=w?w(ft):a.jsx("div",Object.assign({},ft,{children:x.cloneElement(s,{role:"document"})}));dt=Ci(d,p,{unmountOnExit:!0,mountOnEnter:!0,appear:!0,in:!!n,onExit:T,onExiting:E,onExited:ut,onEnter:B,onEntering:P,onEntered:M,children:dt});let pt=null;return l&&(pt=S({ref:X.setBackdropRef,onClick:Ke}),pt=Ci(h,g,{in:!!n,appear:!0,mountOnEnter:!0,unmountOnExit:!0,children:pt})),a.jsx(a.Fragment,{children:ke.createPortal(a.jsxs(a.Fragment,{children:[pt,dt]}),Q)})});vf.displayName="Modal";const Dx=Object.assign(vf,{Manager:js});function Si(e,t){return e.classList?!!t&&e.classList.contains(t):(" "+(e.className.baseVal||e.className)+" ").indexOf(" "+t+" ")!==-1}function _x(e,t){e.classList?e.classList.add(t):Si(e,t)||(typeof e.className=="string"?e.className=e.className+" "+t:e.setAttribute("class",(e.className&&e.className.baseVal||"")+" "+t))}var $x=Function.prototype.bind.call(Function.prototype.call,[].slice);function Vt(e,t){return $x(e.querySelectorAll(t))}function ba(e,t){return e.replace(new RegExp("(^|\\s)"+t+"(?:\\s|$)","g"),"$1").replace(/\s+/g," ").replace(/^\s*|\s*$/g,"")}function Bx(e,t){e.classList?e.classList.remove(t):typeof e.className=="string"?e.className=ba(e.className,t):e.setAttribute("class",ba(e.className&&e.className.baseVal||"",t))}const Ht={FIXED_CONTENT:".fixed-top, .fixed-bottom, .is-fixed, .sticky-top",STICKY_CONTENT:".sticky-top",NAVBAR_TOGGLER:".navbar-toggler"};class Px extends js{adjustAndStore(t,n,r){const o=n.style[t];n.dataset[t]=o,Nt(n,{[t]:`${parseFloat(Nt(n,t))+r}px`})}restore(t,n){const r=n.dataset[t];r!==void 0&&(delete n.dataset[t],Nt(n,{[t]:r}))}setContainerStyle(t){super.setContainerStyle(t);const n=this.getElement();if(_x(n,"modal-open"),!t.scrollBarWidth)return;const r=this.isRTL?"paddingLeft":"paddingRight",o=this.isRTL?"marginLeft":"marginRight";Vt(n,Ht.FIXED_CONTENT).forEach(i=>this.adjustAndStore(r,i,t.scrollBarWidth)),Vt(n,Ht.STICKY_CONTENT).forEach(i=>this.adjustAndStore(o,i,-t.scrollBarWidth)),Vt(n,Ht.NAVBAR_TOGGLER).forEach(i=>this.adjustAndStore(o,i,t.scrollBarWidth))}removeContainerStyle(t){super.removeContainerStyle(t);const n=this.getElement();Bx(n,"modal-open");const r=this.isRTL?"paddingLeft":"paddingRight",o=this.isRTL?"marginLeft":"marginRight";Vt(n,Ht.FIXED_CONTENT).forEach(i=>this.restore(r,i)),Vt(n,Ht.STICKY_CONTENT).forEach(i=>this.restore(o,i)),Vt(n,Ht.NAVBAR_TOGGLER).forEach(i=>this.restore(o,i))}}let Do;function kx(e){return Do||(Do=new Px(e)),Do}const yf=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"modal-body"),a.jsx(n,{ref:o,className:_(e,t),...r})));yf.displayName="ModalBody";const Lx=yf,Mx=x.createContext({onHide(){}}),wf=Mx,bf=x.forwardRef(({bsPrefix:e,className:t,contentClassName:n,centered:r,size:o,fullscreen:i,children:s,scrollable:l,...c},u)=>{e=$(e,"modal");const f=`${e}-dialog`,d=typeof i=="string"?`${e}-fullscreen-${i}`:`${e}-fullscreen`;return a.jsx("div",{...c,ref:u,className:_(f,t,o&&`${e}-${o}`,r&&`${f}-centered`,l&&`${f}-scrollable`,i&&d),children:a.jsx("div",{className:_(`${e}-content`,n),children:s})})});bf.displayName="ModalDialog";const Cf=bf,Sf=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"modal-footer"),a.jsx(n,{ref:o,className:_(e,t),...r})));Sf.displayName="ModalFooter";const Ux=Sf,Vx=x.forwardRef(({closeLabel:e="Close",closeVariant:t,closeButton:n=!1,onHide:r,children:o,...i},s)=>{const l=x.useContext(wf),c=ce(()=>{l==null||l.onHide(),r==null||r()});return a.jsxs("div",{ref:s,...i,children:[o,n&&a.jsx(Hh,{"aria-label":e,variant:t,onClick:c})]})}),Hx=Vx,Af=x.forwardRef(({bsPrefix:e,className:t,closeLabel:n="Close",closeButton:r=!1,...o},i)=>(e=$(e,"modal-header"),a.jsx(Hx,{ref:i,...o,className:_(t,e),closeLabel:n,closeButton:r})));Af.displayName="ModalHeader";const Gx=Af,Wx=is("h4"),jf=x.forwardRef(({className:e,bsPrefix:t,as:n=Wx,...r},o)=>(t=$(t,"modal-title"),a.jsx(n,{ref:o,className:_(e,t),...r})));jf.displayName="ModalTitle";const zx=jf;function Qx(e){return a.jsx(jr,{...e,timeout:null})}function qx(e){return a.jsx(jr,{...e,timeout:null})}const Rf=x.forwardRef(({bsPrefix:e,className:t,style:n,dialogClassName:r,contentClassName:o,children:i,dialogAs:s=Cf,"data-bs-theme":l,"aria-labelledby":c,"aria-describedby":u,"aria-label":f,show:d=!1,animation:p=!0,backdrop:h=!0,keyboard:g=!0,onEscapeKeyDown:m,onShow:v,onHide:y,container:b,autoFocus:w=!0,enforceFocus:S=!0,restoreFocus:F=!0,restoreFocusOptions:C,onEntered:A,onExit:O,onExiting:T,onEnter:N,onEntering:E,onExited:B,backdropClassName:P,manager:M,...V},J)=>{const[Q,X]=x.useState({}),[K,ee]=x.useState(!1),se=x.useRef(!1),he=x.useRef(!1),ae=x.useRef(null),[ye,be]=Sr(),qe=ze(J,be),Ke=ce(y),Pe=Kr();e=$(e,"modal");const Ye=x.useMemo(()=>({onHide:Ke}),[Ke]);function ct(){return M||kx({isRTL:Pe})}function ut(Z){if(!rs)return;const Ze=ct().getScrollbarWidth()>0,un=Z.scrollHeight>yc(Z).documentElement.clientHeight;X({paddingRight:Ze&&!un?va():void 0,paddingLeft:!Ze&&un?va():void 0})}const ft=ce(()=>{ye&&ut(ye.dialog)});us(()=>{pi(window,"resize",ft),ae.current==null||ae.current()});const dt=()=>{se.current=!0},pt=Z=>{se.current&&ye&&Z.target===ye.dialog&&(he.current=!0),se.current=!1},re=()=>{ee(!0),ae.current=Rc(ye.dialog,()=>{ee(!1)})},Rt=Z=>{Z.target===Z.currentTarget&&re()},ht=Z=>{if(h==="static"){Rt(Z);return}if(he.current||Z.target!==Z.currentTarget){he.current=!1;return}y==null||y()},Ao=Z=>{g?m==null||m(Z):(Z.preventDefault(),h==="static"&&re())},jo=(Z,Ze)=>{Z&&ut(Z),N==null||N(Z,Ze)},Je=Z=>{ae.current==null||ae.current(),O==null||O(Z)},kt=(Z,Ze)=>{E==null||E(Z,Ze),Ac(window,"resize",ft)},Gn=Z=>{Z&&(Z.style.display=""),B==null||B(Z),pi(window,"resize",ft)},Wn=x.useCallback(Z=>a.jsx("div",{...Z,className:_(`${e}-backdrop`,P,!p&&"show")}),[p,P,e]),Lt={...n,...Q};Lt.display="block";const zn=Z=>a.jsx("div",{role:"dialog",...Z,style:Lt,className:_(t,e,K&&`${e}-static`,!p&&"show"),onClick:h?ht:void 0,onMouseUp:pt,"data-bs-theme":l,"aria-label":f,"aria-labelledby":c,"aria-describedby":u,children:a.jsx(s,{...V,onMouseDown:dt,className:r,contentClassName:o,children:i})});return a.jsx(wf.Provider,{value:Ye,children:a.jsx(Dx,{show:d,ref:qe,backdrop:h,container:b,keyboard:!0,autoFocus:w,enforceFocus:S,restoreFocus:F,restoreFocusOptions:C,onEscapeKeyDown:Ao,onShow:v,onHide:y,onEnter:jo,onEntering:kt,onEntered:A,onExit:Je,onExiting:T,onExited:Gn,manager:ct(),transition:p?Qx:void 0,backdropTransition:p?qx:void 0,renderBackdrop:Wn,renderDialog:zn})})});Rf.displayName="Modal";const de=Object.assign(Rf,{Body:Lx,Header:Gx,Title:zx,Footer:Ux,Dialog:Cf,TRANSITION_DURATION:300,BACKDROP_TRANSITION_DURATION:150});var Ca={exports:{}},Ai={exports:{}};(function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=n;function n(r){function o(s,l,c,u,f,d){var p=u||"<<anonymous>>",h=d||c;if(l[c]==null)return s?new Error("Required "+f+" `"+h+"` was not specified "+("in `"+p+"`.")):null;for(var g=arguments.length,m=Array(g>6?g-6:0),v=6;v<g;v++)m[v-6]=arguments[v];return r.apply(void 0,[l,c,p,f,h].concat(m))}var i=o.bind(null,!1);return i.isRequired=o.bind(null,!0),i}e.exports=t.default})(Ai,Ai.exports);var Kx=Ai.exports;(function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=i;var n=Kx,r=o(n);function o(s){return s&&s.__esModule?s:{default:s}}function i(){for(var s=arguments.length,l=Array(s),c=0;c<s;c++)l[c]=arguments[c];function u(){for(var f=arguments.length,d=Array(f),p=0;p<f;p++)d[p]=arguments[p];var h=null;return l.forEach(function(g){if(h==null){var m=g.apply(void 0,d);m!=null&&(h=m)}}),h}return(0,r.default)(u)}e.exports=t.default})(Ca,Ca.exports);const Ff=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"nav-item"),a.jsx(n,{ref:o,className:_(e,t),...r})));Ff.displayName="NavItem";const Yx=Ff,Of=x.forwardRef(({bsPrefix:e,className:t,as:n=Hc,active:r,eventKey:o,disabled:i=!1,...s},l)=>{e=$(e,"nav-link");const[c,u]=hf({key:Tn(o,s.href),active:r,disabled:i,...s});return a.jsx(n,{...s,...c,ref:l,disabled:i,className:_(t,e,i&&"disabled",u.isActive&&"active")})});Of.displayName="NavLink";const Ef=Of,If=x.forwardRef((e,t)=>{const{as:n="div",bsPrefix:r,variant:o,fill:i=!1,justify:s=!1,navbar:l,navbarScroll:c,className:u,activeKey:f,...d}=ns(e,{activeKey:"onSelect"}),p=$(r,"nav");let h,g,m=!1;const v=x.useContext(Vu),y=x.useContext(Xc);return v?(h=v.bsPrefix,m=l??!0):y&&({cardHeaderBsPrefix:g}=y),a.jsx(mx,{as:n,ref:t,activeKey:f,className:_(u,{[p]:!m,[`${h}-nav`]:m,[`${h}-nav-scroll`]:m&&c,[`${g}-${o}`]:!!g,[`${p}-${o}`]:!!o,[`${p}-fill`]:i,[`${p}-justified`]:s}),...d})});If.displayName="Nav";const ne=Object.assign(If,{Item:Yx,Link:Ef}),Nf=x.forwardRef(({id:e,title:t,children:n,bsPrefix:r,className:o,rootCloseEvent:i,menuRole:s,disabled:l,active:c,renderMenuOnMount:u,menuVariant:f,...d},p)=>{const h=$(void 0,"nav-item");return a.jsxs(we,{ref:p,...d,className:_(o,h),children:[a.jsx(we.Toggle,{id:e,eventKey:null,active:c,disabled:l,childBsPrefix:r,as:Ef,children:t}),a.jsx(we.Menu,{role:s,renderOnMount:u,rootCloseEvent:i,variant:f,children:n})]})});Nf.displayName="NavDropdown";const Ie=Object.assign(Nf,{Item:we.Item,ItemText:we.ItemText,Divider:we.Divider,Header:we.Header}),Jx=()=>{};function Zx(e,t,{disabled:n,clickTrigger:r}={}){const o=t||Jx;Cu(e,o,{disabled:n,clickTrigger:r});const i=ce(s=>{xf(s)&&o(s)});x.useEffect(()=>{if(n||e==null)return;const s=Ln(xr(e));let l=(s.defaultView||window).event;const c=Ot(s,"keyup",u=>{if(u===l){l=void 0;return}i(u)});return()=>{c()}},[e,n,i])}const Tf=x.forwardRef((e,t)=>{const{flip:n,offset:r,placement:o,containerPadding:i,popperConfig:s={},transition:l,runTransition:c}=e,[u,f]=Sr(),[d,p]=Sr(),h=ze(f,t),g=bi(e.container),m=bi(e.target),[v,y]=x.useState(!e.show),b=bu(m,u,Su({placement:o,enableEvents:!!e.show,containerPadding:i||5,flip:n,offset:r,arrowElement:d,popperConfig:s}));e.show&&v&&y(!1);const w=(...E)=>{y(!0),e.onExited&&e.onExited(...E)},S=e.show||!v;if(Zx(u,e.onHide,{disabled:!e.rootClose||e.rootCloseDisabled,clickTrigger:e.rootCloseEvent}),!S)return null;const{onExit:F,onExiting:C,onEnter:A,onEntering:O,onEntered:T}=e;let N=e.children(Object.assign({},b.attributes.popper,{style:b.styles.popper,ref:h}),{popper:b,placement:o,show:!!e.show,arrowProps:Object.assign({},b.attributes.arrow,{style:b.styles.arrow,ref:p})});return N=Ci(l,c,{in:!!e.show,appear:!0,mountOnEnter:!0,unmountOnExit:!0,children:N,onExit:F,onExiting:C,onExited:w,onEnter:A,onEntering:O,onEntered:T}),g?ke.createPortal(N,g):null});Tf.displayName="Overlay";const Xx=Tf,Df=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"popover-header"),a.jsx(n,{ref:o,className:_(e,t),...r})));Df.displayName="PopoverHeader";const ev=Df,_f=x.forwardRef(({className:e,bsPrefix:t,as:n="div",...r},o)=>(t=$(t,"popover-body"),a.jsx(n,{ref:o,className:_(e,t),...r})));_f.displayName="PopoverBody";const $f=_f;function Bf(e,t){let n=e;return e==="left"?n=t?"end":"start":e==="right"&&(n=t?"start":"end"),n}function Pf(e="absolute"){return{position:e,top:"0",left:"0",opacity:"0",pointerEvents:"none"}}const tv=x.forwardRef(({bsPrefix:e,placement:t="right",className:n,style:r,children:o,body:i,arrowProps:s,hasDoneInitialMeasure:l,popper:c,show:u,...f},d)=>{const p=$(e,"popover"),h=Kr(),[g]=(t==null?void 0:t.split("-"))||[],m=Bf(g,h);let v=r;return u&&!l&&(v={...r,...Pf(c==null?void 0:c.strategy)}),a.jsxs("div",{ref:d,role:"tooltip",style:v,"x-placement":g,className:_(n,p,g&&`bs-popover-${m}`),...f,children:[a.jsx("div",{className:"popover-arrow",...s}),i?a.jsx($f,{children:o}):o]})}),Rs=Object.assign(tv,{Header:ev,Body:$f,POPPER_OFFSET:[0,8]}),kf=x.forwardRef(({bsPrefix:e,placement:t="right",className:n,style:r,children:o,arrowProps:i,hasDoneInitialMeasure:s,popper:l,show:c,...u},f)=>{e=$(e,"tooltip");const d=Kr(),[p]=(t==null?void 0:t.split("-"))||[],h=Bf(p,d);let g=r;return c&&!s&&(g={...r,...Pf(l==null?void 0:l.strategy)}),a.jsxs("div",{ref:f,style:g,role:"tooltip","x-placement":p,className:_(n,e,`bs-tooltip-${h}`),...u,children:[a.jsx("div",{className:"tooltip-arrow",...i}),a.jsx("div",{className:`${e}-inner`,children:o})]})});kf.displayName="Tooltip";const to=Object.assign(kf,{TOOLTIP_OFFSET:[0,6]});function nv(e){const t=x.useRef(null),n=$(void 0,"popover"),r=$(void 0,"tooltip"),o=x.useMemo(()=>({name:"offset",options:{offset:()=>{if(e)return e;if(t.current){if(Si(t.current,n))return Rs.POPPER_OFFSET;if(Si(t.current,r))return to.TOOLTIP_OFFSET}return[0,0]}}}),[e,n,r]);return[t,[o]]}function rv(e,t){const{ref:n}=e,{ref:r}=t;e.ref=n.__wrapped||(n.__wrapped=o=>n(Cr(o))),t.ref=r.__wrapped||(r.__wrapped=o=>r(Cr(o)))}const Lf=x.forwardRef(({children:e,transition:t=jr,popperConfig:n={},rootClose:r=!1,placement:o="top",show:i=!1,...s},l)=>{const c=x.useRef({}),[u,f]=x.useState(null),[d,p]=nv(s.offset),h=ze(l,d),g=t===!0?jr:t||void 0,m=ce(v=>{f(v),n==null||n.onFirstUpdate==null||n.onFirstUpdate(v)});return Ar(()=>{u&&s.target&&(c.current.scheduleUpdate==null||c.current.scheduleUpdate())},[u,s.target]),x.useEffect(()=>{i||f(null)},[i]),a.jsx(Xx,{...s,ref:h,popperConfig:{...n,modifiers:p.concat(n.modifiers||[]),onFirstUpdate:m},transition:g,rootClose:r,placement:o,show:i,children:(v,{arrowProps:y,popper:b,show:w})=>{var S,F;rv(v,y);const C=b==null?void 0:b.placement,A=Object.assign(c.current,{state:b==null?void 0:b.state,scheduleUpdate:b==null?void 0:b.update,placement:C,outOfBoundaries:(b==null||(S=b.state)==null||(F=S.modifiersData.hide)==null?void 0:F.isReferenceHidden)||!1,strategy:n.strategy}),O=!!u;return typeof e=="function"?e({...v,placement:C,show:w,...!t&&w&&{className:"show"},popper:A,arrowProps:y,hasDoneInitialMeasure:O}):x.cloneElement(e,{...v,placement:C,arrowProps:y,popper:A,hasDoneInitialMeasure:O,className:_(e.props.className,!t&&w&&"show"),style:{...e.props.style,...v.style}})}})});Lf.displayName="Overlay";const ov=Lf;function iv(e,t){if(e.contains)return e.contains(t);if(e.compareDocumentPosition)return e===t||!!(e.compareDocumentPosition(t)&16)}function sv(e){return e&&typeof e=="object"?e:{show:e,hide:e}}function Sa(e,t,n){const[r]=t,o=r.currentTarget,i=r.relatedTarget||r.nativeEvent[n];(!i||i!==o)&&!iv(o,i)&&e(...t)}I.oneOf(["click","hover","focus"]);const av=({trigger:e=["hover","focus"],overlay:t,children:n,popperConfig:r={},show:o,defaultShow:i=!1,onToggle:s,delay:l,placement:c,flip:u=c&&c.indexOf("auto")!==-1,...f})=>{const d=x.useRef(null),p=ze(d,n.ref),h=ng(),g=x.useRef(""),[m,v]=mc(o,i,s),y=sv(l),{onFocus:b,onBlur:w,onClick:S}=typeof n!="function"?x.Children.only(n).props:{},F=V=>{p(Cr(V))},C=x.useCallback(()=>{if(h.clear(),g.current="show",!y.show){v(!0);return}h.set(()=>{g.current==="show"&&v(!0)},y.show)},[y.show,v,h]),A=x.useCallback(()=>{if(h.clear(),g.current="hide",!y.hide){v(!1);return}h.set(()=>{g.current==="hide"&&v(!1)},y.hide)},[y.hide,v,h]),O=x.useCallback((...V)=>{C(),b==null||b(...V)},[C,b]),T=x.useCallback((...V)=>{A(),w==null||w(...V)},[A,w]),N=x.useCallback((...V)=>{v(!m),S==null||S(...V)},[S,v,m]),E=x.useCallback((...V)=>{Sa(C,V,"fromElement")},[C]),B=x.useCallback((...V)=>{Sa(A,V,"toElement")},[A]),P=e==null?[]:[].concat(e),M={ref:F};return P.indexOf("click")!==-1&&(M.onClick=N),P.indexOf("focus")!==-1&&(M.onFocus=O,M.onBlur=T),P.indexOf("hover")!==-1&&(M.onMouseOver=E,M.onMouseOut=B),a.jsxs(a.Fragment,{children:[typeof n=="function"?n(M):x.cloneElement(n,M),a.jsx(ov,{...f,show:m,onHide:A,flip:u,placement:c,popperConfig:r,target:d.current,children:t})]})},Ct=av,Mf=x.forwardRef(({bsPrefix:e,className:t,as:n="div",...r},o)=>{const i=$(e,"row"),s=xc(),l=vc(),c=`${i}-cols`,u=[];return s.forEach(f=>{const d=r[f];delete r[f];let p;d!=null&&typeof d=="object"?{cols:p}=d:p=d;const h=f!==l?`-${f}`:"";p!=null&&u.push(`${c}${h}-${p}`)}),a.jsx(n,{ref:o,...r,className:_(t,i,...u)})});Mf.displayName="Row";const lv=Mf,Uf=x.forwardRef(({bsPrefix:e,variant:t,animation:n="border",size:r,as:o="div",className:i,...s},l)=>{e=$(e,"spinner");const c=`${e}-${n}`;return a.jsx(o,{ref:l,...s,className:_(i,c,r&&`${c}-${r}`,t&&`text-${t}`)})});Uf.displayName="Spinner";const cv=Uf,uv={id:I.string,toggleLabel:I.string,href:I.string,target:I.string,onClick:I.func,title:I.node.isRequired,type:I.string,disabled:I.bool,align:Qm,menuRole:I.string,renderMenuOnMount:I.bool,rootCloseEvent:I.string,flip:I.bool,bsPrefix:I.string,variant:I.string,size:I.string},Fs=x.forwardRef(({id:e,bsPrefix:t,size:n,variant:r,title:o,type:i="button",toggleLabel:s="Toggle dropdown",children:l,onClick:c,href:u,target:f,menuRole:d,renderMenuOnMount:p,rootCloseEvent:h,flip:g,...m},v)=>a.jsxs(we,{ref:v,...m,as:wt,children:[a.jsx(z,{size:n,variant:r,disabled:m.disabled,bsPrefix:t,href:u,target:f,onClick:c,type:i,children:o}),a.jsx(we.Toggle,{split:!0,id:e,size:n,variant:r,disabled:m.disabled,childBsPrefix:t,children:a.jsx("span",{className:"visually-hidden",children:s})}),a.jsx(we.Menu,{role:d,renderOnMount:p,rootCloseEvent:h,flip:g,children:l})]}));Fs.propTypes=uv;Fs.displayName="SplitButton";const fv=Fs,dv=x.forwardRef(({bsPrefix:e,className:t,striped:n,bordered:r,borderless:o,hover:i,size:s,variant:l,responsive:c,...u},f)=>{const d=$(e,"table"),p=_(t,d,l&&`${d}-${l}`,s&&`${d}-${s}`,n&&`${d}-${typeof n=="string"?`striped-${n}`:"striped"}`,r&&`${d}-bordered`,o&&`${d}-borderless`,i&&`${d}-hover`),h=a.jsx("table",{...u,className:p,ref:f});if(c){let g=`${d}-responsive`;return typeof c=="string"&&(g=`${g}-${c}`),a.jsx("div",{className:g,children:h})}return h}),st=dv,Vf=e=>a.jsx(Un,{height:e.height&&e.height,width:e.width&&e.width,style:e.style&&e.style,className:e.className&&e.className,src:`https://images.evetech.net/characters/${e.character_id}/portrait?size=${e.size}`}),Ir=e=>a.jsx(Un,{height:e.height&&e.height,width:e.width&&e.width,style:e.style&&e.style,src:`https://images.evetech.net/corporations/${e.corporation_id}/logo?size=${e.size}`}),pv=e=>a.jsx(Un,{height:e.height&&e.height,width:e.width&&e.width,style:e.style&&e.style,src:`https://images.evetech.net/alliances/${e.alliance_id}/logo?size=${e.size}`}),Hf=e=>a.jsx(Un,{height:e.height&&e.height,width:e.width&&e.width,style:e.style&&e.style,src:`https://images.evetech.net/types/${e.type_id}/${e.size>64?"render":"icon"}?size=${e.size}`}),Gf=e=>{const t=e.rounded_images?{borderRadius:"50%"}:{};return a.jsxs("div",{className:e.className&&e.className,style:{height:`${e.size}px`,width:`${e.size}px`,position:"relative"},children:[a.jsx(Vf,{style:t,height:e.size,width:e.size,character_id:e.character.character_id,size:512,className:e.className&&e.className}),a.jsx(Ir,{style:{position:"absolute",bottom:"0",left:"0",...t},height:e.size/4,width:e.size/4,corporation_id:e.character.corporation_id,size:256}),e.character.faction_id?a.jsx(Ir,{style:{position:"absolute",bottom:"0",right:"0",...t},height:e.size/4,width:e.size/4,corporation_id:e.character.faction_id,size:256}):e.character.alliance_id&&a.jsx(pv,{style:{position:"absolute",bottom:"0",right:"0",...t},height:e.size/4,width:e.size/4,alliance_id:e.character.alliance_id,size:256})]})},hv="_refreshAnimate_o9fr8_10",gv="_spin_o9fr8_1",mv="_filterBtn_o9fr8_17",xv="_filterToggle_o9fr8_33",vv={refreshAnimate:hv,spin:gv,filterBtn:mv,filterToggle:xv},yv="_box_203nf_23",wv="_searchInput_203nf_28",bv="_radioWrapper_203nf_40",Cv="_input_203nf_45",Sv="_searchButton_203nf_55",Av="_searchWrapper_203nf_64",jv="_searchWrapperFrom_203nf_68",Rv="_searchIcon_203nf_72",Fv="_xIcon_203nf_73",Ov="_dropDownIcon_203nf_99",le={box:yv,searchInput:wv,radioWrapper:bv,input:Cv,searchButton:Sv,searchWrapper:Av,searchWrapperFrom:jv,searchIcon:Rv,xIcon:Fv,dropDownIcon:Ov},Ev=RegExp.prototype.test.bind(/(<([^>]+)>)/i),Iv=(e,t,n)=>e.getValue(t).reduce((i,s)=>i+=`|${s.name}`,"").toLowerCase().includes(n.toLowerCase()),Nv=({column:e})=>{const n=e.getFilterValue(),r=a.jsx(Rs,{id:"popover-positioned-top",children:a.jsxs("div",{className:"p-3",children:[a.jsx("input",{type:"number",value:(n==null?void 0:n[0])??"",onChange:o=>e.setFilterValue(i=>[o.target.value,i==null?void 0:i[1]]),placeholder:"Min",className:"form-control"}),a.jsx("p",{className:"text-center",children:"to"}),a.jsx("input",{type:"number",value:(n==null?void 0:n[1])??"",onChange:o=>e.setFilterValue(i=>[i==null?void 0:i[0],o.target.value]),placeholder:"Max",className:"form-control"}),a.jsx(z,{variant:"secondary",size:"sm",className:"w-100 mt-2",onClick:()=>document.body.click(),children:"Close"})]})});return a.jsx(Ct,{trigger:"click",placement:"bottom",rootClose:!0,overlay:r,children:a.jsx("form",{className:le.searchWrapperFrom,onReset:()=>{e.setFilterValue(()=>[void 0,void 0])},children:a.jsxs("div",{className:le.searchWrapper,children:[a.jsx(fe.Control,{className:le.searchInput,readOnly:!0,type:"text",placeholder:"Set Range",value:typeof(n==null?void 0:n[0])<"u"||typeof(n==null?void 0:n[1])<"u"?`${typeof(n==null?void 0:n[0])>"u"||(n==null?void 0:n[0])===""?"-∞":n==null?void 0:n[0].toLocaleString()} to ${typeof(n==null?void 0:n[1])>"u"||(n==null?void 0:n[1])===""?"∞":n==null?void 0:n[1].toLocaleString()}`:void 0}),a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 512 512",className:`${le.searchIcon} ${le.dropDownIcon}`,children:a.jsx("path",{fill:"currentColor",d:"M233.4 406.6c12.5 12.5 32.8 12.5 45.3 0l192-192c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L256 338.7 86.6 169.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l192 192z"})}),a.jsx("button",{type:"reset",children:a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",className:le.xIcon,children:a.jsx("path",{fill:"currentColor",d:"M17.3 18.7a1 1 0 0 0 1.4-1.4L13.42 12l5.3-5.3a1 1 0 0 0-1.42-1.4L12 10.58l-5.3-5.3a1 1 0 0 0-1.4 1.42L10.58 12l-5.3 5.3a1 1 0 1 0 1.42 1.4L12 13.42l5.3 5.3Z"})})})]})})})},Tv=({column:e})=>{const t=e.getFilterValue(),n=a.jsx(Rs,{id:"popover-positioned-top",children:a.jsxs("div",{className:`${le.radioWrapper} p-2`,children:[a.jsx(fe.Check,{label:"True",name:"group1",type:"radio",id:"radio-true",onChange:()=>{e.setFilterValue(!0)}}),a.jsx(fe.Check,{label:"False",name:"group1",type:"radio",id:"radio-false",onChange:()=>{e.setFilterValue(!1)}}),a.jsx(z,{variant:"secondary",size:"sm",className:"w-100",onClick:()=>document.body.click(),children:"Close"})]})});return a.jsx(Ct,{trigger:"click",placement:"bottom",rootClose:!0,overlay:n,children:a.jsx("form",{className:le.searchWrapperFrom,onReset:()=>{e.setFilterValue(()=>{})},children:a.jsxs("div",{className:le.searchWrapper,children:[a.jsx(fe.Control,{className:le.searchInput,readOnly:!0,type:"text",placeholder:"Filter",value:typeof t>"u"?void 0:t?"True":"False"}),a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 512 512",className:`${le.searchIcon} ${le.dropDownIcon}`,children:a.jsx("path",{fill:"currentColor",d:"M233.4 406.6c12.5 12.5 32.8 12.5 45.3 0l192-192c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L256 338.7 86.6 169.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l192 192z"})}),a.jsx("button",{type:"reset",children:a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",className:le.xIcon,children:a.jsx("path",{fill:"currentColor",d:"M17.3 18.7a1 1 0 0 0 1.4-1.4L13.42 12l5.3-5.3a1 1 0 0 0-1.42-1.4L12 10.58l-5.3-5.3a1 1 0 0 0-1.4 1.42L10.58 12l-5.3 5.3a1 1 0 1 0 1.42 1.4L12 13.42l5.3 5.3Z"})})})]})})})},Dv=({column:e})=>a.jsx("form",{onReset:()=>{e.setFilterValue(null)},children:a.jsxs("div",{className:le.searchWrapper,children:[a.jsx(fe.Control,{className:le.searchInput,type:"text",placeholder:"Search",onChange:t=>{e.setFilterValue(t.target.value?t.target.value:"")}}),a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",className:le.searchIcon,children:a.jsx("path",{fill:"currentColor","fill-rule":"evenodd",d:"M15.62 17.03a9 9 0 1 1 1.41-1.41l4.68 4.67a1 1 0 0 1-1.42 1.42l-4.67-4.68ZM17 10a7 7 0 1 1-14 0 7 7 0 0 1 14 0Z","clip-rule":"evenodd"})}),a.jsx("button",{type:"reset",children:a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",className:le.xIcon,children:a.jsx("path",{fill:"currentColor",d:"M17.3 18.7a1 1 0 0 0 1.4-1.4L13.42 12l5.3-5.3a1 1 0 0 0-1.42-1.4L12 10.58l-5.3-5.3a1 1 0 0 0-1.4 1.42L10.58 12l-5.3 5.3a1 1 0 1 0 1.42 1.4L12 13.42l5.3 5.3Z"})})})]})}),_v=({column:e})=>{const t=Array.from(e.getFacetedUniqueValues().keys()).sort(),n=e.getFilterValue(),r=Ev(t==null?void 0:t[0])||typeof(t==null?void 0:t[0])=="object",o=t.reduce((i,s)=>(typeof s<"u"&&(r||(n===void 0||s!=null&&s.toLowerCase().includes(n==null?void 0:n.toLowerCase()))&&i.push({value:s,label:s})),i),[]).slice(0,10);return a.jsx(Ct,{trigger:"click",placement:"bottom-start",rootClose:!0,overlay:a.jsx(we,{show:!0,drop:"down-centered",children:a.jsx(we.Menu,{children:a.jsx(a.Fragment,{children:o.length>0?o.map(i=>a.jsx(we.Item,{eventKey:i.value,onClick:()=>{e.setFilterValue(i.value?i.value:""),document.body.click()},children:i.label})):a.jsx(we.Item,{disabled:!0,children:"Start typing to search."})})})}),children:a.jsx("form",{className:le.searchWrapperFrom,onReset:()=>{e.setFilterValue(()=>{})},children:a.jsxs("div",{className:le.searchWrapper,children:[a.jsx(fe.Control,{className:le.searchInput,type:"text",placeholder:"Search",value:typeof n>"u"?void 0:n,onChange:i=>{e.setFilterValue(i.target.value?i.target.value:"")}}),a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",className:le.searchIcon,children:a.jsx("path",{fill:"currentColor","fill-rule":"evenodd",d:"M15.62 17.03a9 9 0 1 1 1.41-1.41l4.68 4.67a1 1 0 0 1-1.42 1.42l-4.67-4.68ZM17 10a7 7 0 1 1-14 0 7 7 0 0 1 14 0Z","clip-rule":"evenodd"})}),a.jsx("button",{type:"reset",children:a.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",className:le.xIcon,children:a.jsx("path",{fill:"currentColor",d:"M17.3 18.7a1 1 0 0 0 1.4-1.4L13.42 12l5.3-5.3a1 1 0 0 0-1.42-1.4L12 10.58l-5.3-5.3a1 1 0 0 0-1.4 1.42L10.58 12l-5.3 5.3a1 1 0 1 0 1.42 1.4L12 13.42l5.3 5.3Z"})})})]})})})},$v=({column:e,table:t})=>{var r;const n=(r=t.getPreFilteredRowModel().flatRows[0])==null?void 0:r.getValue(e.id);return typeof n=="number"?a.jsx(Nv,{column:e}):typeof n=="boolean"?a.jsx(Tv,{column:e}):typeof n=="object"?a.jsx(Dv,{column:e}):a.jsx(_v,{column:e})};/**
   * table-core
   *
   * Copyright (c) TanStack
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE.md file in the root directory of this source tree.
   *
   * @license MIT
   */function yt(e,t){return typeof e=="function"?e(t):e}function Oe(e,t){return n=>{t.setState(r=>({...r,[e]:yt(n,r[e])}))}}function Nr(e){return e instanceof Function}function Bv(e){return Array.isArray(e)&&e.every(t=>typeof t=="number")}function Pv(e,t){const n=[],r=o=>{o.forEach(i=>{n.push(i);const s=t(i);s!=null&&s.length&&r(s)})};return r(e),n}function k(e,t,n){let r=[],o;return i=>{let s;n.key&&n.debug&&(s=Date.now());const l=e(i);if(!(l.length!==r.length||l.some((f,d)=>r[d]!==f)))return o;r=l;let u;if(n.key&&n.debug&&(u=Date.now()),o=t(...l),n==null||n.onChange==null||n.onChange(o),n.key&&n.debug&&n!=null&&n.debug()){const f=Math.round((Date.now()-s)*100)/100,d=Math.round((Date.now()-u)*100)/100,p=d/16,h=(g,m)=>{for(g=String(g);g.length<m;)g=" "+g;return g};console.info(`%c⏱ ${h(d,5)} /${h(f,5)} ms`,`
            font-size: .6rem;
            font-weight: bold;
            color: hsl(${Math.max(0,Math.min(120-120*p,120))}deg 100% 31%);`,n==null?void 0:n.key)}return o}}function L(e,t,n,r){return{debug:()=>{var o;return(o=e==null?void 0:e.debugAll)!=null?o:e[t]},key:!1,onChange:r}}function kv(e,t,n,r){var o,i;const l={...e._getDefaultColumnDef(),...t},c=l.accessorKey;let u=(o=(i=l.id)!=null?i:c?c.replace(".","_"):void 0)!=null?o:typeof l.header=="string"?l.header:void 0,f;if(l.accessorFn?f=l.accessorFn:c&&(c.includes(".")?f=p=>{let h=p;for(const m of c.split(".")){var g;h=(g=h)==null?void 0:g[m]}return h}:f=p=>p[l.accessorKey]),!u)throw new Error;let d={id:`${String(u)}`,accessorFn:f,parent:r,depth:n,columnDef:l,columns:[],getFlatColumns:k(()=>[!0],()=>{var p;return[d,...(p=d.columns)==null?void 0:p.flatMap(h=>h.getFlatColumns())]},L(e.options,"debugColumns")),getLeafColumns:k(()=>[e._getOrderColumnsFn()],p=>{var h;if((h=d.columns)!=null&&h.length){let g=d.columns.flatMap(m=>m.getLeafColumns());return p(g)}return[d]},L(e.options,"debugColumns"))};for(const p of e._features)p.createColumn==null||p.createColumn(d,e);return d}const me="debugHeaders";function Aa(e,t,n){var r;let i={id:(r=n.id)!=null?r:t.id,column:t,index:n.index,isPlaceholder:!!n.isPlaceholder,placeholderId:n.placeholderId,depth:n.depth,subHeaders:[],colSpan:0,rowSpan:0,headerGroup:null,getLeafHeaders:()=>{const s=[],l=c=>{c.subHeaders&&c.subHeaders.length&&c.subHeaders.map(l),s.push(c)};return l(i),s},getContext:()=>({table:e,header:i,column:t})};return e._features.forEach(s=>{s.createHeader==null||s.createHeader(i,e)}),i}const Lv={createTable:e=>{e.getHeaderGroups=k(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.left,e.getState().columnPinning.right],(t,n,r,o)=>{var i,s;const l=(i=r==null?void 0:r.map(d=>n.find(p=>p.id===d)).filter(Boolean))!=null?i:[],c=(s=o==null?void 0:o.map(d=>n.find(p=>p.id===d)).filter(Boolean))!=null?s:[],u=n.filter(d=>!(r!=null&&r.includes(d.id))&&!(o!=null&&o.includes(d.id)));return Jn(t,[...l,...u,...c],e)},L(e.options,me)),e.getCenterHeaderGroups=k(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.left,e.getState().columnPinning.right],(t,n,r,o)=>(n=n.filter(i=>!(r!=null&&r.includes(i.id))&&!(o!=null&&o.includes(i.id))),Jn(t,n,e,"center")),L(e.options,me)),e.getLeftHeaderGroups=k(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.left],(t,n,r)=>{var o;const i=(o=r==null?void 0:r.map(s=>n.find(l=>l.id===s)).filter(Boolean))!=null?o:[];return Jn(t,i,e,"left")},L(e.options,me)),e.getRightHeaderGroups=k(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.right],(t,n,r)=>{var o;const i=(o=r==null?void 0:r.map(s=>n.find(l=>l.id===s)).filter(Boolean))!=null?o:[];return Jn(t,i,e,"right")},L(e.options,me)),e.getFooterGroups=k(()=>[e.getHeaderGroups()],t=>[...t].reverse(),L(e.options,me)),e.getLeftFooterGroups=k(()=>[e.getLeftHeaderGroups()],t=>[...t].reverse(),L(e.options,me)),e.getCenterFooterGroups=k(()=>[e.getCenterHeaderGroups()],t=>[...t].reverse(),L(e.options,me)),e.getRightFooterGroups=k(()=>[e.getRightHeaderGroups()],t=>[...t].reverse(),L(e.options,me)),e.getFlatHeaders=k(()=>[e.getHeaderGroups()],t=>t.map(n=>n.headers).flat(),L(e.options,me)),e.getLeftFlatHeaders=k(()=>[e.getLeftHeaderGroups()],t=>t.map(n=>n.headers).flat(),L(e.options,me)),e.getCenterFlatHeaders=k(()=>[e.getCenterHeaderGroups()],t=>t.map(n=>n.headers).flat(),L(e.options,me)),e.getRightFlatHeaders=k(()=>[e.getRightHeaderGroups()],t=>t.map(n=>n.headers).flat(),L(e.options,me)),e.getCenterLeafHeaders=k(()=>[e.getCenterFlatHeaders()],t=>t.filter(n=>{var r;return!((r=n.subHeaders)!=null&&r.length)}),L(e.options,me)),e.getLeftLeafHeaders=k(()=>[e.getLeftFlatHeaders()],t=>t.filter(n=>{var r;return!((r=n.subHeaders)!=null&&r.length)}),L(e.options,me)),e.getRightLeafHeaders=k(()=>[e.getRightFlatHeaders()],t=>t.filter(n=>{var r;return!((r=n.subHeaders)!=null&&r.length)}),L(e.options,me)),e.getLeafHeaders=k(()=>[e.getLeftHeaderGroups(),e.getCenterHeaderGroups(),e.getRightHeaderGroups()],(t,n,r)=>{var o,i,s,l,c,u;return[...(o=(i=t[0])==null?void 0:i.headers)!=null?o:[],...(s=(l=n[0])==null?void 0:l.headers)!=null?s:[],...(c=(u=r[0])==null?void 0:u.headers)!=null?c:[]].map(f=>f.getLeafHeaders()).flat()},L(e.options,me))}};function Jn(e,t,n,r){var o,i;let s=0;const l=function(p,h){h===void 0&&(h=1),s=Math.max(s,h),p.filter(g=>g.getIsVisible()).forEach(g=>{var m;(m=g.columns)!=null&&m.length&&l(g.columns,h+1)},0)};l(e);let c=[];const u=(p,h)=>{const g={depth:h,id:[r,`${h}`].filter(Boolean).join("_"),headers:[]},m=[];p.forEach(v=>{const y=[...m].reverse()[0],b=v.column.depth===g.depth;let w,S=!1;if(b&&v.column.parent?w=v.column.parent:(w=v.column,S=!0),y&&(y==null?void 0:y.column)===w)y.subHeaders.push(v);else{const F=Aa(n,w,{id:[r,h,w.id,v==null?void 0:v.id].filter(Boolean).join("_"),isPlaceholder:S,placeholderId:S?`${m.filter(C=>C.column===w).length}`:void 0,depth:h,index:m.length});F.subHeaders.push(v),m.push(F)}g.headers.push(v),v.headerGroup=g}),c.push(g),h>0&&u(m,h-1)},f=t.map((p,h)=>Aa(n,p,{depth:s,index:h}));u(f,s-1),c.reverse();const d=p=>p.filter(g=>g.column.getIsVisible()).map(g=>{let m=0,v=0,y=[0];g.subHeaders&&g.subHeaders.length?(y=[],d(g.subHeaders).forEach(w=>{let{colSpan:S,rowSpan:F}=w;m+=S,y.push(F)})):m=1;const b=Math.min(...y);return v=v+b,g.colSpan=m,g.rowSpan=v,{colSpan:m,rowSpan:v}});return d((o=(i=c[0])==null?void 0:i.headers)!=null?o:[]),c}const Zn={size:150,minSize:20,maxSize:Number.MAX_SAFE_INTEGER},_o=()=>({startOffset:null,startSize:null,deltaOffset:null,deltaPercentage:null,isResizingColumn:!1,columnSizingStart:[]}),Mv={getDefaultColumnDef:()=>Zn,getInitialState:e=>({columnSizing:{},columnSizingInfo:_o(),...e}),getDefaultOptions:e=>({columnResizeMode:"onEnd",columnResizeDirection:"ltr",onColumnSizingChange:Oe("columnSizing",e),onColumnSizingInfoChange:Oe("columnSizingInfo",e)}),createColumn:(e,t)=>{e.getSize=()=>{var n,r,o;const i=t.getState().columnSizing[e.id];return Math.min(Math.max((n=e.columnDef.minSize)!=null?n:Zn.minSize,(r=i??e.columnDef.size)!=null?r:Zn.size),(o=e.columnDef.maxSize)!=null?o:Zn.maxSize)},e.getStart=k(n=>[n,On(t,n),t.getState().columnSizing],(n,r)=>r.slice(0,e.getIndex(n)).reduce((o,i)=>o+i.getSize(),0),L(t.options,"debugColumns")),e.getAfter=k(n=>[n,On(t,n),t.getState().columnSizing],(n,r)=>r.slice(e.getIndex(n)+1).reduce((o,i)=>o+i.getSize(),0),L(t.options,"debugColumns")),e.resetSize=()=>{t.setColumnSizing(n=>{let{[e.id]:r,...o}=n;return o})},e.getCanResize=()=>{var n,r;return((n=e.columnDef.enableResizing)!=null?n:!0)&&((r=t.options.enableColumnResizing)!=null?r:!0)},e.getIsResizing=()=>t.getState().columnSizingInfo.isResizingColumn===e.id},createHeader:(e,t)=>{e.getSize=()=>{let n=0;const r=o=>{if(o.subHeaders.length)o.subHeaders.forEach(r);else{var i;n+=(i=o.column.getSize())!=null?i:0}};return r(e),n},e.getStart=()=>{if(e.index>0){const n=e.headerGroup.headers[e.index-1];return n.getStart()+n.getSize()}return 0},e.getResizeHandler=n=>{const r=t.getColumn(e.column.id),o=r==null?void 0:r.getCanResize();return i=>{if(!r||!o||(i.persist==null||i.persist(),$o(i)&&i.touches&&i.touches.length>1))return;const s=e.getSize(),l=e?e.getLeafHeaders().map(y=>[y.column.id,y.column.getSize()]):[[r.id,r.getSize()]],c=$o(i)?Math.round(i.touches[0].clientX):i.clientX,u={},f=(y,b)=>{typeof b=="number"&&(t.setColumnSizingInfo(w=>{var S,F;const C=t.options.columnResizeDirection==="rtl"?-1:1,A=(b-((S=w==null?void 0:w.startOffset)!=null?S:0))*C,O=Math.max(A/((F=w==null?void 0:w.startSize)!=null?F:0),-.999999);return w.columnSizingStart.forEach(T=>{let[N,E]=T;u[N]=Math.round(Math.max(E+E*O,0)*100)/100}),{...w,deltaOffset:A,deltaPercentage:O}}),(t.options.columnResizeMode==="onChange"||y==="end")&&t.setColumnSizing(w=>({...w,...u})))},d=y=>f("move",y),p=y=>{f("end",y),t.setColumnSizingInfo(b=>({...b,isResizingColumn:!1,startOffset:null,startSize:null,deltaOffset:null,deltaPercentage:null,columnSizingStart:[]}))},h=n||typeof document<"u"?document:null,g={moveHandler:y=>d(y.clientX),upHandler:y=>{h==null||h.removeEventListener("mousemove",g.moveHandler),h==null||h.removeEventListener("mouseup",g.upHandler),p(y.clientX)}},m={moveHandler:y=>(y.cancelable&&(y.preventDefault(),y.stopPropagation()),d(y.touches[0].clientX),!1),upHandler:y=>{var b;h==null||h.removeEventListener("touchmove",m.moveHandler),h==null||h.removeEventListener("touchend",m.upHandler),y.cancelable&&(y.preventDefault(),y.stopPropagation()),p((b=y.touches[0])==null?void 0:b.clientX)}},v=Uv()?{passive:!1}:!1;$o(i)?(h==null||h.addEventListener("touchmove",m.moveHandler,v),h==null||h.addEventListener("touchend",m.upHandler,v)):(h==null||h.addEventListener("mousemove",g.moveHandler,v),h==null||h.addEventListener("mouseup",g.upHandler,v)),t.setColumnSizingInfo(y=>({...y,startOffset:c,startSize:s,deltaOffset:0,deltaPercentage:0,columnSizingStart:l,isResizingColumn:r.id}))}}},createTable:e=>{e.setColumnSizing=t=>e.options.onColumnSizingChange==null?void 0:e.options.onColumnSizingChange(t),e.setColumnSizingInfo=t=>e.options.onColumnSizingInfoChange==null?void 0:e.options.onColumnSizingInfoChange(t),e.resetColumnSizing=t=>{var n;e.setColumnSizing(t?{}:(n=e.initialState.columnSizing)!=null?n:{})},e.resetHeaderSizeInfo=t=>{var n;e.setColumnSizingInfo(t?_o():(n=e.initialState.columnSizingInfo)!=null?n:_o())},e.getTotalSize=()=>{var t,n;return(t=(n=e.getHeaderGroups()[0])==null?void 0:n.headers.reduce((r,o)=>r+o.getSize(),0))!=null?t:0},e.getLeftTotalSize=()=>{var t,n;return(t=(n=e.getLeftHeaderGroups()[0])==null?void 0:n.headers.reduce((r,o)=>r+o.getSize(),0))!=null?t:0},e.getCenterTotalSize=()=>{var t,n;return(t=(n=e.getCenterHeaderGroups()[0])==null?void 0:n.headers.reduce((r,o)=>r+o.getSize(),0))!=null?t:0},e.getRightTotalSize=()=>{var t,n;return(t=(n=e.getRightHeaderGroups()[0])==null?void 0:n.headers.reduce((r,o)=>r+o.getSize(),0))!=null?t:0}}};let Xn=null;function Uv(){if(typeof Xn=="boolean")return Xn;let e=!1;try{const t={get passive(){return e=!0,!1}},n=()=>{};window.addEventListener("test",n,t),window.removeEventListener("test",n)}catch{e=!1}return Xn=e,Xn}function $o(e){return e.type==="touchstart"}const Vv={getInitialState:e=>({expanded:{},...e}),getDefaultOptions:e=>({onExpandedChange:Oe("expanded",e),paginateExpandedRows:!0}),createTable:e=>{let t=!1,n=!1;e._autoResetExpanded=()=>{var r,o;if(!t){e._queue(()=>{t=!0});return}if((r=(o=e.options.autoResetAll)!=null?o:e.options.autoResetExpanded)!=null?r:!e.options.manualExpanding){if(n)return;n=!0,e._queue(()=>{e.resetExpanded(),n=!1})}},e.setExpanded=r=>e.options.onExpandedChange==null?void 0:e.options.onExpandedChange(r),e.toggleAllRowsExpanded=r=>{r??!e.getIsAllRowsExpanded()?e.setExpanded(!0):e.setExpanded({})},e.resetExpanded=r=>{var o,i;e.setExpanded(r?{}:(o=(i=e.initialState)==null?void 0:i.expanded)!=null?o:{})},e.getCanSomeRowsExpand=()=>e.getPrePaginationRowModel().flatRows.some(r=>r.getCanExpand()),e.getToggleAllRowsExpandedHandler=()=>r=>{r.persist==null||r.persist(),e.toggleAllRowsExpanded()},e.getIsSomeRowsExpanded=()=>{const r=e.getState().expanded;return r===!0||Object.values(r).some(Boolean)},e.getIsAllRowsExpanded=()=>{const r=e.getState().expanded;return typeof r=="boolean"?r===!0:!(!Object.keys(r).length||e.getRowModel().flatRows.some(o=>!o.getIsExpanded()))},e.getExpandedDepth=()=>{let r=0;return(e.getState().expanded===!0?Object.keys(e.getRowModel().rowsById):Object.keys(e.getState().expanded)).forEach(i=>{const s=i.split(".");r=Math.max(r,s.length)}),r},e.getPreExpandedRowModel=()=>e.getSortedRowModel(),e.getExpandedRowModel=()=>(!e._getExpandedRowModel&&e.options.getExpandedRowModel&&(e._getExpandedRowModel=e.options.getExpandedRowModel(e)),e.options.manualExpanding||!e._getExpandedRowModel?e.getPreExpandedRowModel():e._getExpandedRowModel())},createRow:(e,t)=>{e.toggleExpanded=n=>{t.setExpanded(r=>{var o;const i=r===!0?!0:!!(r!=null&&r[e.id]);let s={};if(r===!0?Object.keys(t.getRowModel().rowsById).forEach(l=>{s[l]=!0}):s=r,n=(o=n)!=null?o:!i,!i&&n)return{...s,[e.id]:!0};if(i&&!n){const{[e.id]:l,...c}=s;return c}return r})},e.getIsExpanded=()=>{var n;const r=t.getState().expanded;return!!((n=t.options.getIsRowExpanded==null?void 0:t.options.getIsRowExpanded(e))!=null?n:r===!0||r!=null&&r[e.id])},e.getCanExpand=()=>{var n,r,o;return(n=t.options.getRowCanExpand==null?void 0:t.options.getRowCanExpand(e))!=null?n:((r=t.options.enableExpanding)!=null?r:!0)&&!!((o=e.subRows)!=null&&o.length)},e.getIsAllParentsExpanded=()=>{let n=!0,r=e;for(;n&&r.parentId;)r=t.getRow(r.parentId,!0),n=r.getIsExpanded();return n},e.getToggleExpandedHandler=()=>{const n=e.getCanExpand();return()=>{n&&e.toggleExpanded()}}}},Wf=(e,t,n)=>{var r;const o=n.toLowerCase();return!!(!((r=e.getValue(t))==null||(r=r.toString())==null||(r=r.toLowerCase())==null)&&r.includes(o))};Wf.autoRemove=e=>Le(e);const zf=(e,t,n)=>{var r;return!!(!((r=e.getValue(t))==null||(r=r.toString())==null)&&r.includes(n))};zf.autoRemove=e=>Le(e);const Qf=(e,t,n)=>{var r;return((r=e.getValue(t))==null||(r=r.toString())==null?void 0:r.toLowerCase())===(n==null?void 0:n.toLowerCase())};Qf.autoRemove=e=>Le(e);const qf=(e,t,n)=>{var r;return(r=e.getValue(t))==null?void 0:r.includes(n)};qf.autoRemove=e=>Le(e)||!(e!=null&&e.length);const Kf=(e,t,n)=>!n.some(r=>{var o;return!((o=e.getValue(t))!=null&&o.includes(r))});Kf.autoRemove=e=>Le(e)||!(e!=null&&e.length);const Yf=(e,t,n)=>n.some(r=>{var o;return(o=e.getValue(t))==null?void 0:o.includes(r)});Yf.autoRemove=e=>Le(e)||!(e!=null&&e.length);const Jf=(e,t,n)=>e.getValue(t)===n;Jf.autoRemove=e=>Le(e);const Zf=(e,t,n)=>e.getValue(t)==n;Zf.autoRemove=e=>Le(e);const Os=(e,t,n)=>{let[r,o]=n;const i=e.getValue(t);return i>=r&&i<=o};Os.resolveFilterValue=e=>{let[t,n]=e,r=typeof t!="number"?parseFloat(t):t,o=typeof n!="number"?parseFloat(n):n,i=t===null||Number.isNaN(r)?-1/0:r,s=n===null||Number.isNaN(o)?1/0:o;if(i>s){const l=i;i=s,s=l}return[i,s]};Os.autoRemove=e=>Le(e)||Le(e[0])&&Le(e[1]);const Xe={includesString:Wf,includesStringSensitive:zf,equalsString:Qf,arrIncludes:qf,arrIncludesAll:Kf,arrIncludesSome:Yf,equals:Jf,weakEquals:Zf,inNumberRange:Os};function Le(e){return e==null||e===""}const Hv={getDefaultColumnDef:()=>({filterFn:"auto"}),getInitialState:e=>({columnFilters:[],globalFilter:void 0,...e}),getDefaultOptions:e=>({onColumnFiltersChange:Oe("columnFilters",e),onGlobalFilterChange:Oe("globalFilter",e),filterFromLeafRows:!1,maxLeafRowFilterDepth:100,globalFilterFn:"auto",getColumnCanGlobalFilter:t=>{var n;const r=(n=e.getCoreRowModel().flatRows[0])==null||(n=n._getAllCellsByColumnId()[t.id])==null?void 0:n.getValue();return typeof r=="string"||typeof r=="number"}}),createColumn:(e,t)=>{e.getAutoFilterFn=()=>{const n=t.getCoreRowModel().flatRows[0],r=n==null?void 0:n.getValue(e.id);return typeof r=="string"?Xe.includesString:typeof r=="number"?Xe.inNumberRange:typeof r=="boolean"||r!==null&&typeof r=="object"?Xe.equals:Array.isArray(r)?Xe.arrIncludes:Xe.weakEquals},e.getFilterFn=()=>{var n,r;return Nr(e.columnDef.filterFn)?e.columnDef.filterFn:e.columnDef.filterFn==="auto"?e.getAutoFilterFn():(n=(r=t.options.filterFns)==null?void 0:r[e.columnDef.filterFn])!=null?n:Xe[e.columnDef.filterFn]},e.getCanFilter=()=>{var n,r,o;return((n=e.columnDef.enableColumnFilter)!=null?n:!0)&&((r=t.options.enableColumnFilters)!=null?r:!0)&&((o=t.options.enableFilters)!=null?o:!0)&&!!e.accessorFn},e.getCanGlobalFilter=()=>{var n,r,o,i;return((n=e.columnDef.enableGlobalFilter)!=null?n:!0)&&((r=t.options.enableGlobalFilter)!=null?r:!0)&&((o=t.options.enableFilters)!=null?o:!0)&&((i=t.options.getColumnCanGlobalFilter==null?void 0:t.options.getColumnCanGlobalFilter(e))!=null?i:!0)&&!!e.accessorFn},e.getIsFiltered=()=>e.getFilterIndex()>-1,e.getFilterValue=()=>{var n;return(n=t.getState().columnFilters)==null||(n=n.find(r=>r.id===e.id))==null?void 0:n.value},e.getFilterIndex=()=>{var n,r;return(n=(r=t.getState().columnFilters)==null?void 0:r.findIndex(o=>o.id===e.id))!=null?n:-1},e.setFilterValue=n=>{t.setColumnFilters(r=>{const o=e.getFilterFn(),i=r==null?void 0:r.find(f=>f.id===e.id),s=yt(n,i?i.value:void 0);if(ja(o,s,e)){var l;return(l=r==null?void 0:r.filter(f=>f.id!==e.id))!=null?l:[]}const c={id:e.id,value:s};if(i){var u;return(u=r==null?void 0:r.map(f=>f.id===e.id?c:f))!=null?u:[]}return r!=null&&r.length?[...r,c]:[c]})},e._getFacetedRowModel=t.options.getFacetedRowModel&&t.options.getFacetedRowModel(t,e.id),e.getFacetedRowModel=()=>e._getFacetedRowModel?e._getFacetedRowModel():t.getPreFilteredRowModel(),e._getFacetedUniqueValues=t.options.getFacetedUniqueValues&&t.options.getFacetedUniqueValues(t,e.id),e.getFacetedUniqueValues=()=>e._getFacetedUniqueValues?e._getFacetedUniqueValues():new Map,e._getFacetedMinMaxValues=t.options.getFacetedMinMaxValues&&t.options.getFacetedMinMaxValues(t,e.id),e.getFacetedMinMaxValues=()=>{if(e._getFacetedMinMaxValues)return e._getFacetedMinMaxValues()}},createRow:(e,t)=>{e.columnFilters={},e.columnFiltersMeta={}},createTable:e=>{e.getGlobalAutoFilterFn=()=>Xe.includesString,e.getGlobalFilterFn=()=>{var t,n;const{globalFilterFn:r}=e.options;return Nr(r)?r:r==="auto"?e.getGlobalAutoFilterFn():(t=(n=e.options.filterFns)==null?void 0:n[r])!=null?t:Xe[r]},e.setColumnFilters=t=>{const n=e.getAllLeafColumns(),r=o=>{var i;return(i=yt(t,o))==null?void 0:i.filter(s=>{const l=n.find(c=>c.id===s.id);if(l){const c=l.getFilterFn();if(ja(c,s.value,l))return!1}return!0})};e.options.onColumnFiltersChange==null||e.options.onColumnFiltersChange(r)},e.setGlobalFilter=t=>{e.options.onGlobalFilterChange==null||e.options.onGlobalFilterChange(t)},e.resetGlobalFilter=t=>{e.setGlobalFilter(t?void 0:e.initialState.globalFilter)},e.resetColumnFilters=t=>{var n,r;e.setColumnFilters(t?[]:(n=(r=e.initialState)==null?void 0:r.columnFilters)!=null?n:[])},e.getPreFilteredRowModel=()=>e.getCoreRowModel(),e.getFilteredRowModel=()=>(!e._getFilteredRowModel&&e.options.getFilteredRowModel&&(e._getFilteredRowModel=e.options.getFilteredRowModel(e)),e.options.manualFiltering||!e._getFilteredRowModel?e.getPreFilteredRowModel():e._getFilteredRowModel()),e._getGlobalFacetedRowModel=e.options.getFacetedRowModel&&e.options.getFacetedRowModel(e,"__global__"),e.getGlobalFacetedRowModel=()=>e.options.manualFiltering||!e._getGlobalFacetedRowModel?e.getPreFilteredRowModel():e._getGlobalFacetedRowModel(),e._getGlobalFacetedUniqueValues=e.options.getFacetedUniqueValues&&e.options.getFacetedUniqueValues(e,"__global__"),e.getGlobalFacetedUniqueValues=()=>e._getGlobalFacetedUniqueValues?e._getGlobalFacetedUniqueValues():new Map,e._getGlobalFacetedMinMaxValues=e.options.getFacetedMinMaxValues&&e.options.getFacetedMinMaxValues(e,"__global__"),e.getGlobalFacetedMinMaxValues=()=>{if(e._getGlobalFacetedMinMaxValues)return e._getGlobalFacetedMinMaxValues()}}};function ja(e,t,n){return(e&&e.autoRemove?e.autoRemove(t,n):!1)||typeof t>"u"||typeof t=="string"&&!t}const Gv=(e,t,n)=>n.reduce((r,o)=>{const i=o.getValue(e);return r+(typeof i=="number"?i:0)},0),Wv=(e,t,n)=>{let r;return n.forEach(o=>{const i=o.getValue(e);i!=null&&(r>i||r===void 0&&i>=i)&&(r=i)}),r},zv=(e,t,n)=>{let r;return n.forEach(o=>{const i=o.getValue(e);i!=null&&(r<i||r===void 0&&i>=i)&&(r=i)}),r},Qv=(e,t,n)=>{let r,o;return n.forEach(i=>{const s=i.getValue(e);s!=null&&(r===void 0?s>=s&&(r=o=s):(r>s&&(r=s),o<s&&(o=s)))}),[r,o]},qv=(e,t)=>{let n=0,r=0;if(t.forEach(o=>{let i=o.getValue(e);i!=null&&(i=+i)>=i&&(++n,r+=i)}),n)return r/n},Kv=(e,t)=>{if(!t.length)return;const n=t.map(i=>i.getValue(e));if(!Bv(n))return;if(n.length===1)return n[0];const r=Math.floor(n.length/2),o=n.sort((i,s)=>i-s);return n.length%2!==0?o[r]:(o[r-1]+o[r])/2},Yv=(e,t)=>Array.from(new Set(t.map(n=>n.getValue(e))).values()),Jv=(e,t)=>new Set(t.map(n=>n.getValue(e))).size,Zv=(e,t)=>t.length,Bo={sum:Gv,min:Wv,max:zv,extent:Qv,mean:qv,median:Kv,unique:Yv,uniqueCount:Jv,count:Zv},Xv={getDefaultColumnDef:()=>({aggregatedCell:e=>{var t,n;return(t=(n=e.getValue())==null||n.toString==null?void 0:n.toString())!=null?t:null},aggregationFn:"auto"}),getInitialState:e=>({grouping:[],...e}),getDefaultOptions:e=>({onGroupingChange:Oe("grouping",e),groupedColumnMode:"reorder"}),createColumn:(e,t)=>{e.toggleGrouping=()=>{t.setGrouping(n=>n!=null&&n.includes(e.id)?n.filter(r=>r!==e.id):[...n??[],e.id])},e.getCanGroup=()=>{var n,r,o,i;return(n=(r=(o=(i=e.columnDef.enableGrouping)!=null?i:!0)!=null?o:t.options.enableGrouping)!=null?r:!0)!=null?n:!!e.accessorFn},e.getIsGrouped=()=>{var n;return(n=t.getState().grouping)==null?void 0:n.includes(e.id)},e.getGroupedIndex=()=>{var n;return(n=t.getState().grouping)==null?void 0:n.indexOf(e.id)},e.getToggleGroupingHandler=()=>{const n=e.getCanGroup();return()=>{n&&e.toggleGrouping()}},e.getAutoAggregationFn=()=>{const n=t.getCoreRowModel().flatRows[0],r=n==null?void 0:n.getValue(e.id);if(typeof r=="number")return Bo.sum;if(Object.prototype.toString.call(r)==="[object Date]")return Bo.extent},e.getAggregationFn=()=>{var n,r;if(!e)throw new Error;return Nr(e.columnDef.aggregationFn)?e.columnDef.aggregationFn:e.columnDef.aggregationFn==="auto"?e.getAutoAggregationFn():(n=(r=t.options.aggregationFns)==null?void 0:r[e.columnDef.aggregationFn])!=null?n:Bo[e.columnDef.aggregationFn]}},createTable:e=>{e.setGrouping=t=>e.options.onGroupingChange==null?void 0:e.options.onGroupingChange(t),e.resetGrouping=t=>{var n,r;e.setGrouping(t?[]:(n=(r=e.initialState)==null?void 0:r.grouping)!=null?n:[])},e.getPreGroupedRowModel=()=>e.getFilteredRowModel(),e.getGroupedRowModel=()=>(!e._getGroupedRowModel&&e.options.getGroupedRowModel&&(e._getGroupedRowModel=e.options.getGroupedRowModel(e)),e.options.manualGrouping||!e._getGroupedRowModel?e.getPreGroupedRowModel():e._getGroupedRowModel())},createRow:(e,t)=>{e.getIsGrouped=()=>!!e.groupingColumnId,e.getGroupingValue=n=>{if(e._groupingValuesCache.hasOwnProperty(n))return e._groupingValuesCache[n];const r=t.getColumn(n);return r!=null&&r.columnDef.getGroupingValue?(e._groupingValuesCache[n]=r.columnDef.getGroupingValue(e.original),e._groupingValuesCache[n]):e.getValue(n)},e._groupingValuesCache={}},createCell:(e,t,n,r)=>{e.getIsGrouped=()=>t.getIsGrouped()&&t.id===n.groupingColumnId,e.getIsPlaceholder=()=>!e.getIsGrouped()&&t.getIsGrouped(),e.getIsAggregated=()=>{var o;return!e.getIsGrouped()&&!e.getIsPlaceholder()&&!!((o=n.subRows)!=null&&o.length)}}};function ey(e,t,n){if(!(t!=null&&t.length)||!n)return e;const r=e.filter(i=>!t.includes(i.id));return n==="remove"?r:[...t.map(i=>e.find(s=>s.id===i)).filter(Boolean),...r]}const ty={getInitialState:e=>({columnOrder:[],...e}),getDefaultOptions:e=>({onColumnOrderChange:Oe("columnOrder",e)}),createColumn:(e,t)=>{e.getIndex=k(n=>[On(t,n)],n=>n.findIndex(r=>r.id===e.id),L(t.options,"debugColumns")),e.getIsFirstColumn=n=>{var r;return((r=On(t,n)[0])==null?void 0:r.id)===e.id},e.getIsLastColumn=n=>{var r;const o=On(t,n);return((r=o[o.length-1])==null?void 0:r.id)===e.id}},createTable:e=>{e.setColumnOrder=t=>e.options.onColumnOrderChange==null?void 0:e.options.onColumnOrderChange(t),e.resetColumnOrder=t=>{var n;e.setColumnOrder(t?[]:(n=e.initialState.columnOrder)!=null?n:[])},e._getOrderColumnsFn=k(()=>[e.getState().columnOrder,e.getState().grouping,e.options.groupedColumnMode],(t,n,r)=>o=>{let i=[];if(!(t!=null&&t.length))i=o;else{const s=[...t],l=[...o];for(;l.length&&s.length;){const c=s.shift(),u=l.findIndex(f=>f.id===c);u>-1&&i.push(l.splice(u,1)[0])}i=[...i,...l]}return ey(i,n,r)},L(e.options,"debugTable"))}},ji=0,Ri=10,Po=()=>({pageIndex:ji,pageSize:Ri}),ny={getInitialState:e=>({...e,pagination:{...Po(),...e==null?void 0:e.pagination}}),getDefaultOptions:e=>({onPaginationChange:Oe("pagination",e)}),createTable:e=>{let t=!1,n=!1;e._autoResetPageIndex=()=>{var r,o;if(!t){e._queue(()=>{t=!0});return}if((r=(o=e.options.autoResetAll)!=null?o:e.options.autoResetPageIndex)!=null?r:!e.options.manualPagination){if(n)return;n=!0,e._queue(()=>{e.resetPageIndex(),n=!1})}},e.setPagination=r=>{const o=i=>yt(r,i);return e.options.onPaginationChange==null?void 0:e.options.onPaginationChange(o)},e.resetPagination=r=>{var o;e.setPagination(r?Po():(o=e.initialState.pagination)!=null?o:Po())},e.setPageIndex=r=>{e.setPagination(o=>{let i=yt(r,o.pageIndex);const s=typeof e.options.pageCount>"u"||e.options.pageCount===-1?Number.MAX_SAFE_INTEGER:e.options.pageCount-1;return i=Math.max(0,Math.min(i,s)),{...o,pageIndex:i}})},e.resetPageIndex=r=>{var o,i;e.setPageIndex(r?ji:(o=(i=e.initialState)==null||(i=i.pagination)==null?void 0:i.pageIndex)!=null?o:ji)},e.resetPageSize=r=>{var o,i;e.setPageSize(r?Ri:(o=(i=e.initialState)==null||(i=i.pagination)==null?void 0:i.pageSize)!=null?o:Ri)},e.setPageSize=r=>{e.setPagination(o=>{const i=Math.max(1,yt(r,o.pageSize)),s=o.pageSize*o.pageIndex,l=Math.floor(s/i);return{...o,pageIndex:l,pageSize:i}})},e.setPageCount=r=>e.setPagination(o=>{var i;let s=yt(r,(i=e.options.pageCount)!=null?i:-1);return typeof s=="number"&&(s=Math.max(-1,s)),{...o,pageCount:s}}),e.getPageOptions=k(()=>[e.getPageCount()],r=>{let o=[];return r&&r>0&&(o=[...new Array(r)].fill(null).map((i,s)=>s)),o},L(e.options,"debugTable")),e.getCanPreviousPage=()=>e.getState().pagination.pageIndex>0,e.getCanNextPage=()=>{const{pageIndex:r}=e.getState().pagination,o=e.getPageCount();return o===-1?!0:o===0?!1:r<o-1},e.previousPage=()=>e.setPageIndex(r=>r-1),e.nextPage=()=>e.setPageIndex(r=>r+1),e.getPrePaginationRowModel=()=>e.getExpandedRowModel(),e.getPaginationRowModel=()=>(!e._getPaginationRowModel&&e.options.getPaginationRowModel&&(e._getPaginationRowModel=e.options.getPaginationRowModel(e)),e.options.manualPagination||!e._getPaginationRowModel?e.getPrePaginationRowModel():e._getPaginationRowModel()),e.getPageCount=()=>{var r;return(r=e.options.pageCount)!=null?r:Math.ceil(e.getPrePaginationRowModel().rows.length/e.getState().pagination.pageSize)}}},ko=()=>({left:[],right:[]}),Lo=()=>({top:[],bottom:[]}),ry={getInitialState:e=>({columnPinning:ko(),rowPinning:Lo(),...e}),getDefaultOptions:e=>({onColumnPinningChange:Oe("columnPinning",e),onRowPinningChange:Oe("rowPinning",e)}),createColumn:(e,t)=>{e.pin=n=>{const r=e.getLeafColumns().map(o=>o.id).filter(Boolean);t.setColumnPinning(o=>{var i,s;if(n==="right"){var l,c;return{left:((l=o==null?void 0:o.left)!=null?l:[]).filter(d=>!(r!=null&&r.includes(d))),right:[...((c=o==null?void 0:o.right)!=null?c:[]).filter(d=>!(r!=null&&r.includes(d))),...r]}}if(n==="left"){var u,f;return{left:[...((u=o==null?void 0:o.left)!=null?u:[]).filter(d=>!(r!=null&&r.includes(d))),...r],right:((f=o==null?void 0:o.right)!=null?f:[]).filter(d=>!(r!=null&&r.includes(d)))}}return{left:((i=o==null?void 0:o.left)!=null?i:[]).filter(d=>!(r!=null&&r.includes(d))),right:((s=o==null?void 0:o.right)!=null?s:[]).filter(d=>!(r!=null&&r.includes(d)))}})},e.getCanPin=()=>e.getLeafColumns().some(r=>{var o,i,s;return((o=r.columnDef.enablePinning)!=null?o:!0)&&((i=(s=t.options.enableColumnPinning)!=null?s:t.options.enablePinning)!=null?i:!0)}),e.getIsPinned=()=>{const n=e.getLeafColumns().map(l=>l.id),{left:r,right:o}=t.getState().columnPinning,i=n.some(l=>r==null?void 0:r.includes(l)),s=n.some(l=>o==null?void 0:o.includes(l));return i?"left":s?"right":!1},e.getPinnedIndex=()=>{var n,r;const o=e.getIsPinned();return o?(n=(r=t.getState().columnPinning)==null||(r=r[o])==null?void 0:r.indexOf(e.id))!=null?n:-1:0}},createRow:(e,t)=>{e.pin=(n,r,o)=>{const i=r?e.getLeafRows().map(c=>{let{id:u}=c;return u}):[],s=o?e.getParentRows().map(c=>{let{id:u}=c;return u}):[],l=new Set([...s,e.id,...i]);t.setRowPinning(c=>{var u,f;if(n==="bottom"){var d,p;return{top:((d=c==null?void 0:c.top)!=null?d:[]).filter(m=>!(l!=null&&l.has(m))),bottom:[...((p=c==null?void 0:c.bottom)!=null?p:[]).filter(m=>!(l!=null&&l.has(m))),...Array.from(l)]}}if(n==="top"){var h,g;return{top:[...((h=c==null?void 0:c.top)!=null?h:[]).filter(m=>!(l!=null&&l.has(m))),...Array.from(l)],bottom:((g=c==null?void 0:c.bottom)!=null?g:[]).filter(m=>!(l!=null&&l.has(m)))}}return{top:((u=c==null?void 0:c.top)!=null?u:[]).filter(m=>!(l!=null&&l.has(m))),bottom:((f=c==null?void 0:c.bottom)!=null?f:[]).filter(m=>!(l!=null&&l.has(m)))}})},e.getCanPin=()=>{var n;const{enableRowPinning:r,enablePinning:o}=t.options;return typeof r=="function"?r(e):(n=r??o)!=null?n:!0},e.getIsPinned=()=>{const n=[e.id],{top:r,bottom:o}=t.getState().rowPinning,i=n.some(l=>r==null?void 0:r.includes(l)),s=n.some(l=>o==null?void 0:o.includes(l));return i?"top":s?"bottom":!1},e.getPinnedIndex=()=>{var n,r;const o=e.getIsPinned();if(!o)return-1;const i=(n=t._getPinnedRows(o))==null?void 0:n.map(s=>{let{id:l}=s;return l});return(r=i==null?void 0:i.indexOf(e.id))!=null?r:-1},e.getCenterVisibleCells=k(()=>[e._getAllVisibleCells(),t.getState().columnPinning.left,t.getState().columnPinning.right],(n,r,o)=>{const i=[...r??[],...o??[]];return n.filter(s=>!i.includes(s.column.id))},L(t.options,"debugRows")),e.getLeftVisibleCells=k(()=>[e._getAllVisibleCells(),t.getState().columnPinning.left,,],(n,r)=>(r??[]).map(i=>n.find(s=>s.column.id===i)).filter(Boolean).map(i=>({...i,position:"left"})),L(t.options,"debugRows")),e.getRightVisibleCells=k(()=>[e._getAllVisibleCells(),t.getState().columnPinning.right],(n,r)=>(r??[]).map(i=>n.find(s=>s.column.id===i)).filter(Boolean).map(i=>({...i,position:"right"})),L(t.options,"debugRows"))},createTable:e=>{e.setColumnPinning=t=>e.options.onColumnPinningChange==null?void 0:e.options.onColumnPinningChange(t),e.resetColumnPinning=t=>{var n,r;return e.setColumnPinning(t?ko():(n=(r=e.initialState)==null?void 0:r.columnPinning)!=null?n:ko())},e.getIsSomeColumnsPinned=t=>{var n;const r=e.getState().columnPinning;if(!t){var o,i;return!!((o=r.left)!=null&&o.length||(i=r.right)!=null&&i.length)}return!!((n=r[t])!=null&&n.length)},e.getLeftLeafColumns=k(()=>[e.getAllLeafColumns(),e.getState().columnPinning.left],(t,n)=>(n??[]).map(r=>t.find(o=>o.id===r)).filter(Boolean),L(e.options,"debugColumns")),e.getRightLeafColumns=k(()=>[e.getAllLeafColumns(),e.getState().columnPinning.right],(t,n)=>(n??[]).map(r=>t.find(o=>o.id===r)).filter(Boolean),L(e.options,"debugColumns")),e.getCenterLeafColumns=k(()=>[e.getAllLeafColumns(),e.getState().columnPinning.left,e.getState().columnPinning.right],(t,n,r)=>{const o=[...n??[],...r??[]];return t.filter(i=>!o.includes(i.id))},L(e.options,"debugColumns")),e.setRowPinning=t=>e.options.onRowPinningChange==null?void 0:e.options.onRowPinningChange(t),e.resetRowPinning=t=>{var n,r;return e.setRowPinning(t?Lo():(n=(r=e.initialState)==null?void 0:r.rowPinning)!=null?n:Lo())},e.getIsSomeRowsPinned=t=>{var n;const r=e.getState().rowPinning;if(!t){var o,i;return!!((o=r.top)!=null&&o.length||(i=r.bottom)!=null&&i.length)}return!!((n=r[t])!=null&&n.length)},e._getPinnedRows=k(t=>[e.getRowModel().rows,e.getState().rowPinning[t],t],(t,n,r)=>{var o;return((o=e.options.keepPinnedRows)==null||o?(n??[]).map(s=>{const l=e.getRow(s,!0);return l.getIsAllParentsExpanded()?l:null}):(n??[]).map(s=>t.find(l=>l.id===s))).filter(Boolean).map(s=>({...s,position:r}))},L(e.options,"debugRows")),e.getTopRows=()=>e._getPinnedRows("top"),e.getBottomRows=()=>e._getPinnedRows("bottom"),e.getCenterRows=k(()=>[e.getRowModel().rows,e.getState().rowPinning.top,e.getState().rowPinning.bottom],(t,n,r)=>{const o=new Set([...n??[],...r??[]]);return t.filter(i=>!o.has(i.id))},L(e.options,"debugRows"))}},oy={getInitialState:e=>({rowSelection:{},...e}),getDefaultOptions:e=>({onRowSelectionChange:Oe("rowSelection",e),enableRowSelection:!0,enableMultiRowSelection:!0,enableSubRowSelection:!0}),createTable:e=>{e.setRowSelection=t=>e.options.onRowSelectionChange==null?void 0:e.options.onRowSelectionChange(t),e.resetRowSelection=t=>{var n;return e.setRowSelection(t?{}:(n=e.initialState.rowSelection)!=null?n:{})},e.toggleAllRowsSelected=t=>{e.setRowSelection(n=>{t=typeof t<"u"?t:!e.getIsAllRowsSelected();const r={...n},o=e.getPreGroupedRowModel().flatRows;return t?o.forEach(i=>{i.getCanSelect()&&(r[i.id]=!0)}):o.forEach(i=>{delete r[i.id]}),r})},e.toggleAllPageRowsSelected=t=>e.setRowSelection(n=>{const r=typeof t<"u"?t:!e.getIsAllPageRowsSelected(),o={...n};return e.getRowModel().rows.forEach(i=>{Fi(o,i.id,r,!0,e)}),o}),e.getPreSelectedRowModel=()=>e.getCoreRowModel(),e.getSelectedRowModel=k(()=>[e.getState().rowSelection,e.getCoreRowModel()],(t,n)=>Object.keys(t).length?Mo(e,n):{rows:[],flatRows:[],rowsById:{}},L(e.options,"debugTable")),e.getFilteredSelectedRowModel=k(()=>[e.getState().rowSelection,e.getFilteredRowModel()],(t,n)=>Object.keys(t).length?Mo(e,n):{rows:[],flatRows:[],rowsById:{}},L(e.options,"debugTable")),e.getGroupedSelectedRowModel=k(()=>[e.getState().rowSelection,e.getSortedRowModel()],(t,n)=>Object.keys(t).length?Mo(e,n):{rows:[],flatRows:[],rowsById:{}},L(e.options,"debugTable")),e.getIsAllRowsSelected=()=>{const t=e.getFilteredRowModel().flatRows,{rowSelection:n}=e.getState();let r=!!(t.length&&Object.keys(n).length);return r&&t.some(o=>o.getCanSelect()&&!n[o.id])&&(r=!1),r},e.getIsAllPageRowsSelected=()=>{const t=e.getPaginationRowModel().flatRows.filter(o=>o.getCanSelect()),{rowSelection:n}=e.getState();let r=!!t.length;return r&&t.some(o=>!n[o.id])&&(r=!1),r},e.getIsSomeRowsSelected=()=>{var t;const n=Object.keys((t=e.getState().rowSelection)!=null?t:{}).length;return n>0&&n<e.getFilteredRowModel().flatRows.length},e.getIsSomePageRowsSelected=()=>{const t=e.getPaginationRowModel().flatRows;return e.getIsAllPageRowsSelected()?!1:t.filter(n=>n.getCanSelect()).some(n=>n.getIsSelected()||n.getIsSomeSelected())},e.getToggleAllRowsSelectedHandler=()=>t=>{e.toggleAllRowsSelected(t.target.checked)},e.getToggleAllPageRowsSelectedHandler=()=>t=>{e.toggleAllPageRowsSelected(t.target.checked)}},createRow:(e,t)=>{e.toggleSelected=(n,r)=>{const o=e.getIsSelected();t.setRowSelection(i=>{var s;if(n=typeof n<"u"?n:!o,e.getCanSelect()&&o===n)return i;const l={...i};return Fi(l,e.id,n,(s=r==null?void 0:r.selectChildren)!=null?s:!0,t),l})},e.getIsSelected=()=>{const{rowSelection:n}=t.getState();return Es(e,n)},e.getIsSomeSelected=()=>{const{rowSelection:n}=t.getState();return Oi(e,n)==="some"},e.getIsAllSubRowsSelected=()=>{const{rowSelection:n}=t.getState();return Oi(e,n)==="all"},e.getCanSelect=()=>{var n;return typeof t.options.enableRowSelection=="function"?t.options.enableRowSelection(e):(n=t.options.enableRowSelection)!=null?n:!0},e.getCanSelectSubRows=()=>{var n;return typeof t.options.enableSubRowSelection=="function"?t.options.enableSubRowSelection(e):(n=t.options.enableSubRowSelection)!=null?n:!0},e.getCanMultiSelect=()=>{var n;return typeof t.options.enableMultiRowSelection=="function"?t.options.enableMultiRowSelection(e):(n=t.options.enableMultiRowSelection)!=null?n:!0},e.getToggleSelectedHandler=()=>{const n=e.getCanSelect();return r=>{var o;n&&e.toggleSelected((o=r.target)==null?void 0:o.checked)}}}},Fi=(e,t,n,r,o)=>{var i;const s=o.getRow(t,!0);n?(s.getCanMultiSelect()||Object.keys(e).forEach(l=>delete e[l]),s.getCanSelect()&&(e[t]=!0)):delete e[t],r&&(i=s.subRows)!=null&&i.length&&s.getCanSelectSubRows()&&s.subRows.forEach(l=>Fi(e,l.id,n,r,o))};function Mo(e,t){const n=e.getState().rowSelection,r=[],o={},i=function(s,l){return s.map(c=>{var u;const f=Es(c,n);if(f&&(r.push(c),o[c.id]=c),(u=c.subRows)!=null&&u.length&&(c={...c,subRows:i(c.subRows)}),f)return c}).filter(Boolean)};return{rows:i(t.rows),flatRows:r,rowsById:o}}function Es(e,t){var n;return(n=t[e.id])!=null?n:!1}function Oi(e,t,n){var r;if(!((r=e.subRows)!=null&&r.length))return!1;let o=!0,i=!1;return e.subRows.forEach(s=>{if(!(i&&!o)&&(s.getCanSelect()&&(Es(s,t)?i=!0:o=!1),s.subRows&&s.subRows.length)){const l=Oi(s,t);l==="all"?i=!0:(l==="some"&&(i=!0),o=!1)}}),o?"all":i?"some":!1}const Ei=/([0-9]+)/gm,iy=(e,t,n)=>Xf(St(e.getValue(n)).toLowerCase(),St(t.getValue(n)).toLowerCase()),sy=(e,t,n)=>Xf(St(e.getValue(n)),St(t.getValue(n))),ay=(e,t,n)=>Is(St(e.getValue(n)).toLowerCase(),St(t.getValue(n)).toLowerCase()),ly=(e,t,n)=>Is(St(e.getValue(n)),St(t.getValue(n))),cy=(e,t,n)=>{const r=e.getValue(n),o=t.getValue(n);return r>o?1:r<o?-1:0},uy=(e,t,n)=>Is(e.getValue(n),t.getValue(n));function Is(e,t){return e===t?0:e>t?1:-1}function St(e){return typeof e=="number"?isNaN(e)||e===1/0||e===-1/0?"":String(e):typeof e=="string"?e:""}function Xf(e,t){const n=e.split(Ei).filter(Boolean),r=t.split(Ei).filter(Boolean);for(;n.length&&r.length;){const o=n.shift(),i=r.shift(),s=parseInt(o,10),l=parseInt(i,10),c=[s,l].sort();if(isNaN(c[0])){if(o>i)return 1;if(i>o)return-1;continue}if(isNaN(c[1]))return isNaN(s)?-1:1;if(s>l)return 1;if(l>s)return-1}return n.length-r.length}const pn={alphanumeric:iy,alphanumericCaseSensitive:sy,text:ay,textCaseSensitive:ly,datetime:cy,basic:uy},fy={getInitialState:e=>({sorting:[],...e}),getDefaultColumnDef:()=>({sortingFn:"auto",sortUndefined:1}),getDefaultOptions:e=>({onSortingChange:Oe("sorting",e),isMultiSortEvent:t=>t.shiftKey}),createColumn:(e,t)=>{e.getAutoSortingFn=()=>{const n=t.getFilteredRowModel().flatRows.slice(10);let r=!1;for(const o of n){const i=o==null?void 0:o.getValue(e.id);if(Object.prototype.toString.call(i)==="[object Date]")return pn.datetime;if(typeof i=="string"&&(r=!0,i.split(Ei).length>1))return pn.alphanumeric}return r?pn.text:pn.basic},e.getAutoSortDir=()=>{const n=t.getFilteredRowModel().flatRows[0];return typeof(n==null?void 0:n.getValue(e.id))=="string"?"asc":"desc"},e.getSortingFn=()=>{var n,r;if(!e)throw new Error;return Nr(e.columnDef.sortingFn)?e.columnDef.sortingFn:e.columnDef.sortingFn==="auto"?e.getAutoSortingFn():(n=(r=t.options.sortingFns)==null?void 0:r[e.columnDef.sortingFn])!=null?n:pn[e.columnDef.sortingFn]},e.toggleSorting=(n,r)=>{const o=e.getNextSortingOrder(),i=typeof n<"u"&&n!==null;t.setSorting(s=>{const l=s==null?void 0:s.find(h=>h.id===e.id),c=s==null?void 0:s.findIndex(h=>h.id===e.id);let u=[],f,d=i?n:o==="desc";if(s!=null&&s.length&&e.getCanMultiSort()&&r?l?f="toggle":f="add":s!=null&&s.length&&c!==s.length-1?f="replace":l?f="toggle":f="replace",f==="toggle"&&(i||o||(f="remove")),f==="add"){var p;u=[...s,{id:e.id,desc:d}],u.splice(0,u.length-((p=t.options.maxMultiSortColCount)!=null?p:Number.MAX_SAFE_INTEGER))}else f==="toggle"?u=s.map(h=>h.id===e.id?{...h,desc:d}:h):f==="remove"?u=s.filter(h=>h.id!==e.id):u=[{id:e.id,desc:d}];return u})},e.getFirstSortDir=()=>{var n,r;return((n=(r=e.columnDef.sortDescFirst)!=null?r:t.options.sortDescFirst)!=null?n:e.getAutoSortDir()==="desc")?"desc":"asc"},e.getNextSortingOrder=n=>{var r,o;const i=e.getFirstSortDir(),s=e.getIsSorted();return s?s!==i&&((r=t.options.enableSortingRemoval)==null||r)&&(!(n&&(o=t.options.enableMultiRemove)!=null)||o)?!1:s==="desc"?"asc":"desc":i},e.getCanSort=()=>{var n,r;return((n=e.columnDef.enableSorting)!=null?n:!0)&&((r=t.options.enableSorting)!=null?r:!0)&&!!e.accessorFn},e.getCanMultiSort=()=>{var n,r;return(n=(r=e.columnDef.enableMultiSort)!=null?r:t.options.enableMultiSort)!=null?n:!!e.accessorFn},e.getIsSorted=()=>{var n;const r=(n=t.getState().sorting)==null?void 0:n.find(o=>o.id===e.id);return r?r.desc?"desc":"asc":!1},e.getSortIndex=()=>{var n,r;return(n=(r=t.getState().sorting)==null?void 0:r.findIndex(o=>o.id===e.id))!=null?n:-1},e.clearSorting=()=>{t.setSorting(n=>n!=null&&n.length?n.filter(r=>r.id!==e.id):[])},e.getToggleSortingHandler=()=>{const n=e.getCanSort();return r=>{n&&(r.persist==null||r.persist(),e.toggleSorting==null||e.toggleSorting(void 0,e.getCanMultiSort()?t.options.isMultiSortEvent==null?void 0:t.options.isMultiSortEvent(r):!1))}}},createTable:e=>{e.setSorting=t=>e.options.onSortingChange==null?void 0:e.options.onSortingChange(t),e.resetSorting=t=>{var n,r;e.setSorting(t?[]:(n=(r=e.initialState)==null?void 0:r.sorting)!=null?n:[])},e.getPreSortedRowModel=()=>e.getGroupedRowModel(),e.getSortedRowModel=()=>(!e._getSortedRowModel&&e.options.getSortedRowModel&&(e._getSortedRowModel=e.options.getSortedRowModel(e)),e.options.manualSorting||!e._getSortedRowModel?e.getPreSortedRowModel():e._getSortedRowModel())}},dy={getInitialState:e=>({columnVisibility:{},...e}),getDefaultOptions:e=>({onColumnVisibilityChange:Oe("columnVisibility",e)}),createColumn:(e,t)=>{e.toggleVisibility=n=>{e.getCanHide()&&t.setColumnVisibility(r=>({...r,[e.id]:n??!e.getIsVisible()}))},e.getIsVisible=()=>{var n,r;return(n=(r=t.getState().columnVisibility)==null?void 0:r[e.id])!=null?n:!0},e.getCanHide=()=>{var n,r;return((n=e.columnDef.enableHiding)!=null?n:!0)&&((r=t.options.enableHiding)!=null?r:!0)},e.getToggleVisibilityHandler=()=>n=>{e.toggleVisibility==null||e.toggleVisibility(n.target.checked)}},createRow:(e,t)=>{e._getAllVisibleCells=k(()=>[e.getAllCells(),t.getState().columnVisibility],n=>n.filter(r=>r.column.getIsVisible()),L(t.options,"debugRows")),e.getVisibleCells=k(()=>[e.getLeftVisibleCells(),e.getCenterVisibleCells(),e.getRightVisibleCells()],(n,r,o)=>[...n,...r,...o],L(t.options,"debugRows"))},createTable:e=>{const t=(n,r)=>k(()=>[r(),r().filter(o=>o.getIsVisible()).map(o=>o.id).join("_")],o=>o.filter(i=>i.getIsVisible==null?void 0:i.getIsVisible()),L(e.options,"debugColumns"));e.getVisibleFlatColumns=t("getVisibleFlatColumns",()=>e.getAllFlatColumns()),e.getVisibleLeafColumns=t("getVisibleLeafColumns",()=>e.getAllLeafColumns()),e.getLeftVisibleLeafColumns=t("getLeftVisibleLeafColumns",()=>e.getLeftLeafColumns()),e.getRightVisibleLeafColumns=t("getRightVisibleLeafColumns",()=>e.getRightLeafColumns()),e.getCenterVisibleLeafColumns=t("getCenterVisibleLeafColumns",()=>e.getCenterLeafColumns()),e.setColumnVisibility=n=>e.options.onColumnVisibilityChange==null?void 0:e.options.onColumnVisibilityChange(n),e.resetColumnVisibility=n=>{var r;e.setColumnVisibility(n?{}:(r=e.initialState.columnVisibility)!=null?r:{})},e.toggleAllColumnsVisible=n=>{var r;n=(r=n)!=null?r:!e.getIsAllColumnsVisible(),e.setColumnVisibility(e.getAllLeafColumns().reduce((o,i)=>({...o,[i.id]:n||!(i.getCanHide!=null&&i.getCanHide())}),{}))},e.getIsAllColumnsVisible=()=>!e.getAllLeafColumns().some(n=>!(n.getIsVisible!=null&&n.getIsVisible())),e.getIsSomeColumnsVisible=()=>e.getAllLeafColumns().some(n=>n.getIsVisible==null?void 0:n.getIsVisible()),e.getToggleAllColumnsVisibilityHandler=()=>n=>{var r;e.toggleAllColumnsVisible((r=n.target)==null?void 0:r.checked)}}};function On(e,t){return t?t==="center"?e.getCenterVisibleLeafColumns():t==="left"?e.getLeftVisibleLeafColumns():e.getRightVisibleLeafColumns():e.getVisibleLeafColumns()}const Ra=[Lv,dy,ty,ry,Hv,fy,Xv,Vv,ny,oy,Mv];function py(e){var t;(e.debugAll||e.debugTable)&&console.info("Creating Table Instance...");let n={_features:Ra};const r=n._features.reduce((f,d)=>Object.assign(f,d.getDefaultOptions==null?void 0:d.getDefaultOptions(n)),{}),o=f=>n.options.mergeOptions?n.options.mergeOptions(r,f):{...r,...f};let s={...{},...(t=e.initialState)!=null?t:{}};n._features.forEach(f=>{var d;s=(d=f.getInitialState==null?void 0:f.getInitialState(s))!=null?d:s});const l=[];let c=!1;const u={_features:Ra,options:{...r,...e},initialState:s,_queue:f=>{l.push(f),c||(c=!0,Promise.resolve().then(()=>{for(;l.length;)l.shift()();c=!1}).catch(d=>setTimeout(()=>{throw d})))},reset:()=>{n.setState(n.initialState)},setOptions:f=>{const d=yt(f,n.options);n.options=o(d)},getState:()=>n.options.state,setState:f=>{n.options.onStateChange==null||n.options.onStateChange(f)},_getRowId:(f,d,p)=>{var h;return(h=n.options.getRowId==null?void 0:n.options.getRowId(f,d,p))!=null?h:`${p?[p.id,d].join("."):d}`},getCoreRowModel:()=>(n._getCoreRowModel||(n._getCoreRowModel=n.options.getCoreRowModel(n)),n._getCoreRowModel()),getRowModel:()=>n.getPaginationRowModel(),getRow:(f,d)=>{let p=(d?n.getPrePaginationRowModel():n.getRowModel()).rowsById[f];if(!p&&(p=n.getCoreRowModel().rowsById[f],!p))throw new Error;return p},_getDefaultColumnDef:k(()=>[n.options.defaultColumn],f=>{var d;return f=(d=f)!=null?d:{},{header:p=>{const h=p.header.column.columnDef;return h.accessorKey?h.accessorKey:h.accessorFn?h.id:null},cell:p=>{var h,g;return(h=(g=p.renderValue())==null||g.toString==null?void 0:g.toString())!=null?h:null},...n._features.reduce((p,h)=>Object.assign(p,h.getDefaultColumnDef==null?void 0:h.getDefaultColumnDef()),{}),...f}},L(e,"debugColumns")),_getColumnDefs:()=>n.options.columns,getAllColumns:k(()=>[n._getColumnDefs()],f=>{const d=function(p,h,g){return g===void 0&&(g=0),p.map(m=>{const v=kv(n,m,g,h),y=m;return v.columns=y.columns?d(y.columns,v,g+1):[],v})};return d(f)},L(e,"debugColumns")),getAllFlatColumns:k(()=>[n.getAllColumns()],f=>f.flatMap(d=>d.getFlatColumns()),L(e,"debugColumns")),_getAllFlatColumnsById:k(()=>[n.getAllFlatColumns()],f=>f.reduce((d,p)=>(d[p.id]=p,d),{}),L(e,"debugColumns")),getAllLeafColumns:k(()=>[n.getAllColumns(),n._getOrderColumnsFn()],(f,d)=>{let p=f.flatMap(h=>h.getLeafColumns());return d(p)},L(e,"debugColumns")),getColumn:f=>n._getAllFlatColumnsById()[f]};Object.assign(n,u);for(let f=0;f<n._features.length;f++){const d=n._features[f];d==null||d.createTable==null||d.createTable(n)}return n}function hy(e,t,n,r){const o=()=>{var s;return(s=i.getValue())!=null?s:e.options.renderFallbackValue},i={id:`${t.id}_${n.id}`,row:t,column:n,getValue:()=>t.getValue(r),renderValue:o,getContext:k(()=>[e,n,t,i],(s,l,c,u)=>({table:s,column:l,row:c,cell:u,getValue:u.getValue,renderValue:u.renderValue}),L(e.options,"debugCells"))};return e._features.forEach(s=>{s.createCell==null||s.createCell(i,n,t,e)},{}),i}const Ns=(e,t,n,r,o,i,s)=>{let l={id:t,index:r,original:n,depth:o,parentId:s,_valuesCache:{},_uniqueValuesCache:{},getValue:c=>{if(l._valuesCache.hasOwnProperty(c))return l._valuesCache[c];const u=e.getColumn(c);if(u!=null&&u.accessorFn)return l._valuesCache[c]=u.accessorFn(l.original,r),l._valuesCache[c]},getUniqueValues:c=>{if(l._uniqueValuesCache.hasOwnProperty(c))return l._uniqueValuesCache[c];const u=e.getColumn(c);if(u!=null&&u.accessorFn)return u.columnDef.getUniqueValues?(l._uniqueValuesCache[c]=u.columnDef.getUniqueValues(l.original,r),l._uniqueValuesCache[c]):(l._uniqueValuesCache[c]=[l.getValue(c)],l._uniqueValuesCache[c])},renderValue:c=>{var u;return(u=l.getValue(c))!=null?u:e.options.renderFallbackValue},subRows:i??[],getLeafRows:()=>Pv(l.subRows,c=>c.subRows),getParentRow:()=>l.parentId?e.getRow(l.parentId,!0):void 0,getParentRows:()=>{let c=[],u=l;for(;;){const f=u.getParentRow();if(!f)break;c.push(f),u=f}return c.reverse()},getAllCells:k(()=>[e.getAllLeafColumns()],c=>c.map(u=>hy(e,l,u,u.id)),L(e.options,"debugRows")),_getAllCellsByColumnId:k(()=>[l.getAllCells()],c=>c.reduce((u,f)=>(u[f.column.id]=f,u),{}),L(e.options,"debugRows"))};for(let c=0;c<e._features.length;c++){const u=e._features[c];u==null||u.createRow==null||u.createRow(l,e)}return l};function Ae(){return{accessor:(e,t)=>typeof e=="function"?{...t,accessorFn:e}:{...t,accessorKey:e},display:e=>e,group:e=>e}}function gy(){return e=>k(()=>[e.options.data],t=>{const n={rows:[],flatRows:[],rowsById:{}},r=function(o,i,s){i===void 0&&(i=0);const l=[];for(let u=0;u<o.length;u++){const f=Ns(e,e._getRowId(o[u],u,s),o[u],u,i,void 0,s==null?void 0:s.id);if(n.flatRows.push(f),n.rowsById[f.id]=f,l.push(f),e.options.getSubRows){var c;f.originalSubRows=e.options.getSubRows(o[u],u),(c=f.originalSubRows)!=null&&c.length&&(f.subRows=r(f.originalSubRows,i+1,f))}}return l};return n.rows=r(t),n},L(e.options,"debugTable","getRowModel",()=>e._autoResetPageIndex()))}function ed(e,t,n){return n.options.filterFromLeafRows?my(e,t,n):xy(e,t,n)}function my(e,t,n){var r;const o=[],i={},s=(r=n.options.maxLeafRowFilterDepth)!=null?r:100,l=function(c,u){u===void 0&&(u=0);const f=[];for(let p=0;p<c.length;p++){var d;let h=c[p];const g=Ns(n,h.id,h.original,h.index,h.depth,void 0,h.parentId);if(g.columnFilters=h.columnFilters,(d=h.subRows)!=null&&d.length&&u<s){if(g.subRows=l(h.subRows,u+1),h=g,t(h)&&!g.subRows.length){f.push(h),i[h.id]=h,o.push(h);continue}if(t(h)||g.subRows.length){f.push(h),i[h.id]=h,o.push(h);continue}}else h=g,t(h)&&(f.push(h),i[h.id]=h,o.push(h))}return f};return{rows:l(e),flatRows:o,rowsById:i}}function xy(e,t,n){var r;const o=[],i={},s=(r=n.options.maxLeafRowFilterDepth)!=null?r:100,l=function(c,u){u===void 0&&(u=0);const f=[];for(let p=0;p<c.length;p++){let h=c[p];if(t(h)){var d;if((d=h.subRows)!=null&&d.length&&u<s){const m=Ns(n,h.id,h.original,h.index,h.depth,void 0,h.parentId);m.subRows=l(h.subRows,u+1),h=m}f.push(h),o.push(h),i[h.id]=h}}return f};return{rows:l(e),flatRows:o,rowsById:i}}function vy(){return e=>k(()=>[e.getPreFilteredRowModel(),e.getState().columnFilters,e.getState().globalFilter],(t,n,r)=>{if(!t.rows.length||!(n!=null&&n.length)&&!r){for(let p=0;p<t.flatRows.length;p++)t.flatRows[p].columnFilters={},t.flatRows[p].columnFiltersMeta={};return t}const o=[],i=[];(n??[]).forEach(p=>{var h;const g=e.getColumn(p.id);if(!g)return;const m=g.getFilterFn();m&&o.push({id:p.id,filterFn:m,resolvedValue:(h=m.resolveFilterValue==null?void 0:m.resolveFilterValue(p.value))!=null?h:p.value})});const s=n.map(p=>p.id),l=e.getGlobalFilterFn(),c=e.getAllLeafColumns().filter(p=>p.getCanGlobalFilter());r&&l&&c.length&&(s.push("__global__"),c.forEach(p=>{var h;i.push({id:p.id,filterFn:l,resolvedValue:(h=l.resolveFilterValue==null?void 0:l.resolveFilterValue(r))!=null?h:r})}));let u,f;for(let p=0;p<t.flatRows.length;p++){const h=t.flatRows[p];if(h.columnFilters={},o.length)for(let g=0;g<o.length;g++){u=o[g];const m=u.id;h.columnFilters[m]=u.filterFn(h,m,u.resolvedValue,v=>{h.columnFiltersMeta[m]=v})}if(i.length){for(let g=0;g<i.length;g++){f=i[g];const m=f.id;if(f.filterFn(h,m,f.resolvedValue,v=>{h.columnFiltersMeta[m]=v})){h.columnFilters.__global__=!0;break}}h.columnFilters.__global__!==!0&&(h.columnFilters.__global__=!1)}}const d=p=>{for(let h=0;h<s.length;h++)if(p.columnFilters[s[h]]===!1)return!1;return!0};return ed(t.rows,d,e)},L(e.options,"debugTable","getFilteredRowModel",()=>e._autoResetPageIndex()))}function yy(){return(e,t)=>k(()=>[e.getPreFilteredRowModel(),e.getState().columnFilters,e.getState().globalFilter,e.getFilteredRowModel()],(n,r,o)=>{if(!n.rows.length||!(r!=null&&r.length)&&!o)return n;const i=[...r.map(l=>l.id).filter(l=>l!==t),o?"__global__":void 0].filter(Boolean),s=l=>{for(let c=0;c<i.length;c++)if(l.columnFilters[i[c]]===!1)return!1;return!0};return ed(n.rows,s,e)},L(e.options,"debugTable"))}function wy(){return(e,t)=>k(()=>{var n;return[(n=e.getColumn(t))==null?void 0:n.getFacetedRowModel()]},n=>{if(!n)return new Map;let r=new Map;for(let i=0;i<n.flatRows.length;i++){const s=n.flatRows[i].getUniqueValues(t);for(let l=0;l<s.length;l++){const c=s[l];if(r.has(c)){var o;r.set(c,((o=r.get(c))!=null?o:0)+1)}else r.set(c,1)}}return r},L(e.options,"debugTable"))}function by(){return(e,t)=>k(()=>{var n;return[(n=e.getColumn(t))==null?void 0:n.getFacetedRowModel()]},n=>{var r;if(!n)return;const o=(r=n.flatRows[0])==null?void 0:r.getUniqueValues(t);if(typeof o>"u")return;let i=[o,o];for(let s=0;s<n.flatRows.length;s++){const l=n.flatRows[s].getUniqueValues(t);for(let c=0;c<l.length;c++){const u=l[c];u<i[0]?i[0]=u:u>i[1]&&(i[1]=u)}}return i},L(e.options,"debugTable"))}function Cy(){return e=>k(()=>[e.getState().sorting,e.getPreSortedRowModel()],(t,n)=>{if(!n.rows.length||!(t!=null&&t.length))return n;const r=e.getState().sorting,o=[],i=r.filter(c=>{var u;return(u=e.getColumn(c.id))==null?void 0:u.getCanSort()}),s={};i.forEach(c=>{const u=e.getColumn(c.id);u&&(s[c.id]={sortUndefined:u.columnDef.sortUndefined,invertSorting:u.columnDef.invertSorting,sortingFn:u.getSortingFn()})});const l=c=>{const u=c.map(f=>({...f}));return u.sort((f,d)=>{for(let h=0;h<i.length;h+=1){var p;const g=i[h],m=s[g.id],v=(p=g==null?void 0:g.desc)!=null?p:!1;let y=0;if(m.sortUndefined){const b=f.getValue(g.id),w=d.getValue(g.id),S=b===void 0,F=w===void 0;(S||F)&&(y=S&&F?0:S?m.sortUndefined:-m.sortUndefined)}if(y===0&&(y=m.sortingFn(f,d,g.id)),y!==0)return v&&(y*=-1),m.invertSorting&&(y*=-1),y}return f.index-d.index}),u.forEach(f=>{var d;o.push(f),(d=f.subRows)!=null&&d.length&&(f.subRows=l(f.subRows))}),u};return{rows:l(n.rows),flatRows:o,rowsById:n.rowsById}},L(e.options,"debugTable","getSortedRowModel",()=>e._autoResetPageIndex()))}function Sy(e){const t=[],n=r=>{var o;t.push(r),(o=r.subRows)!=null&&o.length&&r.getIsExpanded()&&r.subRows.forEach(n)};return e.rows.forEach(n),{rows:t,flatRows:e.flatRows,rowsById:e.rowsById}}function Ay(e){return t=>k(()=>[t.getState().pagination,t.getPrePaginationRowModel(),t.options.paginateExpandedRows?void 0:t.getState().expanded],(n,r)=>{if(!r.rows.length)return r;const{pageSize:o,pageIndex:i}=n;let{rows:s,flatRows:l,rowsById:c}=r;const u=o*i,f=u+o;s=s.slice(u,f);let d;t.options.paginateExpandedRows?d={rows:s,flatRows:l,rowsById:c}:d=Sy({rows:s,flatRows:l,rowsById:c}),d.flatRows=[];const p=h=>{d.flatRows.push(h),h.subRows.length&&h.subRows.forEach(p)};return d.rows.forEach(p),d},L(t.options,"debugTable"))}/**
   * react-table
   *
   * Copyright (c) TanStack
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE.md file in the root directory of this source tree.
   *
   * @license MIT
   */function Fa(e,t){return e?jy(e)?x.createElement(e,t):e:null}function jy(e){return Ry(e)||typeof e=="function"||Fy(e)}function Ry(e){return typeof e=="function"&&(()=>{const t=Object.getPrototypeOf(e);return t.prototype&&t.prototype.isReactComponent})()}function Fy(e){return typeof e=="object"&&typeof e.$$typeof=="symbol"&&["react.memo","react.forward_ref"].includes(e.$$typeof.description)}function Oy(e){const t={state:{},onStateChange:()=>{},renderFallbackValue:null,...e},[n]=x.useState(()=>({current:py(t)})),[r,o]=x.useState(()=>n.current.initialState);return n.current.setOptions(i=>({...i,...e,state:{...r,...e.state},onStateChange:s=>{o(s),e.onStateChange==null||e.onStateChange(s)}})),n.current}var Oa=typeof global<"u"?global:typeof self<"u"?self:typeof window<"u"?window:{},Me=[],Ne=[],Ey=typeof Uint8Array<"u"?Uint8Array:Array,Ts=!1;function td(){Ts=!0;for(var e="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t=0,n=e.length;t<n;++t)Me[t]=e[t],Ne[e.charCodeAt(t)]=t;Ne[45]=62,Ne[95]=63}function Iy(e){Ts||td();var t,n,r,o,i,s,l=e.length;if(l%4>0)throw new Error("Invalid string. Length must be a multiple of 4");i=e[l-2]==="="?2:e[l-1]==="="?1:0,s=new Ey(l*3/4-i),r=i>0?l-4:l;var c=0;for(t=0,n=0;t<r;t+=4,n+=3)o=Ne[e.charCodeAt(t)]<<18|Ne[e.charCodeAt(t+1)]<<12|Ne[e.charCodeAt(t+2)]<<6|Ne[e.charCodeAt(t+3)],s[c++]=o>>16&255,s[c++]=o>>8&255,s[c++]=o&255;return i===2?(o=Ne[e.charCodeAt(t)]<<2|Ne[e.charCodeAt(t+1)]>>4,s[c++]=o&255):i===1&&(o=Ne[e.charCodeAt(t)]<<10|Ne[e.charCodeAt(t+1)]<<4|Ne[e.charCodeAt(t+2)]>>2,s[c++]=o>>8&255,s[c++]=o&255),s}function Ny(e){return Me[e>>18&63]+Me[e>>12&63]+Me[e>>6&63]+Me[e&63]}function Ty(e,t,n){for(var r,o=[],i=t;i<n;i+=3)r=(e[i]<<16)+(e[i+1]<<8)+e[i+2],o.push(Ny(r));return o.join("")}function Ea(e){Ts||td();for(var t,n=e.length,r=n%3,o="",i=[],s=16383,l=0,c=n-r;l<c;l+=s)i.push(Ty(e,l,l+s>c?c:l+s));return r===1?(t=e[n-1],o+=Me[t>>2],o+=Me[t<<4&63],o+="=="):r===2&&(t=(e[n-2]<<8)+e[n-1],o+=Me[t>>10],o+=Me[t>>4&63],o+=Me[t<<2&63],o+="="),i.push(o),i.join("")}function no(e,t,n,r,o){var i,s,l=o*8-r-1,c=(1<<l)-1,u=c>>1,f=-7,d=n?o-1:0,p=n?-1:1,h=e[t+d];for(d+=p,i=h&(1<<-f)-1,h>>=-f,f+=l;f>0;i=i*256+e[t+d],d+=p,f-=8);for(s=i&(1<<-f)-1,i>>=-f,f+=r;f>0;s=s*256+e[t+d],d+=p,f-=8);if(i===0)i=1-u;else{if(i===c)return s?NaN:(h?-1:1)*(1/0);s=s+Math.pow(2,r),i=i-u}return(h?-1:1)*s*Math.pow(2,i-r)}function nd(e,t,n,r,o,i){var s,l,c,u=i*8-o-1,f=(1<<u)-1,d=f>>1,p=o===23?Math.pow(2,-24)-Math.pow(2,-77):0,h=r?0:i-1,g=r?1:-1,m=t<0||t===0&&1/t<0?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(l=isNaN(t)?1:0,s=f):(s=Math.floor(Math.log(t)/Math.LN2),t*(c=Math.pow(2,-s))<1&&(s--,c*=2),s+d>=1?t+=p/c:t+=p*Math.pow(2,1-d),t*c>=2&&(s++,c/=2),s+d>=f?(l=0,s=f):s+d>=1?(l=(t*c-1)*Math.pow(2,o),s=s+d):(l=t*Math.pow(2,d-1)*Math.pow(2,o),s=0));o>=8;e[n+h]=l&255,h+=g,l/=256,o-=8);for(s=s<<o|l,u+=o;u>0;e[n+h]=s&255,h+=g,s/=256,u-=8);e[n+h-g]|=m*128}var Dy={}.toString,rd=Array.isArray||function(e){return Dy.call(e)=="[object Array]"},_y=50;R.TYPED_ARRAY_SUPPORT=Oa.TYPED_ARRAY_SUPPORT!==void 0?Oa.TYPED_ARRAY_SUPPORT:!0;Tr();function Tr(){return R.TYPED_ARRAY_SUPPORT?2147483647:1073741823}function tt(e,t){if(Tr()<t)throw new RangeError("Invalid typed array length");return R.TYPED_ARRAY_SUPPORT?(e=new Uint8Array(t),e.__proto__=R.prototype):(e===null&&(e=new R(t)),e.length=t),e}function R(e,t,n){if(!R.TYPED_ARRAY_SUPPORT&&!(this instanceof R))return new R(e,t,n);if(typeof e=="number"){if(typeof t=="string")throw new Error("If encoding is specified then the first argument must be a string");return Ds(this,e)}return od(this,e,t,n)}R.poolSize=8192;R._augment=function(e){return e.__proto__=R.prototype,e};function od(e,t,n,r){if(typeof t=="number")throw new TypeError('"value" argument must not be a number');return typeof ArrayBuffer<"u"&&t instanceof ArrayBuffer?Py(e,t,n,r):typeof t=="string"?By(e,t,n):ky(e,t)}R.from=function(e,t,n){return od(null,e,t,n)};R.TYPED_ARRAY_SUPPORT&&(R.prototype.__proto__=Uint8Array.prototype,R.__proto__=Uint8Array,typeof Symbol<"u"&&Symbol.species&&R[Symbol.species]);function id(e){if(typeof e!="number")throw new TypeError('"size" argument must be a number');if(e<0)throw new RangeError('"size" argument must not be negative')}function $y(e,t,n,r){return id(t),t<=0?tt(e,t):n!==void 0?typeof r=="string"?tt(e,t).fill(n,r):tt(e,t).fill(n):tt(e,t)}R.alloc=function(e,t,n){return $y(null,e,t,n)};function Ds(e,t){if(id(t),e=tt(e,t<0?0:_s(t)|0),!R.TYPED_ARRAY_SUPPORT)for(var n=0;n<t;++n)e[n]=0;return e}R.allocUnsafe=function(e){return Ds(null,e)};R.allocUnsafeSlow=function(e){return Ds(null,e)};function By(e,t,n){if((typeof n!="string"||n==="")&&(n="utf8"),!R.isEncoding(n))throw new TypeError('"encoding" must be a valid string encoding');var r=sd(t,n)|0;e=tt(e,r);var o=e.write(t,n);return o!==r&&(e=e.slice(0,o)),e}function Ii(e,t){var n=t.length<0?0:_s(t.length)|0;e=tt(e,n);for(var r=0;r<n;r+=1)e[r]=t[r]&255;return e}function Py(e,t,n,r){if(t.byteLength,n<0||t.byteLength<n)throw new RangeError("'offset' is out of bounds");if(t.byteLength<n+(r||0))throw new RangeError("'length' is out of bounds");return n===void 0&&r===void 0?t=new Uint8Array(t):r===void 0?t=new Uint8Array(t,n):t=new Uint8Array(t,n,r),R.TYPED_ARRAY_SUPPORT?(e=t,e.__proto__=R.prototype):e=Ii(e,t),e}function ky(e,t){if(We(t)){var n=_s(t.length)|0;return e=tt(e,n),e.length===0||t.copy(e,0,0,n),e}if(t){if(typeof ArrayBuffer<"u"&&t.buffer instanceof ArrayBuffer||"length"in t)return typeof t.length!="number"||rw(t.length)?tt(e,0):Ii(e,t);if(t.type==="Buffer"&&rd(t.data))return Ii(e,t.data)}throw new TypeError("First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.")}function _s(e){if(e>=Tr())throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+Tr().toString(16)+" bytes");return e|0}R.isBuffer=zt;function We(e){return!!(e!=null&&e._isBuffer)}R.compare=function(t,n){if(!We(t)||!We(n))throw new TypeError("Arguments must be Buffers");if(t===n)return 0;for(var r=t.length,o=n.length,i=0,s=Math.min(r,o);i<s;++i)if(t[i]!==n[i]){r=t[i],o=n[i];break}return r<o?-1:o<r?1:0};R.isEncoding=function(t){switch(String(t).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}};R.concat=function(t,n){if(!rd(t))throw new TypeError('"list" argument must be an Array of Buffers');if(t.length===0)return R.alloc(0);var r;if(n===void 0)for(n=0,r=0;r<t.length;++r)n+=t[r].length;var o=R.allocUnsafe(n),i=0;for(r=0;r<t.length;++r){var s=t[r];if(!We(s))throw new TypeError('"list" argument must be an Array of Buffers');s.copy(o,i),i+=s.length}return o};function sd(e,t){if(We(e))return e.length;if(typeof ArrayBuffer<"u"&&typeof ArrayBuffer.isView=="function"&&(ArrayBuffer.isView(e)||e instanceof ArrayBuffer))return e.byteLength;typeof e!="string"&&(e=""+e);var n=e.length;if(n===0)return 0;for(var r=!1;;)switch(t){case"ascii":case"latin1":case"binary":return n;case"utf8":case"utf-8":case void 0:return Dr(e).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return n*2;case"hex":return n>>>1;case"base64":return pd(e).length;default:if(r)return Dr(e).length;t=(""+t).toLowerCase(),r=!0}}R.byteLength=sd;function Ly(e,t,n){var r=!1;if((t===void 0||t<0)&&(t=0),t>this.length||((n===void 0||n>this.length)&&(n=this.length),n<=0)||(n>>>=0,t>>>=0,n<=t))return"";for(e||(e="utf8");;)switch(e){case"hex":return Ky(this,t,n);case"utf8":case"utf-8":return cd(this,t,n);case"ascii":return Qy(this,t,n);case"latin1":case"binary":return qy(this,t,n);case"base64":return Wy(this,t,n);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return Yy(this,t,n);default:if(r)throw new TypeError("Unknown encoding: "+e);e=(e+"").toLowerCase(),r=!0}}R.prototype._isBuffer=!0;function Et(e,t,n){var r=e[t];e[t]=e[n],e[n]=r}R.prototype.swap16=function(){var t=this.length;if(t%2!==0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var n=0;n<t;n+=2)Et(this,n,n+1);return this};R.prototype.swap32=function(){var t=this.length;if(t%4!==0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var n=0;n<t;n+=4)Et(this,n,n+3),Et(this,n+1,n+2);return this};R.prototype.swap64=function(){var t=this.length;if(t%8!==0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var n=0;n<t;n+=8)Et(this,n,n+7),Et(this,n+1,n+6),Et(this,n+2,n+5),Et(this,n+3,n+4);return this};R.prototype.toString=function(){var t=this.length|0;return t===0?"":arguments.length===0?cd(this,0,t):Ly.apply(this,arguments)};R.prototype.equals=function(t){if(!We(t))throw new TypeError("Argument must be a Buffer");return this===t?!0:R.compare(this,t)===0};R.prototype.inspect=function(){var t="",n=_y;return this.length>0&&(t=this.toString("hex",0,n).match(/.{2}/g).join(" "),this.length>n&&(t+=" ... ")),"<Buffer "+t+">"};R.prototype.compare=function(t,n,r,o,i){if(!We(t))throw new TypeError("Argument must be a Buffer");if(n===void 0&&(n=0),r===void 0&&(r=t?t.length:0),o===void 0&&(o=0),i===void 0&&(i=this.length),n<0||r>t.length||o<0||i>this.length)throw new RangeError("out of range index");if(o>=i&&n>=r)return 0;if(o>=i)return-1;if(n>=r)return 1;if(n>>>=0,r>>>=0,o>>>=0,i>>>=0,this===t)return 0;for(var s=i-o,l=r-n,c=Math.min(s,l),u=this.slice(o,i),f=t.slice(n,r),d=0;d<c;++d)if(u[d]!==f[d]){s=u[d],l=f[d];break}return s<l?-1:l<s?1:0};function ad(e,t,n,r,o){if(e.length===0)return-1;if(typeof n=="string"?(r=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),n=+n,isNaN(n)&&(n=o?0:e.length-1),n<0&&(n=e.length+n),n>=e.length){if(o)return-1;n=e.length-1}else if(n<0)if(o)n=0;else return-1;if(typeof t=="string"&&(t=R.from(t,r)),We(t))return t.length===0?-1:Ia(e,t,n,r,o);if(typeof t=="number")return t=t&255,R.TYPED_ARRAY_SUPPORT&&typeof Uint8Array.prototype.indexOf=="function"?o?Uint8Array.prototype.indexOf.call(e,t,n):Uint8Array.prototype.lastIndexOf.call(e,t,n):Ia(e,[t],n,r,o);throw new TypeError("val must be string, number or Buffer")}function Ia(e,t,n,r,o){var i=1,s=e.length,l=t.length;if(r!==void 0&&(r=String(r).toLowerCase(),r==="ucs2"||r==="ucs-2"||r==="utf16le"||r==="utf-16le")){if(e.length<2||t.length<2)return-1;i=2,s/=2,l/=2,n/=2}function c(h,g){return i===1?h[g]:h.readUInt16BE(g*i)}var u;if(o){var f=-1;for(u=n;u<s;u++)if(c(e,u)===c(t,f===-1?0:u-f)){if(f===-1&&(f=u),u-f+1===l)return f*i}else f!==-1&&(u-=u-f),f=-1}else for(n+l>s&&(n=s-l),u=n;u>=0;u--){for(var d=!0,p=0;p<l;p++)if(c(e,u+p)!==c(t,p)){d=!1;break}if(d)return u}return-1}R.prototype.includes=function(t,n,r){return this.indexOf(t,n,r)!==-1};R.prototype.indexOf=function(t,n,r){return ad(this,t,n,r,!0)};R.prototype.lastIndexOf=function(t,n,r){return ad(this,t,n,r,!1)};function My(e,t,n,r){n=Number(n)||0;var o=e.length-n;r?(r=Number(r),r>o&&(r=o)):r=o;var i=t.length;if(i%2!==0)throw new TypeError("Invalid hex string");r>i/2&&(r=i/2);for(var s=0;s<r;++s){var l=parseInt(t.substr(s*2,2),16);if(isNaN(l))return s;e[n+s]=l}return s}function Uy(e,t,n,r){return io(Dr(t,e.length-n),e,n,r)}function ld(e,t,n,r){return io(tw(t),e,n,r)}function Vy(e,t,n,r){return ld(e,t,n,r)}function Hy(e,t,n,r){return io(pd(t),e,n,r)}function Gy(e,t,n,r){return io(nw(t,e.length-n),e,n,r)}R.prototype.write=function(t,n,r,o){if(n===void 0)o="utf8",r=this.length,n=0;else if(r===void 0&&typeof n=="string")o=n,r=this.length,n=0;else if(isFinite(n))n=n|0,isFinite(r)?(r=r|0,o===void 0&&(o="utf8")):(o=r,r=void 0);else throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");var i=this.length-n;if((r===void 0||r>i)&&(r=i),t.length>0&&(r<0||n<0)||n>this.length)throw new RangeError("Attempt to write outside buffer bounds");o||(o="utf8");for(var s=!1;;)switch(o){case"hex":return My(this,t,n,r);case"utf8":case"utf-8":return Uy(this,t,n,r);case"ascii":return ld(this,t,n,r);case"latin1":case"binary":return Vy(this,t,n,r);case"base64":return Hy(this,t,n,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return Gy(this,t,n,r);default:if(s)throw new TypeError("Unknown encoding: "+o);o=(""+o).toLowerCase(),s=!0}};R.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};function Wy(e,t,n){return t===0&&n===e.length?Ea(e):Ea(e.slice(t,n))}function cd(e,t,n){n=Math.min(e.length,n);for(var r=[],o=t;o<n;){var i=e[o],s=null,l=i>239?4:i>223?3:i>191?2:1;if(o+l<=n){var c,u,f,d;switch(l){case 1:i<128&&(s=i);break;case 2:c=e[o+1],(c&192)===128&&(d=(i&31)<<6|c&63,d>127&&(s=d));break;case 3:c=e[o+1],u=e[o+2],(c&192)===128&&(u&192)===128&&(d=(i&15)<<12|(c&63)<<6|u&63,d>2047&&(d<55296||d>57343)&&(s=d));break;case 4:c=e[o+1],u=e[o+2],f=e[o+3],(c&192)===128&&(u&192)===128&&(f&192)===128&&(d=(i&15)<<18|(c&63)<<12|(u&63)<<6|f&63,d>65535&&d<1114112&&(s=d))}}s===null?(s=65533,l=1):s>65535&&(s-=65536,r.push(s>>>10&1023|55296),s=56320|s&1023),r.push(s),o+=l}return zy(r)}var Na=4096;function zy(e){var t=e.length;if(t<=Na)return String.fromCharCode.apply(String,e);for(var n="",r=0;r<t;)n+=String.fromCharCode.apply(String,e.slice(r,r+=Na));return n}function Qy(e,t,n){var r="";n=Math.min(e.length,n);for(var o=t;o<n;++o)r+=String.fromCharCode(e[o]&127);return r}function qy(e,t,n){var r="";n=Math.min(e.length,n);for(var o=t;o<n;++o)r+=String.fromCharCode(e[o]);return r}function Ky(e,t,n){var r=e.length;(!t||t<0)&&(t=0),(!n||n<0||n>r)&&(n=r);for(var o="",i=t;i<n;++i)o+=ew(e[i]);return o}function Yy(e,t,n){for(var r=e.slice(t,n),o="",i=0;i<r.length;i+=2)o+=String.fromCharCode(r[i]+r[i+1]*256);return o}R.prototype.slice=function(t,n){var r=this.length;t=~~t,n=n===void 0?r:~~n,t<0?(t+=r,t<0&&(t=0)):t>r&&(t=r),n<0?(n+=r,n<0&&(n=0)):n>r&&(n=r),n<t&&(n=t);var o;if(R.TYPED_ARRAY_SUPPORT)o=this.subarray(t,n),o.__proto__=R.prototype;else{var i=n-t;o=new R(i,void 0);for(var s=0;s<i;++s)o[s]=this[s+t]}return o};function pe(e,t,n){if(e%1!==0||e<0)throw new RangeError("offset is not uint");if(e+t>n)throw new RangeError("Trying to access beyond buffer length")}R.prototype.readUIntLE=function(t,n,r){t=t|0,n=n|0,r||pe(t,n,this.length);for(var o=this[t],i=1,s=0;++s<n&&(i*=256);)o+=this[t+s]*i;return o};R.prototype.readUIntBE=function(t,n,r){t=t|0,n=n|0,r||pe(t,n,this.length);for(var o=this[t+--n],i=1;n>0&&(i*=256);)o+=this[t+--n]*i;return o};R.prototype.readUInt8=function(t,n){return n||pe(t,1,this.length),this[t]};R.prototype.readUInt16LE=function(t,n){return n||pe(t,2,this.length),this[t]|this[t+1]<<8};R.prototype.readUInt16BE=function(t,n){return n||pe(t,2,this.length),this[t]<<8|this[t+1]};R.prototype.readUInt32LE=function(t,n){return n||pe(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+this[t+3]*16777216};R.prototype.readUInt32BE=function(t,n){return n||pe(t,4,this.length),this[t]*16777216+(this[t+1]<<16|this[t+2]<<8|this[t+3])};R.prototype.readIntLE=function(t,n,r){t=t|0,n=n|0,r||pe(t,n,this.length);for(var o=this[t],i=1,s=0;++s<n&&(i*=256);)o+=this[t+s]*i;return i*=128,o>=i&&(o-=Math.pow(2,8*n)),o};R.prototype.readIntBE=function(t,n,r){t=t|0,n=n|0,r||pe(t,n,this.length);for(var o=n,i=1,s=this[t+--o];o>0&&(i*=256);)s+=this[t+--o]*i;return i*=128,s>=i&&(s-=Math.pow(2,8*n)),s};R.prototype.readInt8=function(t,n){return n||pe(t,1,this.length),this[t]&128?(255-this[t]+1)*-1:this[t]};R.prototype.readInt16LE=function(t,n){n||pe(t,2,this.length);var r=this[t]|this[t+1]<<8;return r&32768?r|4294901760:r};R.prototype.readInt16BE=function(t,n){n||pe(t,2,this.length);var r=this[t+1]|this[t]<<8;return r&32768?r|4294901760:r};R.prototype.readInt32LE=function(t,n){return n||pe(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24};R.prototype.readInt32BE=function(t,n){return n||pe(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]};R.prototype.readFloatLE=function(t,n){return n||pe(t,4,this.length),no(this,t,!0,23,4)};R.prototype.readFloatBE=function(t,n){return n||pe(t,4,this.length),no(this,t,!1,23,4)};R.prototype.readDoubleLE=function(t,n){return n||pe(t,8,this.length),no(this,t,!0,52,8)};R.prototype.readDoubleBE=function(t,n){return n||pe(t,8,this.length),no(this,t,!1,52,8)};function je(e,t,n,r,o,i){if(!We(e))throw new TypeError('"buffer" argument must be a Buffer instance');if(t>o||t<i)throw new RangeError('"value" argument is out of bounds');if(n+r>e.length)throw new RangeError("Index out of range")}R.prototype.writeUIntLE=function(t,n,r,o){if(t=+t,n=n|0,r=r|0,!o){var i=Math.pow(2,8*r)-1;je(this,t,n,r,i,0)}var s=1,l=0;for(this[n]=t&255;++l<r&&(s*=256);)this[n+l]=t/s&255;return n+r};R.prototype.writeUIntBE=function(t,n,r,o){if(t=+t,n=n|0,r=r|0,!o){var i=Math.pow(2,8*r)-1;je(this,t,n,r,i,0)}var s=r-1,l=1;for(this[n+s]=t&255;--s>=0&&(l*=256);)this[n+s]=t/l&255;return n+r};R.prototype.writeUInt8=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,1,255,0),R.TYPED_ARRAY_SUPPORT||(t=Math.floor(t)),this[n]=t&255,n+1};function ro(e,t,n,r){t<0&&(t=65535+t+1);for(var o=0,i=Math.min(e.length-n,2);o<i;++o)e[n+o]=(t&255<<8*(r?o:1-o))>>>(r?o:1-o)*8}R.prototype.writeUInt16LE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,2,65535,0),R.TYPED_ARRAY_SUPPORT?(this[n]=t&255,this[n+1]=t>>>8):ro(this,t,n,!0),n+2};R.prototype.writeUInt16BE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,2,65535,0),R.TYPED_ARRAY_SUPPORT?(this[n]=t>>>8,this[n+1]=t&255):ro(this,t,n,!1),n+2};function oo(e,t,n,r){t<0&&(t=4294967295+t+1);for(var o=0,i=Math.min(e.length-n,4);o<i;++o)e[n+o]=t>>>(r?o:3-o)*8&255}R.prototype.writeUInt32LE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,4,4294967295,0),R.TYPED_ARRAY_SUPPORT?(this[n+3]=t>>>24,this[n+2]=t>>>16,this[n+1]=t>>>8,this[n]=t&255):oo(this,t,n,!0),n+4};R.prototype.writeUInt32BE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,4,4294967295,0),R.TYPED_ARRAY_SUPPORT?(this[n]=t>>>24,this[n+1]=t>>>16,this[n+2]=t>>>8,this[n+3]=t&255):oo(this,t,n,!1),n+4};R.prototype.writeIntLE=function(t,n,r,o){if(t=+t,n=n|0,!o){var i=Math.pow(2,8*r-1);je(this,t,n,r,i-1,-i)}var s=0,l=1,c=0;for(this[n]=t&255;++s<r&&(l*=256);)t<0&&c===0&&this[n+s-1]!==0&&(c=1),this[n+s]=(t/l>>0)-c&255;return n+r};R.prototype.writeIntBE=function(t,n,r,o){if(t=+t,n=n|0,!o){var i=Math.pow(2,8*r-1);je(this,t,n,r,i-1,-i)}var s=r-1,l=1,c=0;for(this[n+s]=t&255;--s>=0&&(l*=256);)t<0&&c===0&&this[n+s+1]!==0&&(c=1),this[n+s]=(t/l>>0)-c&255;return n+r};R.prototype.writeInt8=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,1,127,-128),R.TYPED_ARRAY_SUPPORT||(t=Math.floor(t)),t<0&&(t=255+t+1),this[n]=t&255,n+1};R.prototype.writeInt16LE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,2,32767,-32768),R.TYPED_ARRAY_SUPPORT?(this[n]=t&255,this[n+1]=t>>>8):ro(this,t,n,!0),n+2};R.prototype.writeInt16BE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,2,32767,-32768),R.TYPED_ARRAY_SUPPORT?(this[n]=t>>>8,this[n+1]=t&255):ro(this,t,n,!1),n+2};R.prototype.writeInt32LE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,4,2147483647,-2147483648),R.TYPED_ARRAY_SUPPORT?(this[n]=t&255,this[n+1]=t>>>8,this[n+2]=t>>>16,this[n+3]=t>>>24):oo(this,t,n,!0),n+4};R.prototype.writeInt32BE=function(t,n,r){return t=+t,n=n|0,r||je(this,t,n,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),R.TYPED_ARRAY_SUPPORT?(this[n]=t>>>24,this[n+1]=t>>>16,this[n+2]=t>>>8,this[n+3]=t&255):oo(this,t,n,!1),n+4};function ud(e,t,n,r,o,i){if(n+r>e.length)throw new RangeError("Index out of range");if(n<0)throw new RangeError("Index out of range")}function fd(e,t,n,r,o){return o||ud(e,t,n,4),nd(e,t,n,r,23,4),n+4}R.prototype.writeFloatLE=function(t,n,r){return fd(this,t,n,!0,r)};R.prototype.writeFloatBE=function(t,n,r){return fd(this,t,n,!1,r)};function dd(e,t,n,r,o){return o||ud(e,t,n,8),nd(e,t,n,r,52,8),n+8}R.prototype.writeDoubleLE=function(t,n,r){return dd(this,t,n,!0,r)};R.prototype.writeDoubleBE=function(t,n,r){return dd(this,t,n,!1,r)};R.prototype.copy=function(t,n,r,o){if(r||(r=0),!o&&o!==0&&(o=this.length),n>=t.length&&(n=t.length),n||(n=0),o>0&&o<r&&(o=r),o===r||t.length===0||this.length===0)return 0;if(n<0)throw new RangeError("targetStart out of bounds");if(r<0||r>=this.length)throw new RangeError("sourceStart out of bounds");if(o<0)throw new RangeError("sourceEnd out of bounds");o>this.length&&(o=this.length),t.length-n<o-r&&(o=t.length-n+r);var i=o-r,s;if(this===t&&r<n&&n<o)for(s=i-1;s>=0;--s)t[s+n]=this[s+r];else if(i<1e3||!R.TYPED_ARRAY_SUPPORT)for(s=0;s<i;++s)t[s+n]=this[s+r];else Uint8Array.prototype.set.call(t,this.subarray(r,r+i),n);return i};R.prototype.fill=function(t,n,r,o){if(typeof t=="string"){if(typeof n=="string"?(o=n,n=0,r=this.length):typeof r=="string"&&(o=r,r=this.length),t.length===1){var i=t.charCodeAt(0);i<256&&(t=i)}if(o!==void 0&&typeof o!="string")throw new TypeError("encoding must be a string");if(typeof o=="string"&&!R.isEncoding(o))throw new TypeError("Unknown encoding: "+o)}else typeof t=="number"&&(t=t&255);if(n<0||this.length<n||this.length<r)throw new RangeError("Out of range index");if(r<=n)return this;n=n>>>0,r=r===void 0?this.length:r>>>0,t||(t=0);var s;if(typeof t=="number")for(s=n;s<r;++s)this[s]=t;else{var l=We(t)?t:Dr(new R(t,o).toString()),c=l.length;for(s=0;s<r-n;++s)this[s+n]=l[s%c]}return this};var Jy=/[^+\/0-9A-Za-z-_]/g;function Zy(e){if(e=Xy(e).replace(Jy,""),e.length<2)return"";for(;e.length%4!==0;)e=e+"=";return e}function Xy(e){return e.trim?e.trim():e.replace(/^\s+|\s+$/g,"")}function ew(e){return e<16?"0"+e.toString(16):e.toString(16)}function Dr(e,t){t=t||1/0;for(var n,r=e.length,o=null,i=[],s=0;s<r;++s){if(n=e.charCodeAt(s),n>55295&&n<57344){if(!o){if(n>56319){(t-=3)>-1&&i.push(239,191,189);continue}else if(s+1===r){(t-=3)>-1&&i.push(239,191,189);continue}o=n;continue}if(n<56320){(t-=3)>-1&&i.push(239,191,189),o=n;continue}n=(o-55296<<10|n-56320)+65536}else o&&(t-=3)>-1&&i.push(239,191,189);if(o=null,n<128){if((t-=1)<0)break;i.push(n)}else if(n<2048){if((t-=2)<0)break;i.push(n>>6|192,n&63|128)}else if(n<65536){if((t-=3)<0)break;i.push(n>>12|224,n>>6&63|128,n&63|128)}else if(n<1114112){if((t-=4)<0)break;i.push(n>>18|240,n>>12&63|128,n>>6&63|128,n&63|128)}else throw new Error("Invalid code point")}return i}function tw(e){for(var t=[],n=0;n<e.length;++n)t.push(e.charCodeAt(n)&255);return t}function nw(e,t){for(var n,r,o,i=[],s=0;s<e.length&&!((t-=2)<0);++s)n=e.charCodeAt(s),r=n>>8,o=n%256,i.push(o),i.push(r);return i}function pd(e){return Iy(Zy(e))}function io(e,t,n,r){for(var o=0;o<r&&!(o+n>=t.length||o>=e.length);++o)t[o+n]=e[o];return o}function rw(e){return e!==e}function zt(e){return e!=null&&(!!e._isBuffer||hd(e)||ow(e))}function hd(e){return!!e.constructor&&typeof e.constructor.isBuffer=="function"&&e.constructor.isBuffer(e)}function ow(e){return typeof e.readFloatLE=="function"&&typeof e.slice=="function"&&hd(e.slice(0,0))}const iw=46,sw=/\\(\\)?/g,aw=RegExp(`[^.[\\]]+|\\[(?:([^"'][^[]*)|(["'])((?:(?!\\2)[^\\\\]|\\\\.)*?)\\2)\\]|(?=(?:\\.|\\[\\])(?:\\.|\\[\\]|$))`,"g"),lw=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,cw=/^\w*$/,uw=function(e){return Object.prototype.toString.call(e)},gd=function(e){const t=typeof e;return t==="symbol"||t==="object"&&e&&uw(e)==="[object Symbol]"},fw=function(e,t){if(Array.isArray(e))return!1;const n=typeof e;return n==="number"||n==="symbol"||n==="boolean"||!e||gd(e)?!0:cw.test(e)||!lw.test(e)||t!=null&&e in Object(t)},dw=function(e){const t=[];return e.charCodeAt(0)===iw&&t.push(""),e.replace(aw,function(n,r,o,i){let s=n;o?s=i.replace(sw,"$1"):r&&(s=r.trim()),t.push(s)}),t},pw=function(e,t){return Array.isArray(e)?e:fw(e,t)?[e]:dw(e)},hw=function(e){if(typeof e=="string"||gd(e))return e;const t=`${e}`;return t=="0"&&1/e==-INFINITY?"-0":t},gw=function(e,t){t=pw(t,e);let n=0;const r=t.length;for(;e!=null&&n<r;)e=e[hw(t[n++])];return n&&n===r?e:void 0},mw=function(e){return typeof e=="object"&&e!==null&&!Array.isArray(e)},md=function(e){if(e==null)return[void 0,void 0];if(typeof e!="object")return[Error('Invalid option "columns": expect an array or an object')];if(Array.isArray(e)){const t=[];for(const n of e)if(typeof n=="string")t.push({key:n,header:n});else if(typeof n=="object"&&n!==null&&!Array.isArray(n)){if(!n.key)return[Error('Invalid column definition: property "key" is required')];n.header===void 0&&(n.header=n.key),t.push(n)}else return[Error("Invalid column definition: expect a string or an object")];e=t}else{const t=[];for(const n in e)t.push({key:n,header:e[n]});e=t}return[void 0,e]};class Qt extends Error{constructor(t,n,...r){Array.isArray(n)&&(n=n.join(" ")),super(n),Error.captureStackTrace!==void 0&&Error.captureStackTrace(this,Qt),this.code=t;for(const o of r)for(const i in o){const s=o[i];this[i]=zt(s)?s.toString():s==null?s:JSON.parse(JSON.stringify(s))}}}const xw=function(e){return e.replace(/([A-Z])/g,function(t,n){return"_"+n.toLowerCase()})},xd=function(e){const t={};for(const o in e)t[xw(o)]=e[o];if(t.bom===void 0||t.bom===null||t.bom===!1)t.bom=!1;else if(t.bom!==!0)return[new Qt("CSV_OPTION_BOOLEAN_INVALID_TYPE",["option `bom` is optional and must be a boolean value,",`got ${JSON.stringify(t.bom)}`])];if(t.delimiter===void 0||t.delimiter===null)t.delimiter=",";else if(zt(t.delimiter))t.delimiter=t.delimiter.toString();else if(typeof t.delimiter!="string")return[new Qt("CSV_OPTION_DELIMITER_INVALID_TYPE",["option `delimiter` must be a buffer or a string,",`got ${JSON.stringify(t.delimiter)}`])];if(t.quote===void 0||t.quote===null)t.quote='"';else if(t.quote===!0)t.quote='"';else if(t.quote===!1)t.quote="";else if(zt(t.quote))t.quote=t.quote.toString();else if(typeof t.quote!="string")return[new Qt("CSV_OPTION_QUOTE_INVALID_TYPE",["option `quote` must be a boolean, a buffer or a string,",`got ${JSON.stringify(t.quote)}`])];if((t.quoted===void 0||t.quoted===null)&&(t.quoted=!1),t.escape_formulas===void 0||t.escape_formulas===null)t.escape_formulas=!1;else if(typeof t.escape_formulas!="boolean")return[new Qt("CSV_OPTION_ESCAPE_FORMULAS_INVALID_TYPE",["option `escape_formulas` must be a boolean,",`got ${JSON.stringify(t.escape_formulas)}`])];if((t.quoted_empty===void 0||t.quoted_empty===null)&&(t.quoted_empty=void 0),t.quoted_match===void 0||t.quoted_match===null||t.quoted_match===!1?t.quoted_match=null:Array.isArray(t.quoted_match)||(t.quoted_match=[t.quoted_match]),t.quoted_match)for(const o of t.quoted_match){const i=typeof o=="string",s=o instanceof RegExp;if(!i&&!s)return[Error(`Invalid Option: quoted_match must be a string or a regex, got ${JSON.stringify(o)}`)]}if((t.quoted_string===void 0||t.quoted_string===null)&&(t.quoted_string=!1),(t.eof===void 0||t.eof===null)&&(t.eof=!0),t.escape===void 0||t.escape===null)t.escape='"';else if(zt(t.escape))t.escape=t.escape.toString();else if(typeof t.escape!="string")return[Error(`Invalid Option: escape must be a buffer or a string, got ${JSON.stringify(t.escape)}`)];if(t.escape.length>1)return[Error(`Invalid Option: escape must be one character, got ${t.escape.length} characters`)];(t.header===void 0||t.header===null)&&(t.header=!1);const[n,r]=md(t.columns);if(n!==void 0)return[n];if(t.columns=r,(t.quoted===void 0||t.quoted===null)&&(t.quoted=!1),(t.cast===void 0||t.cast===null)&&(t.cast={}),(t.cast.bigint===void 0||t.cast.bigint===null)&&(t.cast.bigint=o=>""+o),(t.cast.boolean===void 0||t.cast.boolean===null)&&(t.cast.boolean=o=>o?"1":""),(t.cast.date===void 0||t.cast.date===null)&&(t.cast.date=o=>""+o.getTime()),(t.cast.number===void 0||t.cast.number===null)&&(t.cast.number=o=>""+o),(t.cast.object===void 0||t.cast.object===null)&&(t.cast.object=o=>JSON.stringify(o)),(t.cast.string===void 0||t.cast.string===null)&&(t.cast.string=function(o){return o}),t.on_record!==void 0&&typeof t.on_record!="function")return[Error('Invalid Option: "on_record" must be a function.')];if(t.record_delimiter===void 0||t.record_delimiter===null)t.record_delimiter=`
`;else if(zt(t.record_delimiter))t.record_delimiter=t.record_delimiter.toString();else if(typeof t.record_delimiter!="string")return[Error(`Invalid Option: record_delimiter must be a buffer or a string, got ${JSON.stringify(t.record_delimiter)}`)];switch(t.record_delimiter){case"unix":t.record_delimiter=`
`;break;case"mac":t.record_delimiter="\r";break;case"windows":t.record_delimiter=`\r
`;break;case"ascii":t.record_delimiter="";break;case"unicode":t.record_delimiter="\u2028";break}return[void 0,t]},vw=R.from([239,187,191]),yw=function(e,t,n){return{options:e,state:t,info:n,__transform:function(r,o){if(!Array.isArray(r)&&typeof r!="object")return Error(`Invalid Record: expect an array or an object, got ${JSON.stringify(r)}`);if(this.info.records===0){if(Array.isArray(r)){if(this.options.header===!0&&this.options.columns===void 0)return Error("Undiscoverable Columns: header option requires column option or object records")}else if(this.options.columns===void 0){const[l,c]=md(Object.keys(r));if(l)return;this.options.columns=c}}if(this.info.records===0){this.bom(o);const l=this.headers(o);if(l)return l}try{this.options.on_record&&this.options.on_record(r,this.info.records)}catch(l){return l}let i,s;if(this.options.eof){if([i,s]=this.stringify(r),i)return i;if(s===void 0)return;s=s+this.options.record_delimiter}else{if([i,s]=this.stringify(r),i)return i;if(s===void 0)return;(this.options.header||this.info.records)&&(s=this.options.record_delimiter+s)}this.info.records++,o(s)},stringify:function(r,o=!1){if(typeof r!="object")return[void 0,r];const{columns:i}=this.options,s=[];if(Array.isArray(r)){i&&r.splice(i.length);for(let c=0;c<r.length;c++){const u=r[c],[f,d]=this.__cast(u,{index:c,column:c,records:this.info.records,header:o});if(f)return[f];s[c]=[d,u]}}else for(let c=0;c<i.length;c++){const u=gw(r,i[c].key),[f,d]=this.__cast(u,{index:c,column:i[c].key,records:this.info.records,header:o});if(f)return[f];s[c]=[d,u]}let l="";for(let c=0;c<s.length;c++){let u,f,[d,p]=s[c];if(typeof d=="string")u=this.options;else if(mw(d)){if(u=d,d=u.value,delete u.value,typeof d!="string"&&d!==void 0&&d!==null&&f)return[Error(`Invalid Casting Value: returned value must return a string, null or undefined, got ${JSON.stringify(d)}`)];if(u={...this.options,...u},[f,u]=xd(u),f!==void 0)return[f]}else if(d==null)u=this.options;else return[Error(`Invalid Casting Value: returned value must return a string, an object, null or undefined, got ${JSON.stringify(d)}`)];const{delimiter:h,escape:g,quote:m,quoted:v,quoted_empty:y,quoted_string:b,quoted_match:w,record_delimiter:S,escape_formulas:F}=u;if(d===""&&p===""){let C=w&&w.filter(O=>typeof O=="string"?d.indexOf(O)!==-1:O.test(d));C=C&&C.length>0,(C||y===!0||b===!0&&y!==!1)===!0&&(d=m+d+m),l+=d}else if(d){if(typeof d!="string")return[Error(`Formatter must return a string, null or undefined, got ${JSON.stringify(d)}`)];const C=h.length&&d.indexOf(h)>=0,A=m!==""&&d.indexOf(m)>=0,O=d.indexOf(g)>=0&&g!==m,T=d.indexOf(S)>=0,N=b&&typeof p=="string";let E=w&&w.filter(P=>typeof P=="string"?d.indexOf(P)!==-1:P.test(d));if(E=E&&E.length>0,F)switch(d[0]){case"=":case"+":case"-":case"@":case"	":case"\r":case"＝":case"＋":case"－":case"＠":d=`'${d}`;break}const B=A===!0||C||T||v||N||E;if(B===!0&&O===!0){const P=g==="\\"?new RegExp(g+g,"g"):new RegExp(g,"g");d=d.replace(P,g+g)}if(A===!0){const P=new RegExp(m,"g");d=d.replace(P,g+m)}B===!0&&(d=m+d+m),l+=d}else(y===!0||p===""&&b===!0&&y!==!1)&&(l+=m+m);c!==s.length-1&&(l+=h)}return[void 0,l]},bom:function(r){this.options.bom===!0&&r(vw)},headers:function(r){if(this.options.header===!1||this.options.columns===void 0)return;let o,i=this.options.columns.map(s=>s.header);if(this.options.eof?([o,i]=this.stringify(i,!0),i+=this.options.record_delimiter):[o,i]=this.stringify(i),o)return o;r(i)},__cast:function(r,o){const i=typeof r;try{return i==="string"?[void 0,this.options.cast.string(r,o)]:i==="bigint"?[void 0,this.options.cast.bigint(r,o)]:i==="number"?[void 0,this.options.cast.number(r,o)]:i==="boolean"?[void 0,this.options.cast.boolean(r,o)]:r instanceof Date?[void 0,this.options.cast.date(r,o)]:i==="object"&&r!==null?[void 0,this.options.cast.object(r,o)]:[void 0,r,r]}catch(s){return[s]}}}},ww=function(e,t={}){const n=[],[r,o]=xd(t);if(r!==void 0)throw r;const l=yw(o,{stop:!1},{records:0});for(const c of e){const u=l.__transform(c,function(f){n.push(f)});if(u!==void 0)throw u}if(n.length===0){l.bom(u=>{n.push(u)});const c=l.headers(u=>{n.push(u)});if(c!==void 0)throw c}return n.join("")};function Ta(e){return a.jsx(to,{id:"character_tooltip",style:{position:"fixed"},children:e})}const bw=(e,t)=>{const{rows:n}=e.getCoreRowModel(),r=e.getHeaderGroups().map(u=>u.headers.map(f=>f.column.columnDef.header)),o=n.map(u=>u.getVisibleCells().map(f=>f.getValue()));console.log(r,o);const i=ww([...r,...o]),s="csv",l=new Blob([i],{type:`text/${s};charset=utf8;`}),c=document.createElement("a");c.download=t,c.href=URL.createObjectURL(l),c.setAttribute("visibility","hidden"),document.body.appendChild(c),c.click(),document.body.removeChild(c)},so=({isFetching:e=!1,debugTable:t=!1,data:n=[],columns:r,striped:o=!1,hover:i=!1,initialState:s=void 0,exportFileName:l=void 0})=>{let c={pagination:{pageSize:15}};s!==void 0&&(c=s);const u=Oy({data:n,columns:r,getCoreRowModel:gy(),getFilteredRowModel:vy(),getSortedRowModel:Cy(),getPaginationRowModel:Ay(),getFacetedRowModel:yy(),getFacetedUniqueValues:wy(),getFacetedMinMaxValues:by(),debugTable:t,initialState:c});return a.jsx(Cw,{table:u,data:n,columns:r,isFetching:e,debugTable:t,initialState:s,striped:o,hover:i,exportFileName:l})};function Cw({table:e,isFetching:t=!1,striped:n=!1,hover:r=!1,debugTable:o=!1,exportFileName:i=void 0}){const{rows:s}=e.getRowModel(),l=Mp(),c=typeof i<"u"?i:`ExportedData_${l.pathname}`;return a.jsxs(a.Fragment,{children:[a.jsxs(st,{striped:n,hover:r,children:[a.jsx("thead",{children:e.getHeaderGroups().map(u=>a.jsxs(a.Fragment,{children:[a.jsx("tr",{children:u.headers.map(f=>a.jsx("th",{colSpan:f.colSpan,children:f.isPlaceholder?null:a.jsxs("div",{className:f.column.getCanSort()?"d-flex align-items-center cursor-pointer select-none":"d-flex align-items-center",onClick:f.column.getToggleSortingHandler(),children:[f.column.getCanSort()?a.jsx("div",{children:{asc:a.jsx("i",{className:"fas fa-sort-down fa-fw"}),desc:a.jsx("i",{className:"fas fa-sort-up fa-fw"})}[f.column.getIsSorted()]??a.jsx("i",{className:"fas fa-sort fa-fw"})}):null,a.jsx("div",{children:Fa(f.column.columnDef.header,f.getContext())})]})},f.id))},`name-${u.id}`),a.jsx("tr",{children:u.headers.map(f=>a.jsx("th",{colSpan:f.colSpan,children:f.column.getCanFilter()&&s.length>=0?a.jsx($v,{column:f.column,table:e}):a.jsx(a.Fragment,{})},f.id))},`filter-${u.id}`)]}))}),a.jsx("tbody",{children:s.map(u=>a.jsx("tr",{children:u.getVisibleCells().map(f=>a.jsx("td",{style:{verticalAlign:"middle"},children:Fa(f.column.columnDef.cell,f.getContext())},f.id))},u.id))})]}),a.jsxs("div",{className:"d-flex justify-content-between",children:[a.jsxs(wt,{children:[a.jsx(z,{active:!0,variant:"info",children:a.jsxs(a.Fragment,{children:[e.getState().pagination.pageIndex+1," of ",e.getPageCount()]})}),t?a.jsx(Ct,{placement:"bottom",trigger:"focus",overlay:Ta("Refreshing Data"),children:a.jsx(z,{variant:"info",children:a.jsx("i",{className:vv.refreshAnimate+" fas fa-sync"})})}):a.jsx(Ct,{placement:"bottom",trigger:"focus",overlay:Ta("Data Loaded: "+new Date().toLocaleString()),children:a.jsx(z,{variant:"info",children:a.jsx("i",{className:"far fa-check-circle"})})}),a.jsx(z,{active:!0,variant:"primary",onClick:()=>bw(e,c),children:"Export Table to CSV"})," "]}),a.jsxs(Gh,{children:[a.jsxs(wt,{children:[a.jsx(z,{variant:"success",onClick:()=>e.setPageIndex(0),disabled:!e.getCanPreviousPage(),children:a.jsx("i",{className:"fas fa-angle-double-left"})})," ",a.jsx(z,{variant:"success",onClick:()=>e.previousPage(),disabled:!e.getCanPreviousPage(),children:a.jsx("i",{className:"fas fa-caret-left"})})," ",a.jsx(z,{variant:"success",onClick:()=>e.nextPage(),disabled:!e.getCanNextPage(),children:a.jsx("i",{className:"fas fa-caret-right"})}),a.jsx(z,{variant:"success",onClick:()=>e.setPageIndex(e.getPageCount()-1),disabled:!e.getCanNextPage(),children:a.jsx("i",{className:"fas fa-angle-double-right"})})]}),a.jsxs(wt,{className:"ms-1",children:[a.jsx(z,{active:!0,variant:"success",children:"Page Size:"})," ",a.jsx(fv,{id:"pageSizeDropdown",variant:"success",title:e.getState().pagination.pageSize,children:[15,30,60,100,1e6].map(u=>a.jsxs(we.Item,{id:`${u}`,eventKey:u,onClick:f=>{console.log(f.target.id),e.setPageSize(Number(f.target.id))},children:["Show ",u]},u))})]})]})]}),o&&a.jsxs("div",{className:"col-xs-12",children:[a.jsxs("div",{children:[e.getRowModel().rows.length," Rows"]}),a.jsx("pre",{children:JSON.stringify(e.getState(),null,2)})]})]})}const Be=({data:e,isFetching:t,columns:n})=>a.jsx(so,{isFetching:t,columns:n,data:e});/*! js-cookie v3.0.5 | MIT */function er(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)e[r]=n[r]}return e}var Sw={read:function(e){return e[0]==='"'&&(e=e.slice(1,-1)),e.replace(/(%[\dA-F]{2})+/gi,decodeURIComponent)},write:function(e){return encodeURIComponent(e).replace(/%(2[346BF]|3[AC-F]|40|5[BDE]|60|7[BCD])/g,decodeURIComponent)}};function Ni(e,t){function n(o,i,s){if(!(typeof document>"u")){s=er({},t,s),typeof s.expires=="number"&&(s.expires=new Date(Date.now()+s.expires*864e5)),s.expires&&(s.expires=s.expires.toUTCString()),o=encodeURIComponent(o).replace(/%(2[346B]|5E|60|7C)/g,decodeURIComponent).replace(/[()]/g,escape);var l="";for(var c in s)s[c]&&(l+="; "+c,s[c]!==!0&&(l+="="+s[c].split(";")[0]));return document.cookie=o+"="+e.write(i,o)+l}}function r(o){if(!(typeof document>"u"||arguments.length&&!o)){for(var i=document.cookie?document.cookie.split("; "):[],s={},l=0;l<i.length;l++){var c=i[l].split("="),u=c.slice(1).join("=");try{var f=decodeURIComponent(c[0]);if(s[f]=e.read(u,f),o===f)break}catch{}}return o?s[o]:s}}return Object.create({set:n,get:r,remove:function(o,i){n(o,"",er({},i,{expires:-1}))},withAttributes:function(o){return Ni(this.converter,er({},this.attributes,o))},withConverter:function(o){return Ni(er({},this.converter,o),this.attributes)}},{attributes:{value:Object.freeze(t)},converter:{value:Object.freeze(e)}})}var vd=Ni(Sw,{path:"/"});const Aw={"Content-Type":"application/json"},jw=/\{[^{}]+\}/g;class Rw extends Request{constructor(t,n){super(t,n);for(const r in n)r in this||(this[r]=n[r])}}function Fw(){return Math.random().toString(36).slice(2,11)}function Ow(e){let{baseUrl:t="",fetch:n=globalThis.fetch,querySerializer:r,bodySerializer:o,headers:i,...s}={...e};t.endsWith("/")&&(t=t.substring(0,t.length-1)),i=_a(Aw,i);const l=[];async function c(u,f){const{fetch:d=n,headers:p,params:h={},parseAs:g="json",querySerializer:m,bodySerializer:v=o??Iw,...y}=f||{};let b=typeof r=="function"?r:Da(r);m&&(b=typeof m=="function"?m:Da({...typeof r=="object"?r:{},...m}));const w={redirect:"follow",...s,...y,headers:_a(i,p,h.header)};w.body&&(w.body=v(w.body),w.body instanceof FormData&&w.headers.delete("Content-Type"));let S,F,C=new Rw(Nw(u,{baseUrl:t,params:h,querySerializer:b}),w);if(l.length){S=Fw(),F=Object.freeze({baseUrl:t,fetch:d,parseAs:g,querySerializer:b,bodySerializer:v});for(const T of l)if(T&&typeof T=="object"&&typeof T.onRequest=="function"){const N=await T.onRequest({request:C,schemaPath:u,params:h,options:F,id:S});if(N){if(!(N instanceof Request))throw new Error("onRequest: must return new Request() when modifying the request");C=N}}}let A=await d(C);if(l.length)for(let T=l.length-1;T>=0;T--){const N=l[T];if(N&&typeof N=="object"&&typeof N.onResponse=="function"){const E=await N.onResponse({request:C,response:A,schemaPath:u,params:h,options:F,id:S});if(E){if(!(E instanceof Response))throw new Error("onResponse: must return new Response() when modifying the response");A=E}}}if(A.status===204||A.headers.get("Content-Length")==="0")return A.ok?{data:{},response:A}:{error:{},response:A};if(A.ok)return g==="stream"?{data:A.body,response:A}:{data:await A[g](),response:A};let O=await A.text();try{O=JSON.parse(O)}catch{}return{error:O,response:A}}return{async GET(u,f){return c(u,{...f,method:"GET"})},async PUT(u,f){return c(u,{...f,method:"PUT"})},async POST(u,f){return c(u,{...f,method:"POST"})},async DELETE(u,f){return c(u,{...f,method:"DELETE"})},async OPTIONS(u,f){return c(u,{...f,method:"OPTIONS"})},async HEAD(u,f){return c(u,{...f,method:"HEAD"})},async PATCH(u,f){return c(u,{...f,method:"PATCH"})},async TRACE(u,f){return c(u,{...f,method:"TRACE"})},use(...u){for(const f of u)if(f){if(typeof f!="object"||!("onRequest"in f||"onResponse"in f))throw new Error("Middleware must be an object with one of `onRequest()` or `onResponse()`");l.push(f)}},eject(...u){for(const f of u){const d=l.indexOf(f);d!==-1&&l.splice(d,1)}}}}function ao(e,t,n){if(t==null)return"";if(typeof t=="object")throw new Error("Deeply-nested arrays/objects aren’t supported. Provide your own `querySerializer()` to handle these.");return`${e}=${(n==null?void 0:n.allowReserved)===!0?t:encodeURIComponent(t)}`}function yd(e,t,n){if(!t||typeof t!="object")return"";const r=[],o={simple:",",label:".",matrix:";"}[n.style]||"&";if(n.style!=="deepObject"&&n.explode===!1){for(const l in t)r.push(l,n.allowReserved===!0?t[l]:encodeURIComponent(t[l]));const s=r.join(",");switch(n.style){case"form":return`${e}=${s}`;case"label":return`.${s}`;case"matrix":return`;${e}=${s}`;default:return s}}for(const s in t){const l=n.style==="deepObject"?`${e}[${s}]`:s;r.push(ao(l,t[s],n))}const i=r.join(o);return n.style==="label"||n.style==="matrix"?`${o}${i}`:i}function wd(e,t,n){if(!Array.isArray(t))return"";if(n.explode===!1){const i={form:",",spaceDelimited:"%20",pipeDelimited:"|"}[n.style]||",",s=(n.allowReserved===!0?t:t.map(l=>encodeURIComponent(l))).join(i);switch(n.style){case"simple":return s;case"label":return`.${s}`;case"matrix":return`;${e}=${s}`;default:return`${e}=${s}`}}const r={simple:",",label:".",matrix:";"}[n.style]||"&",o=[];for(const i of t)n.style==="simple"||n.style==="label"?o.push(n.allowReserved===!0?i:encodeURIComponent(i)):o.push(ao(e,i,n));return n.style==="label"||n.style==="matrix"?`${r}${o.join(r)}`:o.join(r)}function Da(e){return function(n){const r=[];if(n&&typeof n=="object")for(const o in n){const i=n[o];if(i!=null){if(Array.isArray(i)){r.push(wd(o,i,{style:"form",explode:!0,...e==null?void 0:e.array,allowReserved:(e==null?void 0:e.allowReserved)||!1}));continue}if(typeof i=="object"){r.push(yd(o,i,{style:"deepObject",explode:!0,...e==null?void 0:e.object,allowReserved:(e==null?void 0:e.allowReserved)||!1}));continue}r.push(ao(o,i,e))}}return r.join("&")}}function Ew(e,t){let n=e;for(const r of e.match(jw)??[]){let o=r.substring(1,r.length-1),i=!1,s="simple";if(o.endsWith("*")&&(i=!0,o=o.substring(0,o.length-1)),o.startsWith(".")?(s="label",o=o.substring(1)):o.startsWith(";")&&(s="matrix",o=o.substring(1)),!t||t[o]===void 0||t[o]===null)continue;const l=t[o];if(Array.isArray(l)){n=n.replace(r,wd(o,l,{style:s,explode:i}));continue}if(typeof l=="object"){n=n.replace(r,yd(o,l,{style:s,explode:i}));continue}if(s==="matrix"){n=n.replace(r,`;${ao(o,l)}`);continue}n=n.replace(r,s==="label"?`.${encodeURIComponent(l)}`:encodeURIComponent(l))}return n}function Iw(e){return JSON.stringify(e)}function Nw(e,t){var o;let n=`${t.baseUrl}${e}`;(o=t.params)!=null&&o.path&&(n=Ew(n,t.params.path));let r=t.querySerializer(t.params.query??{});return r.startsWith("?")&&(r=r.substring(1)),r&&(n+=`?${r}`),n}function _a(...e){const t=new Headers;for(const n of e){if(!n||typeof n!="object")continue;const r=n instanceof Headers?n.entries():Object.entries(n);for(const[o,i]of r)if(i===null)t.delete(o);else if(Array.isArray(i))for(const s of i)t.append(o,s);else i!==void 0&&t.set(o,i)}return t}const $s=()=>{const e=vd.get("csrftoken");return Ow({baseUrl:"/",headers:{"x-csrftoken":e||""}})};function bd(e,t){return function(){return e.apply(t,arguments)}}const{toString:Tw}=Object.prototype,{getPrototypeOf:Bs}=Object,lo=(e=>t=>{const n=Tw.call(t);return e[n]||(e[n]=n.slice(8,-1).toLowerCase())})(Object.create(null)),Qe=e=>(e=e.toLowerCase(),t=>lo(t)===e),co=e=>t=>typeof t===e,{isArray:an}=Array,Dn=co("undefined");function Dw(e){return e!==null&&!Dn(e)&&e.constructor!==null&&!Dn(e.constructor)&&De(e.constructor.isBuffer)&&e.constructor.isBuffer(e)}const Cd=Qe("ArrayBuffer");function _w(e){let t;return typeof ArrayBuffer<"u"&&ArrayBuffer.isView?t=ArrayBuffer.isView(e):t=e&&e.buffer&&Cd(e.buffer),t}const $w=co("string"),De=co("function"),Sd=co("number"),uo=e=>e!==null&&typeof e=="object",Bw=e=>e===!0||e===!1,vr=e=>{if(lo(e)!=="object")return!1;const t=Bs(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)},Pw=Qe("Date"),kw=Qe("File"),Lw=Qe("Blob"),Mw=Qe("FileList"),Uw=e=>uo(e)&&De(e.pipe),Vw=e=>{let t;return e&&(typeof FormData=="function"&&e instanceof FormData||De(e.append)&&((t=lo(e))==="formdata"||t==="object"&&De(e.toString)&&e.toString()==="[object FormData]"))},Hw=Qe("URLSearchParams"),Gw=e=>e.trim?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"");function Vn(e,t,{allOwnKeys:n=!1}={}){if(e===null||typeof e>"u")return;let r,o;if(typeof e!="object"&&(e=[e]),an(e))for(r=0,o=e.length;r<o;r++)t.call(null,e[r],r,e);else{const i=n?Object.getOwnPropertyNames(e):Object.keys(e),s=i.length;let l;for(r=0;r<s;r++)l=i[r],t.call(null,e[l],l,e)}}function Ad(e,t){t=t.toLowerCase();const n=Object.keys(e);let r=n.length,o;for(;r-- >0;)if(o=n[r],t===o.toLowerCase())return o;return null}const jd=typeof globalThis<"u"?globalThis:typeof self<"u"?self:typeof window<"u"?window:global,Rd=e=>!Dn(e)&&e!==jd;function Ti(){const{caseless:e}=Rd(this)&&this||{},t={},n=(r,o)=>{const i=e&&Ad(t,o)||o;vr(t[i])&&vr(r)?t[i]=Ti(t[i],r):vr(r)?t[i]=Ti({},r):an(r)?t[i]=r.slice():t[i]=r};for(let r=0,o=arguments.length;r<o;r++)arguments[r]&&Vn(arguments[r],n);return t}const Ww=(e,t,n,{allOwnKeys:r}={})=>(Vn(t,(o,i)=>{n&&De(o)?e[i]=bd(o,n):e[i]=o},{allOwnKeys:r}),e),zw=e=>(e.charCodeAt(0)===65279&&(e=e.slice(1)),e),Qw=(e,t,n,r)=>{e.prototype=Object.create(t.prototype,r),e.prototype.constructor=e,Object.defineProperty(e,"super",{value:t.prototype}),n&&Object.assign(e.prototype,n)},qw=(e,t,n,r)=>{let o,i,s;const l={};if(t=t||{},e==null)return t;do{for(o=Object.getOwnPropertyNames(e),i=o.length;i-- >0;)s=o[i],(!r||r(s,e,t))&&!l[s]&&(t[s]=e[s],l[s]=!0);e=n!==!1&&Bs(e)}while(e&&(!n||n(e,t))&&e!==Object.prototype);return t},Kw=(e,t,n)=>{e=String(e),(n===void 0||n>e.length)&&(n=e.length),n-=t.length;const r=e.indexOf(t,n);return r!==-1&&r===n},Yw=e=>{if(!e)return null;if(an(e))return e;let t=e.length;if(!Sd(t))return null;const n=new Array(t);for(;t-- >0;)n[t]=e[t];return n},Jw=(e=>t=>e&&t instanceof e)(typeof Uint8Array<"u"&&Bs(Uint8Array)),Zw=(e,t)=>{const r=(e&&e[Symbol.iterator]).call(e);let o;for(;(o=r.next())&&!o.done;){const i=o.value;t.call(e,i[0],i[1])}},Xw=(e,t)=>{let n;const r=[];for(;(n=e.exec(t))!==null;)r.push(n);return r},e0=Qe("HTMLFormElement"),t0=e=>e.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,function(n,r,o){return r.toUpperCase()+o}),$a=(({hasOwnProperty:e})=>(t,n)=>e.call(t,n))(Object.prototype),n0=Qe("RegExp"),Fd=(e,t)=>{const n=Object.getOwnPropertyDescriptors(e),r={};Vn(n,(o,i)=>{let s;(s=t(o,i,e))!==!1&&(r[i]=s||o)}),Object.defineProperties(e,r)},r0=e=>{Fd(e,(t,n)=>{if(De(e)&&["arguments","caller","callee"].indexOf(n)!==-1)return!1;const r=e[n];if(De(r)){if(t.enumerable=!1,"writable"in t){t.writable=!1;return}t.set||(t.set=()=>{throw Error("Can not rewrite read-only method '"+n+"'")})}})},o0=(e,t)=>{const n={},r=o=>{o.forEach(i=>{n[i]=!0})};return an(e)?r(e):r(String(e).split(t)),n},i0=()=>{},s0=(e,t)=>(e=+e,Number.isFinite(e)?e:t),Uo="abcdefghijklmnopqrstuvwxyz",Ba="0123456789",Od={DIGIT:Ba,ALPHA:Uo,ALPHA_DIGIT:Uo+Uo.toUpperCase()+Ba},a0=(e=16,t=Od.ALPHA_DIGIT)=>{let n="";const{length:r}=t;for(;e--;)n+=t[Math.random()*r|0];return n};function l0(e){return!!(e&&De(e.append)&&e[Symbol.toStringTag]==="FormData"&&e[Symbol.iterator])}const c0=e=>{const t=new Array(10),n=(r,o)=>{if(uo(r)){if(t.indexOf(r)>=0)return;if(!("toJSON"in r)){t[o]=r;const i=an(r)?[]:{};return Vn(r,(s,l)=>{const c=n(s,o+1);!Dn(c)&&(i[l]=c)}),t[o]=void 0,i}}return r};return n(e,0)},u0=Qe("AsyncFunction"),f0=e=>e&&(uo(e)||De(e))&&De(e.then)&&De(e.catch),j={isArray:an,isArrayBuffer:Cd,isBuffer:Dw,isFormData:Vw,isArrayBufferView:_w,isString:$w,isNumber:Sd,isBoolean:Bw,isObject:uo,isPlainObject:vr,isUndefined:Dn,isDate:Pw,isFile:kw,isBlob:Lw,isRegExp:n0,isFunction:De,isStream:Uw,isURLSearchParams:Hw,isTypedArray:Jw,isFileList:Mw,forEach:Vn,merge:Ti,extend:Ww,trim:Gw,stripBOM:zw,inherits:Qw,toFlatObject:qw,kindOf:lo,kindOfTest:Qe,endsWith:Kw,toArray:Yw,forEachEntry:Zw,matchAll:Xw,isHTMLForm:e0,hasOwnProperty:$a,hasOwnProp:$a,reduceDescriptors:Fd,freezeMethods:r0,toObjectSet:o0,toCamelCase:t0,noop:i0,toFiniteNumber:s0,findKey:Ad,global:jd,isContextDefined:Rd,ALPHABET:Od,generateString:a0,isSpecCompliantForm:l0,toJSONObject:c0,isAsyncFn:u0,isThenable:f0};function Y(e,t,n,r,o){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=new Error().stack,this.message=e,this.name="AxiosError",t&&(this.code=t),n&&(this.config=n),r&&(this.request=r),o&&(this.response=o)}j.inherits(Y,Error,{toJSON:function(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:j.toJSONObject(this.config),code:this.code,status:this.response&&this.response.status?this.response.status:null}}});const Ed=Y.prototype,Id={};["ERR_BAD_OPTION_VALUE","ERR_BAD_OPTION","ECONNABORTED","ETIMEDOUT","ERR_NETWORK","ERR_FR_TOO_MANY_REDIRECTS","ERR_DEPRECATED","ERR_BAD_RESPONSE","ERR_BAD_REQUEST","ERR_CANCELED","ERR_NOT_SUPPORT","ERR_INVALID_URL"].forEach(e=>{Id[e]={value:e}});Object.defineProperties(Y,Id);Object.defineProperty(Ed,"isAxiosError",{value:!0});Y.from=(e,t,n,r,o,i)=>{const s=Object.create(Ed);return j.toFlatObject(e,s,function(c){return c!==Error.prototype},l=>l!=="isAxiosError"),Y.call(s,e.message,t,n,r,o),s.cause=e,s.name=e.name,i&&Object.assign(s,i),s};const d0=null;function Di(e){return j.isPlainObject(e)||j.isArray(e)}function Nd(e){return j.endsWith(e,"[]")?e.slice(0,-2):e}function Pa(e,t,n){return e?e.concat(t).map(function(o,i){return o=Nd(o),!n&&i?"["+o+"]":o}).join(n?".":""):t}function p0(e){return j.isArray(e)&&!e.some(Di)}const h0=j.toFlatObject(j,{},null,function(t){return/^is[A-Z]/.test(t)});function fo(e,t,n){if(!j.isObject(e))throw new TypeError("target must be an object");t=t||new FormData,n=j.toFlatObject(n,{metaTokens:!0,dots:!1,indexes:!1},!1,function(m,v){return!j.isUndefined(v[m])});const r=n.metaTokens,o=n.visitor||f,i=n.dots,s=n.indexes,c=(n.Blob||typeof Blob<"u"&&Blob)&&j.isSpecCompliantForm(t);if(!j.isFunction(o))throw new TypeError("visitor must be a function");function u(g){if(g===null)return"";if(j.isDate(g))return g.toISOString();if(!c&&j.isBlob(g))throw new Y("Blob is not supported. Use a Buffer instead.");return j.isArrayBuffer(g)||j.isTypedArray(g)?c&&typeof Blob=="function"?new Blob([g]):Buffer.from(g):g}function f(g,m,v){let y=g;if(g&&!v&&typeof g=="object"){if(j.endsWith(m,"{}"))m=r?m:m.slice(0,-2),g=JSON.stringify(g);else if(j.isArray(g)&&p0(g)||(j.isFileList(g)||j.endsWith(m,"[]"))&&(y=j.toArray(g)))return m=Nd(m),y.forEach(function(w,S){!(j.isUndefined(w)||w===null)&&t.append(s===!0?Pa([m],S,i):s===null?m:m+"[]",u(w))}),!1}return Di(g)?!0:(t.append(Pa(v,m,i),u(g)),!1)}const d=[],p=Object.assign(h0,{defaultVisitor:f,convertValue:u,isVisitable:Di});function h(g,m){if(!j.isUndefined(g)){if(d.indexOf(g)!==-1)throw Error("Circular reference detected in "+m.join("."));d.push(g),j.forEach(g,function(y,b){(!(j.isUndefined(y)||y===null)&&o.call(t,y,j.isString(b)?b.trim():b,m,p))===!0&&h(y,m?m.concat(b):[b])}),d.pop()}}if(!j.isObject(e))throw new TypeError("data must be an object");return h(e),t}function ka(e){const t={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(e).replace(/[!'()~]|%20|%00/g,function(r){return t[r]})}function Ps(e,t){this._pairs=[],e&&fo(e,this,t)}const Td=Ps.prototype;Td.append=function(t,n){this._pairs.push([t,n])};Td.toString=function(t){const n=t?function(r){return t.call(this,r,ka)}:ka;return this._pairs.map(function(o){return n(o[0])+"="+n(o[1])},"").join("&")};function g0(e){return encodeURIComponent(e).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}function Dd(e,t,n){if(!t)return e;const r=n&&n.encode||g0,o=n&&n.serialize;let i;if(o?i=o(t,n):i=j.isURLSearchParams(t)?t.toString():new Ps(t,n).toString(r),i){const s=e.indexOf("#");s!==-1&&(e=e.slice(0,s)),e+=(e.indexOf("?")===-1?"?":"&")+i}return e}class La{constructor(){this.handlers=[]}use(t,n,r){return this.handlers.push({fulfilled:t,rejected:n,synchronous:r?r.synchronous:!1,runWhen:r?r.runWhen:null}),this.handlers.length-1}eject(t){this.handlers[t]&&(this.handlers[t]=null)}clear(){this.handlers&&(this.handlers=[])}forEach(t){j.forEach(this.handlers,function(r){r!==null&&t(r)})}}const _d={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1},m0=typeof URLSearchParams<"u"?URLSearchParams:Ps,x0=typeof FormData<"u"?FormData:null,v0=typeof Blob<"u"?Blob:null,y0={isBrowser:!0,classes:{URLSearchParams:m0,FormData:x0,Blob:v0},protocols:["http","https","file","blob","url","data"]},$d=typeof window<"u"&&typeof document<"u",w0=(e=>$d&&["ReactNative","NativeScript","NS"].indexOf(e)<0)(typeof navigator<"u"&&navigator.product),b0=typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope&&typeof self.importScripts=="function",C0=Object.freeze(Object.defineProperty({__proto__:null,hasBrowserEnv:$d,hasStandardBrowserEnv:w0,hasStandardBrowserWebWorkerEnv:b0},Symbol.toStringTag,{value:"Module"})),Ue={...C0,...y0};function S0(e,t){return fo(e,new Ue.classes.URLSearchParams,Object.assign({visitor:function(n,r,o,i){return Ue.isNode&&j.isBuffer(n)?(this.append(r,n.toString("base64")),!1):i.defaultVisitor.apply(this,arguments)}},t))}function A0(e){return j.matchAll(/\w+|\[(\w*)]/g,e).map(t=>t[0]==="[]"?"":t[1]||t[0])}function j0(e){const t={},n=Object.keys(e);let r;const o=n.length;let i;for(r=0;r<o;r++)i=n[r],t[i]=e[i];return t}function Bd(e){function t(n,r,o,i){let s=n[i++];if(s==="__proto__")return!0;const l=Number.isFinite(+s),c=i>=n.length;return s=!s&&j.isArray(o)?o.length:s,c?(j.hasOwnProp(o,s)?o[s]=[o[s],r]:o[s]=r,!l):((!o[s]||!j.isObject(o[s]))&&(o[s]=[]),t(n,r,o[s],i)&&j.isArray(o[s])&&(o[s]=j0(o[s])),!l)}if(j.isFormData(e)&&j.isFunction(e.entries)){const n={};return j.forEachEntry(e,(r,o)=>{t(A0(r),o,n,0)}),n}return null}function R0(e,t,n){if(j.isString(e))try{return(t||JSON.parse)(e),j.trim(e)}catch(r){if(r.name!=="SyntaxError")throw r}return(n||JSON.stringify)(e)}const ks={transitional:_d,adapter:["xhr","http"],transformRequest:[function(t,n){const r=n.getContentType()||"",o=r.indexOf("application/json")>-1,i=j.isObject(t);if(i&&j.isHTMLForm(t)&&(t=new FormData(t)),j.isFormData(t))return o?JSON.stringify(Bd(t)):t;if(j.isArrayBuffer(t)||j.isBuffer(t)||j.isStream(t)||j.isFile(t)||j.isBlob(t))return t;if(j.isArrayBufferView(t))return t.buffer;if(j.isURLSearchParams(t))return n.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),t.toString();let l;if(i){if(r.indexOf("application/x-www-form-urlencoded")>-1)return S0(t,this.formSerializer).toString();if((l=j.isFileList(t))||r.indexOf("multipart/form-data")>-1){const c=this.env&&this.env.FormData;return fo(l?{"files[]":t}:t,c&&new c,this.formSerializer)}}return i||o?(n.setContentType("application/json",!1),R0(t)):t}],transformResponse:[function(t){const n=this.transitional||ks.transitional,r=n&&n.forcedJSONParsing,o=this.responseType==="json";if(t&&j.isString(t)&&(r&&!this.responseType||o)){const s=!(n&&n.silentJSONParsing)&&o;try{return JSON.parse(t)}catch(l){if(s)throw l.name==="SyntaxError"?Y.from(l,Y.ERR_BAD_RESPONSE,this,null,this.response):l}}return t}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:Ue.classes.FormData,Blob:Ue.classes.Blob},validateStatus:function(t){return t>=200&&t<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};j.forEach(["delete","get","head","post","put","patch"],e=>{ks.headers[e]={}});const Ls=ks,F0=j.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),O0=e=>{const t={};let n,r,o;return e&&e.split(`
`).forEach(function(s){o=s.indexOf(":"),n=s.substring(0,o).trim().toLowerCase(),r=s.substring(o+1).trim(),!(!n||t[n]&&F0[n])&&(n==="set-cookie"?t[n]?t[n].push(r):t[n]=[r]:t[n]=t[n]?t[n]+", "+r:r)}),t},Ma=Symbol("internals");function hn(e){return e&&String(e).trim().toLowerCase()}function yr(e){return e===!1||e==null?e:j.isArray(e)?e.map(yr):String(e)}function E0(e){const t=Object.create(null),n=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;let r;for(;r=n.exec(e);)t[r[1]]=r[2];return t}const I0=e=>/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim());function Vo(e,t,n,r,o){if(j.isFunction(r))return r.call(this,t,n);if(o&&(t=n),!!j.isString(t)){if(j.isString(r))return t.indexOf(r)!==-1;if(j.isRegExp(r))return r.test(t)}}function N0(e){return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(t,n,r)=>n.toUpperCase()+r)}function T0(e,t){const n=j.toCamelCase(" "+t);["get","set","has"].forEach(r=>{Object.defineProperty(e,r+n,{value:function(o,i,s){return this[r].call(this,t,o,i,s)},configurable:!0})})}class po{constructor(t){t&&this.set(t)}set(t,n,r){const o=this;function i(l,c,u){const f=hn(c);if(!f)throw new Error("header name must be a non-empty string");const d=j.findKey(o,f);(!d||o[d]===void 0||u===!0||u===void 0&&o[d]!==!1)&&(o[d||c]=yr(l))}const s=(l,c)=>j.forEach(l,(u,f)=>i(u,f,c));return j.isPlainObject(t)||t instanceof this.constructor?s(t,n):j.isString(t)&&(t=t.trim())&&!I0(t)?s(O0(t),n):t!=null&&i(n,t,r),this}get(t,n){if(t=hn(t),t){const r=j.findKey(this,t);if(r){const o=this[r];if(!n)return o;if(n===!0)return E0(o);if(j.isFunction(n))return n.call(this,o,r);if(j.isRegExp(n))return n.exec(o);throw new TypeError("parser must be boolean|regexp|function")}}}has(t,n){if(t=hn(t),t){const r=j.findKey(this,t);return!!(r&&this[r]!==void 0&&(!n||Vo(this,this[r],r,n)))}return!1}delete(t,n){const r=this;let o=!1;function i(s){if(s=hn(s),s){const l=j.findKey(r,s);l&&(!n||Vo(r,r[l],l,n))&&(delete r[l],o=!0)}}return j.isArray(t)?t.forEach(i):i(t),o}clear(t){const n=Object.keys(this);let r=n.length,o=!1;for(;r--;){const i=n[r];(!t||Vo(this,this[i],i,t,!0))&&(delete this[i],o=!0)}return o}normalize(t){const n=this,r={};return j.forEach(this,(o,i)=>{const s=j.findKey(r,i);if(s){n[s]=yr(o),delete n[i];return}const l=t?N0(i):String(i).trim();l!==i&&delete n[i],n[l]=yr(o),r[l]=!0}),this}concat(...t){return this.constructor.concat(this,...t)}toJSON(t){const n=Object.create(null);return j.forEach(this,(r,o)=>{r!=null&&r!==!1&&(n[o]=t&&j.isArray(r)?r.join(", "):r)}),n}[Symbol.iterator](){return Object.entries(this.toJSON())[Symbol.iterator]()}toString(){return Object.entries(this.toJSON()).map(([t,n])=>t+": "+n).join(`
`)}get[Symbol.toStringTag](){return"AxiosHeaders"}static from(t){return t instanceof this?t:new this(t)}static concat(t,...n){const r=new this(t);return n.forEach(o=>r.set(o)),r}static accessor(t){const r=(this[Ma]=this[Ma]={accessors:{}}).accessors,o=this.prototype;function i(s){const l=hn(s);r[l]||(T0(o,s),r[l]=!0)}return j.isArray(t)?t.forEach(i):i(t),this}}po.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]);j.reduceDescriptors(po.prototype,({value:e},t)=>{let n=t[0].toUpperCase()+t.slice(1);return{get:()=>e,set(r){this[n]=r}}});j.freezeMethods(po);const nt=po;function Ho(e,t){const n=this||Ls,r=t||n,o=nt.from(r.headers);let i=r.data;return j.forEach(e,function(l){i=l.call(n,i,o.normalize(),t?t.status:void 0)}),o.normalize(),i}function Pd(e){return!!(e&&e.__CANCEL__)}function Hn(e,t,n){Y.call(this,e??"canceled",Y.ERR_CANCELED,t,n),this.name="CanceledError"}j.inherits(Hn,Y,{__CANCEL__:!0});function D0(e,t,n){const r=n.config.validateStatus;!n.status||!r||r(n.status)?e(n):t(new Y("Request failed with status code "+n.status,[Y.ERR_BAD_REQUEST,Y.ERR_BAD_RESPONSE][Math.floor(n.status/100)-4],n.config,n.request,n))}const _0=Ue.hasStandardBrowserEnv?{write(e,t,n,r,o,i){const s=[e+"="+encodeURIComponent(t)];j.isNumber(n)&&s.push("expires="+new Date(n).toGMTString()),j.isString(r)&&s.push("path="+r),j.isString(o)&&s.push("domain="+o),i===!0&&s.push("secure"),document.cookie=s.join("; ")},read(e){const t=document.cookie.match(new RegExp("(^|;\\s*)("+e+")=([^;]*)"));return t?decodeURIComponent(t[3]):null},remove(e){this.write(e,"",Date.now()-864e5)}}:{write(){},read(){return null},remove(){}};function $0(e){return/^([a-z][a-z\d+\-.]*:)?\/\//i.test(e)}function B0(e,t){return t?e.replace(/\/?\/$/,"")+"/"+t.replace(/^\/+/,""):e}function kd(e,t){return e&&!$0(t)?B0(e,t):t}const P0=Ue.hasStandardBrowserEnv?function(){const t=/(msie|trident)/i.test(navigator.userAgent),n=document.createElement("a");let r;function o(i){let s=i;return t&&(n.setAttribute("href",s),s=n.href),n.setAttribute("href",s),{href:n.href,protocol:n.protocol?n.protocol.replace(/:$/,""):"",host:n.host,search:n.search?n.search.replace(/^\?/,""):"",hash:n.hash?n.hash.replace(/^#/,""):"",hostname:n.hostname,port:n.port,pathname:n.pathname.charAt(0)==="/"?n.pathname:"/"+n.pathname}}return r=o(window.location.href),function(s){const l=j.isString(s)?o(s):s;return l.protocol===r.protocol&&l.host===r.host}}():function(){return function(){return!0}}();function k0(e){const t=/^([-+\w]{1,25})(:?\/\/|:)/.exec(e);return t&&t[1]||""}function L0(e,t){e=e||10;const n=new Array(e),r=new Array(e);let o=0,i=0,s;return t=t!==void 0?t:1e3,function(c){const u=Date.now(),f=r[i];s||(s=u),n[o]=c,r[o]=u;let d=i,p=0;for(;d!==o;)p+=n[d++],d=d%e;if(o=(o+1)%e,o===i&&(i=(i+1)%e),u-s<t)return;const h=f&&u-f;return h?Math.round(p*1e3/h):void 0}}function Ua(e,t){let n=0;const r=L0(50,250);return o=>{const i=o.loaded,s=o.lengthComputable?o.total:void 0,l=i-n,c=r(l),u=i<=s;n=i;const f={loaded:i,total:s,progress:s?i/s:void 0,bytes:l,rate:c||void 0,estimated:c&&s&&u?(s-i)/c:void 0,event:o};f[t?"download":"upload"]=!0,e(f)}}const M0=typeof XMLHttpRequest<"u",U0=M0&&function(e){return new Promise(function(n,r){let o=e.data;const i=nt.from(e.headers).normalize();let{responseType:s,withXSRFToken:l}=e,c;function u(){e.cancelToken&&e.cancelToken.unsubscribe(c),e.signal&&e.signal.removeEventListener("abort",c)}let f;if(j.isFormData(o)){if(Ue.hasStandardBrowserEnv||Ue.hasStandardBrowserWebWorkerEnv)i.setContentType(!1);else if((f=i.getContentType())!==!1){const[m,...v]=f?f.split(";").map(y=>y.trim()).filter(Boolean):[];i.setContentType([m||"multipart/form-data",...v].join("; "))}}let d=new XMLHttpRequest;if(e.auth){const m=e.auth.username||"",v=e.auth.password?unescape(encodeURIComponent(e.auth.password)):"";i.set("Authorization","Basic "+btoa(m+":"+v))}const p=kd(e.baseURL,e.url);d.open(e.method.toUpperCase(),Dd(p,e.params,e.paramsSerializer),!0),d.timeout=e.timeout;function h(){if(!d)return;const m=nt.from("getAllResponseHeaders"in d&&d.getAllResponseHeaders()),y={data:!s||s==="text"||s==="json"?d.responseText:d.response,status:d.status,statusText:d.statusText,headers:m,config:e,request:d};D0(function(w){n(w),u()},function(w){r(w),u()},y),d=null}if("onloadend"in d?d.onloadend=h:d.onreadystatechange=function(){!d||d.readyState!==4||d.status===0&&!(d.responseURL&&d.responseURL.indexOf("file:")===0)||setTimeout(h)},d.onabort=function(){d&&(r(new Y("Request aborted",Y.ECONNABORTED,e,d)),d=null)},d.onerror=function(){r(new Y("Network Error",Y.ERR_NETWORK,e,d)),d=null},d.ontimeout=function(){let v=e.timeout?"timeout of "+e.timeout+"ms exceeded":"timeout exceeded";const y=e.transitional||_d;e.timeoutErrorMessage&&(v=e.timeoutErrorMessage),r(new Y(v,y.clarifyTimeoutError?Y.ETIMEDOUT:Y.ECONNABORTED,e,d)),d=null},Ue.hasStandardBrowserEnv&&(l&&j.isFunction(l)&&(l=l(e)),l||l!==!1&&P0(p))){const m=e.xsrfHeaderName&&e.xsrfCookieName&&_0.read(e.xsrfCookieName);m&&i.set(e.xsrfHeaderName,m)}o===void 0&&i.setContentType(null),"setRequestHeader"in d&&j.forEach(i.toJSON(),function(v,y){d.setRequestHeader(y,v)}),j.isUndefined(e.withCredentials)||(d.withCredentials=!!e.withCredentials),s&&s!=="json"&&(d.responseType=e.responseType),typeof e.onDownloadProgress=="function"&&d.addEventListener("progress",Ua(e.onDownloadProgress,!0)),typeof e.onUploadProgress=="function"&&d.upload&&d.upload.addEventListener("progress",Ua(e.onUploadProgress)),(e.cancelToken||e.signal)&&(c=m=>{d&&(r(!m||m.type?new Hn(null,e,d):m),d.abort(),d=null)},e.cancelToken&&e.cancelToken.subscribe(c),e.signal&&(e.signal.aborted?c():e.signal.addEventListener("abort",c)));const g=k0(p);if(g&&Ue.protocols.indexOf(g)===-1){r(new Y("Unsupported protocol "+g+":",Y.ERR_BAD_REQUEST,e));return}d.send(o||null)})},_i={http:d0,xhr:U0};j.forEach(_i,(e,t)=>{if(e){try{Object.defineProperty(e,"name",{value:t})}catch{}Object.defineProperty(e,"adapterName",{value:t})}});const Va=e=>`- ${e}`,V0=e=>j.isFunction(e)||e===null||e===!1,Ld={getAdapter:e=>{e=j.isArray(e)?e:[e];const{length:t}=e;let n,r;const o={};for(let i=0;i<t;i++){n=e[i];let s;if(r=n,!V0(n)&&(r=_i[(s=String(n)).toLowerCase()],r===void 0))throw new Y(`Unknown adapter '${s}'`);if(r)break;o[s||"#"+i]=r}if(!r){const i=Object.entries(o).map(([l,c])=>`adapter ${l} `+(c===!1?"is not supported by the environment":"is not available in the build"));let s=t?i.length>1?`since :
`+i.map(Va).join(`
`):" "+Va(i[0]):"as no adapter specified";throw new Y("There is no suitable adapter to dispatch the request "+s,"ERR_NOT_SUPPORT")}return r},adapters:_i};function Go(e){if(e.cancelToken&&e.cancelToken.throwIfRequested(),e.signal&&e.signal.aborted)throw new Hn(null,e)}function Ha(e){return Go(e),e.headers=nt.from(e.headers),e.data=Ho.call(e,e.transformRequest),["post","put","patch"].indexOf(e.method)!==-1&&e.headers.setContentType("application/x-www-form-urlencoded",!1),Ld.getAdapter(e.adapter||Ls.adapter)(e).then(function(r){return Go(e),r.data=Ho.call(e,e.transformResponse,r),r.headers=nt.from(r.headers),r},function(r){return Pd(r)||(Go(e),r&&r.response&&(r.response.data=Ho.call(e,e.transformResponse,r.response),r.response.headers=nt.from(r.response.headers))),Promise.reject(r)})}const Ga=e=>e instanceof nt?e.toJSON():e;function nn(e,t){t=t||{};const n={};function r(u,f,d){return j.isPlainObject(u)&&j.isPlainObject(f)?j.merge.call({caseless:d},u,f):j.isPlainObject(f)?j.merge({},f):j.isArray(f)?f.slice():f}function o(u,f,d){if(j.isUndefined(f)){if(!j.isUndefined(u))return r(void 0,u,d)}else return r(u,f,d)}function i(u,f){if(!j.isUndefined(f))return r(void 0,f)}function s(u,f){if(j.isUndefined(f)){if(!j.isUndefined(u))return r(void 0,u)}else return r(void 0,f)}function l(u,f,d){if(d in t)return r(u,f);if(d in e)return r(void 0,u)}const c={url:i,method:i,data:i,baseURL:s,transformRequest:s,transformResponse:s,paramsSerializer:s,timeout:s,timeoutMessage:s,withCredentials:s,withXSRFToken:s,adapter:s,responseType:s,xsrfCookieName:s,xsrfHeaderName:s,onUploadProgress:s,onDownloadProgress:s,decompress:s,maxContentLength:s,maxBodyLength:s,beforeRedirect:s,transport:s,httpAgent:s,httpsAgent:s,cancelToken:s,socketPath:s,responseEncoding:s,validateStatus:l,headers:(u,f)=>o(Ga(u),Ga(f),!0)};return j.forEach(Object.keys(Object.assign({},e,t)),function(f){const d=c[f]||o,p=d(e[f],t[f],f);j.isUndefined(p)&&d!==l||(n[f]=p)}),n}const Md="1.6.7",Ms={};["object","boolean","number","function","string","symbol"].forEach((e,t)=>{Ms[e]=function(r){return typeof r===e||"a"+(t<1?"n ":" ")+e}});const Wa={};Ms.transitional=function(t,n,r){function o(i,s){return"[Axios v"+Md+"] Transitional option '"+i+"'"+s+(r?". "+r:"")}return(i,s,l)=>{if(t===!1)throw new Y(o(s," has been removed"+(n?" in "+n:"")),Y.ERR_DEPRECATED);return n&&!Wa[s]&&(Wa[s]=!0,console.warn(o(s," has been deprecated since v"+n+" and will be removed in the near future"))),t?t(i,s,l):!0}};function H0(e,t,n){if(typeof e!="object")throw new Y("options must be an object",Y.ERR_BAD_OPTION_VALUE);const r=Object.keys(e);let o=r.length;for(;o-- >0;){const i=r[o],s=t[i];if(s){const l=e[i],c=l===void 0||s(l,i,e);if(c!==!0)throw new Y("option "+i+" must be "+c,Y.ERR_BAD_OPTION_VALUE);continue}if(n!==!0)throw new Y("Unknown option "+i,Y.ERR_BAD_OPTION)}}const $i={assertOptions:H0,validators:Ms},gt=$i.validators;class _r{constructor(t){this.defaults=t,this.interceptors={request:new La,response:new La}}async request(t,n){try{return await this._request(t,n)}catch(r){if(r instanceof Error){let o;Error.captureStackTrace?Error.captureStackTrace(o={}):o=new Error;const i=o.stack?o.stack.replace(/^.+\n/,""):"";r.stack?i&&!String(r.stack).endsWith(i.replace(/^.+\n.+\n/,""))&&(r.stack+=`
`+i):r.stack=i}throw r}}_request(t,n){typeof t=="string"?(n=n||{},n.url=t):n=t||{},n=nn(this.defaults,n);const{transitional:r,paramsSerializer:o,headers:i}=n;r!==void 0&&$i.assertOptions(r,{silentJSONParsing:gt.transitional(gt.boolean),forcedJSONParsing:gt.transitional(gt.boolean),clarifyTimeoutError:gt.transitional(gt.boolean)},!1),o!=null&&(j.isFunction(o)?n.paramsSerializer={serialize:o}:$i.assertOptions(o,{encode:gt.function,serialize:gt.function},!0)),n.method=(n.method||this.defaults.method||"get").toLowerCase();let s=i&&j.merge(i.common,i[n.method]);i&&j.forEach(["delete","get","head","post","put","patch","common"],g=>{delete i[g]}),n.headers=nt.concat(s,i);const l=[];let c=!0;this.interceptors.request.forEach(function(m){typeof m.runWhen=="function"&&m.runWhen(n)===!1||(c=c&&m.synchronous,l.unshift(m.fulfilled,m.rejected))});const u=[];this.interceptors.response.forEach(function(m){u.push(m.fulfilled,m.rejected)});let f,d=0,p;if(!c){const g=[Ha.bind(this),void 0];for(g.unshift.apply(g,l),g.push.apply(g,u),p=g.length,f=Promise.resolve(n);d<p;)f=f.then(g[d++],g[d++]);return f}p=l.length;let h=n;for(d=0;d<p;){const g=l[d++],m=l[d++];try{h=g(h)}catch(v){m.call(this,v);break}}try{f=Ha.call(this,h)}catch(g){return Promise.reject(g)}for(d=0,p=u.length;d<p;)f=f.then(u[d++],u[d++]);return f}getUri(t){t=nn(this.defaults,t);const n=kd(t.baseURL,t.url);return Dd(n,t.params,t.paramsSerializer)}}j.forEach(["delete","get","head","options"],function(t){_r.prototype[t]=function(n,r){return this.request(nn(r||{},{method:t,url:n,data:(r||{}).data}))}});j.forEach(["post","put","patch"],function(t){function n(r){return function(i,s,l){return this.request(nn(l||{},{method:t,headers:r?{"Content-Type":"multipart/form-data"}:{},url:i,data:s}))}}_r.prototype[t]=n(),_r.prototype[t+"Form"]=n(!0)});const wr=_r;class Us{constructor(t){if(typeof t!="function")throw new TypeError("executor must be a function.");let n;this.promise=new Promise(function(i){n=i});const r=this;this.promise.then(o=>{if(!r._listeners)return;let i=r._listeners.length;for(;i-- >0;)r._listeners[i](o);r._listeners=null}),this.promise.then=o=>{let i;const s=new Promise(l=>{r.subscribe(l),i=l}).then(o);return s.cancel=function(){r.unsubscribe(i)},s},t(function(i,s,l){r.reason||(r.reason=new Hn(i,s,l),n(r.reason))})}throwIfRequested(){if(this.reason)throw this.reason}subscribe(t){if(this.reason){t(this.reason);return}this._listeners?this._listeners.push(t):this._listeners=[t]}unsubscribe(t){if(!this._listeners)return;const n=this._listeners.indexOf(t);n!==-1&&this._listeners.splice(n,1)}static source(){let t;return{token:new Us(function(o){t=o}),cancel:t}}}const G0=Us;function W0(e){return function(n){return e.apply(null,n)}}function z0(e){return j.isObject(e)&&e.isAxiosError===!0}const Bi={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511};Object.entries(Bi).forEach(([e,t])=>{Bi[t]=e});const Q0=Bi;function Ud(e){const t=new wr(e),n=bd(wr.prototype.request,t);return j.extend(n,wr.prototype,t,{allOwnKeys:!0}),j.extend(n,t,null,{allOwnKeys:!0}),n.create=function(o){return Ud(nn(e,o))},n}const q=Ud(Ls);q.Axios=wr;q.CanceledError=Hn;q.CancelToken=G0;q.isCancel=Pd;q.VERSION=Md;q.toFormData=fo;q.AxiosError=Y;q.Cancel=q.CanceledError;q.all=function(t){return Promise.all(t)};q.spread=W0;q.isAxiosError=z0;q.mergeConfig=nn;q.AxiosHeaders=nt;q.formToJSON=e=>Bd(j.isHTMLForm(e)?new FormData(e):e);q.getAdapter=Ld.getAdapter;q.HttpStatusCode=Q0;q.default=q;q.defaults.xsrfHeaderName="X-CSRFToken";async function Ee(e,t){const{GET:n}=$s(),{data:r,error:o}=await n(e,{params:{path:{character_id:t}}});if(o)console.log(o);else return console.log(r),r}async function q0(e){return Ee("/audit/api/account/{character_id}/contacts",e)}async function K0(e){return Ee("/audit/api/account/{character_id}/loyalty",e)}async function Y0(e){return Ee("/audit/api/account/{character_id}/notifications",e)}async function J0(e){return Ee("/audit/api/account/{character_id}/clones",e)}async function Z0(e){return Ee("/audit/api/account/{character_id}/roles",e)}async function X0(e){return Ee("/audit/api/account/{character_id}/glance/assets",e)}async function eb(e){return Ee("/audit/api/account/{character_id}/glance/activities",e)}async function tb(e){return Ee("/audit/api/account/{character_id}/glance/faction",e)}async function nb(e){return Ee("/audit/api/account/{character_id}/market",e)}async function rb(e){return Ee("/audit/api/account/{character_id}/contracts",e)}async function ob(e){return Ee("/audit/api/account/{character_id}/skills",e)}async function ib(e){return Ee("/audit/api/account/{character_id}/skillqueues",e)}async function sb(e){return Ee("/audit/api/account/{character_id}/doctrines",e)}async function ab(){const{GET:e}=$s(),{data:t,error:n}=await e("/audit/api/account/list");if(n)console.log(n);else return console.log(t),t}async function lb(e,t){const{GET:n}=$s(),{data:r,error:o}=await n("/audit/api/account/{character_id}/asset/{location_id}/groups",{params:{path:{character_id:e,location_id:t}}});if(o)console.log(o);else return console.log(r),r}async function Vs(e){const t=await q.get(`/audit/api/account/${e}/status`);console.log(`got character status from api for '${e}'`);const n=Array.from(new Set(t.data.characters.reduce((o,i)=>{try{return o.concat(Object.keys(i.last_updates))}catch{return o}},[])));return n.sort(),{characters:t.data.characters,main:t.data.main,headers:n}}async function cb(e){const t=await q.get(`/audit/api/account/${e}/pubdata`);return console.log(`get pubdata in api ${e}`),{characters:t.data}}async function ub(e){const t=await q.get(`/audit/api/account/${e}/mail`);return console.log(`get Contracts in api ${e}`),t.data}async function fb(e,t){if(console.log(`sent postMailBody ${e}, ${t}`),!e&&!t)return{};const n=await q.get(`/audit/api/account/${e}/mail/${t}`);return console.log(`search mail body in api ${e}, ${t}`),n.data}async function db(e){return console.log(`sent account refresh ${e}`),(await q.post(`/audit/api/account/refresh?character_id=${e}`,{character_id:e},{headers:{"X-CSRFToken":vd.get("csrftoken")}})).data}async function pb(e,t){const n=await q.get(`/audit/api/account/${e}/asset/${t}/list`);return console.log(`get asset list in api ${e} ${t}`),n.data}async function hb(e){const t=await q.get(`/audit/api/account/${e}/asset/locations`);return console.log(`get asset locations in api ${e}`),t.data}async function gb(e){const t=await q.get(`/audit/api/account/${e}/wallet`);return console.log(`get wallet in api ${e}`),t.data.items}const mb=(e,t,n,r)=>{var i,s,l,c;const o=[n,{code:t,...r||{}}];if((s=(i=e==null?void 0:e.services)==null?void 0:i.logger)!=null&&s.forward)return e.services.logger.forward(o,"warn","react-i18next::",!0);Dt(o[0])&&(o[0]=`react-i18next:: ${o[0]}`),(c=(l=e==null?void 0:e.services)==null?void 0:l.logger)!=null&&c.warn?e.services.logger.warn(...o):console!=null&&console.warn&&console.warn(...o)},za={},Pi=(e,t,n,r)=>{Dt(n)&&za[n]||(Dt(n)&&(za[n]=new Date),mb(e,t,n,r))},Vd=(e,t)=>()=>{if(e.isInitialized)t();else{const n=()=>{setTimeout(()=>{e.off("initialized",n)},0),t()};e.on("initialized",n)}},ki=(e,t,n)=>{e.loadNamespaces(t,Vd(e,n))},Qa=(e,t,n,r)=>{if(Dt(n)&&(n=[n]),e.options.preload&&e.options.preload.indexOf(t)>-1)return ki(e,n,r);n.forEach(o=>{e.options.ns.indexOf(o)<0&&e.options.ns.push(o)}),e.loadLanguages(t,Vd(e,r))},xb=(e,t,n={})=>!t.languages||!t.languages.length?(Pi(t,"NO_LANGUAGES","i18n.languages were undefined or empty",{languages:t.languages}),!0):t.hasLoadedNamespace(e,{lng:n.lng,precheck:(r,o)=>{var i;if(((i=n.bindI18n)==null?void 0:i.indexOf("languageChanging"))>-1&&r.services.backendConnector.backend&&r.isLanguageChangingTo&&!o(r.isLanguageChangingTo,e))return!1}}),Dt=e=>typeof e=="string",vb=e=>typeof e=="object"&&e!==null,yb=/&(?:amp|#38|lt|#60|gt|#62|apos|#39|quot|#34|nbsp|#160|copy|#169|reg|#174|hellip|#8230|#x2F|#47);/g,wb={"&amp;":"&","&#38;":"&","&lt;":"<","&#60;":"<","&gt;":">","&#62;":">","&apos;":"'","&#39;":"'","&quot;":'"',"&#34;":'"',"&nbsp;":" ","&#160;":" ","&copy;":"©","&#169;":"©","&reg;":"®","&#174;":"®","&hellip;":"…","&#8230;":"…","&#x2F;":"/","&#47;":"/"},bb=e=>wb[e],Cb=e=>e.replace(yb,bb);let Li={bindI18n:"languageChanged",bindI18nStore:"",transEmptyNodeValue:"",transSupportBasicHtmlNodes:!0,transWrapTextNodes:"",transKeepBasicHtmlNodesFor:["br","strong","i","p"],useSuspense:!0,unescape:Cb};const Sb=(e={})=>{Li={...Li,...e}},Ab=()=>Li;let Hd;const jb=e=>{Hd=e},Rb=()=>Hd,Fb={type:"3rdParty",init(e){Sb(e.options.react),jb(e)}},Ob=x.createContext();class Eb{constructor(){this.usedNamespaces={}}addUsedNamespaces(t){t.forEach(n=>{this.usedNamespaces[n]||(this.usedNamespaces[n]=!0)})}getUsedNamespaces(){return Object.keys(this.usedNamespaces)}}const Ib=(e,t)=>{const n=x.useRef();return x.useEffect(()=>{n.current=t?n.current:e},[e,t]),n.current},Gd=(e,t,n,r)=>e.getFixedT(t,n,r),Nb=(e,t,n,r)=>x.useCallback(Gd(e,t,n,r),[e,t,n,r]),G=(e,t={})=>{var S,F,C,A;const{i18n:n}=t,{i18n:r,defaultNS:o}=x.useContext(Ob)||{},i=n||r||Rb();if(i&&!i.reportNamespaces&&(i.reportNamespaces=new Eb),!i){Pi(i,"NO_I18NEXT_INSTANCE","useTranslation: You will need to pass in an i18next instance by using initReactI18next");const O=(N,E)=>Dt(E)?E:vb(E)&&Dt(E.defaultValue)?E.defaultValue:Array.isArray(N)?N[N.length-1]:N,T=[O,{},!1];return T.t=O,T.i18n={},T.ready=!1,T}(S=i.options.react)!=null&&S.wait&&Pi(i,"DEPRECATED_OPTION","useTranslation: It seems you are still using the old wait option, you may migrate to the new useSuspense behaviour.");const s={...Ab(),...i.options.react,...t},{useSuspense:l,keyPrefix:c}=s;let u=e||o||((F=i.options)==null?void 0:F.defaultNS);u=Dt(u)?[u]:u||["translation"],(A=(C=i.reportNamespaces).addUsedNamespaces)==null||A.call(C,u);const f=(i.isInitialized||i.initializedStoreOnce)&&u.every(O=>xb(O,i,s)),d=Nb(i,t.lng||null,s.nsMode==="fallback"?u:u[0],c),p=()=>d,h=()=>Gd(i,t.lng||null,s.nsMode==="fallback"?u:u[0],c),[g,m]=x.useState(p);let v=u.join();t.lng&&(v=`${t.lng}${v}`);const y=Ib(v),b=x.useRef(!0);x.useEffect(()=>{const{bindI18n:O,bindI18nStore:T}=s;b.current=!0,!f&&!l&&(t.lng?Qa(i,t.lng,u,()=>{b.current&&m(h)}):ki(i,u,()=>{b.current&&m(h)})),f&&y&&y!==v&&b.current&&m(h);const N=()=>{b.current&&m(h)};return O&&(i==null||i.on(O,N)),T&&(i==null||i.store.on(T,N)),()=>{b.current=!1,i&&(O==null||O.split(" ").forEach(E=>i.off(E,N))),T&&i&&T.split(" ").forEach(E=>i.store.off(E,N))}},[i,v]),x.useEffect(()=>{b.current&&f&&m(p)},[i,c,f]);const w=[g,i,f];if(w.t=g,w.i18n=i,w.ready=f,f||!f&&!l)return w;throw new Promise(O=>{t.lng?Qa(i,t.lng,u,()=>O()):ki(i,u,()=>O())})},Tb=()=>{const{t:e}=G(),{characterID:t}=ie(),{data:n,isFetching:r}=te({queryKey:["contacts",t],queryFn:()=>ab(),refetchOnWindowFocus:!1}),o=Ae(),i=[o.accessor("main.character_id",{header:"",enableColumnFilter:!1,enableSorting:!1,cell:s=>a.jsx(Vf,{size:32,character_id:s.getValue()})}),o.accessor("main.character_name",{header:e("Character")}),o.accessor("main.corporation_id",{header:"",enableColumnFilter:!1,enableSorting:!1,cell:s=>a.jsx(Ir,{size:32,corporation_id:s.getValue()})}),o.accessor("main.corporation_name",{header:e("Main Corporation")}),o.accessor("characters",{header:e("Characters"),cell:s=>{var l;return s.getValue()?a.jsx("div",{className:"flex-container text-center",children:(l=s==null?void 0:s.getValue())==null?void 0:l.map(c=>a.jsx(Re,{className:"padded-label",bg:c.active?"primary":"danger",children:c.character.character_name}))}):a.jsx(a.Fragment,{})},filterFn:(s,l,c)=>{var u,f;if(c){let d=(f=(u=s.original)==null?void 0:u.characters)==null?void 0:f.reduce((p,h)=>p+"  "+h.character.character_name,"");return d?d.toLowerCase().includes(c.toLowerCase()):!1}else return!0}}),o.accessor("main",{header:"",enableColumnFilter:!1,enableSorting:!1,cell:s=>s.getValue()?a.jsx(ge,{className:"btn btn-primary",to:{pathname:`audit/r_beta/${s.getValue().character_id}/`},children:a.jsx("i",{className:"fas fa-external-link","aria-hidden":"true"})}):a.jsx(a.Fragment,{})})];return a.jsx(a.Fragment,{children:a.jsx(Be,{data:n,isFetching:r,columns:i})})},Db={option:e=>({...e,color:"black"})},Wd=({characterID:e,setLocation:t})=>{const{isLoading:n,data:r}=te(["asset_loc",e],()=>hb(e),{refetchOnWindowFocus:!1});return a.jsx(cc,{isLoading:n,styles:Db,options:r,onChange:o=>t(o.value)})},_b="_flexContainer_ia7nm_1",$b="_errorAnim_ia7nm_33",Bb="_shake_ia7nm_1",Pb="_ldsDualRing_ia7nm_38",$r={flexContainer:_b,errorAnim:$b,shake:Bb,ldsDualRing:Pb,"lds-dual-ring":"_lds-dual-ring_ia7nm_1"},kb=({className:e=""})=>a.jsx("div",{className:e+" "+$r.ldsDualRing}),$t=(e={title:"Loading..."})=>a.jsx("div",{className:$r.flexContainer,children:a.jsxs("div",{className:"text-center",children:[a.jsx(kb,{}),a.jsx("h3",{children:e.title&&e.title}),a.jsx("p",{children:e.message&&e.message})]})}),Br=(e={title:"Error Loading Component"})=>a.jsx("div",{className:$r.flexContainer,children:a.jsxs("div",{className:"text-center",children:[a.jsx("div",{className:$r.errorAnim,children:a.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"100",height:"100",fill:"currentColor",className:"bi bi-exclamation-triangle",viewBox:"0 0 16 16",children:[a.jsx("path",{d:"M7.938 2.016A.13.13 0 0 1 8.002 2a.13.13 0 0 1 .063.016.146.146 0 0 1 .054.057l6.857 11.667c.036.06.035.124.002.183a.163.163 0 0 1-.054.06.116.116 0 0 1-.066.017H1.146a.115.115 0 0 1-.066-.017.163.163 0 0 1-.054-.06.176.176 0 0 1 .002-.183L7.884 2.073a.147.147 0 0 1 .054-.057zm1.044-.45a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566z"}),a.jsx("path",{d:"M7.002 12a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 5.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995z"})]})}),a.jsx("h3",{children:e.title&&e.title}),a.jsx("p",{children:e.message&&e.message}),a.jsx("p",{})]})}),Lb=()=>{const{t:e}=G(),{characterID:t}=ie(),[n,r]=x.useState(0),{data:o,isFetching:i}=te({queryKey:["assetGroups",t,n],queryFn:()=>lb(Number(t),Number(n)),refetchOnWindowFocus:!1});return console.log(i),a.jsxs(a.Fragment,{children:[a.jsxs("div",{className:"m-3 d-flex align-items-center",children:[a.jsx("h5",{className:"me-1",children:e("Location Filter")}),a.jsx("div",{className:"flex-grow-1",children:a.jsx(Wd,{characterID:t?Number(t):0,setLocation:r})})]}),i?a.jsx($t,{title:e("Data Loading"),message:e("Please Wait")}):a.jsx("div",{className:"d-flex flex-wrap justify-content-evenly",children:o==null?void 0:o.map(s=>{var l;return a.jsxs(D,{className:"m-3",children:[a.jsx(D.Header,{children:a.jsx(D.Title,{children:s.name})}),a.jsxs(D.Body,{style:{height:"500px",overflowY:"scroll"},children:[a.jsx(st,{striped:!0,style:{marginBottom:0,minWidth:"400px"},children:a.jsx("thead",{children:a.jsxs("tr",{children:[a.jsx("th",{children:e("Group")}),a.jsx("th",{className:"text-end",children:e("Count")})]},"head "+s.name)})}),a.jsx("div",{className:"table-div",children:a.jsx(st,{striped:!0,children:a.jsx("tbody",{children:(l=s==null?void 0:s.items)==null?void 0:l.map(c=>a.jsxs("tr",{children:[a.jsx("td",{children:c.label}),a.jsx("td",{className:"text-end no-wrap",children:c.value.toLocaleString()})]},s.name+" "+c.label+" "+c.value))})})})]})]},s.name)})})]})},Mb=()=>{const{t:e}=G(),{characterID:t}=ie(),[n,r]=x.useState(0),{data:o,isFetching:i}=te({queryKey:["assetList",t,n],queryFn:()=>pb(Number(t),n),refetchOnWindowFocus:!1,initialData:{characters:[],main:void 0,headers:[]}}),s=Ae(),l=[s.accessor("character.character_name",{header:e("Character")}),s.accessor("item.name",{header:e("Item Type")}),s.accessor("item.cat",{header:e("Category")}),s.accessor("quantity",{header:e("Quantity")}),s.accessor("location.name",{header:e("Location")})];return a.jsxs(a.Fragment,{children:[a.jsxs("div",{className:"m-3 d-flex align-items-center",children:[a.jsx("h5",{className:"me-1",children:e("Location Filter")}),a.jsx("div",{className:"flex-grow-1",children:a.jsx(Wd,{characterID:t?Number(t):0,setLocation:r})})]}),a.jsx(Be,{isFetching:i,data:o,columns:l})]})},Ub="_menuRefreshSpin_17lcv_1",Vb="_spin_17lcv_1",Hb={menuRefreshSpin:Ub,spin:Vb},Gb=()=>{const{characterID:e}=ie(),{refetch:t,isFetching:n}=te("my_key",()=>db(e?Number(e):0),{refetchOnWindowFocus:!1,enabled:!1});async function r(){return await t()}return a.jsx(z,{className:"btn-success",onClick:r,children:a.jsx("i",{className:`fa-solid fa-refresh ${n&&Hb.menuRefreshSpin}`})})};var zd={exports:{}},Wb=zd.exports=typeof window<"u"&&window.Math==Math?window:typeof self<"u"&&self.Math==Math?self:Function("return this")();typeof __g=="number"&&(__g=Wb);var ho=zd.exports,Qd={exports:{}},zb=Qd.exports={version:"2.6.12"};typeof __e=="number"&&(__e=zb);var ln=Qd.exports,Qb=function(e){if(typeof e!="function")throw TypeError(e+" is not a function!");return e},qb=Qb,qd=function(e,t,n){if(qb(e),t===void 0)return e;switch(n){case 1:return function(r){return e.call(t,r)};case 2:return function(r,o){return e.call(t,r,o)};case 3:return function(r,o,i){return e.call(t,r,o,i)}}return function(){return e.apply(t,arguments)}},Hs={},Wo,qa;function go(){return qa||(qa=1,Wo=function(e){return typeof e=="object"?e!==null:typeof e=="function"}),Wo}var zo,Ka;function mo(){if(Ka)return zo;Ka=1;var e=go();return zo=function(t){if(!e(t))throw TypeError(t+" is not an object!");return t},zo}var Gs=function(e){try{return!!e()}catch{return!0}},Pt=!Gs(function(){return Object.defineProperty({},"a",{get:function(){return 7}}).a!=7}),Qo,Ya;function Kd(){if(Ya)return Qo;Ya=1;var e=go(),t=ho.document,n=e(t)&&e(t.createElement);return Qo=function(r){return n?t.createElement(r):{}},Qo}var Yd=!Pt&&!Gs(function(){return Object.defineProperty(Kd()("div"),"a",{get:function(){return 7}}).a!=7}),tr=go(),Jd=function(e,t){if(!tr(e))return e;var n,r;if(t&&typeof(n=e.toString)=="function"&&!tr(r=n.call(e))||typeof(n=e.valueOf)=="function"&&!tr(r=n.call(e))||!t&&typeof(n=e.toString)=="function"&&!tr(r=n.call(e)))return r;throw TypeError("Can't convert object to primitive value")},Ja=mo(),Kb=Yd,Yb=Jd,Jb=Object.defineProperty;Hs.f=Pt?Object.defineProperty:function(t,n,r){if(Ja(t),n=Yb(n,!0),Ja(r),Kb)try{return Jb(t,n,r)}catch{}if("get"in r||"set"in r)throw TypeError("Accessors not supported!");return"value"in r&&(t[n]=r.value),t};var Zd=function(e,t){return{enumerable:!(e&1),configurable:!(e&2),writable:!(e&4),value:t}},Zb=Hs,Xb=Zd,eC=Pt?function(e,t,n){return Zb.f(e,t,Xb(1,n))}:function(e,t,n){return e[t]=n,e},tC={}.hasOwnProperty,Ws=function(e,t){return tC.call(e,t)},nr=ho,qo=ln,Za=qd,nC=eC,rC=Ws,rr="prototype",xe=function(e,t,n){var r=e&xe.F,o=e&xe.G,i=e&xe.S,s=e&xe.P,l=e&xe.B,c=e&xe.W,u=o?qo:qo[t]||(qo[t]={}),f=u[rr],d=o?nr:i?nr[t]:(nr[t]||{})[rr],p,h,g;o&&(n=t);for(p in n)h=!r&&d&&d[p]!==void 0,!(h&&rC(u,p))&&(g=h?d[p]:n[p],u[p]=o&&typeof d[p]!="function"?n[p]:l&&h?Za(g,nr):c&&d[p]==g?function(m){var v=function(y,b,w){if(this instanceof m){switch(arguments.length){case 0:return new m;case 1:return new m(y);case 2:return new m(y,b)}return new m(y,b,w)}return m.apply(this,arguments)};return v[rr]=m[rr],v}(g):s&&typeof g=="function"?Za(Function.call,g):g,s&&((u.virtual||(u.virtual={}))[p]=g,e&xe.R&&f&&!f[p]&&nC(f,p,g)))};xe.F=1;xe.G=2;xe.S=4;xe.P=8;xe.B=16;xe.W=32;xe.U=64;xe.R=128;var xo=xe,oC={}.toString,iC=function(e){return oC.call(e).slice(8,-1)},sC=iC,Xd=Object("z").propertyIsEnumerable(0)?Object:function(e){return sC(e)=="String"?e.split(""):Object(e)},ep=function(e){if(e==null)throw TypeError("Can't call method on  "+e);return e},aC=Xd,lC=ep,vo=function(e){return aC(lC(e))},cC=Math.ceil,uC=Math.floor,tp=function(e){return isNaN(e=+e)?0:(e>0?uC:cC)(e)},fC=tp,dC=Math.min,pC=function(e){return e>0?dC(fC(e),9007199254740991):0},hC=tp,gC=Math.max,mC=Math.min,xC=function(e,t){return e=hC(e),e<0?gC(e+t,0):mC(e,t)},vC=vo,yC=pC,wC=xC,bC=function(e){return function(t,n,r){var o=vC(t),i=yC(o.length),s=wC(r,i),l;if(e&&n!=n){for(;i>s;)if(l=o[s++],l!=l)return!0}else for(;i>s;s++)if((e||s in o)&&o[s]===n)return e||s||0;return!e&&-1}},Ko={exports:{}},Xa;function CC(){if(Xa)return Ko.exports;Xa=1;var e=ln,t=ho,n="__core-js_shared__",r=t[n]||(t[n]={});return(Ko.exports=function(o,i){return r[o]||(r[o]=i!==void 0?i:{})})("versions",[]).push({version:e.version,mode:"pure",copyright:"© 2020 Denis Pushkarev (zloirock.ru)"}),Ko.exports}var Yo,el;function SC(){if(el)return Yo;el=1;var e=0,t=Math.random();return Yo=function(n){return"Symbol(".concat(n===void 0?"":n,")_",(++e+t).toString(36))},Yo}var Jo,tl;function np(){if(tl)return Jo;tl=1;var e=CC()("keys"),t=SC();return Jo=function(n){return e[n]||(e[n]=t(n))},Jo}var nl=Ws,AC=vo,jC=bC(!1),RC=np()("IE_PROTO"),FC=function(e,t){var n=AC(e),r=0,o=[],i;for(i in n)i!=RC&&nl(n,i)&&o.push(i);for(;t.length>r;)nl(n,i=t[r++])&&(~jC(o,i)||o.push(i));return o},rp="constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf".split(","),OC=FC,EC=rp,zs=Object.keys||function(t){return OC(t,EC)},Zo={},rl;function IC(){return rl||(rl=1,Zo.f=Object.getOwnPropertySymbols),Zo}var yo={};yo.f={}.propertyIsEnumerable;var NC=ep,TC=function(e){return Object(NC(e))},Xo,ol;function DC(){if(ol)return Xo;ol=1;var e=Pt,t=zs,n=IC(),r=yo,o=TC,i=Xd,s=Object.assign;return Xo=!s||Gs(function(){var l={},c={},u=Symbol(),f="abcdefghijklmnopqrst";return l[u]=7,f.split("").forEach(function(d){c[d]=d}),s({},l)[u]!=7||Object.keys(s({},c)).join("")!=f})?function(c,u){for(var f=o(c),d=arguments.length,p=1,h=n.f,g=r.f;d>p;)for(var m=i(arguments[p++]),v=h?t(m).concat(h(m)):t(m),y=v.length,b=0,w;y>b;)w=v[b++],(!e||g.call(m,w))&&(f[w]=m[w]);return f}:s,Xo}var ei=xo;ei(ei.S+ei.F,"Object",{assign:DC()});var _C=ln.Object.assign;const il=at(_C);function Mi(){return Mi=il?il.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Mi.apply(null,arguments)}var ti,sl;function $C(){if(sl)return ti;sl=1;var e=Hs,t=mo(),n=zs;return ti=Pt?Object.defineProperties:function(o,i){t(o);for(var s=n(i),l=s.length,c=0,u;l>c;)e.f(o,u=s[c++],i[u]);return o},ti}var ni,al;function BC(){if(al)return ni;al=1;var e=ho.document;return ni=e&&e.documentElement,ni}var ri,ll;function PC(){if(ll)return ri;ll=1;var e=mo(),t=$C(),n=rp,r=np()("IE_PROTO"),o=function(){},i="prototype",s=function(){var l=Kd()("iframe"),c=n.length,u="<",f=">",d;for(l.style.display="none",BC().appendChild(l),l.src="javascript:",d=l.contentWindow.document,d.open(),d.write(u+"script"+f+"document.F=Object"+u+"/script"+f),d.close(),s=d.F;c--;)delete s[i][n[c]];return s()};return ri=Object.create||function(c,u){var f;return c!==null?(o[i]=e(c),f=new o,o[i]=null,f[r]=c):f=s(),u===void 0?f:t(f,u)},ri}var cl=xo;cl(cl.S,"Object",{create:PC()});var kC=ln.Object,LC=function(t,n){return kC.create(t,n)};const MC=at(LC);var oi={},ul;function UC(){if(ul)return oi;ul=1;var e=yo,t=Zd,n=vo,r=Jd,o=Ws,i=Yd,s=Object.getOwnPropertyDescriptor;return oi.f=Pt?s:function(c,u){if(c=n(c),u=r(u,!0),i)try{return s(c,u)}catch{}if(o(c,u))return t(!e.f.call(c,u),c[u])},oi}var ii,fl;function VC(){if(fl)return ii;fl=1;var e=go(),t=mo(),n=function(r,o){if(t(r),!e(o)&&o!==null)throw TypeError(o+": can't set as prototype!")};return ii={set:Object.setPrototypeOf||("__proto__"in{}?function(r,o,i){try{i=qd(Function.call,UC().f(Object.prototype,"__proto__").set,2),i(r,[]),o=!(r instanceof Array)}catch{o=!0}return function(l,c){return n(l,c),o?l.__proto__=c:i(l,c),l}}({},!1):void 0),check:n},ii}var dl=xo;dl(dl.S,"Object",{setPrototypeOf:VC().set});var HC=ln.Object.setPrototypeOf;const pl=at(HC);function Ui(e,t){return Ui=pl?pl.bind():function(n,r){return n.__proto__=r,n},Ui(e,t)}function GC(e,t){e.prototype=MC(t.prototype),e.prototype.constructor=e,Ui(e,t)}function WC(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)>=0)continue;n[r]=e[r]}return n}var zC=Pt,QC=zs,qC=vo,KC=yo.f,YC=function(e){return function(t){for(var n=qC(t),r=QC(n),o=r.length,i=0,s=[],l;o>i;)l=r[i++],(!zC||KC.call(n,l))&&s.push(e?[l,n[l]]:n[l]);return s}},hl=xo,JC=YC(!0);hl(hl.S,"Object",{entries:function(t){return JC(t)}});var ZC=ln.Object.entries,XC=ZC;const eS=at(XC);function tS(e){return function(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];var o=n[n.length-1];return typeof o=="function"?e.apply(void 0,n):function(i){return e.apply(void 0,n.concat([i]))}}}function or(e,t){var n=(e.bsClass||"").trim();return n==null&&Zp(!1),n+(t?"-"+t:"")}var nS=tS(function(e,t){var n=t.propTypes||(t.propTypes={}),r=t.defaultProps||(t.defaultProps={});return n.bsClass=I.string,r.bsClass=e,t});function rS(e){return{bsClass:e.bsClass,bsSize:e.bsSize,bsStyle:e.bsStyle,bsRole:e.bsRole}}function oS(e){return e==="bsClass"||e==="bsSize"||e==="bsStyle"||e==="bsRole"}function iS(e){var t={};return eS(e).forEach(function(n){var r=n[0],o=n[1];oS(r)||(t[r]=o)}),[rS(e),t]}var sS={responsive:I.bool,rounded:I.bool,circle:I.bool,thumbnail:I.bool},aS={responsive:!1,rounded:!1,circle:!1,thumbnail:!1},Qs=function(e){GC(t,e);function t(){return e.apply(this,arguments)||this}var n=t.prototype;return n.render=function(){var o,i=this.props,s=i.responsive,l=i.rounded,c=i.circle,u=i.thumbnail,f=i.className,d=WC(i,["responsive","rounded","circle","thumbnail","className"]),p=iS(d),h=p[0],g=p[1],m=(o={},o[or(h,"responsive")]=s,o[or(h,"rounded")]=l,o[or(h,"circle")]=c,o[or(h,"thumbnail")]=u,o);return H.createElement("img",Mi({},g,{className:_(f,m)}))},t}(H.Component);Qs.propTypes=sS;Qs.defaultProps=aS;const qs=nS("img",Qs),lS=e=>H.createElement(qs,{height:e.height&&e.height,width:e.width&&e.width,style:e.style&&e.style,src:`https://images.evetech.net/characters/${e.character_id}/portrait?size=${e.size}`}),cS=e=>H.createElement(qs,{height:e.height&&e.height,width:e.width&&e.width,style:e.style&&e.style,src:`https://images.evetech.net/corporations/${e.corporation_id}/logo?size=${e.size}`}),uS=e=>H.createElement(qs,{height:e.height&&e.height,width:e.width&&e.width,style:e.style&&e.style,src:`https://images.evetech.net/alliances/${e.alliance_id}/logo?size=${e.size}`});function op(e,t){t===void 0&&(t={});var n=t.insertAt;if(!(!e||typeof document>"u")){var r=document.head||document.getElementsByTagName("head")[0],o=document.createElement("style");o.type="text/css",n==="top"&&r.firstChild?r.insertBefore(o,r.firstChild):r.appendChild(o),o.styleSheet?o.styleSheet.cssText=e:o.appendChild(document.createTextNode(e))}}var fS=`.Loader-module_flexContainer__GlMdi {
  margin-top: 150px;
  display: flex;
  align-items: center;
  justify-content: center;
  align-content: center;
  flex-wrap: wrap;
  flex-direction: row;
}

@keyframes Loader-module_shake__1mapc {
  10%,
  90% {
    transform: translate3d(-1px, 0, 0);
  }

  20%,
  80% {
    transform: translate3d(2px, 0, 0);
  }

  30%,
  50%,
  70% {
    transform: translate3d(-4px, 0, 0);
  }

  40%,
  60% {
    transform: translate3d(4px, 0, 0);
  }
}

.Loader-module_errorAnim__h3bUy {
  animation: Loader-module_shake__1mapc 0.82s cubic-bezier(0.36, 0.07, 0.19, 0.97) both;
  animation-iteration-count: infinite;
}

.Loader-module_ldsDualRing__EJnqD {
  display: inline-block;
  width: 80px;
  height: 80px;
}

.Loader-module_ldsDualRing__EJnqD:after {
  content: " ";
  display: block;
  width: 64px;
  height: 64px;
  margin: 8px;
  border-radius: 50%;
  border-width: 6px;
  border-style: solid;
  border-left-color: inherit;
  border-top-color: transparent;
  border-right-color: inherit;
  border-bottom-color: transparent;
  animation: Loader-module_lds-dual-ring__4SWmn 1.2s linear infinite;
}

@keyframes Loader-module_lds-dual-ring__4SWmn {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}

/*# sourceMappingURL=data:application/json;base64,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 */`,gl={flexContainer:"Loader-module_flexContainer__GlMdi",errorAnim:"Loader-module_errorAnim__h3bUy",shake:"Loader-module_shake__1mapc",ldsDualRing:"Loader-module_ldsDualRing__EJnqD","lds-dual-ring":"Loader-module_lds-dual-ring__4SWmn"};op(fS);const dS=(e={title:"Loading..."})=>H.createElement("div",{className:gl.flexContainer},H.createElement("div",{className:"text-center"},H.createElement("div",null,H.createElement("div",{className:gl.ldsDualRing})),H.createElement("h3",null,e.title&&e.title),H.createElement("p",null,e.message&&e.message)));var pS=`@keyframes BaseTable-module_spin__lpdYb {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(359deg);
  }
}

.BaseTable-module_glyphiconRefreshAnimate__HIIZm {
  -animation: BaseTable-module_spin__lpdYb 2s infinite linear;
  -ms-animation: BaseTable-module_spin__lpdYb 2s infinite linear;
  -webkit-animation: BaseTable-module_spin__lpdYb 2s infinite linear;
  -moz-animation: BaseTable-module_spin__lpdYb 2s infinite linear;
}

.BaseTable-module_filterBtn__ODmli{
  color: hsl(0, 0%, 50%) !important;
  margin-top: 2px !important;
  min-height: 38px !important;
  background-color: white !important;
  border-color: hsl(0, 0%, 80%) !important;
  border-top-left-radius: 4px !important;
  border-bottom-left-radius: 4px !important;
  border-right: 0 !important;
  border-width: 1px !important;
  font-weight: bold !important;
  display: flex !important;
  font-size: 15px !important;
  font-family: "Lato","Helvetica Neue",Helvetica,Arial,sans-serif !important;
}

.BaseTable-module_filterToggle__tmPmV{
  stroke: hsl(0, 0%, 80%) !important;
  fill: hsl(0, 0%, 80%) !important;
  stroke-width: 0;
  padding-top: 8px !important;
  margin-top: 2px !important;
  min-height: 38px !important;
  background-color: white !important;
  border-color: hsl(0, 0%, 80%) !important;
  border-top-right-radius: 4px !important;
  border-bottom-right-radius: 4px !important;
  border-left: 0 !important;
  border-width: 1px !important;
  display: flex !important;
  font-size: 15px !important;
}
/*# sourceMappingURL=data:application/json;base64,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 */`;op(pS);function ml({message:e}){return a.jsx(to,{id:"character_tooltip",style:{position:"fixed"},children:e})}const hS=()=>{const{t:e}=G(),{characterID:t}=ie(),n={borderRadius:"25%"},{data:r}=te(["status",t],()=>Vs(t?Number(t):0),{refetchOnWindowFocus:!1}),o=r==null?void 0:r.characters.filter(i=>!i.active).map(i=>i.character.character_name);return a.jsx(D,{children:a.jsxs("div",{className:"d-flex justify-content-start align-items-center flex-no-wrap",children:[a.jsx(lS,{style:{borderRadius:"0.375rem 0 0 0.375rem"},className:"m-0",character_id:r==null?void 0:r.main.character_id,size:64}),a.jsx("h4",{className:"m-1 mx-3",children:r==null?void 0:r.main.character_name}),a.jsx(cS,{style:n,className:"m-1 mx-3",corporation_id:r==null?void 0:r.main.corporation_id,size:32}),a.jsx("h5",{className:"m-1 mx-3",children:r==null?void 0:r.main.corporation_name}),(r==null?void 0:r.main.alliance_id)&&a.jsxs(a.Fragment,{children:[a.jsx(uS,{style:n,className:"m-1 mx-3",alliance_id:r==null?void 0:r.main.alliance_id,size:32}),a.jsx("h5",{className:"m-1 mx-3",children:r==null?void 0:r.main.alliance_name})]}),a.jsxs(wt,{className:"me-3 ms-auto",children:[a.jsx(Gb,{}),r?o.length===0?a.jsx(Ct,{placement:"left",overlay:ml({message:e("No Account Flags")}),children:a.jsx(z,{className:"btn-success",children:a.jsx("i",{className:"fa-solid fa-check"})})}):a.jsx(Ct,{placement:"left",overlay:ml({message:e(`Character Flags: ${o.join(", ")}`)}),children:a.jsx(z,{className:"btn-danger",children:o.length})}):a.jsx(a.Fragment,{})]})]})})},gS=({data:e,characterID:t})=>{const{t:n}=G();return a.jsxs(a.Fragment,{children:[a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{as:ge,to:`/audit/r/${t}/account/overview`,children:n("Overview")},"Overview")}),e&&e.map(r=>{var o;return console.log(r.name),r.links?a.jsx(Ie,{as:"li",id:r.name,title:r.name,children:(o=r.links)==null?void 0:o.map(i=>a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:`/audit/r/${t}/${i.link}`,id:i.name,children:i.name},i.name)}))},r.name):a.jsx(a.Fragment,{children:r.link.startsWith("/")?a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{id:r.name,href:r.link,children:a.jsx(a.Fragment,{children:r.name})},r.name)}):a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{as:ge,to:`/audit/r/${t}/${r.link}`,id:r.name,children:a.jsx(a.Fragment,{children:r.name})},r.name)})})})]})},xl=document.getElementById("nav-left"),mS=()=>{const{characterID:e}=ie(),{isLoading:t,error:n,data:r}=te({queryKey:["Menu"],queryFn:async()=>(await q.get("/audit/api/account/menu")).data,refetchOnWindowFocus:!1});return xl?ke.createPortal(a.jsx(gS,{error:!!n,characterID:String(e),isLoading:t,data:r}),xl):a.jsx(a.Fragment,{})},xS="_menuRefreshSpin_17lcv_1",vS="_spin_17lcv_1",yS={menuRefreshSpin:xS,spin:vS},ir=document.getElementById("nav-right"),wS=()=>{const{t:e}=G(),t=uc(),[n,r]=H.useState(!1);return H.useEffect(()=>{n||ir&&(ir.innerHTML="",r(!0))},[n]),n?ir?ke.createPortal(a.jsxs(a.Fragment,{children:[t?a.jsx(a.Fragment,{children:a.jsx(ne.Link,{children:a.jsx("i",{className:`fas fa-sync-alt fa-fw ${yS.menuRefreshSpin}`})})}):a.jsx(a.Fragment,{}),a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{href:"/audit/char/add/",children:e("Add Character")},"Add Character")}),a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{as:ge,to:"account/list",children:e("Account List")},"Account List")})]}),ir):a.jsx(a.Fragment,{}):null},bS=()=>a.jsxs(a.Fragment,{children:[a.jsx(mS,{}),a.jsx(wS,{}),a.jsx(hS,{}),a.jsx(fs,{children:a.jsxs("div",{className:"mt-4",children:[a.jsx(dc,{})," "]})})]}),CS=()=>{const{t:e}=G(),{characterID:t}=ie(),{data:n,isFetching:r}=te({queryKey:["clones",t],queryFn:()=>J0(Number(t)),refetchOnWindowFocus:!1}),o=Ae(),i=[o.accessor("character.character_name",{header:e("Character")}),o.accessor("home.name",{header:e("Home")}),o.accessor("last_clone_jump",{header:e("Last Jump")}),o.accessor("last_station_change",{header:e("Last Station Change")}),o.accessor("clones",{header:e("Clones"),cell:s=>{var l;return a.jsxs(st,{children:[a.jsxs("thead",{children:[a.jsx("th",{children:e("Location")}),a.jsx("th",{className:"text-end",children:e("Implants")})]}),a.jsx("tbody",{children:(l=s.getValue())==null?void 0:l.map(c=>{var u,f;return a.jsxs("tr",{children:[a.jsxs("td",{children:[c.name," ",(u=c.location)==null?void 0:u.name]}),a.jsx("td",{className:"",children:a.jsx("div",{className:"d-flex justify-content-end align-items-center",children:(f=c.implants)!=null&&f.length?c.implants.map(d=>a.jsx(Hf,{textContent:d.name,type_id:d.id,size:32})):a.jsx("i",{className:"fa-regular fa-circle-xmark"})})})]})})})]})}})];return a.jsx(a.Fragment,{children:a.jsx(Be,{data:n,isFetching:r,columns:i})})},It=({checked:e})=>e?a.jsx(z,{variant:"success",children:a.jsx("i",{className:"fa-solid fa-check"})}):a.jsx(z,{variant:"secondary",children:a.jsx("i",{className:"fa-solid fa-xmark"})}),SS=()=>{const{t:e}=G(),{characterID:t}=ie(),[n,r]=x.useState(!0),{data:o,isFetching:i}=te({queryKey:["contacts",t],queryFn:()=>q0(Number(t)),refetchOnWindowFocus:!1}),s=Ae(),l=[s.accessor("character.character_name",{header:e("Character")}),s.accessor("contact.name",{header:e("Contact"),cell:u=>a.jsxs(a.Fragment,{children:[u.getValue()," ",u.row.original.contact.id<=4e6&&a.jsx(Re,{children:"NPC"})]})}),s.accessor("blocked",{header:e("Blocked"),cell:u=>a.jsx(It,{checked:u.getValue()})}),s.accessor("watched",{header:e("Watching"),cell:u=>a.jsx(It,{checked:u.getValue()})}),s.accessor("standing",{header:"Standing"}),s.accessor("contact.cat",{header:"Type"})],c=o==null?void 0:o.filter(u=>n?!0:u.contact.id>4e6);return a.jsxs(a.Fragment,{children:[a.jsx(D.Header,{className:"text-end",children:a.jsx("div",{className:"d-flex justify-content-end",children:a.jsx(fe.Check,{type:"switch",id:"custom-switch",label:"Show NPC Contacts",onChange:u=>{r(u.target.checked)},defaultChecked:n})})}),a.jsx(Be,{data:c,isFetching:i,columns:l})]})};function Te({strValue:e,text:t,valuePre:n="",valuePost:r="",children:o}){return e||o?a.jsxs("tr",{className:"m-0",children:[a.jsx("td",{className:"m-0",children:a.jsx("p",{className:"text-end m-0 py-0",children:t})}),a.jsxs("td",{style:{paddingLeft:"10px"},className:"m-0",children:[e&&a.jsxs("p",{className:"m-0 py-0",children:[n," ",e," ",r]}),o]})]}):a.jsx(a.Fragment,{})}function wn({dateStrValue:e,text:t,valuePre:n="",valuePost:r=""}){return e?a.jsx(Te,{strValue:new Date(e).toLocaleString(),text:t,valuePre:n,valuePost:r}):a.jsx(a.Fragment,{})}function AS({intValue:e,text:t,valuePre:n="",valuePost:r=""}){return e!==0?a.jsx(Te,{strValue:e.toLocaleString(),text:t,valuePre:n,valuePost:r}):a.jsx(a.Fragment,{})}function mt({strValue:e,text:t,valuePre:n="",valuePost:r=""}){let o=parseInt(e);return e?a.jsx(AS,{intValue:o,text:t,valuePre:n,valuePost:r}):a.jsx(a.Fragment,{})}const jS="_strikeOut_1bswx_1",cn={strikeOut:jS};class wo extends x.Component{constructor(t){super(t),this.state={hasError:!1}}componentDidCatch(t,n){console.error("ErrorBoundary caught an error: ",t,n),this.setState({hasError:!0})}render(){return this.state.hasError?a.jsx(Br,{}):this.props.children}}function vl({data:e,header:t=""}){const{t:n}=G(),r=Ae(),o=[r.accessor("type_name",{header:n("Character")}),r.accessor("quantity",{header:n("QTY")})];return a.jsx(wo,{children:e.length>0&&a.jsxs(a.Fragment,{children:[a.jsx("h6",{className:cn.strikeOut,children:t}),a.jsx(Be,{data:e,columns:o,isFetching:!1})]})})}function RS({data:e,shown:t,setShown:n}){var o,i;const{t:r}=G();return a.jsxs(de,{show:t,size:"lg",onHide:()=>{n(!1)},children:[a.jsx(de.Header,{closeButton:!0,children:a.jsx(de.Title,{children:"Contract Detail"})}),a.jsxs(de.Body,{children:[a.jsxs("table",{className:"table",children:[a.jsx(Te,{strValue:e==null?void 0:e.issuer,text:"From:"}),a.jsx(Te,{strValue:e==null?void 0:e.assignee,text:"To:"}),a.jsx(Te,{strValue:(e==null?void 0:e.acceptor)===(e==null?void 0:e.assignee)?null:e==null?void 0:e.acceptor,text:"Acceptor:"}),a.jsx(Te,{strValue:e==null?void 0:e.availability,text:r("Availability")}),a.jsx(Te,{strValue:e==null?void 0:e.status,text:r("Status")}),a.jsx(mt,{strValue:e==null?void 0:e.start_location_id,text:r("Start Location")}),a.jsx(mt,{strValue:e==null?void 0:e.end_location_id,text:r("End Location")}),a.jsx(wn,{dateStrValue:e==null?void 0:e.date_issued,text:r("Issued")}),a.jsx(wn,{dateStrValue:e==null?void 0:e.date_accepted,text:r("Accepted")}),a.jsx(wn,{dateStrValue:e==null?void 0:e.date_completed,text:r("Completed")}),a.jsx(wn,{dateStrValue:e==null?void 0:e.date_expired,text:"Expiry"}),a.jsx(mt,{strValue:e==null?void 0:e.price,text:r("Price"),valuePre:"$"}),a.jsx(mt,{strValue:e==null?void 0:e.collateral,text:r("Collateral"),valuePre:"$"}),a.jsx(mt,{strValue:e==null?void 0:e.reward,text:r("Reward"),valuePre:"$"}),a.jsx(mt,{strValue:e==null?void 0:e.buyout,text:r("Buyout"),valuePre:"$"}),a.jsx(mt,{strValue:e==null?void 0:e.volume,text:r("Volume"),valuePost:"m3"}),a.jsx(mt,{strValue:e==null?void 0:e.days_to_complete,text:r("Days to Complete")}),a.jsx(Te,{strValue:e==null?void 0:e.title,text:r("Description")})]}),a.jsx(vl,{data:(o=e==null?void 0:e.items)==null?void 0:o.filter(s=>s.is_included),header:r("Items Received")}),a.jsx(vl,{data:(i=e==null?void 0:e.items)==null?void 0:i.filter(s=>!s.is_included),header:r("Items Wanted")})]}),a.jsx(de.Footer,{children:a.jsx(z,{className:"w-100",onClick:()=>n(!1),children:r("Close")})})]})}const FS=()=>{const{t:e}=G(),{characterID:t}=ie(),[n,r]=x.useState(!1),[o,i]=x.useState(null),{data:s,isFetching:l}=te({queryKey:["contracts",t],queryFn:()=>rb(Number(t)),refetchOnWindowFocus:!1}),c=Ae(),u=[c.accessor("character",{header:e("Character")}),c.accessor("date_issued",{header:e("Date Created")}),c.accessor("contract_type",{header:e("Type")}),c.accessor("status",{header:e("Status")}),c.accessor("assignee",{header:e("Assignee")}),c.accessor("price",{header:e("Price")}),c.accessor("tittle",{header:e("Tittle")}),c.accessor("items",{header:e("Details"),cell:f=>a.jsx(a.Fragment,{children:a.jsx(z,{className:"w-100",onClick:()=>{i(f.row.original),r(!0)},children:e("Show Detail")})})})];return a.jsxs(a.Fragment,{children:[a.jsx(Be,{data:s,isFetching:l,columns:u}),a.jsx(RS,{data:o,shown:n,setShown:r})]})},ip=({setFilterText:e,labelText:t})=>a.jsxs("div",{className:"flex-grow-1 flex-even d-flex text-nowrap",children:[a.jsx("div",{className:"my-auto mx-2",children:a.jsx("h6",{children:t})}),a.jsx(rf,{className:"m-2",type:"text",onChange:n=>e(n.target.value)})]}),OS="_skillBlock_1v52a_1",ES={skillBlock:OS},sp=({level:e,active:t=0,trained:n=0})=>{const r=n-t,o=e-t-r,i=5-Math.max(e,t,n);return a.jsxs("div",{className:" text-no-wrap",children:[Array.from(Array(t)).map(s=>a.jsx("i",{className:"fas fa-circle"})),r>0?Array.from(Array(r)).map(s=>a.jsx("i",{className:"fas fa-circle",style:{color:"grey"}})):a.jsx(a.Fragment,{}),o>0?Array.from(Array(o)).map(s=>a.jsx("i",{className:"fas fa-circle",style:{color:"orange"}})):a.jsx(a.Fragment,{}),Array.from(Array(i)).map(s=>a.jsx("i",{className:"far fa-circle",style:{color:"grey"}}))]})},ap=({skill:e,level:t,active:n=0,trained:r=0,sp:o=0,className:i=""})=>a.jsx("div",{className:`${i} ${ES.skillBlock}`,children:a.jsxs("div",{className:"d-flex flex-row justify-content-between my-1 mx-3 align-items-center text-nowrap",children:[a.jsx("span",{className:"flex-grow-1  text-nowrap",children:e}),o?a.jsxs("span",{className:"badge bg-secondary me-1 text-nowrap",children:[o.toLocaleString()," SP"]}):a.jsx(a.Fragment,{}),a.jsx(sp,{level:t,active:n,trained:r})]})}),IS=()=>{const{t:e}=G();return a.jsxs("div",{className:"d-flex flex-column w-100",children:[a.jsx("h5",{className:"text-center",children:"Key"}),a.jsxs("div",{className:"d-flex text-center justify-content-center",children:[a.jsxs("div",{className:"m-3",children:[a.jsx("p",{children:e("Trained Level")}),a.jsx("i",{className:"fas fa-circle"})]}),a.jsxs("div",{className:"m-3",children:[a.jsx("p",{children:e("Omega Restricted")}),a.jsx("i",{className:"fas fa-circle",style:{color:"grey"}})]}),a.jsxs("div",{className:"m-3",children:[a.jsx("p",{children:e("Missing Level")}),a.jsx("i",{className:"fas fa-circle",style:{color:"orange"}})]})]})]})},NS=({show:e,setShow:t,name:n,skill_reqs:r,skill_list:o})=>{const{t:i}=G(),s=()=>{t(!e)};return a.jsxs(de,{show:e,onHide:()=>s(),children:[a.jsx(de.Header,{closeButton:!0,children:a.jsxs(de.Title,{children:[n," - ",i("Missing Skills")]})}),a.jsxs(de.Body,{children:[Object.entries(r).map(([l,c])=>{let u=0,f=0;return o[l]&&(f=o[l].active_level,u=o[l].trained_level),a.jsx(ap,{skill:l,level:Number(c),active:f,trained:u,className:"w-100"})}),a.jsx("hr",{}),a.jsx(IS,{})]}),a.jsx(de.Footer,{children:a.jsx(z,{onClick:()=>s(),children:i("Close")})})]})};var bo={},TS=function(){var e=document.getSelection();if(!e.rangeCount)return function(){};for(var t=document.activeElement,n=[],r=0;r<e.rangeCount;r++)n.push(e.getRangeAt(r));switch(t.tagName.toUpperCase()){case"INPUT":case"TEXTAREA":t.blur();break;default:t=null;break}return e.removeAllRanges(),function(){e.type==="Caret"&&e.removeAllRanges(),e.rangeCount||n.forEach(function(o){e.addRange(o)}),t&&t.focus()}},DS=TS,yl={"text/plain":"Text","text/html":"Url",default:"Text"},_S="Copy to clipboard: #{key}, Enter";function $S(e){var t=(/mac os x/i.test(navigator.userAgent)?"⌘":"Ctrl")+"+C";return e.replace(/#{\s*key\s*}/g,t)}function BS(e,t){var n,r,o,i,s,l,c=!1;t||(t={}),n=t.debug||!1;try{o=DS(),i=document.createRange(),s=document.getSelection(),l=document.createElement("span"),l.textContent=e,l.ariaHidden="true",l.style.all="unset",l.style.position="fixed",l.style.top=0,l.style.clip="rect(0, 0, 0, 0)",l.style.whiteSpace="pre",l.style.webkitUserSelect="text",l.style.MozUserSelect="text",l.style.msUserSelect="text",l.style.userSelect="text",l.addEventListener("copy",function(f){if(f.stopPropagation(),t.format)if(f.preventDefault(),typeof f.clipboardData>"u"){n&&console.warn("unable to use e.clipboardData"),n&&console.warn("trying IE specific stuff"),window.clipboardData.clearData();var d=yl[t.format]||yl.default;window.clipboardData.setData(d,e)}else f.clipboardData.clearData(),f.clipboardData.setData(t.format,e);t.onCopy&&(f.preventDefault(),t.onCopy(f.clipboardData))}),document.body.appendChild(l),i.selectNodeContents(l),s.addRange(i);var u=document.execCommand("copy");if(!u)throw new Error("copy command was unsuccessful");c=!0}catch(f){n&&console.error("unable to copy using execCommand: ",f),n&&console.warn("trying IE specific stuff");try{window.clipboardData.setData(t.format||"text",e),t.onCopy&&t.onCopy(window.clipboardData),c=!0}catch(d){n&&console.error("unable to copy using clipboardData: ",d),n&&console.error("falling back to prompt"),r=$S("message"in t?t.message:_S),window.prompt(r,e)}}finally{s&&(typeof s.removeRange=="function"?s.removeRange(i):s.removeAllRanges()),l&&document.body.removeChild(l),o()}return c}var PS=BS;function Vi(e){"@babel/helpers - typeof";return Vi=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Vi(e)}Object.defineProperty(bo,"__esModule",{value:!0});bo.CopyToClipboard=void 0;var sr=lp(x),kS=lp(PS),LS=["text","onCopy","options","children"];function lp(e){return e&&e.__esModule?e:{default:e}}function wl(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(o){return Object.getOwnPropertyDescriptor(e,o).enumerable})),n.push.apply(n,r)}return n}function bl(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?wl(Object(n),!0).forEach(function(r){Ks(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):wl(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function MS(e,t){if(e==null)return{};var n=US(e,t),r,o;if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(o=0;o<i.length;o++)r=i[o],!(t.indexOf(r)>=0)&&Object.prototype.propertyIsEnumerable.call(e,r)&&(n[r]=e[r])}return n}function US(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}function VS(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function Cl(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}function HS(e,t,n){return t&&Cl(e.prototype,t),n&&Cl(e,n),Object.defineProperty(e,"prototype",{writable:!1}),e}function GS(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&Hi(e,t)}function Hi(e,t){return Hi=Object.setPrototypeOf||function(r,o){return r.__proto__=o,r},Hi(e,t)}function WS(e){var t=QS();return function(){var r=Pr(e),o;if(t){var i=Pr(this).constructor;o=Reflect.construct(r,arguments,i)}else o=r.apply(this,arguments);return zS(this,o)}}function zS(e,t){if(t&&(Vi(t)==="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return cp(e)}function cp(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function QS(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}function Pr(e){return Pr=Object.setPrototypeOf?Object.getPrototypeOf:function(n){return n.__proto__||Object.getPrototypeOf(n)},Pr(e)}function Ks(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var up=function(e){GS(n,e);var t=WS(n);function n(){var r;VS(this,n);for(var o=arguments.length,i=new Array(o),s=0;s<o;s++)i[s]=arguments[s];return r=t.call.apply(t,[this].concat(i)),Ks(cp(r),"onClick",function(l){var c=r.props,u=c.text,f=c.onCopy,d=c.children,p=c.options,h=sr.default.Children.only(d),g=(0,kS.default)(u,p);f&&f(u,g),h&&h.props&&typeof h.props.onClick=="function"&&h.props.onClick(l)}),r}return HS(n,[{key:"render",value:function(){var o=this.props;o.text,o.onCopy,o.options;var i=o.children,s=MS(o,LS),l=sr.default.Children.only(i);return sr.default.cloneElement(l,bl(bl({},s),{},{onClick:this.onClick}))}}]),n}(sr.default.PureComponent);bo.CopyToClipboard=up;Ks(up,"defaultProps",{onCopy:void 0,options:void 0});var qS=bo,Gi=qS.CopyToClipboard;Gi.CopyToClipboard=Gi;var KS=Gi;const ar=({name:e,skill_reqs:t,skill_list:n})=>{const[r,o]=x.useState(!1);let i=Object.entries(t).length===0,s=i?{variant:"success"}:{variant:"danger"},l=Object.entries(t).reduce((u,[f,d])=>{let p=0;return n[f]&&(p=n[f].trained_level),u&&p>=Number(d)},!0);!i&&l&&(s={variant:"warning"});let c=Object.entries(t).reduce((u,[f,d])=>u+""+f+" "+d+`
`,"");return a.jsx(a.Fragment,{children:a.jsx(a.Fragment,{children:a.jsxs("div",{className:"m-2",children:[a.jsxs(wt,{children:[a.jsxs(z,{...s,size:"sm",onClick:()=>o(!0),children:[e,i?a.jsx(a.Fragment,{}):a.jsx(a.Fragment,{})]}),l?a.jsx(z,{size:"sm",...s,className:"flex-one",children:i?a.jsx("i",{className:"fa-solid fa-check"}):a.jsx("i",{className:"fa-solid fa-circle-exclamation"})}):a.jsx(KS.CopyToClipboard,{text:c,children:a.jsx(z,{size:"sm",variant:"danger",children:a.jsx("i",{className:"fa-solid fa-copy"})})})]}),i?a.jsx(a.Fragment,{}):a.jsx(NS,{show:r,setShow:o,name:e,skill_reqs:t,skill_list:n})]})})})},YS=()=>{const{t:e}=G(),{characterID:t}=ie(),[n,r]=x.useState(""),[o,i]=x.useState(!1),{data:s}=te({queryKey:["doctrines",t],queryFn:()=>sb(Number(t)),refetchOnWindowFocus:!1});return a.jsxs(a.Fragment,{children:[a.jsx("h5",{className:"text-center",children:e("Status Key")}),a.jsxs("div",{className:"d-flex justify-content-center align-items-center flex-column",children:[a.jsxs("table",{className:"table",children:[a.jsxs("tr",{className:"row align-items-center",children:[a.jsx("td",{className:"col align-items-center text-end",children:a.jsx(ar,{name:"Passed",skill_reqs:[],skill_list:{}})}),a.jsx("td",{className:"col align-items-center",children:a.jsx("p",{className:"m-0",children:e("All Skills Trained")})})]}),a.jsxs("tr",{className:"row align-items-center",children:[a.jsx("td",{className:"col align-items-center text-end",children:a.jsx(ar,{name:e("Alpha Restricted"),skill_reqs:{"Some Skill Trained But Limited":5},skill_list:{"Some Skill Trained But Limited":{active_level:4,trained_level:5}}})}),a.jsx("td",{className:"col align-items-center",children:a.jsxs("p",{className:"m-0 text-nowrap",children:[e("Some Skills Restricted by Alpha State"),a.jsx("br",{}),e("Click to Show More")]})})]}),a.jsxs("tr",{className:"row align-items-center",children:[a.jsx("td",{className:"col align-items-center text-end",children:a.jsx(ar,{name:"Failed",skill_reqs:{"Some Skill":5},skill_list:{"Some Skill":{active_level:1,trained_level:1}}})}),a.jsx("td",{className:"col align-items-center",children:a.jsxs("p",{className:"m-0 text-nowrap",children:[e("Some Missing Skills"),a.jsx("br",{}),e("Click to Show More"),a.jsx("br",{}),e("Click Copy for easy import in game")]})})]}),a.jsx("tr",{children:a.jsx("td",{colSpan:2})})]}),a.jsx(ip,{setFilterText:r,labelText:e("Search:")}),a.jsx(fe.Check,{type:"switch",id:"custom-switch",label:e("Hide Failures"),onChange:l=>{i(l.target.checked)},defaultChecked:o})]}),s?s.map(l=>{const c=Object.entries(l.doctrines).length;return Object.entries(l.doctrines).reduce((f,[d,p])=>f||(!o||Object.entries(p).length===0)&&(n.length==0||d.toLowerCase().includes(n.toLocaleLowerCase())),!1)&&a.jsxs(D,{className:"my-2",children:[a.jsx(D.Header,{children:a.jsx(D.Title,{children:a.jsxs("div",{className:"m-0",children:[l.character.character_name," ",a.jsxs("span",{className:"float-end",children:[l.character.corporation_name,l.character.alliance_name&&` (${l.character.alliance_name})`]})]})})}),a.jsxs(D.Body,{className:"d-flex align-items-center",children:[a.jsx("div",{className:"flex-one m-2",children:a.jsx(Gf,{size:128,character:l.character})}),a.jsx("div",{className:"d-flex flex-grow-1 justify-content-center flex-wrap",children:c>0?a.jsx(a.Fragment,{children:Object.entries(l.doctrines).map(([f,d])=>(!o||Object.entries(d).length===0)&&(n.length==0||f.toLowerCase().includes(n.toLocaleLowerCase()))&&a.jsx(ar,{name:f,skill_reqs:d,skill_list:l.skills}))}):a.jsx("p",{children:e("No Tokens")})})]})]})}):a.jsx(dS,{title:e("Data Loading"),message:e("Please Wait")})]})},JS=()=>{const{t:e}=G(),{characterID:t}=ie(),{data:n,isFetching:r}=te({queryKey:["LP",t],queryFn:()=>K0(Number(t)),refetchOnWindowFocus:!1}),o=Ae(),i=[o.accessor("character.character_name",{header:e("Character")}),o.accessor("character.corporation_name",{header:e("Corporation")}),o.accessor("corporation.name",{header:e("LP Corporation")}),o.accessor("amount",{header:e("Quantity")})];return a.jsx(a.Fragment,{children:a.jsx(Be,{data:n,isFetching:r,columns:i})})};function ZS({msg_data:e,shown:t,setShown:n}){const{t:r}=G(),{isFetching:o,error:i,data:s}=te(["mailBody",e==null?void 0:e.character_id,e==null?void 0:e.mail_id],()=>fb(e==null?void 0:e.character_id,e==null?void 0:e.mail_id),{refetchOnWindowFocus:!1});return a.jsxs(de,{size:"lg",show:t,onHide:()=>{n(!1)},children:[a.jsx(de.Header,{closeButton:!0,children:a.jsx(de.Title,{children:r("Mail Detail")})}),a.jsxs(de.Body,{children:[a.jsxs("div",{className:"container-fluid",children:[a.jsx(Te,{strValue:e==null?void 0:e.from,text:"From:"}),a.jsx(Te,{text:"Labels:",children:a.jsx("span",{style:{overflowWrap:"anywhere"},children:e==null?void 0:e.labels.map(l=>a.jsx(Re,{style:{marginLeft:"5px"},children:l}))})}),a.jsxs(Te,{text:"Recipients:",children:[(e==null?void 0:e.recipients.length)>2&&a.jsxs("p",{children:[e==null?void 0:e.recipients.length," ",r("Recipients")]}),a.jsx("span",{style:{overflowWrap:"anywhere"},children:e==null?void 0:e.recipients.map(l=>a.jsx(Re,{style:{marginLeft:"5px"},children:l}))})]}),a.jsx(wn,{dateStrValue:e==null?void 0:e.timestamp,text:"Timestamp:"}),a.jsx(Te,{strValue:e==null?void 0:e.subject,text:"Subject:"})]}),a.jsx("hr",{}),i&&a.jsx("p",{children:r("Error from API")}),o&&a.jsx("p",{children:"Loading From API..."}),s&&a.jsx("p",{dangerouslySetInnerHTML:{__html:`${s==null?void 0:s.body}`}})]}),a.jsx(de.Footer,{children:a.jsx(z,{onClick:()=>n(!1),children:r("Close")})})]})}const XS=()=>{const{t:e}=G();let{characterID:t}=ie();const[n,r]=x.useState(!1),[o,i]=x.useState(null),{isFetching:s,data:l}=te(["mail",t],()=>ub(Number(t)),{initialData:[],refetchOnWindowFocus:!1}),c=Ae(),u=[c.accessor("character",{header:e("Character")}),c.accessor("from",{header:e("From")}),c.accessor("labels",{header:e("Labels"),cell:f=>a.jsx("p",{children:f.getValue().map(d=>a.jsx(Re,{style:{marginLeft:"5px"},children:d}))})}),c.accessor("recipients",{header:e("To"),cell:f=>f.getValue().length>2?a.jsx("p",{children:a.jsxs(Re,{bg:"warning",children:["+ ",f.getValue().length," ",e("Recipients")]})}):a.jsx("p",{children:f.getValue().map(d=>a.jsx(Re,{style:{marginLeft:"5px"},bg:"info",children:d}))})}),c.accessor("timestamp",{header:e("Date"),cell:f=>a.jsx("div",{children:new Date(f.getValue()).toLocaleString()})}),c.accessor("subject",{header:e("Subject")}),c.accessor("subject",{header:e("Details"),cell:f=>a.jsx(a.Fragment,{children:a.jsx(z,{onClick:()=>{i(f.row.original),r(!0)},children:e("Show Detail")})})})];return a.jsxs(wo,{children:[a.jsx(so,{isFetching:s,data:l,columns:u}),a.jsx(ZS,{msg_data:o,shown:n,setShown:r})]})},eA=()=>{const{t:e}=G(),{characterID:t}=ie(),{data:n,isFetching:r}=te({queryKey:["market",t],queryFn:()=>nb(Number(t)),refetchOnWindowFocus:!1}),o=Ae(),i=[o.accessor("character.character_name",{header:e("Character")}),o.accessor("buy_order",{header:e("Buy Order"),cell:s=>s.getValue()===!0?a.jsx("i",{className:"fa-solid fa-square-check text-success text-center w-100"}):a.jsx("i",{className:"fa-solid fa-square-xmark text-warning text-center w-100"})}),o.accessor("date",{header:e("Date"),cell:s=>`${new Date(s.getValue()).toUTCString()}`}),o.accessor("item.name",{header:e("Item Type")}),o.accessor("location.name",{header:e("Location")}),o.accessor("price",{header:e("Price")}),o.accessor("volume_remain",{header:e("Volume"),cell:s=>`${s.getValue()}/${s.row.original.volume_total}`})];return a.jsxs(a.Fragment,{children:[a.jsx("h4",{className:"text-center",children:e("Active Orders")}),a.jsx(Be,{data:n==null?void 0:n.active,isFetching:r,columns:i}),a.jsx("h4",{className:"text-center",children:e("Expired Orders")}),a.jsx(Be,{data:n==null?void 0:n.expired,isFetching:r,columns:i})]})},tA=()=>{const{t:e}=G(),{characterID:t}=ie(),{data:n,isFetching:r}=te({queryKey:["notification",t],queryFn:()=>Y0(Number(t)),refetchOnWindowFocus:!1}),o=Ae(),i=[o.accessor("character.character_name",{header:e("Character")}),o.accessor("is_read",{header:e("Is Read"),cell:s=>a.jsx(It,{checked:!!s.getValue()})}),o.accessor("timestamp",{header:e("Date"),cell:s=>a.jsx(a.Fragment,{children:new Date(s.getValue()).toUTCString()}),enableColumnFilter:!1}),o.accessor("notification_type",{header:e("Type")}),o.accessor("notification_text",{header:e("Text"),cell:s=>a.jsx("pre",{children:s.getValue()}),enableColumnFilter:!1})];return a.jsx(a.Fragment,{children:a.jsx(Be,{data:n,isFetching:r,columns:i})})},nA=e=>e?a.jsx(to,{placement:"top",id:e,style:{position:"fixed"},children:e}):a.jsx(a.Fragment,{}),ue=({iconSrc:e,text:t,textVariant:n,isLoading:r,toolTipText:o})=>a.jsx(Ct,{trigger:["hover","focus"],overlay:nA(o),children:a.jsxs("div",{className:`d-flex m-1 ${t?"pt-2":""} flex-column align-items-center`,style:{minWidth:"64px",height:"64px"},children:[a.jsx("img",{src:e,height:t||r?32:64,width:t||r?32:64}),r?a.jsx(cv,{animation:"border",size:"sm"}):t&&a.jsx("h6",{className:`text-${n} text-nowrap mx-1`,children:t})]})}),oe=({iconSrc:e,text:t,cardVariant:n,textVariant:r,isLoading:o,borderVariant:i,toolTipText:s})=>a.jsx(D,{border:n,className:`m-2 ${i=="thick"?"border-4":"border-2"} ${t||o&&"pt-2"}`,children:a.jsx(ue,{iconSrc:e,text:t,textVariant:r,isLoading:o,toolTipText:s})}),fp="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAABCJJREFUeNrsWe1LU2EUvw/4dX+A61uQgSUYsyQTtkRC0PVGhBP6ErhVWNNtaZPl3XxNdEsFoY2+hS3IilIJK2oWZREXIxJiH/qW/gH7fO/tPCKktsE9d8992bo/GGPovc85v+d3znPOeTjOggULFixYsPC/gqh98Mev30n4cpjRqcP799Up/d8KtYtIklgWClBPgCjZTOpTTh8CJLHKpFEd04kAqdCfFjlCBPjeKNoXWfYi88xi3aEDGV0IEMV/ckCOEOI7VnMwy2Ifv3z/6UA6vwnrx3XJAatr6/Y8Ckgcr61m4vyntXUbvD+KPM6i9bXVOV0IAOMq97J/wlGzwCqK4f1ecKgS8Uga1hd0OwXy7H6KlfPvv35zyZLkkRHSh+1XvX6FyvjfdQRC7GVYOP9uVbDB8cqjpE9I1Fl/JKcrAXuOwExTw9EcCwJkWeJlmUPUFyTV1FAnFLMmixBYYeH86w+fXfBeF+KRbHNjfdGhpzYEqshfDRYt/+XMR5r1eYLTfpQF8RXqpCqvQJKiR95mi7OhaPlLsswTWbYhEl+q5WQjkyOXcAZj6c0Klf0kRvqtzc4Ow5shFlh49ZYWVJisT6vNKEsbDCVAhCOPEEzW51JnWpqzZUHA06VlDxQ8DkTcC+daT6VNMw8oBvMvXtqh4PEipR/TwhZDCIBCisY9quC5eLZ1oywISD957oHEh2lzhfbzp9Na2aMrAXOPn9m3Oz3F0oeCJ6SlTUzqgAeP5pXtKCFBWFDxKA0SZBqqrkKVZvZS+4WcKRQgyVJSqUdIeLY/+eCj4WEOAkSJK1WwIaCE7wgsBTDKAb4CXSNNeEHEqzYRtb65u8HZ5H0bOEOTo+KsT8fqVzsvCyWngAK7791WgOIaqetKp1CSIbAX07P3HJAYPRjp03LXiBzAPAQSM7NU+g85xFwfWmJfd9c1wQgCmCsAWlyvTFCXGqmg/7ohzjNXwERiCkpikkQ8kr0Z8HdwBoKZAu5MxPH3eYzHW4YSAM4HwSGU9MO9oWxZEDA8Nk4vNdow0o+E+5hnfbAjueP9cV0IiA2N2CRRNHSySzE4POoGOxzYKrFoAqDY4eGDmuxGByLMpQ8KdO74KehCwG0+BtIXXYhHhMEoz3y8BXbYd9lBiPYK6I8M2FRcamgy2QU7dladuZGh2IbmBOCvsrnU2Mgw88luuD9Cd79NbZeoioC+W2E38ipbGB8bTWu0+wFu9+2SoCkBod4++9aiOOlrMtkFW9x5cpC2CqBHHjiEkX4sPjmRY+18IBhyQ9/By0UOSlAEdPcEsJcamam7iQwrp/3dPXY6YIENKFh4wXqoPKO4Gbrh99PF5zjUlZbuEGamp32aKEASt+LezM5v5RvNegFINmZ3Hh3/KALEEhh9E0JHaxYsWLBgwYJS/BFgAE4Kq3N5izE5AAAAAElFTkSuQmCC",Wi="/static/corptools/bs5/static/img/omega_128-B8POqXI6.png",dp="/static/corptools/bs5/static/img/skillInjector_64-CiNLYJYo.png",pp="data:image/png;base64,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",rA=()=>{var c,u,f,d;const{t:e}=G(),{characterID:t}=ie(),{data:n,isLoading:r}=te({queryKey:["glances","account",t],queryFn:()=>Vs(t?Number(t):0),refetchOnWindowFocus:!1}),o=(c=n==null?void 0:n.characters)==null?void 0:c.reduce((p,h)=>{try{return p+h.isk}catch{return p}},0),i=(u=n==null?void 0:n.characters)==null?void 0:u.reduce((p,h)=>{try{return p+h.sp}catch{return p}},0),s=(f=n==null?void 0:n.characters)==null?void 0:f.filter(p=>!p.active).length,l=(d=n==null?void 0:n.characters)==null?void 0:d.length;return a.jsxs(a.Fragment,{children:[a.jsx("h3",{className:`${cn.strikeOut} w-100 text-center mt-3`,children:e("Account at a Glance")}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsx(oe,{cardVariant:o<1e6?"warning":void 0,iconSrc:fp,textVariant:o<1e6?"warning":void 0,text:`Ƶ${o==null?void 0:o.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})}`,isLoading:r,toolTipText:e("Total Liquid Isk across all characters")}),a.jsx(oe,{cardVariant:i<1e6?"warning":void 0,iconSrc:dp,textVariant:i<1e6?"warning":void 0,text:`${i==null?void 0:i.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})} SP`,isLoading:r,toolTipText:e("Total SP across all characters")}),a.jsx(oe,{iconSrc:Wi,text:l==null?void 0:l.toLocaleString(),isLoading:r,toolTipText:e("Count of all known alts")}),a.jsx(oe,{cardVariant:s>0?"danger":"success",iconSrc:pp,textVariant:s>0?"danger":"success",text:s==null?void 0:s.toLocaleString(),isLoading:r,toolTipText:e("Count of all known alts not loading into audit")})]})]})};q.defaults.xsrfHeaderName="X-CSRFToken";async function oA(){return 1}async function iA(e){const t=await q.get(`/audit/api/corporation/${e}/glance/assets`);return console.log(`get glance/assets in api ${e}`),t.data}async function sA(e){const t=await q.get(`/audit/api/corporation/${e}/character/status`);return console.log(`get glance/assets in api ${e}`),t.data}async function aA(e){const t=await q.get(`/audit/api/corporation/${e}/glance/activities`);return console.log(`get glance/activities in api ${e}`),t.data}async function lA(e){const t=await q.get(`/audit/api/corporation/${e}/glance/faction`);return console.log(`get glance/faction in api ${e}`),t.data}async function cA(){const e=await q.get("/audit/api/corp/structures");return console.log("get structures in api"),e.data}const uA="/static/corptools/bs5/static/img/asteroid_64-_mwThky8.png",fA="/static/corptools/bs5/static/img/gas_64-lUUIHkb8.png",dA="/static/corptools/bs5/static/img/ice_64-C-X-JxCQ.png",pA="/static/corptools/bs5/static/img/incursion_2_64-CezWswVX.png",hA="/static/corptools/bs5/static/img/industry_128-DM0mBaQY.png",gA="/static/corptools/bs5/static/img/market_128-oRcbZRsd.png",mA="/static/corptools/bs5/static/img/missions_2_128-Dg_KBb12.png",xA="/static/corptools/bs5/static/img/moonAsteroid_JackpotR32-CbqQRgx1.png",vA="/static/corptools/bs5/static/img/npcbattleship_32-BFJ3Lc7-.png",yA="/static/corptools/bs5/static/img/planet_128-BhhMKsyX.png",wA="/static/corptools/bs5/static/img/triglavian_128-RGqDm8eK.png",hp=({data:e})=>{var n,r,o,i,s,l,c,u;const{t}=G();return a.jsxs(a.Fragment,{children:[a.jsx("h3",{className:`${cn.strikeOut} w-100 text-center mt-3`,children:"Activity"}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:t("PvE")})}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsx(oe,{iconSrc:pA,cardVariant:e!=null&&e.incursion?"success":void 0,text:(e==null?void 0:e.incursion)&&`+Ƶ${(n=e==null?void 0:e.incursion)==null?void 0:n.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})}`,toolTipText:t("Total Isk earned in Incursions in the last 30 Days")}),a.jsx(oe,{iconSrc:wA,cardVariant:e!=null&&e.pochven?"success":void 0,text:(e==null?void 0:e.pochven)&&`+Ƶ${(r=e==null?void 0:e.pochven)==null?void 0:r.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})}`,toolTipText:t("Total Isk earned in Pochven in the last 30 Days")}),a.jsx(oe,{iconSrc:vA,cardVariant:e!=null&&e.ratting?"success":void 0,text:(e==null?void 0:e.ratting)&&`+Ƶ${(o=e==null?void 0:e.ratting)==null?void 0:o.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})}`,toolTipText:t("Total Isk earned Ratting in the last 30 Days")}),a.jsx(oe,{iconSrc:mA,cardVariant:e!=null&&e.mission?"success":void 0,text:(e==null?void 0:e.mission)&&`+Ƶ${(i=e==null?void 0:e.mission)==null?void 0:i.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})}`,toolTipText:t("Total Isk earned running missions in the last 30 Days")})]})]}),a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:t("Economic")})}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsx(oe,{iconSrc:gA,cardVariant:e!=null&&e.market?"success":void 0}),a.jsx(oe,{iconSrc:hA,cardVariant:e!=null&&e.industry?"success":void 0,toolTipText:t("Industry activities such as manufacturing or reactions")})]})]}),a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:t("Mining")})}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsx(oe,{iconSrc:dA,cardVariant:e!=null&&e.mining_ice?"success":void 0,text:(e==null?void 0:e.mining_ice)&&`${(s=e==null?void 0:e.mining_ice)==null?void 0:s.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})} m3`,toolTipText:t("Total m3 of Ice mined in the last 30 Days")}),a.jsx(oe,{iconSrc:uA,cardVariant:e!=null&&e.mining_ore?"success":void 0,text:(e==null?void 0:e.mining_ore)&&`${(l=e==null?void 0:e.mining_ore)==null?void 0:l.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})} m3`,toolTipText:t("Total m3 of standard ore mined in the last 30 Days")}),a.jsx(oe,{iconSrc:xA,cardVariant:e!=null&&e.mining_moon?"success":void 0,text:(e==null?void 0:e.mining_moon)&&`${(c=e==null?void 0:e.mining_moon)==null?void 0:c.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})} m3`,toolTipText:t("Total m3 of moon ore mined in the last 30 Days")}),a.jsx(oe,{iconSrc:fA,cardVariant:e!=null&&e.mining_gas?"success":void 0,text:(e==null?void 0:e.mining_gas)&&`${(u=e==null?void 0:e.mining_gas)==null?void 0:u.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})} m3`,toolTipText:t("Total m3 of gas anomalies mined in the last 30 Days")}),a.jsx(oe,{iconSrc:yA,cardVariant:e!=null&&e.pi?"success":void 0,toolTipText:t("Planetary import/export seen in the last 30 Days")})]})]})]})]})},bA=()=>{const{characterID:e}=ie(),{data:t}=te({queryKey:["glances","activities",e],queryFn:()=>eb(e?Number(e):0),refetchOnWindowFocus:!1});return a.jsx(hp,{data:t})},CA=()=>{const{data:e}=te({queryKey:["glances","corp","activities",0],queryFn:()=>aA(0),refetchOnWindowFocus:!1});return a.jsx(hp,{data:e})},SA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAOFJREFUeNpiYBgFo2AUUAD+//8/H4QH0nIYmD8glj99+vQ5CNPVEciWy8nJdaioqBQAuefp4gh0y4FCGUDMARQSoLkjcFmOJE87RxCynKaOINZymjiCVMup7ghyLMfmCCA3AJc6JkIGHT169OajR48eAJkLgPgHsQ5gZGT8AKQ2QrkGZDsACm6QYjkpgIlhgMGoA1gIKTAwMJA/c+ZMgrGxsQMZ5ttT7ABVVVUFIKUwICEAzEqMQKphWLeqGAmUZvupYgkjoyPZaeD27dvUiP8EaElKchpwhGoeBaOAZgAgwADRIPnv6gjUcQAAAABJRU5ErkJggg==",AA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAATVJREFUeNpiYBgFo4AC8P////kgPJCWw8D8AbH86dOnz0GYro5AtlxOTq5DRUWlAMg9TxdHoFsOFMoAYg6gkADNHYHLciR52jmCkOU0dQSxltPEEaRaTnVHELIcapEAIUcAuQG47GAi5IijR4/efPTo0QMgcwEQ/0C2AEjtB2FsjmBkZPwApDZCuQZkOwAKbuCw3ACK9+MKCUKAiYxogVsODJ0LIEyJI1gosdzGxgYUxBeA4v5AOgHqCEdo8FM3BHBZDsQbgBYmQtMIySFBlAOMjY1xWo6U6Mh2BN5suH379uOwGu/IkSPngcIN+LIVUjUNyoL90GzYQLYDYIAYy3G0FSh3ACmWY3MERQ4gx3J0R+BzACMhA4CJ6yF6giPVEVAzGshNiwEMlANqmDEKRsEwBQABBgAOibaZR7OUTgAAAABJRU5ErkJggg==",jA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAPZJREFUeNpiYBgFFID////PB+GBtBwG5g+I5U+fPn0OwnR1BLLlcnJyHSoqKgVA7nm6OALdcqBQBhBzAIUEaO4IXJYjydPOEYQsp6kjiLWcJo4g1XKqOoJcy6niCEotp9gR1LAcmyOA3AB0eSZcGo8ePXrz0aNHD4DMBUD8g1wHMDIyfgBSG6FcA6IdAAU3KLGcGIDTAdbW1uoWFhYcVMjGAkDKn9ya7jzUAIrj/8iRI+eBQg10cwQOywPoEhJUsZxcR1DVclIdQRPLiXUETS0n5Ai6WI7LEXS1HIcj6Gs5tmY53S1HdsSAWY4EAgbS8lFAMQAIMACyRj6cz5mg0AAAAABJRU5ErkJggg==",RA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAMVJREFUeNpiYBgFo2AUUAD+//8/H4QH0nIYmD8glj99+vQ5CNPVEciWy8nJdaioqBQAuefp4gh0y4FCGUDMARQSoLkjcFmOJE87RxCynKaOINZymjiCVMup7ghyLMfmCCA3AJc6JkIGHT169OajR48eAJkLgPgHsQ5gZGT8AKQ2QrkGZDsACm6QYjkpgIlhgMGoA1gIKTAwMJA/c+ZMgrGxsQMZ5ttT7ABVVVUFIKUwICEAzEqMQKphtOk1CkbBKKAlAAgwADz48ZFJ3SP6AAAAAElFTkSuQmCC",FA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAL1JREFUeNpiYBgFo2AUjIKhDP7//z8fhAfSchiYPyCWP3369DkI09URyJbLycl1qKioFAC55+niCHTLgUIZQMwBFBKguSNwWY4kTztHELKcEkcwEmM5kEoAsXfs2HHi8+fPP93c3E7w8/P/wKGFH4gLoOwFjIyMidTKauSC+RSFABAEALEBhbF4AYg3DMrSlJFAFOyniiWMjI645FgIab59+7YCFdwASsQLSHYA1OUJo9XuKBgFo2BYA4AAAwDuOPZAKdxOvgAAAABJRU5ErkJggg==",OA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAARxJREFUeNpiYBgFo4AC8P////kgPJCWw8D8AbH86dOnz0GYro5AtlxOTq5DRUWlAMg9TxdHoFsOFMoAYg6gkADNHYHLciR52jmCkOU0dQSxltPEEaRaTlVHkGs5VRxBqeUUO4IalmNzBJAbgC7PhEvj0aNHbz569OgBkLkAiH+Q6wBGRsYPQGojlGtAtAOg4AYllhMDmBgGGIw6gAWXhIGBgfyZM2cSjI2NHdCkJkATFtYUD6QKsEjZk5p18IHzUIvw5XmsAKisgagQAPqQEZviI0eO+FtbW4Oy0n6geY6wkIA6aD8o4IDZ94KNjc1GejTFzkN9Dfc50IHnoQ4PoFd78DzdLcfWKKW75ciOGDDLkUDAQFo+CigGAAEGAKzczqNJim5wAAAAAElFTkSuQmCC",EA="/static/corptools/bs5/static/img/extractor_64-BQGwjQ_v.png",IA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAARtJREFUeNpiYBgFRIL////P/088mE+suSzEWg6kEp49e/bi6NGjN/Gptba2VpeSkkoA6mFgZGRMpJrPnz59+lxOTq4DKJQBxA64sIWFhQdQ+XlSQ4IUyzmI0CdAsSPItZwqjqDUcoocQS3LiXUEEz7NbGxsL4DUAiD+QY2sDMxBBkAqgJQ8D3K5ADV8f+TIkfNAoQaiHEANR1BkOaWOoIrl5DqCqpaT6ghyLGcixSHAukBCVVU1gYRseQGIN9C1OKZKMTxaF4z4usBgQOsCNBcPTF1ADUdQXCJS4giqFcfkOIJUyxmJMRBI7YcmTlDRupGAFn+QWmCCu2BjY7ORWsUxckgQBKQEOyMJ7gCVBaCKSIJuFdEooAcACDAAVWOwQScYFDwAAAAASUVORK5CYII=",NA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAZ9JREFUeNrsV7FugzAQhQihjJkZWLtGYgHB0G7dwifQrWM/IVu7tX9A+gfNxJgFxBjGdKuQoBk7dqPn1qmQhWufTduFkyzHoNx7tu/eHYYxmcC6rks7dUtF/i0ROExJ27bHoiieMcTDMDxzHCcBH4ZpmldoAn3wIAge67p+gfVBloDv+/OyLG+JDxEJ7rE3TfPquu4dPLqGMVe4vgWMvex1jAquTGJM8CESsIz772ZDfyABR+98A+NdlwDc/xtMW7pcCglQO4wBLrLZf+vMRMCSiWCYbhT9P9AAVJZiAr5jIxdhK/Bx8RMJLgHP877BIS2rKIq2GOQ8z1dQDwjxHSGBEY0uy7KSiBH5DY728HjNCgiykhIRuqdCtBYSOJkOOK+cSxNgwZF9QcojwRKwOFJ8uvMKxhOmLxjqA8j8hW0kUkc2tHOmQJ3zBvQBl7zq1/MttFinNAtKcIwKHtXSLNsHSEmxbdtHndIMcbNUyiQmjxcqu9dOZSwJLLgpS4KmUNXrbLj6z8j3Zyr/6QcK5thNJI8YURnH2flkv20fAgwA/mRRRowKgjEAAAAASUVORK5CYII=",TA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAJxJREFUeNpiYBgFo2AUjIKhDP7//z8fhAfSchiYPyCWP3369DkI09URyJbLycl1qKioFAC55+niCHTLgUIZQMwBFBKguSNwWY4kTztHELKcEkcwEmM5kEoAsXfs2HHi8+fPP93c3E7w8/P/wKGFH4gLoOwFjIyMidTKauSC+RSFABAEALEBhbF4AYg3jBbdo2AUjIJRMAoGJQAIMABD/+3i1WyW1AAAAABJRU5ErkJggg==",DA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAUhJREFUeNpiYBgFo2AUEAD///+f/598MJ+Q+SyELAdSCc+ePXtx9OjRm6Q43NraWl1KSioBaAYDIyNjIskOQLbc0tJy4aNHjx4A+TeIdYCFhQXH8ePH20FmEHIEzmB/+vTpczk5uQ6gUAYQc5ARfQJAfJ7Y6KCq5WQ7gpqWY3MEkBuALMeETQMowUHjfAEQ/6DUAcD4/wCkNkK5BgQdAAU3qGE5IcA00OXMqANYiEnBQKqATPMnQBMg2UUxyPL96CmXBOAPNMMRnyNwOsDY2BhuOTBbXrCxsdlIis1HjhzxB9YHIIfvBzmClELj//bt24+DCiMQG2jQeaBwA3oBQmJNCiqE+qEFUQNBB8AAJZbjqs6JdgA1LMfmCKIcQE3L0R2B7gBGbAqBqfYhkHkBiDdQu3UFNbuBkNoAGpY9AQyjYBSMAiQAEGAA489NnZ/6iiAAAAAASUVORK5CYII=",_A="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAPhJREFUeNpiYBgFo2AUEAn+//8//z/xYD6x5rIQazmQSnj27NmLo0eP3sSn1traWl1KSioBqIeBkZExkWo+f/r06XM5ObkOoFAGEDvgwhYWFh5A5edJDQlSLOcgQp8AxY4g13KqOYISy7E5AsgNwKaGCZ8BoAT36NGjB0DmAiD+QaoDgInwA5DaCOUakOwAKLhBjuXEAqaBLl9GHTDgDmDElw3fv3//4e/fvw9EREQ+UGCHAggDc0QjkG4gqS4QFBQUwJV9qAVY8ORhRmwuHnYAXxrYT1WLGBkdSW4P3L59W4GKbkiAFulEpwFHqKZRMApGwfAGAAEGAJy+xoU1pcSFAAAAAElFTkSuQmCC",$A="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAANxJREFUeNpiYBgFo2AUjAIiwf///+f/Jx7MJ9ZcFmItB1IJz549e3H06NGb+NRaW1urS0lJJQD1MDAyMiZSzedPnz59Licn1wEUygBiB1zYwsLCA6j8PKkhQYrlHEToE6DYEeRaTjVHUGI5NkcAuQHY1DDhMwCU4B49evQAyFwAxD9IdQAwEX4AUhuhXAOSHQAFN8ixnFjANNDly6gDBtwBjPiy4fv37z/8/fv3gYiIyAcK7FAAYWCOaATSDSTVBYKCggK4sg+1AAuePMyIzcWjYBSMglEw7ABAgAEAnPm+J1RtnyoAAAAASUVORK5CYII=",BA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAXlJREFUeNrsl7FugzAQQKMOKGPGTigDH+CxY8aO/gQm1DFjNjpWYsjYbskndOMHQF2QMlZiyYTSCSQG2o2eJbuyEOCYs8PSk04oPuT3wBgui8V/IKJt2wPLOeEiDrPAi6K4sLyphAx3XffF87wt/DzdRKILh6EnyCUMraxLDMGluj0JFdyqxLVwKxK6cKMSU+FGJLBwHYk71SSO43zB4Qj5g1nONE0JHOiUVy27ghXm6pMkOcHQs5YARsIIfKqEUbiuhDF4H0glMQYXNR2BVkfiGjir8e2sdcvPkGRMQgEnfA65pr3ulUJiDF6hnoe6rl8lic1QS9YD3wh4HMcfqJ2QZdlO6v38rkQP3BcnR1H0zmuP2G3oD0lw8BicGOkL4E7Qbwg+/75Hcs8K7JwgCI5G4SLyPH8Qayt/3cTzwOCU0jcY2kGubfWGpGmav1ZcwMuyrCT4vdXuOAzDNUh8ivWW+oatdXj37YdtWtAS7I/JLHAplhj4rwADAAc8Lmsu6N7iAAAAAElFTkSuQmCC",PA="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAUhJREFUeNrslz0OgjAYhqmTo6MTEwcwYeUOduEAbo4egdHNI+DMpFNHHSCOcAUHorfArwlNKukP9gcXvuSLUJs+T4q+QBDMZVFd1+W0/wlnlf8F3rbti/akEjw8DMNjFEUHOK0nkRjCYWgPvYShlXcJEbwoijWF99/7k1DA6779SWjgrPxI6OBlWda0vUno4DCWQWMuE4QSdI6xAEDvKrggmHiJrBfIZIzFGJE4jt9pmhI43FRV1SRJcoXjBtbesi1GCO3g40znQN+YhO1voCOEPFjaSbb96zoPduKk2wGtACsRXBbFAzl7ARlcFcW8hJWACq6LYjbfRiBXwcdEMbeGcWEHUYznKJ6j2EoAohir4DIJJwKyKB7xtOwvin98ZHcbxSbvDc6i2PRvrBJAugXgPv+k937oi2mW9GsYxzEO7MvFGn7qI8AAjvv49jSDa0QAAAAASUVORK5CYII=",gp=({data:e,isLoading:t})=>{const{t:n}=G();return a.jsxs(a.Fragment,{children:[a.jsx("h3",{className:`${cn.strikeOut} w-100 text-center mt-3`,children:"Assets"}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:n("Subcapital")})}),a.jsxs("div",{className:"d-flex align-items-center flex-wrap justify-content-center",children:[a.jsx(ue,{iconSrc:TA,textVariant:e!=null&&e.frigate?"info":"warning",text:e!=null&&e.frigate?e==null?void 0:e.frigate:"-",isLoading:t,toolTipText:n("Count of Frigate hulls owned")}),a.jsx(ue,{iconSrc:FA,textVariant:e!=null&&e.destroyer?"info":"warning",text:e!=null&&e.destroyer?e==null?void 0:e.destroyer:"-",isLoading:t,toolTipText:n("Count of Destroyer hulls owned")}),a.jsx(ue,{iconSrc:RA,textVariant:e!=null&&e.cruiser?"info":"warning",text:e!=null&&e.cruiser?e==null?void 0:e.cruiser:"-",isLoading:t,toolTipText:n("Count of Cruiser hulls owned")}),a.jsx(ue,{iconSrc:SA,textVariant:e!=null&&e.battlecruiser?"info":"warning",text:e!=null&&e.battlecruiser?e==null?void 0:e.battlecruiser:"-",isLoading:t,toolTipText:n("Count of battlecruisers hulls owned")}),a.jsx(ue,{iconSrc:AA,textVariant:e!=null&&e.battleship?"info":"warning",text:e!=null&&e.battleship?e==null?void 0:e.battleship:"-",isLoading:t,toolTipText:n("Count of battleship hulls owned")})]})]}),a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:n("Capital")})}),a.jsxs("div",{className:"d-flex align-items-center flex-wrap justify-content-center",children:[a.jsx(ue,{iconSrc:jA,textVariant:e!=null&&e.carrier?"info":"warning",text:e!=null&&e.carrier?e==null?void 0:e.carrier:"-",isLoading:t,toolTipText:n("Count of Carrier hulls owned")}),a.jsx(ue,{iconSrc:IA,textVariant:e!=null&&e.fax?"info":"warning",text:e!=null&&e.fax?e==null?void 0:e.fax:"-",isLoading:t,toolTipText:n("Count of Fax hulls owned")}),a.jsx(ue,{iconSrc:OA,textVariant:e!=null&&e.dread?"info":"warning",text:e!=null&&e.dread?e==null?void 0:e.dread:"-",isLoading:t,toolTipText:n("Count of Dread hulls owned")}),a.jsx(ue,{iconSrc:BA,textVariant:e!=null&&e.supercarrier?"info":"warning",text:e!=null&&e.supercarrier?e==null?void 0:e.supercarrier:"-",toolTipText:n("Count of Super Carrier hulls owned")}),a.jsx(ue,{iconSrc:PA,textVariant:e!=null&&e.titan?"info":"warning",text:e!=null&&e.titan?e==null?void 0:e.titan:"-",toolTipText:n("Count of Titan hulls owned")})]})]}),a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:n("Industrial")})}),a.jsxs("div",{className:"d-flex align-items-center flex-wrap justify-content-center",children:[a.jsx(ue,{iconSrc:$A,textVariant:e!=null&&e.mining?"info":"warning",text:e!=null&&e.mining?e==null?void 0:e.mining:"-",isLoading:t,toolTipText:n("Count of Subcap Industry hulls owned")}),a.jsx(ue,{iconSrc:_A,textVariant:e!=null&&e.hauler?"info":"warning",text:e!=null&&e.hauler?e==null?void 0:e.hauler:"-",isLoading:t,toolTipText:n("Count of Subcap Hauler hulls owned")}),a.jsx(ue,{iconSrc:DA,textVariant:e!=null&&e.indy_command?"info":"warning",text:e!=null&&e.indy_command?e==null?void 0:e.indy_command:"-",isLoading:t,toolTipText:n("Count of Subcap Industrial Command hulls owned")}),a.jsx(ue,{iconSrc:NA,textVariant:e!=null&&e.capital_indy?"info":"warning",text:e!=null&&e.capital_indy?e==null?void 0:e.capital_indy:"-",isLoading:t,toolTipText:n("Count of Capital Industrial hulls owned")})]})]}),a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:n("Notable")})}),a.jsxs("div",{className:"d-flex align-items-center",children:[a.jsx(ue,{iconSrc:dp,textVariant:e!=null&&e.injector?"info":"warning",text:e!=null&&e.injector?e==null?void 0:e.injector:"-",isLoading:t,toolTipText:n("Count of Skill Injectors owned")}),a.jsx(ue,{iconSrc:EA,textVariant:e!=null&&e.extractor?"info":"warning",text:e!=null&&e.extractor?e==null?void 0:e.extractor:"-",isLoading:t,toolTipText:n("Count of Skill Extractors owned")})]})]})]})]})},kA=()=>{const{characterID:e}=ie(),{data:t,isLoading:n}=te({queryKey:["glances","assets",e],queryFn:()=>X0(e?Number(e):0),refetchOnWindowFocus:!1});return console.log(t,n),a.jsx(gp,{data:t,isLoading:n})},LA=()=>{const{data:e,isLoading:t}=te({queryKey:["glances","corp","assets",0],queryFn:()=>iA(0),refetchOnWindowFocus:!1});return a.jsx(gp,{data:e,isLoading:t})},MA="/static/corptools/bs5/static/img/amarr_128-B9KvGWt4.png",UA="/static/corptools/bs5/static/img/caldari_128-BSQ2VRRx.png",VA="data:image/png;base64,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",HA="/static/corptools/bs5/static/img/gallente_128-oOYpsEmX.png",GA="/static/corptools/bs5/static/img/minmatar128-BCerHXFk.png",mp=({data:e})=>{var n,r,o,i,s,l,c,u,f,d,p;const{t}=G();return a.jsxs(a.Fragment,{children:[a.jsx("h3",{className:`${cn.strikeOut} w-100 text-center mt-3`,children:"Affiliations"}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:t("Detected Militia")})}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsx(oe,{iconSrc:MA,cardVariant:(n=e==null?void 0:e.factions)!=null&&n.amarr?"success":void 0}),a.jsx(oe,{iconSrc:HA,cardVariant:(r=e==null?void 0:e.factions)!=null&&r.gallente?"success":void 0}),a.jsx(oe,{iconSrc:GA,cardVariant:(o=e==null?void 0:e.factions)!=null&&o.minmatar?"success":void 0}),a.jsx(oe,{iconSrc:UA,cardVariant:(i=e==null?void 0:e.factions)!=null&&i.caldari?"success":void 0}),a.jsx(oe,{cardVariant:(s=e==null?void 0:e.factions)!=null&&s.angel?"success":void 0,iconSrc:"https://images.evetech.net/corporations/500011/logo?size=128"}),a.jsx(oe,{cardVariant:(l=e==null?void 0:e.factions)!=null&&l.guristas?"success":void 0,iconSrc:"https://images.evetech.net/corporations/500010/logo?size=128"})]})]}),a.jsxs(D,{className:"m-2",children:[a.jsx(D.Header,{className:"text-center",children:a.jsx(D.Title,{children:t("Loyalty Points")})}),a.jsxs("div",{className:"d-flex h-100 align-items-center flex-wrap justify-content-center",children:[a.jsx(ue,{iconSrc:VA,text:(c=e==null?void 0:e.lp)!=null&&c.total?(f=(u=e==null?void 0:e.lp)==null?void 0:u.total)==null?void 0:f.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"}):"0",textVariant:"info"}),(p=(d=e==null?void 0:e.lp)==null?void 0:d.top_five)==null?void 0:p.map(h=>{var g;return a.jsx(ue,{iconSrc:`https://images.evetech.net/corporations/${h.corp_id}/logo?size=128`,text:h!=null&&h.lp?(g=h==null?void 0:h.lp)==null?void 0:g.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"}):"?",textVariant:"muted"})})]})]})]})]})},WA=()=>{const{characterID:e}=ie(),{data:t}=te({queryKey:["glances","faction",e],queryFn:()=>tb(e?Number(e):0),refetchOnWindowFocus:!1});return a.jsx(mp,{data:t})},zA=()=>{const{data:e}=te({queryKey:["glances","corp","faction",0],queryFn:()=>lA(0),refetchOnWindowFocus:!1});return a.jsx(mp,{data:e})},QA=()=>a.jsxs("div",{className:"d-flex flex-column align-items-center",children:[a.jsx(rA,{}),a.jsx(kA,{}),a.jsx(bA,{}),a.jsx(WA,{})]}),qA=()=>a.jsx(a.Fragment,{children:a.jsx(QA,{})}),KA="_menuRefreshSpin_17lcv_1",YA="_spin_17lcv_1",JA={menuRefreshSpin:KA,spin:YA};function Ys({children:e,character:t,style:n,bg:r,border:o,isFetching:i,headerIcon:s,heading:l,roundedImages:c,portaitSize:u=350}){return a.jsx(D,{className:"m-2",style:n,bg:r,border:o,children:a.jsxs(D.Body,{className:"d-flex flex-column align-items-center p-0",children:[a.jsx(Gf,{className:"card-img-top",size:u,character:t,roundedImages:c}),a.jsxs(D.Title,{className:"text-center w-100 pt-2",children:[a.jsxs(lv,{className:"justify-content-between",children:[a.jsx("div",{className:"w-auto",children:s&&a.jsx("i",{className:`${s} fa-fw`})}),a.jsx("div",{className:"w-auto",children:l}),a.jsx("div",{className:"w-auto",children:i&&a.jsx("i",{className:`fas fa-sync-alt fa-fw ${JA.menuRefreshSpin}`})})]}),s&&a.jsx(a.Fragment,{})]}),e]})},`panel ${t.character_name}`)}const ZA=({isFetching:e,data:t})=>{const{t:n}=G();return t?a.jsx("div",{className:"d-flex justify-content-around align-items-center flex-row flex-wrap",children:t==null?void 0:t.characters.map(r=>{var i;const o=r.active?"success":"warning";return a.jsx(Ys,{border:o,isFetching:e,character:r.character,heading:r.character.character_name,roundedImages:"10",children:a.jsx("div",{style:{width:"350px"},children:a.jsxs("div",{children:[a.jsx(st,{striped:!0,style:{marginBottom:0},children:a.jsx("thead",{children:a.jsxs("tr",{children:[a.jsx("th",{children:n("Corporation")}),a.jsx("th",{className:"text-end",children:n("Joined")})]},`head-${r.character}`)})}),a.jsx("div",{style:{width:"350px",height:"250px",overflowY:"auto"},className:"card-img-bottom",children:a.jsx(st,{striped:!0,children:a.jsx("tbody",{children:(i=r.history)==null?void 0:i.map(s=>a.jsxs("tr",{children:[a.jsx("td",{children:s.corporation.corporation_name}),a.jsx("td",{className:"text-end text-nowrap",children:s.start.slice(0,10)})]},s.start))})})})]})})})})}):a.jsx($t,{})},XA=()=>{const{characterID:e}=ie(),{data:t,isFetching:n}=te(["pubdata",e],()=>cb(e?Number(e):0),{refetchOnWindowFocus:!1});return console.log(t),a.jsx(a.Fragment,{children:a.jsx(ZA,{isFetching:n,data:t})})},ej=()=>{const{t:e}=G(),{characterID:t}=ie(),{data:n,isFetching:r}=te({queryKey:["roles",t],queryFn:()=>Z0(Number(t)),refetchOnWindowFocus:!1}),o=Ae(),i=[o.accessor("character.character_name",{header:e("Character")}),o.accessor("character.corporation_name",{header:e("Corporation")}),o.accessor("director",{header:e("Director"),cell:s=>a.jsx(It,{checked:s.getValue()})}),o.accessor("station_manager",{header:e("Station Manager"),cell:s=>a.jsx(It,{checked:s.getValue()})}),o.accessor("personnel_manager",{header:e("Personnel Manager"),cell:s=>a.jsx(It,{checked:s.getValue()})}),o.accessor("accountant",{header:e("Accountant"),cell:s=>a.jsx(It,{checked:s.getValue()})}),o.accessor("titles",{header:e("Titles"),cell:s=>{var l;return(l=s.getValue())==null?void 0:l.map(c=>a.jsx(Re,{bg:"secondary",children:c.name}))}})];return a.jsx(a.Fragment,{children:a.jsx(Be,{data:n,isFetching:r,columns:i})})};var tj=["date","verboseDate","tooltip","children"];function zi(){return zi=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},zi.apply(this,arguments)}function nj(e,t){if(e==null)return{};var n=rj(e,t),r,o;if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(o=0;o<i.length;o++)r=i[o],!(t.indexOf(r)>=0)&&Object.prototype.propertyIsEnumerable.call(e,r)&&(n[r]=e[r])}return n}function rj(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}function kr(e,t){var n=e.date,r=e.verboseDate,o=e.tooltip,i=e.children,s=nj(e,tj),l=x.useMemo(function(){return n.toISOString()},[n]);return H.createElement("time",zi({ref:t},s,{dateTime:l,title:o?r:void 0}),i)}kr=H.forwardRef(kr);kr.propTypes={date:I.instanceOf(Date).isRequired,verboseDate:I.string,tooltip:I.bool.isRequired,children:I.string.isRequired};function Qi(e){"@babel/helpers - typeof";return Qi=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Qi(e)}function oj(e){if(xp())return Intl.DateTimeFormat.supportedLocalesOf(e)[0]}function xp(){var e=(typeof Intl>"u"?"undefined":Qi(Intl))==="object";return e&&typeof Intl.DateTimeFormat=="function"}function Lr(e){"@babel/helpers - typeof";return Lr=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Lr(e)}function ij(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function Sl(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}function sj(e,t,n){return t&&Sl(e.prototype,t),n&&Sl(e,n),Object.defineProperty(e,"prototype",{writable:!1}),e}var vp=function(){function e(){ij(this,e),this.cache={}}return sj(e,[{key:"get",value:function(){for(var n=this.cache,r=arguments.length,o=new Array(r),i=0;i<r;i++)o[i]=arguments[i];for(var s=0,l=o;s<l.length;s++){var c=l[s];if(Lr(n)!=="object")return;n=n[c]}return n}},{key:"put",value:function(){for(var n=arguments.length,r=new Array(n),o=0;o<n;o++)r[o]=arguments[o];for(var i=r.pop(),s=r.pop(),l=this.cache,c=0,u=r;c<u.length;c++){var f=u[c];Lr(l[f])!=="object"&&(l[f]={}),l=l[f]}return l[s]=i}}]),e}(),Al=new vp,aj=xp(),lj=function(t){return t.toString()};function cj(e,t){if(!aj)return lj;var n=fj(e),r=JSON.stringify(t),o=Al.get(String(n),r)||Al.put(String(n),r,new Intl.DateTimeFormat(n,t));return function(i){return o.format(i)}}const uj=_p(cj);var si={};function fj(e){var t=e.toString();return si[t]?si[t]:si[t]=oj(e)}function qi(e){"@babel/helpers - typeof";return qi=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},qi(e)}function dj(e){return pj(e)?e:new Date(e)}function pj(e){return e instanceof Date||hj(e)}function hj(e){return qi(e)==="object"&&typeof e.getTime=="function"}var jl=new vp;function gj(e,t){var n=t.polyfill,r=String(e)+":"+String(n);return jl.get(r)||jl.put(r,new ts(e,{polyfill:n}))}var Co={exports:{}},bn={exports:{}};(function(){var e,t,n,r,o,i;typeof performance<"u"&&performance!==null&&performance.now?bn.exports=function(){return performance.now()}:typeof process<"u"&&process!==null&&process.hrtime?(bn.exports=function(){return(e()-o)/1e6},t=process.hrtime,e=function(){var s;return s=t(),s[0]*1e9+s[1]},r=e(),i=process.uptime()*1e9,o=r-i):Date.now?(bn.exports=function(){return Date.now()-n},n=Date.now()):(bn.exports=function(){return new Date().getTime()-n},n=new Date().getTime())}).call(fc);var mj=bn.exports,xj=mj,rt=typeof window>"u"?fc:window,lr=["moz","webkit"],Kt="AnimationFrame",rn=rt["request"+Kt],_n=rt["cancel"+Kt]||rt["cancelRequest"+Kt];for(var gn=0;!rn&&gn<lr.length;gn++)rn=rt[lr[gn]+"Request"+Kt],_n=rt[lr[gn]+"Cancel"+Kt]||rt[lr[gn]+"CancelRequest"+Kt];if(!rn||!_n){var ai=0,Rl=0,Ft=[],vj=1e3/60;rn=function(e){if(Ft.length===0){var t=xj(),n=Math.max(0,vj-(t-ai));ai=n+t,setTimeout(function(){var r=Ft.slice(0);Ft.length=0;for(var o=0;o<r.length;o++)if(!r[o].cancelled)try{r[o].callback(ai)}catch(i){setTimeout(function(){throw i},0)}},Math.round(n))}return Ft.push({handle:++Rl,callback:e,cancelled:!1}),Rl},_n=function(e){for(var t=0;t<Ft.length;t++)Ft[t].handle===e&&(Ft[t].cancelled=!0)}}Co.exports=function(e){return rn.call(rt,e)};Co.exports.cancel=function(){_n.apply(rt,arguments)};Co.exports.polyfill=function(e){e||(e=rt),e.requestAnimationFrame=rn,e.cancelAnimationFrame=_n};var yj=Co.exports;const Fl=at(yj);function wj(e,t){if(e.length===0)return 0;for(var n=0,r=e.length-1,o;n<=r;){o=Math.floor((r+n)/2);var i=t(e[o]);if(i===0)return o;if(i<0){if(n=o+1,n>r)return n}else if(r=o-1,r<n)return n}}function bj(e,t){return jj(e)||Aj(e,t)||Sj(e,t)||Cj()}function Cj(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Sj(e,t){if(e){if(typeof e=="string")return Ol(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if(n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set")return Array.from(e);if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return Ol(e,t)}}function Ol(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function Aj(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r=[],o=!0,i=!1,s,l;try{for(n=n.call(e);!(o=(s=n.next()).done)&&(r.push(s.value),!(t&&r.length===t));o=!0);}catch(c){i=!0,l=c}finally{try{!o&&n.return!=null&&n.return()}finally{if(i)throw l}}return r}}function jj(e){if(Array.isArray(e))return e}const Rj={instances:[],add:function(t){var n=this,r=this.instances.length===0;return yp(this.instances,t),r&&this.start(),{stop:function(){wp(n.instances,t),n.instances.length===0&&n.stop()},forceUpdate:function(){El(t,n.instances)}}},tick:function(){for(var t=Date.now();;){var n=this.instances[0];if(t>=n.nextUpdateTime)El(n,this.instances);else break}},scheduleNextTick:function(){var t=this;this.scheduledTick=Fl(function(){t.tick(),t.scheduleNextTick()})},start:function(){this.scheduleNextTick()},stop:function(){Fl.cancel(this.scheduledTick)}};function Fj(e){var t=e.getNextValue(),n=bj(t,2),r=n[0],o=n[1];e.setValue(r),e.nextUpdateTime=o}function El(e,t){Fj(e),wp(t,e),yp(t,e)}function yp(e,t){var n=Oj(e,t);e.splice(n,0,t)}function wp(e,t){var n=e.indexOf(t);e.splice(n,1)}function Oj(e,t){var n=t.nextUpdateTime;return wj(e,function(r){return r.nextUpdateTime===n?0:r.nextUpdateTime>n?1:-1})}function cr(e,t){return Tj(e)||Nj(e,t)||Ij(e,t)||Ej()}function Ej(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Ij(e,t){if(e){if(typeof e=="string")return Il(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if(n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set")return Array.from(e);if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return Il(e,t)}}function Il(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function Nj(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r=[],o=!0,i=!1,s,l;try{for(n=n.call(e);!(o=(s=n.next()).done)&&(r.push(s.value),!(t&&r.length===t));o=!0);}catch(c){i=!0,l=c}finally{try{!o&&n.return!=null&&n.return()}finally{if(i)throw l}}return r}}function Tj(e){if(Array.isArray(e))return e}function Dj(e){var t=e.date,n=e.future,r=e.locale,o=e.locales,i=e.timeStyle,s=e.round,l=e.minTimeLeft,c=e.formatVerboseDate,u=e.verboseDateFormat,f=u===void 0?Bj:u,d=e.updateInterval,p=e.tick,h=p===void 0?!0:p,g=e.now,m=e.timeOffset,v=m===void 0?0:m,y=e.polyfill,b=x.useMemo(function(){return r&&(o=[r]),o.concat(ts.getDefaultLocale())},[r,o]),w=x.useMemo(function(){return gj(b,{polyfill:y})},[b,y]);t=x.useMemo(function(){return dj(t)},[t]);var S=x.useCallback(function(){var Q=(g||Date.now())-v,X;if(n&&Q>=t.getTime()&&(Q=t.getTime(),X=!0),l!==void 0){var K=t.getTime()-l*1e3;Q>K&&(Q=K,X=!0)}var ee=w.format(t,i,{getTimeToNextUpdate:!0,now:Q,future:n,round:s}),se=cr(ee,2),he=se[0],ae=se[1];return X?ae=$j:ae=d||ae||60*1e3,[he,Q+ae]},[t,n,i,d,s,l,w,g]),F=x.useRef();F.current=S;var C=x.useMemo(S,[]),A=cr(C,2),O=A[0],T=A[1],N=x.useState(O),E=cr(N,2),B=E[0],P=E[1],M=x.useRef();x.useEffect(function(){if(h)return M.current=Rj.add({getNextValue:function(){return F.current()},setValue:P,nextUpdateTime:T}),function(){return M.current.stop()}},[h]),x.useEffect(function(){if(M.current)M.current.forceUpdate();else{var Q=S(),X=cr(Q,1),K=X[0];P(K)}},[S]);var V=x.useMemo(function(){return uj(b,f)},[b,f]),J=x.useMemo(function(){return c?c(t):V(t)},[t,c,V]);return{date:t,formattedDate:B,verboseDate:J}}var _j=365*24*60*60*1e3,$j=1e3*_j,Bj={weekday:"long",day:"numeric",month:"long",year:"numeric",hour:"numeric",minute:"2-digit",second:"2-digit"},Ki=I.oneOfType,Nl=I.arrayOf,qt=I.string,Tl=I.number,Cn=I.shape,ur=I.func,Pj=Ki([Cn({minTime:Tl,formatAs:qt.isRequired}),Cn({test:ur,formatAs:qt.isRequired}),Cn({minTime:Tl,format:ur.isRequired}),Cn({test:ur,format:ur.isRequired})]),kj=Ki([qt,Cn({steps:Nl(Pj).isRequired,labels:Ki([qt,Nl(qt)]).isRequired,round:qt})]),Lj=["date","future","timeStyle","round","minTimeLeft","locale","locales","formatVerboseDate","verboseDateFormat","updateInterval","tick","now","timeOffset","polyfill","tooltip","component","container","wrapperComponent","wrapperProps"];function Mr(){return Mr=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Mr.apply(this,arguments)}function Mj(e,t){if(e==null)return{};var n=Uj(e,t),r,o;if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(o=0;o<i.length;o++)r=i[o],!(t.indexOf(r)>=0)&&Object.prototype.propertyIsEnumerable.call(e,r)&&(n[r]=e[r])}return n}function Uj(e,t){if(e==null)return{};var n={},r=Object.keys(e),o,i;for(i=0;i<r.length;i++)o=r[i],!(t.indexOf(o)>=0)&&(n[o]=e[o]);return n}function Ur(e){var t=e.date,n=e.future,r=e.timeStyle,o=e.round,i=e.minTimeLeft,s=e.locale,l=e.locales,c=l===void 0?[]:l,u=e.formatVerboseDate,f=e.verboseDateFormat,d=e.updateInterval,p=e.tick,h=e.now,g=e.timeOffset,m=e.polyfill,v=e.tooltip,y=v===void 0?!0:v,b=e.component,w=b===void 0?kr:b,S=e.container,F=e.wrapperComponent,C=e.wrapperProps,A=Mj(e,Lj),O=Dj({date:t,future:n,timeStyle:r,round:o,minTimeLeft:i,locale:s,locales:c,formatVerboseDate:u,verboseDateFormat:f,updateInterval:d,tick:p,now:h,timeOffset:g,polyfill:m}),T=O.date,N=O.verboseDate,E=O.formattedDate,B=H.createElement(w,Mr({date:T,verboseDate:N,tooltip:y},A),E),P=F||S;return P?H.createElement(P,Mr({},C,{verboseDate:N}),B):B}Ur.propTypes={date:I.oneOfType([I.instanceOf(Date),I.number]).isRequired,locale:I.string,locales:I.arrayOf(I.string),future:I.bool,timeStyle:kj,round:I.string,minTimeLeft:I.number,component:I.elementType,tooltip:I.bool,formatVerboseDate:I.func,verboseDateFormat:I.object,updateInterval:I.oneOfType([I.number,I.arrayOf(I.shape({threshold:I.number,interval:I.number.isRequired}))]),tick:I.bool,now:I.number,timeOffset:I.number,polyfill:I.bool,wrapperComponent:I.elementType,wrapperProps:I.object};Ur=H.memo(Ur);const bp=Ur,Vj=()=>{const{t:e}=G(),{characterID:t}=ie(),{isLoading:n,isFetching:r,error:o,data:i}=te(["skills",t],()=>ib(t?Number(t):0),{refetchOnWindowFocus:!1}),[s,l]=x.useState(!0),[c,u]=x.useState(!0),[f,d]=x.useState(!1);if(n)return a.jsx($t,{});if(o)return a.jsx(Br,{});const p=v=>{l(v.currentTarget.checked)},h=v=>{u(v.currentTarget.checked)},g=v=>{d(v.currentTarget.checked)};let m=i.filter(v=>{let y=!1,b=!1,w=!1;return v.queue?v.queue.length&&v.queue[0].end?y=!0:v.queue.length?b=!0:w=!0:w=!0,s&&y||f&&w||c&&b});return n?a.jsx($t,{}):o?a.jsx(Br,{}):a.jsxs(a.Fragment,{children:[a.jsx("h5",{className:"text-center",children:e("Filters")}),a.jsxs(Ss,{className:"col-xs-12 text-center",children:[a.jsx(fe.Check,{defaultChecked:s,onChange:p,label:e("Active"),inline:!0}),a.jsx(fe.Check,{defaultChecked:c,onChange:h,label:e("Paused"),inline:!0}),a.jsx(fe.Check,{defaultChecked:f,onChange:g,label:e("Empty"),inline:!0})]}),a.jsx("div",{className:"d-flex justify-content-around align-items-center flex-row flex-wrap",children:m==null?void 0:m.map(v=>{var b;let y=v.queue.length?{border:"success"}:{border:"warning"};return v.queue.length>0&&!v.queue[0].end&&(y={border:"info"}),a.jsxs(Ys,{...y,isFetching:r,character:v.character,heading:v.character.character_name,roundedImages:"10",portaitSize:450,children:[a.jsxs("h6",{children:[v.character.corporation_name,v.character.alliance_name&&` (${v.character.alliance_name})`]}),a.jsx("div",{style:{width:"450px"},children:a.jsxs("div",{children:[a.jsx(st,{striped:!0,style:{marginBottom:0},children:a.jsx("thead",{children:a.jsxs("tr",{children:[a.jsx("th",{children:e("Skill")}),a.jsx("th",{className:"text-end",children:e("Level")})]},`head-${v.character.character_name}`)})}),a.jsx("div",{style:{width:"450px",height:"350px",overflowY:"auto"},className:"card-img-bottom",children:a.jsx(st,{striped:!0,children:a.jsx("tbody",{children:(b=v.queue)==null?void 0:b.map(w=>a.jsx("tr",{children:a.jsxs("td",{className:"no-margin",children:[a.jsxs("div",{className:"d-flex justify-content-between",children:[a.jsx("p",{className:"m-0",children:w.skill}),a.jsx(sp,{level:w.end_level,trained:w.current_level,active:w.current_level})]}),a.jsx("div",{className:"d-flex justify-content-between",children:w.end?a.jsxs(a.Fragment,{children:[a.jsx(bp,{date:Date.parse(w.end)}),a.jsxs("p",{className:"m-0 small",children:[(w.end_sp-w.start_sp).toLocaleString(),"/",w.end_sp.toLocaleString()," SP"]})]}):a.jsxs(a.Fragment,{children:[a.jsx("i",{className:"fa-solid fa-pause"}),a.jsxs("p",{className:"m-0",children:[(w.end_sp-w.start_sp).toLocaleString(),"/",w.end_sp.toLocaleString()," SP"]})]})})]})},`${v.character.character_name}${w.skill}${w.end_level}`))})})})]})})]})})})]})},Hj={option:e=>({...e,color:"black"})},li=({setFilter:e,options:t,labelText:n})=>a.jsxs("div",{className:"flex-grow-1 flex-even d-flex text-nowrap",children:[a.jsx("div",{className:"my-auto mx-2",children:a.jsx("h6",{children:n})}),a.jsx(cc,{className:"m-1 flex-grow-1",styles:Hj,options:t,onChange:r=>e(r.value),defaultValue:t[0]})]}),Gj=({group:e,skills:t})=>{const{t:n}=G();return a.jsxs(gr.Item,{eventKey:`${e}`,children:[a.jsxs(gr.Header,{children:[a.jsx("span",{className:"flex-grow-1",children:e}),a.jsxs("span",{className:"badge bg-secondary me-2",children:[t.reduce((r,o)=>(r+=o.sp,r),0).toLocaleString()," ",n("Filtered SP")]})]}),a.jsx(gr.Body,{className:"d-flex flex-wrap ",children:t.sort(function(r,o){const i=r.skill.toLowerCase(),s=o.skill.toLowerCase();return i<s?-1:i>s?1:0}).map(r=>a.jsx(ap,{skill:r.skill,level:r.level,active:r.active,trained:r.active,sp:r.sp}))})]})},Wj=({data:e})=>{const n=((r,o)=>r.reduce((i,s)=>({...i,[s[o]]:(i[s[o]]||[]).concat(s)}),{}))(e,"group");return Object.entries(n).length===0?a.jsx($t,{title:"Nothing Found"}):(console.log(n),a.jsx(wo,{children:a.jsx(gr,{defaultActiveKey:[],alwaysOpen:!0,children:Object.entries(n).sort(function(r,o){const i=r[0].toLowerCase(),s=o[0].toLowerCase();return i<s?-1:i>s?1:0}).map(r=>a.jsx(Gj,{group:r[0],skills:r[1]}))})}))},zj=()=>{var h,g,m;const{t:e}=G(),{characterID:t}=ie(),[n,r]=x.useState(t),[o,i]=x.useState("All"),[s,l]=x.useState(""),[c,u]=x.useState(-1),{isLoading:f,error:d,data:p}=te(["skills",t],()=>ob(t?Number(t):0),{refetchOnWindowFocus:!1});if(f)return a.jsx($t,{title:e("Data Loading"),message:e("Please Wait")});if(d)return a.jsx(Br,{});if(n==="0")return r(p[0].character.character_id),a.jsx($t,{title:e("Data Loading"),message:e("Please Wait")});{const v=p.filter(C=>C.character.character_id===Number(n||0));let y=(h=v==null?void 0:v[0])==null?void 0:h.skills;o!==""&&o!=="All"&&(y=y==null?void 0:y.filter(C=>C.group.toLowerCase().includes(o.toLowerCase()))),c>=0&&(y=y==null?void 0:y.filter(C=>C.level===c)),s!==""&&(y=y==null?void 0:y.filter(C=>C.skill.toLowerCase().includes(s.toLowerCase())));const b=p.map(C=>({value:C.character.character_id,label:C.character.character_name})),w=[{value:-1,label:e("All")},{value:0,label:e("0")},{value:1,label:e("1")},{value:2,label:e("2")},{value:3,label:e("3")},{value:4,label:e("4")},{value:5,label:e("5")}],S=new Set;(m=(g=v==null?void 0:v[0])==null?void 0:g.skills)==null||m.forEach(C=>{S.add(C.group)});const F=[{value:"All",label:"All"}].concat([...S.values()].sort().map(C=>({value:C,label:C})));return a.jsxs(wo,{children:[a.jsx(li,{setFilter:r,options:b,labelText:e("Character Select:")}),a.jsxs("div",{className:"d-flex justify-content-between mb-3",children:[a.jsx(li,{setFilter:u,options:w,labelText:e("Level Filter:")}),a.jsx(li,{setFilter:i,options:F,labelText:e("Group Filter:")}),a.jsx(ip,{setFilterText:l,labelText:e("Skill Filter:")})]}),a.jsx(Wj,{data:y})]})}};function fr(e){const t=new Date(e);if(!Number.isNaN(t.valueOf()))return t;const n=String(e).match(/\d+/g);if(n==null||n.length<=2)return t;{const[r,o,...i]=n.map(c=>parseInt(c)),s=[r,o-1,...i];return new Date(Date.UTC(...s))}}function Dl(e,t,n){const r=e!==1?t+"s":t;return e+" "+r+" "+n}function Yi(){return Yi=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Yi.apply(this,arguments)}const Sn=60,An=Sn*60,Yt=An*24,dr=Yt*7,_l=Yt*30,$l=Yt*365,Qj=()=>Date.now();function Cp({date:e,formatter:t=Dl,component:n="time",live:r=!0,minPeriod:o=0,maxPeriod:i=dr,title:s,now:l=Qj,...c}){const[u,f]=x.useState(l());x.useEffect(()=>{if(!r)return;const F=(()=>{const C=fr(e).valueOf();if(!C)return console.warn("[react-timeago] Invalid Date provided"),0;const A=Math.round(Math.abs(u-C)/1e3),O=A<Sn?1e3:A<An?1e3*Sn:A<Yt?1e3*An:1e3*dr,T=Math.min(Math.max(O,o*1e3),i*1e3);return T?setTimeout(()=>{f(l())},T):0})();return()=>{F&&clearTimeout(F)}},[e,r,i,o,l,u]);const d=n,p=fr(e).valueOf();if(!p)return null;const h=Math.round(Math.abs(u-p)/1e3),g=p<u?"ago":"from now",[m,v]=h<Sn?[Math.round(h),"second"]:h<An?[Math.round(h/Sn),"minute"]:h<Yt?[Math.round(h/An),"hour"]:h<dr?[Math.round(h/Yt),"day"]:h<_l?[Math.round(h/dr),"week"]:h<$l?[Math.round(h/_l),"month"]:[Math.round(h/$l),"year"],y=typeof s>"u"?typeof e=="string"?e:fr(e).toISOString().substr(0,16).replace("T"," "):s,b=d==="time"?{...c,dateTime:fr(e).toISOString()}:c,w=Dl.bind(null,m,v,g);return x.createElement(d,Yi({},b,{title:y}),t(m,v,g,p,w,l))}const qj=({data:e,isFetching:t})=>{const{t:n}=G(),[r,o]=H.useState(!1),[i,s]=H.useState(null);return a.jsxs("div",{className:"d-flex justify-content-around align-items-center flex-row flex-wrap",children:[e==null?void 0:e.characters.map(l=>{const c=l.active?"success":"warning";return a.jsx(Ys,{border:c,character:l.character,heading:l.character.character_name,roundedImages:"10",isFetching:t,portaitSize:450,children:a.jsxs("div",{className:"mt-2",style:{width:"450px"},children:[a.jsxs(D.Text,{className:"text-center",children:[l.character.corporation_name,a.jsx("br",{}),l.character.alliance_name?l.character.alliance_name:a.jsx("br",{})]}),a.jsxs(D.Text,{className:"text-center",children:[n("Skill Points"),":"," ",a.jsx(Re,{className:"text-center",children:l.sp&&l.sp.toLocaleString()}),a.jsx("br",{}),n("Isk"),":"," ",a.jsxs(Re,{className:"text-center",children:["$",l.isk&&l.isk.toLocaleString()]})]}),a.jsx(D.Title,{className:"text-center",children:n("Location")}),a.jsxs(D.Text,{className:"text-center",children:[a.jsx(Re,{className:"text-center",children:l.location?l.location:n("Unknown Location")}),a.jsx("br",{}),a.jsxs(Re,{className:"text-center m-1",children:[l.ship_name&&a.jsx(a.Fragment,{children:l.ship_name}),l.ship&&a.jsxs(a.Fragment,{children:[a.jsx("br",{}),l.ship]})]})]}),a.jsxs(D.Text,{className:"text-center",children:[a.jsxs(wt,{className:"w-75",children:[a.jsx(z,{variant:"secondary",size:"sm",href:`https://zkillboard.com/character/${l.character.character_id}`,children:"zKill"}),a.jsx(z,{variant:"secondary",size:"sm",href:`https://evewho.com/character/${l.character.character_id}`,children:"EVE Who"}),a.jsx(z,{variant:"secondary",size:"sm",href:`https://evemaps.dotlan.net/corp/${l.character.corporation_name.replace(" ","_")}`,children:"DotLan"}),a.jsx(z,{variant:"secondary",size:"sm",href:`https://www.eve411.com/character/${l.character.character_id}`,children:"EVE411"})]}),a.jsxs(wt,{className:"w-75 mt-1",children:[a.jsx(z,{variant:"secondary",size:"sm",href:`https://forums.eveonline.com/u/${l.character.character_name.replace(" ","_")}/summary`,children:"EVE Forums"}),a.jsx(z,{variant:"secondary",size:"sm",href:`https://eve-search.com/search/author/${l.character.character_name}`,children:"EVE Search"})]}),a.jsx(z,{variant:c,size:"sm",className:"w-100 mt-2",style:{borderTopLeftRadius:0,borderTopRightRadius:0},onClick:()=>{s(l),o(!0)},children:n("Show Update Status")})]})]})})}),(i==null?void 0:i.character)&&a.jsxs(de,{show:r,onHide:()=>{o(!1)},children:[a.jsx(de.Header,{closeButton:!0,children:n(`${i==null?void 0:i.character.character_name} Update Status`)}),a.jsx(de.Body,{children:a.jsx("div",{children:a.jsxs(st,{striped:!0,style:{marginBottom:0},children:[a.jsx("thead",{children:a.jsxs("tr",{children:[a.jsx("th",{children:n("Update")}),a.jsx("th",{className:"text-end",children:n("Last Run")})]},`head-${i==null?void 0:i.character}`)}),a.jsx("tbody",{children:e==null?void 0:e.headers.map(l=>a.jsxs("tr",{children:[a.jsx("td",{children:l}),a.jsx("td",{className:"text-end",children:i!=null&&i.last_updates&&i!=null&&i.last_updates[l]?a.jsx(Cp,{date:i==null?void 0:i.last_updates[l]}):n("Never")})]},l))})]})})}),a.jsx(de.Footer,{children:a.jsx(z,{variant:"secondary",className:"w-100",onClick:()=>{o(!1)},children:n("Close")})})]})]})},Kj=({data:e,isFetching:t})=>{var i,s,l;const{t:n}=G(),r=Ae();let o=[r.accessor("character.character_name",{header:n("Character")}),r.accessor("character.corporation_name",{header:n("Corporation")}),r.accessor("character.alliance_name",{header:n("Alliance")}),r.accessor("isk",{header:n("Isk"),cell:c=>{var u;return(u=c.getValue())==null?void 0:u.toLocaleString()}}),r.accessor("sp",{header:n("SP"),cell:c=>{var u;return(u=c.getValue())==null?void 0:u.toLocaleString()}}),r.accessor("active",{header:n("Active"),cell:c=>{const u=c.getValue();return a.jsx("div",{className:"text-center",children:a.jsx(z,{variant:u?"success":"warning",children:u?a.jsx("i",{className:"fa-solid fa-check"}):a.jsx("i",{className:"fa-solid fa-xmark"})})})}})];return console.log(e==null?void 0:e.last_updates),(i=e==null?void 0:e.characters[0])!=null&&i.last_updates&&((l=Object.keys((s=e==null?void 0:e.characters[0])==null?void 0:s.last_updates))==null||l.map(c=>{console.log(c),o.push(r.accessor(`last_updates.${c}`,{header:c,cell:u=>u.getValue()?a.jsx(Cp,{date:u.getValue()}):n("Never")}))})),a.jsx(so,{data:e==null?void 0:e.characters,isFetching:t,columns:o})},Yj=()=>{const{t:e}=G(),{characterID:t}=ie(),[n,r]=x.useState(!1),{data:o,isFetching:i}=te({queryKey:["status",t],queryFn:()=>Vs(t?Number(t):0),refetchOnWindowFocus:!1,initialData:{characters:[],main:void 0,headers:[]}});return a.jsxs(a.Fragment,{children:[a.jsx(D.Header,{className:"text-end",children:a.jsx("div",{className:"d-flex justify-content-end",children:a.jsx(fe.Check,{type:"switch",id:"custom-switch",label:e("Display in Table Format"),onChange:s=>{r(s.target.checked)},defaultChecked:n})})}),n?a.jsx(Kj,{isFetching:i,data:o}):a.jsx(a.Fragment,{children:a.jsx(qj,{isFetching:i,data:o})})]})},Jj=()=>{const{t:e}=G(),{characterID:t}=ie(),{data:n,isFetching:r}=te({queryKey:["wallet",t],queryFn:()=>gb(Number(t)),refetchOnWindowFocus:!1}),o=Ae(),i=[o.accessor("character.character_name",{header:e("Character")}),o.accessor("date",{header:e("Date")}),o.accessor("ref_type",{header:e("Type")}),o.accessor("first_party.name",{header:e("First Party")}),o.accessor("second_party.name",{header:e("Second Party")}),o.accessor("amount",{header:e("Amount")}),o.accessor("balance",{header:e("Balance")}),o.accessor("reason",{header:e("Reason")})];return a.jsx(a.Fragment,{children:a.jsx(Be,{data:n,isFetching:r,columns:i})})},Zj=()=>{var r,o,i,s,l,c,u,f,d,p,h,g,m,v,y,b,w,S;const{t:e}=G(),{data:t,isLoading:n}=te({queryKey:["glances","corporation","status",0],queryFn:()=>sA(0),refetchOnWindowFocus:!1});return a.jsxs(a.Fragment,{children:[a.jsxs("h3",{className:`${cn.strikeOut} w-100 text-center mt-3`,children:['"',e("Corporation Members"),'"']}),a.jsxs("div",{className:"d-flex flex-wrap justify-content-center",children:[a.jsx(oe,{cardVariant:((r=t==null?void 0:t.characters)==null?void 0:r.liquid)<1e6?"warning":void 0,iconSrc:fp,textVariant:((o=t==null?void 0:t.characters)==null?void 0:o.liquid)<1e6?"warning":void 0,text:`Ƶ${(s=(i=t==null?void 0:t.characters)==null?void 0:i.liquid)==null?void 0:s.toLocaleString("en-US",{maximumFractionDigits:2,notation:"compact",compactDisplay:"short"})}`,isLoading:n,toolTipText:e("Total Liquid Isk across all characters and alts in corporation")}),a.jsx(oe,{iconSrc:Wi,text:(c=(l=t==null?void 0:t.characters)==null?void 0:l.known_and_alts)==null?void 0:c.toLocaleString(),isLoading:n,toolTipText:e("Count of all known Characters and Alts")}),a.jsx(oe,{cardVariant:((u=t==null?void 0:t.characters)==null?void 0:u.known_in_corp)<((f=t==null?void 0:t.characters)==null?void 0:f.in_corp)?"warning":"success",textVariant:((d=t==null?void 0:t.characters)==null?void 0:d.known_in_corp)<((p=t==null?void 0:t.characters)==null?void 0:p.in_corp)?"warning":"success",iconSrc:Wi,text:`${(g=(h=t==null?void 0:t.characters)==null?void 0:h.known_in_corp)==null?void 0:g.toLocaleString()}/${(v=(m=t==null?void 0:t.characters)==null?void 0:m.in_corp)==null?void 0:v.toLocaleString()}`,isLoading:n,toolTipText:e("Count of all known Characters in Corp")}),a.jsx(oe,{cardVariant:((y=t==null?void 0:t.characters)==null?void 0:y.bad)>0?"danger":"success",iconSrc:pp,textVariant:((b=t==null?void 0:t.characters)==null?void 0:b.bad)>0?"danger":"success",text:(S=(w=t==null?void 0:t.characters)==null?void 0:w.bad)==null?void 0:S.toLocaleString(),isLoading:n,toolTipText:e("Count of all known characters or alts not loading into audit")})]})]})},Xj=()=>a.jsxs("div",{className:"d-flex flex-column align-items-center",children:[a.jsx(Zj,{}),a.jsx(CA,{}),a.jsx(LA,{}),a.jsx(zA,{})]}),eR=e=>{const{t}=G();return console.log(e),a.jsxs(a.Fragment,{children:[a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{as:ge,to:"/audit/r_beta/corp/glance",children:t("Overview")},"Glance")}),a.jsxs(Ie,{as:"li",title:"Structures",children:[a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:"/audit/r_beta/corp/structures",children:t("Structures")},"Structures")}),a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:"/audit/r_beta/corp/bridges",children:t("Bridges")},"bridges")}),a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:"/audit/r_beta/corp/fuel",children:t("Fuel")},"bridges")}),a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:"/audit/r_beta/corp/metenox",children:t("Metenox")},"bridges")}),a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:"/audit/r_beta/corp/pocos",children:t("Pocos")},"pocos")})]}),a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{as:ge,to:"/audit/r_beta/corp/wallets",children:t("Wallets")},"Wallets")}),a.jsxs(Ie,{as:"li",title:"Assets",children:[a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:"/audit/r_beta/corp/assetgroup",children:t("Asset Overview")},"assetgroup")}),a.jsx(ne.Item,{as:"li",children:a.jsx(Ie.Item,{as:ge,to:"/audit/r_beta/corp/assetlist",children:t("Asset List")},"assetlist")})]}),a.jsx(ne.Item,{as:"li",children:a.jsx(ne.Link,{as:ge,to:"/audit/r_beta/corp/sov",children:t("Sov")},"bridges")})]})},Bl=document.getElementById("nav-left"),tR=()=>Bl?ke.createPortal(a.jsx(eR,{}),Bl):a.jsx(a.Fragment,{});function nR(){const{t:e}=G(),{mutate:t}=$p(oA);return a.jsxs(a.Fragment,{children:[a.jsx(Ie,{title:"Add Token",id:"add-token",children:a.jsx("form",{action:"/audit/corp/add_options",method:"get",className:"m-4",style:{width:"350px"},children:a.jsxs(fe,{children:[a.jsx(fe.Check,{label:e("Structures"),type:"checkbox",defaultChecked:!0,inline:!0,id:"s",name:"s"}),a.jsx("br",{}),a.jsx(fe.Check,{type:"checkbox",defaultChecked:!1,id:"a",name:"a",label:e("Assets")}),a.jsx("h6",{children:e("Assets Enables LO Levels in Bridges")}),a.jsx(fe.Check,{type:"checkbox",defaultChecked:!1,id:"m",name:"m",label:e("Moons")}),a.jsx("h6",{children:e("Moons enable Active Observation Tracking")}),a.jsx(fe.Check,{type:"checkbox",defaultChecked:!1,id:"w",name:"w",label:e("Wallets")}),a.jsx("h6",{children:e("Required for invoice module on holding corps")}),a.jsx(fe.Check,{type:"checkbox",defaultChecked:!1,id:"t",name:"t",label:e("Member Tracking")}),a.jsx("h6",{children:e("Member Tracking enables the Last Login Tracking of characters for smart filters")}),a.jsx(fe.Check,{type:"checkbox",defaultChecked:!1,id:"c",name:"c",label:e("Contracts")}),a.jsx("br",{}),a.jsx("br",{}),a.jsx(z,{variant:"primary",type:"submit",children:e("Add Token")})]})})}),a.jsx(ne.Link,{onClick:()=>t(),children:a.jsx("i",{className:"fa fa-refresh","aria-hidden":"true"})})]})}const rR="_menuRefreshSpin_17lcv_1",oR="_spin_17lcv_1",iR={menuRefreshSpin:rR,spin:oR},pr=document.getElementById("nav-right"),sR=()=>{const{t:e}=G(),t=uc(),[n,r]=H.useState(!1);return H.useEffect(()=>{n||pr&&(pr.innerHTML="",r(!0))},[n]),n?pr?ke.createPortal(a.jsxs(a.Fragment,{children:[t?a.jsx(a.Fragment,{children:a.jsx(ne.Link,{children:a.jsx("i",{className:`fas fa-sync-alt fa-fw ${iR.menuRefreshSpin}`})})}):a.jsx(a.Fragment,{}),a.jsx(nR,{}),a.jsx(ne.Link,{as:ge,to:"corporations",children:e("Corporations")},"corporation_list"),a.jsx(ne.Link,{as:ge,to:"audit/r/0",children:a.jsx("i",{className:"fa-solid fa-users"})},"corporation_list")]}),pr):a.jsx(a.Fragment,{}):null},aR=()=>a.jsxs(a.Fragment,{children:[a.jsx(tR,{}),a.jsx(sR,{}),a.jsx(fs,{children:a.jsxs(D,{className:"mt-4",children:[a.jsx(dc,{})," "]})})]});function lR(e){let t=e instanceof Number;return t&&(t=isNaN(e)),Object.prototype.toString.call(e)==="[object Date]"&&!t}function cR({date:e}){const t=new Date(e),n=navigator.language||(navigator.languages||["en"])[0];return lR(t)?a.jsxs(a.Fragment,{children:[a.jsx(bp,{date:t}),a.jsx("br",{}),a.jsx(Xm.Caption,{children:t.toLocaleString(n,{timeZone:"UTC",hour12:!1,year:"numeric",month:"numeric",day:"numeric",hour:"2-digit",minute:"2-digit"})})]}):a.jsx(a.Fragment,{})}const uR=({data:e,isFetching:t})=>{const{t:n}=G(),r=Ae(),o=[r.accessor("location.name",{header:n("System")}),r.accessor("name",{header:n("Structure")}),r.accessor("type.id",{header:"",enableColumnFilter:!1,enableSorting:!1,cell:i=>i.getValue()?a.jsx(Hf,{type_id:i.getValue(),size:32}):a.jsx(a.Fragment,{})}),r.accessor("type.name",{header:n("Type")}),r.accessor("owner.corporation_id",{header:"",enableColumnFilter:!1,enableSorting:!1,cell:i=>i.getValue()?a.jsx(Ir,{corporation_id:i.getValue(),size:32}):a.jsx(a.Fragment,{})}),r.accessor("owner.corporation_name",{header:n("Owner")}),r.accessor("fuel_expiry",{header:n("Fuel Expiry"),enableColumnFilter:!1,cell:i=>a.jsx(cR,{date:i.getValue()})}),r.accessor("state",{header:n("State")}),r.accessor("services",{header:n("Services"),filterFn:Iv,cell:i=>i.getValue()?a.jsx("div",{className:"text-center",style:{maxWidth:"500px",display:"flex",alignItems:"center",flexWrap:"wrap",alignContent:"center",justifyContent:"center",flexDirection:"row"},children:i.getValue().map(s=>a.jsx(Re,{bg:s.state==="online"?"primary":"danger",children:s.name}))}):a.jsx(a.Fragment,{})})];return a.jsx(so,{isFetching:t,columns:o,data:e})},fR=()=>{const{data:e,isFetching:t}=te({queryKey:["structures"],queryFn:()=>cA(),refetchOnWindowFocus:!1,initialData:{characters:[],main:void 0,headers:[]}});return a.jsx(a.Fragment,{children:a.jsx(uR,{data:e,isFetching:t})})},U=e=>typeof e=="string",mn=()=>{let e,t;const n=new Promise((r,o)=>{e=r,t=o});return n.resolve=e,n.reject=t,n},Pl=e=>e==null?"":""+e,dR=(e,t,n)=>{e.forEach(r=>{t[r]&&(n[r]=t[r])})},pR=/###/g,kl=e=>e&&e.indexOf("###")>-1?e.replace(pR,"."):e,Ll=e=>!e||U(e),En=(e,t,n)=>{const r=U(t)?t.split("."):t;let o=0;for(;o<r.length-1;){if(Ll(e))return{};const i=kl(r[o]);!e[i]&&n&&(e[i]=new n),Object.prototype.hasOwnProperty.call(e,i)?e=e[i]:e={},++o}return Ll(e)?{}:{obj:e,k:kl(r[o])}},Ml=(e,t,n)=>{const{obj:r,k:o}=En(e,t,Object);if(r!==void 0||t.length===1){r[o]=n;return}let i=t[t.length-1],s=t.slice(0,t.length-1),l=En(e,s,Object);for(;l.obj===void 0&&s.length;)i=`${s[s.length-1]}.${i}`,s=s.slice(0,s.length-1),l=En(e,s,Object),l!=null&&l.obj&&typeof l.obj[`${l.k}.${i}`]<"u"&&(l.obj=void 0);l.obj[`${l.k}.${i}`]=n},hR=(e,t,n,r)=>{const{obj:o,k:i}=En(e,t,Object);o[i]=o[i]||[],o[i].push(n)},Vr=(e,t)=>{const{obj:n,k:r}=En(e,t);if(n&&Object.prototype.hasOwnProperty.call(n,r))return n[r]},gR=(e,t,n)=>{const r=Vr(e,n);return r!==void 0?r:Vr(t,n)},Sp=(e,t,n)=>{for(const r in t)r!=="__proto__"&&r!=="constructor"&&(r in e?U(e[r])||e[r]instanceof String||U(t[r])||t[r]instanceof String?n&&(e[r]=t[r]):Sp(e[r],t[r],n):e[r]=t[r]);return e},Gt=e=>e.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,"\\$&");var mR={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","/":"&#x2F;"};const xR=e=>U(e)?e.replace(/[&<>"'\/]/g,t=>mR[t]):e;class vR{constructor(t){this.capacity=t,this.regExpMap=new Map,this.regExpQueue=[]}getRegExp(t){const n=this.regExpMap.get(t);if(n!==void 0)return n;const r=new RegExp(t);return this.regExpQueue.length===this.capacity&&this.regExpMap.delete(this.regExpQueue.shift()),this.regExpMap.set(t,r),this.regExpQueue.push(t),r}}const yR=[" ",",","?","!",";"],wR=new vR(20),bR=(e,t,n)=>{t=t||"",n=n||"";const r=yR.filter(s=>t.indexOf(s)<0&&n.indexOf(s)<0);if(r.length===0)return!0;const o=wR.getRegExp(`(${r.map(s=>s==="?"?"\\?":s).join("|")})`);let i=!o.test(e);if(!i){const s=e.indexOf(n);s>0&&!o.test(e.substring(0,s))&&(i=!0)}return i},Ji=function(e,t){let n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:".";if(!e)return;if(e[t])return Object.prototype.hasOwnProperty.call(e,t)?e[t]:void 0;const r=t.split(n);let o=e;for(let i=0;i<r.length;){if(!o||typeof o!="object")return;let s,l="";for(let c=i;c<r.length;++c)if(c!==i&&(l+=n),l+=r[c],s=o[l],s!==void 0){if(["string","number","boolean"].indexOf(typeof s)>-1&&c<r.length-1)continue;i+=c-i+1;break}o=s}return o},Hr=e=>e==null?void 0:e.replace("_","-"),CR={type:"logger",log(e){this.output("log",e)},warn(e){this.output("warn",e)},error(e){this.output("error",e)},output(e,t){var n,r;(r=(n=console==null?void 0:console[e])==null?void 0:n.apply)==null||r.call(n,console,t)}};class Gr{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.init(t,n)}init(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.prefix=n.prefix||"i18next:",this.logger=t||CR,this.options=n,this.debug=n.debug}log(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"log","",!0)}warn(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"warn","",!0)}error(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"error","")}deprecate(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"warn","WARNING DEPRECATED: ",!0)}forward(t,n,r,o){return o&&!this.debug?null:(U(t[0])&&(t[0]=`${r}${this.prefix} ${t[0]}`),this.logger[n](t))}create(t){return new Gr(this.logger,{prefix:`${this.prefix}:${t}:`,...this.options})}clone(t){return t=t||this.options,t.prefix=t.prefix||this.prefix,new Gr(this.logger,t)}}var Ve=new Gr;class So{constructor(){this.observers={}}on(t,n){return t.split(" ").forEach(r=>{this.observers[r]||(this.observers[r]=new Map);const o=this.observers[r].get(n)||0;this.observers[r].set(n,o+1)}),this}off(t,n){if(this.observers[t]){if(!n){delete this.observers[t];return}this.observers[t].delete(n)}}emit(t){for(var n=arguments.length,r=new Array(n>1?n-1:0),o=1;o<n;o++)r[o-1]=arguments[o];this.observers[t]&&Array.from(this.observers[t].entries()).forEach(s=>{let[l,c]=s;for(let u=0;u<c;u++)l(...r)}),this.observers["*"]&&Array.from(this.observers["*"].entries()).forEach(s=>{let[l,c]=s;for(let u=0;u<c;u++)l.apply(l,[t,...r])})}}class Ul extends So{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{ns:["translation"],defaultNS:"translation"};super(),this.data=t||{},this.options=n,this.options.keySeparator===void 0&&(this.options.keySeparator="."),this.options.ignoreJSONStructure===void 0&&(this.options.ignoreJSONStructure=!0)}addNamespaces(t){this.options.ns.indexOf(t)<0&&this.options.ns.push(t)}removeNamespaces(t){const n=this.options.ns.indexOf(t);n>-1&&this.options.ns.splice(n,1)}getResource(t,n,r){var u,f;let o=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};const i=o.keySeparator!==void 0?o.keySeparator:this.options.keySeparator,s=o.ignoreJSONStructure!==void 0?o.ignoreJSONStructure:this.options.ignoreJSONStructure;let l;t.indexOf(".")>-1?l=t.split("."):(l=[t,n],r&&(Array.isArray(r)?l.push(...r):U(r)&&i?l.push(...r.split(i)):l.push(r)));const c=Vr(this.data,l);return!c&&!n&&!r&&t.indexOf(".")>-1&&(t=l[0],n=l[1],r=l.slice(2).join(".")),c||!s||!U(r)?c:Ji((f=(u=this.data)==null?void 0:u[t])==null?void 0:f[n],r,i)}addResource(t,n,r,o){let i=arguments.length>4&&arguments[4]!==void 0?arguments[4]:{silent:!1};const s=i.keySeparator!==void 0?i.keySeparator:this.options.keySeparator;let l=[t,n];r&&(l=l.concat(s?r.split(s):r)),t.indexOf(".")>-1&&(l=t.split("."),o=n,n=l[1]),this.addNamespaces(n),Ml(this.data,l,o),i.silent||this.emit("added",t,n,r,o)}addResources(t,n,r){let o=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{silent:!1};for(const i in r)(U(r[i])||Array.isArray(r[i]))&&this.addResource(t,n,i,r[i],{silent:!0});o.silent||this.emit("added",t,n,r)}addResourceBundle(t,n,r,o,i){let s=arguments.length>5&&arguments[5]!==void 0?arguments[5]:{silent:!1,skipCopy:!1},l=[t,n];t.indexOf(".")>-1&&(l=t.split("."),o=r,r=n,n=l[1]),this.addNamespaces(n);let c=Vr(this.data,l)||{};s.skipCopy||(r=JSON.parse(JSON.stringify(r))),o?Sp(c,r,i):c={...c,...r},Ml(this.data,l,c),s.silent||this.emit("added",t,n,r)}removeResourceBundle(t,n){this.hasResourceBundle(t,n)&&delete this.data[t][n],this.removeNamespaces(n),this.emit("removed",t,n)}hasResourceBundle(t,n){return this.getResource(t,n)!==void 0}getResourceBundle(t,n){return n||(n=this.options.defaultNS),this.getResource(t,n)}getDataByLanguage(t){return this.data[t]}hasLanguageSomeTranslations(t){const n=this.getDataByLanguage(t);return!!(n&&Object.keys(n)||[]).find(o=>n[o]&&Object.keys(n[o]).length>0)}toJSON(){return this.data}}var Ap={processors:{},addPostProcessor(e){this.processors[e.name]=e},handle(e,t,n,r,o){return e.forEach(i=>{var s;t=((s=this.processors[i])==null?void 0:s.process(t,n,r,o))??t}),t}};const Vl={},Hl=e=>!U(e)&&typeof e!="boolean"&&typeof e!="number";class Wr extends So{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};super(),dR(["resourceStore","languageUtils","pluralResolver","interpolator","backendConnector","i18nFormat","utils"],t,this),this.options=n,this.options.keySeparator===void 0&&(this.options.keySeparator="."),this.logger=Ve.create("translator")}changeLanguage(t){t&&(this.language=t)}exists(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{interpolation:{}};if(t==null)return!1;const r=this.resolve(t,n);return(r==null?void 0:r.res)!==void 0}extractFromKey(t,n){let r=n.nsSeparator!==void 0?n.nsSeparator:this.options.nsSeparator;r===void 0&&(r=":");const o=n.keySeparator!==void 0?n.keySeparator:this.options.keySeparator;let i=n.ns||this.options.defaultNS||[];const s=r&&t.indexOf(r)>-1,l=!this.options.userDefinedKeySeparator&&!n.keySeparator&&!this.options.userDefinedNsSeparator&&!n.nsSeparator&&!bR(t,r,o);if(s&&!l){const c=t.match(this.interpolator.nestingRegexp);if(c&&c.length>0)return{key:t,namespaces:U(i)?[i]:i};const u=t.split(r);(r!==o||r===o&&this.options.ns.indexOf(u[0])>-1)&&(i=u.shift()),t=u.join(o)}return{key:t,namespaces:U(i)?[i]:i}}translate(t,n,r){if(typeof n!="object"&&this.options.overloadTranslationOptionHandler&&(n=this.options.overloadTranslationOptionHandler(arguments)),typeof n=="object"&&(n={...n}),n||(n={}),t==null)return"";Array.isArray(t)||(t=[String(t)]);const o=n.returnDetails!==void 0?n.returnDetails:this.options.returnDetails,i=n.keySeparator!==void 0?n.keySeparator:this.options.keySeparator,{key:s,namespaces:l}=this.extractFromKey(t[t.length-1],n),c=l[l.length-1],u=n.lng||this.language,f=n.appendNamespaceToCIMode||this.options.appendNamespaceToCIMode;if((u==null?void 0:u.toLowerCase())==="cimode"){if(f){const E=n.nsSeparator||this.options.nsSeparator;return o?{res:`${c}${E}${s}`,usedKey:s,exactUsedKey:s,usedLng:u,usedNS:c,usedParams:this.getUsedParamsDetails(n)}:`${c}${E}${s}`}return o?{res:s,usedKey:s,exactUsedKey:s,usedLng:u,usedNS:c,usedParams:this.getUsedParamsDetails(n)}:s}const d=this.resolve(t,n);let p=d==null?void 0:d.res;const h=(d==null?void 0:d.usedKey)||s,g=(d==null?void 0:d.exactUsedKey)||s,m=["[object Number]","[object Function]","[object RegExp]"],v=n.joinArrays!==void 0?n.joinArrays:this.options.joinArrays,y=!this.i18nFormat||this.i18nFormat.handleAsObject,b=n.count!==void 0&&!U(n.count),w=Wr.hasDefaultValue(n),S=b?this.pluralResolver.getSuffix(u,n.count,n):"",F=n.ordinal&&b?this.pluralResolver.getSuffix(u,n.count,{ordinal:!1}):"",C=b&&!n.ordinal&&n.count===0,A=C&&n[`defaultValue${this.options.pluralSeparator}zero`]||n[`defaultValue${S}`]||n[`defaultValue${F}`]||n.defaultValue;let O=p;y&&!p&&w&&(O=A);const T=Hl(O),N=Object.prototype.toString.apply(O);if(y&&O&&T&&m.indexOf(N)<0&&!(U(v)&&Array.isArray(O))){if(!n.returnObjects&&!this.options.returnObjects){this.options.returnedObjectHandler||this.logger.warn("accessing an object - but returnObjects options is not enabled!");const E=this.options.returnedObjectHandler?this.options.returnedObjectHandler(h,O,{...n,ns:l}):`key '${s} (${this.language})' returned an object instead of string.`;return o?(d.res=E,d.usedParams=this.getUsedParamsDetails(n),d):E}if(i){const E=Array.isArray(O),B=E?[]:{},P=E?g:h;for(const M in O)if(Object.prototype.hasOwnProperty.call(O,M)){const V=`${P}${i}${M}`;w&&!p?B[M]=this.translate(V,{...n,defaultValue:Hl(A)?A[M]:void 0,joinArrays:!1,ns:l}):B[M]=this.translate(V,{...n,joinArrays:!1,ns:l}),B[M]===V&&(B[M]=O[M])}p=B}}else if(y&&U(v)&&Array.isArray(p))p=p.join(v),p&&(p=this.extendTranslation(p,t,n,r));else{let E=!1,B=!1;!this.isValidLookup(p)&&w&&(E=!0,p=A),this.isValidLookup(p)||(B=!0,p=s);const M=(n.missingKeyNoValueFallbackToKey||this.options.missingKeyNoValueFallbackToKey)&&B?void 0:p,V=w&&A!==p&&this.options.updateMissing;if(B||E||V){if(this.logger.log(V?"updateKey":"missingKey",u,c,s,V?A:p),i){const K=this.resolve(s,{...n,keySeparator:!1});K&&K.res&&this.logger.warn("Seems the loaded translations were in flat JSON format instead of nested. Either set keySeparator: false on init or make sure your translations are published in nested format.")}let J=[];const Q=this.languageUtils.getFallbackCodes(this.options.fallbackLng,n.lng||this.language);if(this.options.saveMissingTo==="fallback"&&Q&&Q[0])for(let K=0;K<Q.length;K++)J.push(Q[K]);else this.options.saveMissingTo==="all"?J=this.languageUtils.toResolveHierarchy(n.lng||this.language):J.push(n.lng||this.language);const X=(K,ee,se)=>{var ae;const he=w&&se!==p?se:M;this.options.missingKeyHandler?this.options.missingKeyHandler(K,c,ee,he,V,n):(ae=this.backendConnector)!=null&&ae.saveMissing&&this.backendConnector.saveMissing(K,c,ee,he,V,n),this.emit("missingKey",K,c,ee,p)};this.options.saveMissing&&(this.options.saveMissingPlurals&&b?J.forEach(K=>{const ee=this.pluralResolver.getSuffixes(K,n);C&&n[`defaultValue${this.options.pluralSeparator}zero`]&&ee.indexOf(`${this.options.pluralSeparator}zero`)<0&&ee.push(`${this.options.pluralSeparator}zero`),ee.forEach(se=>{X([K],s+se,n[`defaultValue${se}`]||A)})}):X(J,s,A))}p=this.extendTranslation(p,t,n,d,r),B&&p===s&&this.options.appendNamespaceToMissingKey&&(p=`${c}:${s}`),(B||E)&&this.options.parseMissingKeyHandler&&(p=this.options.parseMissingKeyHandler(this.options.appendNamespaceToMissingKey?`${c}:${s}`:s,E?p:void 0))}return o?(d.res=p,d.usedParams=this.getUsedParamsDetails(n),d):p}extendTranslation(t,n,r,o,i){var u,f;var s=this;if((u=this.i18nFormat)!=null&&u.parse)t=this.i18nFormat.parse(t,{...this.options.interpolation.defaultVariables,...r},r.lng||this.language||o.usedLng,o.usedNS,o.usedKey,{resolved:o});else if(!r.skipInterpolation){r.interpolation&&this.interpolator.init({...r,interpolation:{...this.options.interpolation,...r.interpolation}});const d=U(t)&&(((f=r==null?void 0:r.interpolation)==null?void 0:f.skipOnVariables)!==void 0?r.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables);let p;if(d){const g=t.match(this.interpolator.nestingRegexp);p=g&&g.length}let h=r.replace&&!U(r.replace)?r.replace:r;if(this.options.interpolation.defaultVariables&&(h={...this.options.interpolation.defaultVariables,...h}),t=this.interpolator.interpolate(t,h,r.lng||this.language||o.usedLng,r),d){const g=t.match(this.interpolator.nestingRegexp),m=g&&g.length;p<m&&(r.nest=!1)}!r.lng&&o&&o.res&&(r.lng=this.language||o.usedLng),r.nest!==!1&&(t=this.interpolator.nest(t,function(){for(var g=arguments.length,m=new Array(g),v=0;v<g;v++)m[v]=arguments[v];return(i==null?void 0:i[0])===m[0]&&!r.context?(s.logger.warn(`It seems you are nesting recursively key: ${m[0]} in key: ${n[0]}`),null):s.translate(...m,n)},r)),r.interpolation&&this.interpolator.reset()}const l=r.postProcess||this.options.postProcess,c=U(l)?[l]:l;return t!=null&&(c!=null&&c.length)&&r.applyPostProcessor!==!1&&(t=Ap.handle(c,t,n,this.options&&this.options.postProcessPassResolved?{i18nResolved:{...o,usedParams:this.getUsedParamsDetails(r)},...r}:r,this)),t}resolve(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r,o,i,s,l;return U(t)&&(t=[t]),t.forEach(c=>{if(this.isValidLookup(r))return;const u=this.extractFromKey(c,n),f=u.key;o=f;let d=u.namespaces;this.options.fallbackNS&&(d=d.concat(this.options.fallbackNS));const p=n.count!==void 0&&!U(n.count),h=p&&!n.ordinal&&n.count===0,g=n.context!==void 0&&(U(n.context)||typeof n.context=="number")&&n.context!=="",m=n.lngs?n.lngs:this.languageUtils.toResolveHierarchy(n.lng||this.language,n.fallbackLng);d.forEach(v=>{var y,b;this.isValidLookup(r)||(l=v,!Vl[`${m[0]}-${v}`]&&((y=this.utils)!=null&&y.hasLoadedNamespace)&&!((b=this.utils)!=null&&b.hasLoadedNamespace(l))&&(Vl[`${m[0]}-${v}`]=!0,this.logger.warn(`key "${o}" for languages "${m.join(", ")}" won't get resolved as namespace "${l}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!")),m.forEach(w=>{var C;if(this.isValidLookup(r))return;s=w;const S=[f];if((C=this.i18nFormat)!=null&&C.addLookupKeys)this.i18nFormat.addLookupKeys(S,f,w,v,n);else{let A;p&&(A=this.pluralResolver.getSuffix(w,n.count,n));const O=`${this.options.pluralSeparator}zero`,T=`${this.options.pluralSeparator}ordinal${this.options.pluralSeparator}`;if(p&&(S.push(f+A),n.ordinal&&A.indexOf(T)===0&&S.push(f+A.replace(T,this.options.pluralSeparator)),h&&S.push(f+O)),g){const N=`${f}${this.options.contextSeparator}${n.context}`;S.push(N),p&&(S.push(N+A),n.ordinal&&A.indexOf(T)===0&&S.push(N+A.replace(T,this.options.pluralSeparator)),h&&S.push(N+O))}}let F;for(;F=S.pop();)this.isValidLookup(r)||(i=F,r=this.getResource(w,v,F,n))}))})}),{res:r,usedKey:o,exactUsedKey:i,usedLng:s,usedNS:l}}isValidLookup(t){return t!==void 0&&!(!this.options.returnNull&&t===null)&&!(!this.options.returnEmptyString&&t==="")}getResource(t,n,r){var i;let o=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};return(i=this.i18nFormat)!=null&&i.getResource?this.i18nFormat.getResource(t,n,r,o):this.resourceStore.getResource(t,n,r,o)}getUsedParamsDetails(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};const n=["defaultValue","ordinal","context","replace","lng","lngs","fallbackLng","ns","keySeparator","nsSeparator","returnObjects","returnDetails","joinArrays","postProcess","interpolation"],r=t.replace&&!U(t.replace);let o=r?t.replace:t;if(r&&typeof t.count<"u"&&(o.count=t.count),this.options.interpolation.defaultVariables&&(o={...this.options.interpolation.defaultVariables,...o}),!r){o={...o};for(const i of n)delete o[i]}return o}static hasDefaultValue(t){const n="defaultValue";for(const r in t)if(Object.prototype.hasOwnProperty.call(t,r)&&n===r.substring(0,n.length)&&t[r]!==void 0)return!0;return!1}}class Gl{constructor(t){this.options=t,this.supportedLngs=this.options.supportedLngs||!1,this.logger=Ve.create("languageUtils")}getScriptPartFromCode(t){if(t=Hr(t),!t||t.indexOf("-")<0)return null;const n=t.split("-");return n.length===2||(n.pop(),n[n.length-1].toLowerCase()==="x")?null:this.formatLanguageCode(n.join("-"))}getLanguagePartFromCode(t){if(t=Hr(t),!t||t.indexOf("-")<0)return t;const n=t.split("-");return this.formatLanguageCode(n[0])}formatLanguageCode(t){if(U(t)&&t.indexOf("-")>-1){let n;try{n=Intl.getCanonicalLocales(t)[0]}catch{}return n&&this.options.lowerCaseLng&&(n=n.toLowerCase()),n||(this.options.lowerCaseLng?t.toLowerCase():t)}return this.options.cleanCode||this.options.lowerCaseLng?t.toLowerCase():t}isSupportedCode(t){return(this.options.load==="languageOnly"||this.options.nonExplicitSupportedLngs)&&(t=this.getLanguagePartFromCode(t)),!this.supportedLngs||!this.supportedLngs.length||this.supportedLngs.indexOf(t)>-1}getBestMatchFromCodes(t){if(!t)return null;let n;return t.forEach(r=>{if(n)return;const o=this.formatLanguageCode(r);(!this.options.supportedLngs||this.isSupportedCode(o))&&(n=o)}),!n&&this.options.supportedLngs&&t.forEach(r=>{if(n)return;const o=this.getLanguagePartFromCode(r);if(this.isSupportedCode(o))return n=o;n=this.options.supportedLngs.find(i=>{if(i===o)return i;if(!(i.indexOf("-")<0&&o.indexOf("-")<0)&&(i.indexOf("-")>0&&o.indexOf("-")<0&&i.substring(0,i.indexOf("-"))===o||i.indexOf(o)===0&&o.length>1))return i})}),n||(n=this.getFallbackCodes(this.options.fallbackLng)[0]),n}getFallbackCodes(t,n){if(!t)return[];if(typeof t=="function"&&(t=t(n)),U(t)&&(t=[t]),Array.isArray(t))return t;if(!n)return t.default||[];let r=t[n];return r||(r=t[this.getScriptPartFromCode(n)]),r||(r=t[this.formatLanguageCode(n)]),r||(r=t[this.getLanguagePartFromCode(n)]),r||(r=t.default),r||[]}toResolveHierarchy(t,n){const r=this.getFallbackCodes(n||this.options.fallbackLng||[],t),o=[],i=s=>{s&&(this.isSupportedCode(s)?o.push(s):this.logger.warn(`rejecting language code not found in supportedLngs: ${s}`))};return U(t)&&(t.indexOf("-")>-1||t.indexOf("_")>-1)?(this.options.load!=="languageOnly"&&i(this.formatLanguageCode(t)),this.options.load!=="languageOnly"&&this.options.load!=="currentOnly"&&i(this.getScriptPartFromCode(t)),this.options.load!=="currentOnly"&&i(this.getLanguagePartFromCode(t))):U(t)&&i(this.formatLanguageCode(t)),r.forEach(s=>{o.indexOf(s)<0&&i(this.formatLanguageCode(s))}),o}}const Wl={zero:0,one:1,two:2,few:3,many:4,other:5},zl={select:e=>e===1?"one":"other",resolvedOptions:()=>({pluralCategories:["one","other"]})};class SR{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.languageUtils=t,this.options=n,this.logger=Ve.create("pluralResolver"),this.pluralRulesCache={}}addRule(t,n){this.rules[t]=n}clearCache(){this.pluralRulesCache={}}getRule(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};const r=Hr(t==="dev"?"en":t),o=n.ordinal?"ordinal":"cardinal",i=JSON.stringify({cleanedCode:r,type:o});if(i in this.pluralRulesCache)return this.pluralRulesCache[i];let s;try{s=new Intl.PluralRules(r,{type:o})}catch{if(!Intl)return this.logger.error("No Intl support, please use an Intl polyfill!"),zl;if(!t.match(/-|_/))return zl;const c=this.languageUtils.getLanguagePartFromCode(t);s=this.getRule(c,n)}return this.pluralRulesCache[i]=s,s}needsPlural(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=this.getRule(t,n);return r||(r=this.getRule("dev",n)),(r==null?void 0:r.resolvedOptions().pluralCategories.length)>1}getPluralFormsOfKey(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};return this.getSuffixes(t,r).map(o=>`${n}${o}`)}getSuffixes(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=this.getRule(t,n);return r||(r=this.getRule("dev",n)),r?r.resolvedOptions().pluralCategories.sort((o,i)=>Wl[o]-Wl[i]).map(o=>`${this.options.prepend}${n.ordinal?`ordinal${this.options.prepend}`:""}${o}`):[]}getSuffix(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};const o=this.getRule(t,r);return o?`${this.options.prepend}${r.ordinal?`ordinal${this.options.prepend}`:""}${o.select(n)}`:(this.logger.warn(`no plural rule found for: ${t}`),this.getSuffix("dev",n,r))}}const Ql=function(e,t,n){let r=arguments.length>3&&arguments[3]!==void 0?arguments[3]:".",o=arguments.length>4&&arguments[4]!==void 0?arguments[4]:!0,i=gR(e,t,n);return!i&&o&&U(n)&&(i=Ji(e,n,r),i===void 0&&(i=Ji(t,n,r))),i},ci=e=>e.replace(/\$/g,"$$$$");class AR{constructor(){var n;let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};this.logger=Ve.create("interpolator"),this.options=t,this.format=((n=t==null?void 0:t.interpolation)==null?void 0:n.format)||(r=>r),this.init(t)}init(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};t.interpolation||(t.interpolation={escapeValue:!0});const{escape:n,escapeValue:r,useRawValueToEscape:o,prefix:i,prefixEscaped:s,suffix:l,suffixEscaped:c,formatSeparator:u,unescapeSuffix:f,unescapePrefix:d,nestingPrefix:p,nestingPrefixEscaped:h,nestingSuffix:g,nestingSuffixEscaped:m,nestingOptionsSeparator:v,maxReplaces:y,alwaysFormat:b}=t.interpolation;this.escape=n!==void 0?n:xR,this.escapeValue=r!==void 0?r:!0,this.useRawValueToEscape=o!==void 0?o:!1,this.prefix=i?Gt(i):s||"{{",this.suffix=l?Gt(l):c||"}}",this.formatSeparator=u||",",this.unescapePrefix=f?"":d||"-",this.unescapeSuffix=this.unescapePrefix?"":f||"",this.nestingPrefix=p?Gt(p):h||Gt("$t("),this.nestingSuffix=g?Gt(g):m||Gt(")"),this.nestingOptionsSeparator=v||",",this.maxReplaces=y||1e3,this.alwaysFormat=b!==void 0?b:!1,this.resetRegExp()}reset(){this.options&&this.init(this.options)}resetRegExp(){const t=(n,r)=>(n==null?void 0:n.source)===r?(n.lastIndex=0,n):new RegExp(r,"g");this.regexp=t(this.regexp,`${this.prefix}(.+?)${this.suffix}`),this.regexpUnescape=t(this.regexpUnescape,`${this.prefix}${this.unescapePrefix}(.+?)${this.unescapeSuffix}${this.suffix}`),this.nestingRegexp=t(this.nestingRegexp,`${this.nestingPrefix}(.+?)${this.nestingSuffix}`)}interpolate(t,n,r,o){var h;let i,s,l;const c=this.options&&this.options.interpolation&&this.options.interpolation.defaultVariables||{},u=g=>{if(g.indexOf(this.formatSeparator)<0){const b=Ql(n,c,g,this.options.keySeparator,this.options.ignoreJSONStructure);return this.alwaysFormat?this.format(b,void 0,r,{...o,...n,interpolationkey:g}):b}const m=g.split(this.formatSeparator),v=m.shift().trim(),y=m.join(this.formatSeparator).trim();return this.format(Ql(n,c,v,this.options.keySeparator,this.options.ignoreJSONStructure),y,r,{...o,...n,interpolationkey:v})};this.resetRegExp();const f=(o==null?void 0:o.missingInterpolationHandler)||this.options.missingInterpolationHandler,d=((h=o==null?void 0:o.interpolation)==null?void 0:h.skipOnVariables)!==void 0?o.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables;return[{regex:this.regexpUnescape,safeValue:g=>ci(g)},{regex:this.regexp,safeValue:g=>this.escapeValue?ci(this.escape(g)):ci(g)}].forEach(g=>{for(l=0;i=g.regex.exec(t);){const m=i[1].trim();if(s=u(m),s===void 0)if(typeof f=="function"){const y=f(t,i,o);s=U(y)?y:""}else if(o&&Object.prototype.hasOwnProperty.call(o,m))s="";else if(d){s=i[0];continue}else this.logger.warn(`missed to pass in variable ${m} for interpolating ${t}`),s="";else!U(s)&&!this.useRawValueToEscape&&(s=Pl(s));const v=g.safeValue(s);if(t=t.replace(i[0],v),d?(g.regex.lastIndex+=s.length,g.regex.lastIndex-=i[0].length):g.regex.lastIndex=0,l++,l>=this.maxReplaces)break}}),t}nest(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},o,i,s;const l=(c,u)=>{const f=this.nestingOptionsSeparator;if(c.indexOf(f)<0)return c;const d=c.split(new RegExp(`${f}[ ]*{`));let p=`{${d[1]}`;c=d[0],p=this.interpolate(p,s);const h=p.match(/'/g),g=p.match(/"/g);(((h==null?void 0:h.length)??0)%2===0&&!g||g.length%2!==0)&&(p=p.replace(/'/g,'"'));try{s=JSON.parse(p),u&&(s={...u,...s})}catch(m){return this.logger.warn(`failed parsing options string in nesting for key ${c}`,m),`${c}${f}${p}`}return s.defaultValue&&s.defaultValue.indexOf(this.prefix)>-1&&delete s.defaultValue,c};for(;o=this.nestingRegexp.exec(t);){let c=[];s={...r},s=s.replace&&!U(s.replace)?s.replace:s,s.applyPostProcessor=!1,delete s.defaultValue;let u=!1;if(o[0].indexOf(this.formatSeparator)!==-1&&!/{.*}/.test(o[1])){const f=o[1].split(this.formatSeparator).map(d=>d.trim());o[1]=f.shift(),c=f,u=!0}if(i=n(l.call(this,o[1].trim(),s),s),i&&o[0]===t&&!U(i))return i;U(i)||(i=Pl(i)),i||(this.logger.warn(`missed to resolve ${o[1]} for nesting ${t}`),i=""),u&&(i=c.reduce((f,d)=>this.format(f,d,r.lng,{...r,interpolationkey:o[1].trim()}),i.trim())),t=t.replace(o[0],i),this.regexp.lastIndex=0}return t}}const jR=e=>{let t=e.toLowerCase().trim();const n={};if(e.indexOf("(")>-1){const r=e.split("(");t=r[0].toLowerCase().trim();const o=r[1].substring(0,r[1].length-1);t==="currency"&&o.indexOf(":")<0?n.currency||(n.currency=o.trim()):t==="relativetime"&&o.indexOf(":")<0?n.range||(n.range=o.trim()):o.split(";").forEach(s=>{if(s){const[l,...c]=s.split(":"),u=c.join(":").trim().replace(/^'+|'+$/g,""),f=l.trim();n[f]||(n[f]=u),u==="false"&&(n[f]=!1),u==="true"&&(n[f]=!0),isNaN(u)||(n[f]=parseInt(u,10))}})}return{formatName:t,formatOptions:n}},Wt=e=>{const t={};return(n,r,o)=>{let i=o;o&&o.interpolationkey&&o.formatParams&&o.formatParams[o.interpolationkey]&&o[o.interpolationkey]&&(i={...i,[o.interpolationkey]:void 0});const s=r+JSON.stringify(i);let l=t[s];return l||(l=e(Hr(r),o),t[s]=l),l(n)}};class RR{constructor(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};this.logger=Ve.create("formatter"),this.options=t,this.formats={number:Wt((n,r)=>{const o=new Intl.NumberFormat(n,{...r});return i=>o.format(i)}),currency:Wt((n,r)=>{const o=new Intl.NumberFormat(n,{...r,style:"currency"});return i=>o.format(i)}),datetime:Wt((n,r)=>{const o=new Intl.DateTimeFormat(n,{...r});return i=>o.format(i)}),relativetime:Wt((n,r)=>{const o=new Intl.RelativeTimeFormat(n,{...r});return i=>o.format(i,r.range||"day")}),list:Wt((n,r)=>{const o=new Intl.ListFormat(n,{...r});return i=>o.format(i)})},this.init(t)}init(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{interpolation:{}};this.formatSeparator=n.interpolation.formatSeparator||","}add(t,n){this.formats[t.toLowerCase().trim()]=n}addCached(t,n){this.formats[t.toLowerCase().trim()]=Wt(n)}format(t,n,r){let o=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};const i=n.split(this.formatSeparator);if(i.length>1&&i[0].indexOf("(")>1&&i[0].indexOf(")")<0&&i.find(l=>l.indexOf(")")>-1)){const l=i.findIndex(c=>c.indexOf(")")>-1);i[0]=[i[0],...i.splice(1,l)].join(this.formatSeparator)}return i.reduce((l,c)=>{var d;const{formatName:u,formatOptions:f}=jR(c);if(this.formats[u]){let p=l;try{const h=((d=o==null?void 0:o.formatParams)==null?void 0:d[o.interpolationkey])||{},g=h.locale||h.lng||o.locale||o.lng||r;p=this.formats[u](l,g,{...f,...o,...h})}catch(h){this.logger.warn(h)}return p}else this.logger.warn(`there was no format function for ${u}`);return l},t)}}const FR=(e,t)=>{e.pending[t]!==void 0&&(delete e.pending[t],e.pendingCount--)};class OR extends So{constructor(t,n,r){var i,s;let o=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};super(),this.backend=t,this.store=n,this.services=r,this.languageUtils=r.languageUtils,this.options=o,this.logger=Ve.create("backendConnector"),this.waitingReads=[],this.maxParallelReads=o.maxParallelReads||10,this.readingCalls=0,this.maxRetries=o.maxRetries>=0?o.maxRetries:5,this.retryTimeout=o.retryTimeout>=1?o.retryTimeout:350,this.state={},this.queue=[],(s=(i=this.backend)==null?void 0:i.init)==null||s.call(i,r,o.backend,o)}queueLoad(t,n,r,o){const i={},s={},l={},c={};return t.forEach(u=>{let f=!0;n.forEach(d=>{const p=`${u}|${d}`;!r.reload&&this.store.hasResourceBundle(u,d)?this.state[p]=2:this.state[p]<0||(this.state[p]===1?s[p]===void 0&&(s[p]=!0):(this.state[p]=1,f=!1,s[p]===void 0&&(s[p]=!0),i[p]===void 0&&(i[p]=!0),c[d]===void 0&&(c[d]=!0)))}),f||(l[u]=!0)}),(Object.keys(i).length||Object.keys(s).length)&&this.queue.push({pending:s,pendingCount:Object.keys(s).length,loaded:{},errors:[],callback:o}),{toLoad:Object.keys(i),pending:Object.keys(s),toLoadLanguages:Object.keys(l),toLoadNamespaces:Object.keys(c)}}loaded(t,n,r){const o=t.split("|"),i=o[0],s=o[1];n&&this.emit("failedLoading",i,s,n),!n&&r&&this.store.addResourceBundle(i,s,r,void 0,void 0,{skipCopy:!0}),this.state[t]=n?-1:2,n&&r&&(this.state[t]=0);const l={};this.queue.forEach(c=>{hR(c.loaded,[i],s),FR(c,t),n&&c.errors.push(n),c.pendingCount===0&&!c.done&&(Object.keys(c.loaded).forEach(u=>{l[u]||(l[u]={});const f=c.loaded[u];f.length&&f.forEach(d=>{l[u][d]===void 0&&(l[u][d]=!0)})}),c.done=!0,c.errors.length?c.callback(c.errors):c.callback())}),this.emit("loaded",l),this.queue=this.queue.filter(c=>!c.done)}read(t,n,r){let o=arguments.length>3&&arguments[3]!==void 0?arguments[3]:0,i=arguments.length>4&&arguments[4]!==void 0?arguments[4]:this.retryTimeout,s=arguments.length>5?arguments[5]:void 0;if(!t.length)return s(null,{});if(this.readingCalls>=this.maxParallelReads){this.waitingReads.push({lng:t,ns:n,fcName:r,tried:o,wait:i,callback:s});return}this.readingCalls++;const l=(u,f)=>{if(this.readingCalls--,this.waitingReads.length>0){const d=this.waitingReads.shift();this.read(d.lng,d.ns,d.fcName,d.tried,d.wait,d.callback)}if(u&&f&&o<this.maxRetries){setTimeout(()=>{this.read.call(this,t,n,r,o+1,i*2,s)},i);return}s(u,f)},c=this.backend[r].bind(this.backend);if(c.length===2){try{const u=c(t,n);u&&typeof u.then=="function"?u.then(f=>l(null,f)).catch(l):l(null,u)}catch(u){l(u)}return}return c(t,n,l)}prepareLoading(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},o=arguments.length>3?arguments[3]:void 0;if(!this.backend)return this.logger.warn("No backend was added via i18next.use. Will not load resources."),o&&o();U(t)&&(t=this.languageUtils.toResolveHierarchy(t)),U(n)&&(n=[n]);const i=this.queueLoad(t,n,r,o);if(!i.toLoad.length)return i.pending.length||o(),null;i.toLoad.forEach(s=>{this.loadOne(s)})}load(t,n,r){this.prepareLoading(t,n,{},r)}reload(t,n,r){this.prepareLoading(t,n,{reload:!0},r)}loadOne(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"";const r=t.split("|"),o=r[0],i=r[1];this.read(o,i,"read",void 0,void 0,(s,l)=>{s&&this.logger.warn(`${n}loading namespace ${i} for language ${o} failed`,s),!s&&l&&this.logger.log(`${n}loaded namespace ${i} for language ${o}`,l),this.loaded(t,s,l)})}saveMissing(t,n,r,o,i){var c,u,f,d,p;let s=arguments.length>5&&arguments[5]!==void 0?arguments[5]:{},l=arguments.length>6&&arguments[6]!==void 0?arguments[6]:()=>{};if((u=(c=this.services)==null?void 0:c.utils)!=null&&u.hasLoadedNamespace&&!((d=(f=this.services)==null?void 0:f.utils)!=null&&d.hasLoadedNamespace(n))){this.logger.warn(`did not save key "${r}" as the namespace "${n}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!");return}if(!(r==null||r==="")){if((p=this.backend)!=null&&p.create){const h={...s,isUpdate:i},g=this.backend.create.bind(this.backend);if(g.length<6)try{let m;g.length===5?m=g(t,n,r,o,h):m=g(t,n,r,o),m&&typeof m.then=="function"?m.then(v=>l(null,v)).catch(l):l(null,m)}catch(m){l(m)}else g(t,n,r,o,l,h)}!t||!t[0]||this.store.addResource(t[0],n,r,o)}}}const ql=()=>({debug:!1,initAsync:!0,ns:["translation"],defaultNS:["translation"],fallbackLng:["dev"],fallbackNS:!1,supportedLngs:!1,nonExplicitSupportedLngs:!1,load:"all",preload:!1,simplifyPluralSuffix:!0,keySeparator:".",nsSeparator:":",pluralSeparator:"_",contextSeparator:"_",partialBundledLanguages:!1,saveMissing:!1,updateMissing:!1,saveMissingTo:"fallback",saveMissingPlurals:!0,missingKeyHandler:!1,missingInterpolationHandler:!1,postProcess:!1,postProcessPassResolved:!1,returnNull:!1,returnEmptyString:!0,returnObjects:!1,joinArrays:!1,returnedObjectHandler:!1,parseMissingKeyHandler:!1,appendNamespaceToMissingKey:!1,appendNamespaceToCIMode:!1,overloadTranslationOptionHandler:e=>{let t={};if(typeof e[1]=="object"&&(t=e[1]),U(e[1])&&(t.defaultValue=e[1]),U(e[2])&&(t.tDescription=e[2]),typeof e[2]=="object"||typeof e[3]=="object"){const n=e[3]||e[2];Object.keys(n).forEach(r=>{t[r]=n[r]})}return t},interpolation:{escapeValue:!0,format:e=>e,prefix:"{{",suffix:"}}",formatSeparator:",",unescapePrefix:"-",nestingPrefix:"$t(",nestingSuffix:")",nestingOptionsSeparator:",",maxReplaces:1e3,skipOnVariables:!0}}),Kl=e=>{var t,n;return U(e.ns)&&(e.ns=[e.ns]),U(e.fallbackLng)&&(e.fallbackLng=[e.fallbackLng]),U(e.fallbackNS)&&(e.fallbackNS=[e.fallbackNS]),((n=(t=e.supportedLngs)==null?void 0:t.indexOf)==null?void 0:n.call(t,"cimode"))<0&&(e.supportedLngs=e.supportedLngs.concat(["cimode"])),typeof e.initImmediate=="boolean"&&(e.initAsync=e.initImmediate),e},hr=()=>{},ER=e=>{Object.getOwnPropertyNames(Object.getPrototypeOf(e)).forEach(n=>{typeof e[n]=="function"&&(e[n]=e[n].bind(e))})};class $n extends So{constructor(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},n=arguments.length>1?arguments[1]:void 0;if(super(),this.options=Kl(t),this.services={},this.logger=Ve,this.modules={external:[]},ER(this),n&&!this.isInitialized&&!t.isClone){if(!this.options.initAsync)return this.init(t,n),this;setTimeout(()=>{this.init(t,n)},0)}}init(){var t=this;let n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},r=arguments.length>1?arguments[1]:void 0;this.isInitializing=!0,typeof n=="function"&&(r=n,n={}),n.defaultNS==null&&n.ns&&(U(n.ns)?n.defaultNS=n.ns:n.ns.indexOf("translation")<0&&(n.defaultNS=n.ns[0]));const o=ql();this.options={...o,...this.options,...Kl(n)},this.options.interpolation={...o.interpolation,...this.options.interpolation},n.keySeparator!==void 0&&(this.options.userDefinedKeySeparator=n.keySeparator),n.nsSeparator!==void 0&&(this.options.userDefinedNsSeparator=n.nsSeparator);const i=f=>f?typeof f=="function"?new f:f:null;if(!this.options.isClone){this.modules.logger?Ve.init(i(this.modules.logger),this.options):Ve.init(null,this.options);let f;this.modules.formatter?f=this.modules.formatter:f=RR;const d=new Gl(this.options);this.store=new Ul(this.options.resources,this.options);const p=this.services;p.logger=Ve,p.resourceStore=this.store,p.languageUtils=d,p.pluralResolver=new SR(d,{prepend:this.options.pluralSeparator,simplifyPluralSuffix:this.options.simplifyPluralSuffix}),f&&(!this.options.interpolation.format||this.options.interpolation.format===o.interpolation.format)&&(p.formatter=i(f),p.formatter.init(p,this.options),this.options.interpolation.format=p.formatter.format.bind(p.formatter)),p.interpolator=new AR(this.options),p.utils={hasLoadedNamespace:this.hasLoadedNamespace.bind(this)},p.backendConnector=new OR(i(this.modules.backend),p.resourceStore,p,this.options),p.backendConnector.on("*",function(h){for(var g=arguments.length,m=new Array(g>1?g-1:0),v=1;v<g;v++)m[v-1]=arguments[v];t.emit(h,...m)}),this.modules.languageDetector&&(p.languageDetector=i(this.modules.languageDetector),p.languageDetector.init&&p.languageDetector.init(p,this.options.detection,this.options)),this.modules.i18nFormat&&(p.i18nFormat=i(this.modules.i18nFormat),p.i18nFormat.init&&p.i18nFormat.init(this)),this.translator=new Wr(this.services,this.options),this.translator.on("*",function(h){for(var g=arguments.length,m=new Array(g>1?g-1:0),v=1;v<g;v++)m[v-1]=arguments[v];t.emit(h,...m)}),this.modules.external.forEach(h=>{h.init&&h.init(this)})}if(this.format=this.options.interpolation.format,r||(r=hr),this.options.fallbackLng&&!this.services.languageDetector&&!this.options.lng){const f=this.services.languageUtils.getFallbackCodes(this.options.fallbackLng);f.length>0&&f[0]!=="dev"&&(this.options.lng=f[0])}!this.services.languageDetector&&!this.options.lng&&this.logger.warn("init: no languageDetector is used and no lng is defined"),["getResource","hasResourceBundle","getResourceBundle","getDataByLanguage"].forEach(f=>{this[f]=function(){return t.store[f](...arguments)}}),["addResource","addResources","addResourceBundle","removeResourceBundle"].forEach(f=>{this[f]=function(){return t.store[f](...arguments),t}});const c=mn(),u=()=>{const f=(d,p)=>{this.isInitializing=!1,this.isInitialized&&!this.initializedStoreOnce&&this.logger.warn("init: i18next is already initialized. You should call init just once!"),this.isInitialized=!0,this.options.isClone||this.logger.log("initialized",this.options),this.emit("initialized",this.options),c.resolve(p),r(d,p)};if(this.languages&&!this.isInitialized)return f(null,this.t.bind(this));this.changeLanguage(this.options.lng,f)};return this.options.resources||!this.options.initAsync?u():setTimeout(u,0),c}loadResources(t){var i,s;let r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:hr;const o=U(t)?t:this.language;if(typeof t=="function"&&(r=t),!this.options.resources||this.options.partialBundledLanguages){if((o==null?void 0:o.toLowerCase())==="cimode"&&(!this.options.preload||this.options.preload.length===0))return r();const l=[],c=u=>{if(!u||u==="cimode")return;this.services.languageUtils.toResolveHierarchy(u).forEach(d=>{d!=="cimode"&&l.indexOf(d)<0&&l.push(d)})};o?c(o):this.services.languageUtils.getFallbackCodes(this.options.fallbackLng).forEach(f=>c(f)),(s=(i=this.options.preload)==null?void 0:i.forEach)==null||s.call(i,u=>c(u)),this.services.backendConnector.load(l,this.options.ns,u=>{!u&&!this.resolvedLanguage&&this.language&&this.setResolvedLanguage(this.language),r(u)})}else r(null)}reloadResources(t,n,r){const o=mn();return typeof t=="function"&&(r=t,t=void 0),typeof n=="function"&&(r=n,n=void 0),t||(t=this.languages),n||(n=this.options.ns),r||(r=hr),this.services.backendConnector.reload(t,n,i=>{o.resolve(),r(i)}),o}use(t){if(!t)throw new Error("You are passing an undefined module! Please check the object you are passing to i18next.use()");if(!t.type)throw new Error("You are passing a wrong module! Please check the object you are passing to i18next.use()");return t.type==="backend"&&(this.modules.backend=t),(t.type==="logger"||t.log&&t.warn&&t.error)&&(this.modules.logger=t),t.type==="languageDetector"&&(this.modules.languageDetector=t),t.type==="i18nFormat"&&(this.modules.i18nFormat=t),t.type==="postProcessor"&&Ap.addPostProcessor(t),t.type==="formatter"&&(this.modules.formatter=t),t.type==="3rdParty"&&this.modules.external.push(t),this}setResolvedLanguage(t){if(!(!t||!this.languages)&&!(["cimode","dev"].indexOf(t)>-1))for(let n=0;n<this.languages.length;n++){const r=this.languages[n];if(!(["cimode","dev"].indexOf(r)>-1)&&this.store.hasLanguageSomeTranslations(r)){this.resolvedLanguage=r;break}}}changeLanguage(t,n){var r=this;this.isLanguageChangingTo=t;const o=mn();this.emit("languageChanging",t);const i=c=>{this.language=c,this.languages=this.services.languageUtils.toResolveHierarchy(c),this.resolvedLanguage=void 0,this.setResolvedLanguage(c)},s=(c,u)=>{u?(i(u),this.translator.changeLanguage(u),this.isLanguageChangingTo=void 0,this.emit("languageChanged",u),this.logger.log("languageChanged",u)):this.isLanguageChangingTo=void 0,o.resolve(function(){return r.t(...arguments)}),n&&n(c,function(){return r.t(...arguments)})},l=c=>{var f,d;!t&&!c&&this.services.languageDetector&&(c=[]);const u=U(c)?c:this.services.languageUtils.getBestMatchFromCodes(c);u&&(this.language||i(u),this.translator.language||this.translator.changeLanguage(u),(d=(f=this.services.languageDetector)==null?void 0:f.cacheUserLanguage)==null||d.call(f,u)),this.loadResources(u,p=>{s(p,u)})};return!t&&this.services.languageDetector&&!this.services.languageDetector.async?l(this.services.languageDetector.detect()):!t&&this.services.languageDetector&&this.services.languageDetector.async?this.services.languageDetector.detect.length===0?this.services.languageDetector.detect().then(l):this.services.languageDetector.detect(l):l(t),o}getFixedT(t,n,r){var o=this;const i=function(s,l){let c;if(typeof l!="object"){for(var u=arguments.length,f=new Array(u>2?u-2:0),d=2;d<u;d++)f[d-2]=arguments[d];c=o.options.overloadTranslationOptionHandler([s,l].concat(f))}else c={...l};c.lng=c.lng||i.lng,c.lngs=c.lngs||i.lngs,c.ns=c.ns||i.ns,c.keyPrefix!==""&&(c.keyPrefix=c.keyPrefix||r||i.keyPrefix);const p=o.options.keySeparator||".";let h;return c.keyPrefix&&Array.isArray(s)?h=s.map(g=>`${c.keyPrefix}${p}${g}`):h=c.keyPrefix?`${c.keyPrefix}${p}${s}`:s,o.t(h,c)};return U(t)?i.lng=t:i.lngs=t,i.ns=n,i.keyPrefix=r,i}t(){var o;for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return(o=this.translator)==null?void 0:o.translate(...n)}exists(){var o;for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return(o=this.translator)==null?void 0:o.exists(...n)}setDefaultNamespace(t){this.options.defaultNS=t}hasLoadedNamespace(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};if(!this.isInitialized)return this.logger.warn("hasLoadedNamespace: i18next was not initialized",this.languages),!1;if(!this.languages||!this.languages.length)return this.logger.warn("hasLoadedNamespace: i18n.languages were undefined or empty",this.languages),!1;const r=n.lng||this.resolvedLanguage||this.languages[0],o=this.options?this.options.fallbackLng:!1,i=this.languages[this.languages.length-1];if(r.toLowerCase()==="cimode")return!0;const s=(l,c)=>{const u=this.services.backendConnector.state[`${l}|${c}`];return u===-1||u===0||u===2};if(n.precheck){const l=n.precheck(this,s);if(l!==void 0)return l}return!!(this.hasResourceBundle(r,t)||!this.services.backendConnector.backend||this.options.resources&&!this.options.partialBundledLanguages||s(r,t)&&(!o||s(i,t)))}loadNamespaces(t,n){const r=mn();return this.options.ns?(U(t)&&(t=[t]),t.forEach(o=>{this.options.ns.indexOf(o)<0&&this.options.ns.push(o)}),this.loadResources(o=>{r.resolve(),n&&n(o)}),r):(n&&n(),Promise.resolve())}loadLanguages(t,n){const r=mn();U(t)&&(t=[t]);const o=this.options.preload||[],i=t.filter(s=>o.indexOf(s)<0&&this.services.languageUtils.isSupportedCode(s));return i.length?(this.options.preload=o.concat(i),this.loadResources(s=>{r.resolve(),n&&n(s)}),r):(n&&n(),Promise.resolve())}dir(t){var o,i;if(t||(t=this.resolvedLanguage||(((o=this.languages)==null?void 0:o.length)>0?this.languages[0]:this.language)),!t)return"rtl";const n=["ar","shu","sqr","ssh","xaa","yhd","yud","aao","abh","abv","acm","acq","acw","acx","acy","adf","ads","aeb","aec","afb","ajp","apc","apd","arb","arq","ars","ary","arz","auz","avl","ayh","ayl","ayn","ayp","bbz","pga","he","iw","ps","pbt","pbu","pst","prp","prd","ug","ur","ydd","yds","yih","ji","yi","hbo","men","xmn","fa","jpr","peo","pes","prs","dv","sam","ckb"],r=((i=this.services)==null?void 0:i.languageUtils)||new Gl(ql());return n.indexOf(r.getLanguagePartFromCode(t))>-1||t.toLowerCase().indexOf("-arab")>1?"rtl":"ltr"}static createInstance(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},n=arguments.length>1?arguments[1]:void 0;return new $n(t,n)}cloneInstance(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:hr;const r=t.forkResourceStore;r&&delete t.forkResourceStore;const o={...this.options,...t,isClone:!0},i=new $n(o);if((t.debug!==void 0||t.prefix!==void 0)&&(i.logger=i.logger.clone(t)),["store","services","language"].forEach(l=>{i[l]=this[l]}),i.services={...this.services},i.services.utils={hasLoadedNamespace:i.hasLoadedNamespace.bind(i)},r){const l=Object.keys(this.store.data).reduce((c,u)=>(c[u]={...this.store.data[u]},Object.keys(c[u]).reduce((f,d)=>(f[d]={...c[u][d]},f),{})),{});i.store=new Ul(l,o),i.services.resourceStore=i.store}return i.translator=new Wr(i.services,o),i.translator.on("*",function(l){for(var c=arguments.length,u=new Array(c>1?c-1:0),f=1;f<c;f++)u[f-1]=arguments[f];i.emit(l,...u)}),i.init(o,n),i.translator.options=o,i.translator.backendConnector.services.utils={hasLoadedNamespace:i.hasLoadedNamespace.bind(i)},i}toJSON(){return{options:this.options,store:this.store,language:this.language,languages:this.languages,resolvedLanguage:this.resolvedLanguage}}}const ve=$n.createInstance();ve.createInstance=$n.createInstance;ve.createInstance;ve.dir;ve.init;ve.loadResources;ve.reloadResources;ve.use;ve.changeLanguage;ve.getFixedT;ve.t;ve.exists;ve.setDefaultNamespace;ve.hasLoadedNamespace;ve.loadNamespaces;ve.loadLanguages;function Zi(e){"@babel/helpers - typeof";return Zi=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Zi(e)}function jp(){return typeof XMLHttpRequest=="function"||(typeof XMLHttpRequest>"u"?"undefined":Zi(XMLHttpRequest))==="object"}function IR(e){return!!e&&typeof e.then=="function"}function NR(e){return IR(e)?e:Promise.resolve(e)}const TR="modulepreload",DR=function(e){return"/"+e},Yl={},_R=function(t,n,r){let o=Promise.resolve();if(n&&n.length>0){const i=document.getElementsByTagName("link");o=Promise.all(n.map(s=>{if(s=DR(s),s in Yl)return;Yl[s]=!0;const l=s.endsWith(".css"),c=l?'[rel="stylesheet"]':"";if(!!r)for(let d=i.length-1;d>=0;d--){const p=i[d];if(p.href===s&&(!l||p.rel==="stylesheet"))return}else if(document.querySelector(`link[href="${s}"]${c}`))return;const f=document.createElement("link");if(f.rel=l?"stylesheet":TR,l||(f.as="script",f.crossOrigin=""),f.href=s,document.head.appendChild(f),l)return new Promise((d,p)=>{f.addEventListener("load",d),f.addEventListener("error",()=>p(new Error(`Unable to preload CSS for ${s}`)))})}))}return o.then(()=>t()).catch(i=>{const s=new Event("vite:preloadError",{cancelable:!0});if(s.payload=i,window.dispatchEvent(s),!s.defaultPrevented)throw i})};function Jl(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(o){return Object.getOwnPropertyDescriptor(e,o).enumerable})),n.push.apply(n,r)}return n}function Zl(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Jl(Object(n),!0).forEach(function(r){$R(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Jl(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function $R(e,t,n){return(t=BR(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function BR(e){var t=PR(e,"string");return Bt(t)=="symbol"?t:t+""}function PR(e,t){if(Bt(e)!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t||"default");if(Bt(r)!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function Bt(e){"@babel/helpers - typeof";return Bt=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Bt(e)}var At=typeof fetch=="function"?fetch:void 0;typeof global<"u"&&global.fetch?At=global.fetch:typeof window<"u"&&window.fetch&&(At=window.fetch);var Bn;jp()&&(typeof global<"u"&&global.XMLHttpRequest?Bn=global.XMLHttpRequest:typeof window<"u"&&window.XMLHttpRequest&&(Bn=window.XMLHttpRequest));var zr;typeof ActiveXObject=="function"&&(typeof global<"u"&&global.ActiveXObject?zr=global.ActiveXObject:typeof window<"u"&&window.ActiveXObject&&(zr=window.ActiveXObject));typeof At!="function"&&(At=void 0);if(!At&&!Bn&&!zr)try{_R(()=>import("./browser-ponyfill-ToTdgQUL.js").then(e=>e.b),__vite__mapDeps([0,1])).then(function(e){At=e.default}).catch(function(){})}catch{}var Xi=function(t,n){if(n&&Bt(n)==="object"){var r="";for(var o in n)r+="&"+encodeURIComponent(o)+"="+encodeURIComponent(n[o]);if(!r)return t;t=t+(t.indexOf("?")!==-1?"&":"?")+r.slice(1)}return t},Xl=function(t,n,r,o){var i=function(c){if(!c.ok)return r(c.statusText||"Error",{status:c.status});c.text().then(function(u){r(null,{status:c.status,data:u})}).catch(r)};if(o){var s=o(t,n);if(s instanceof Promise){s.then(i).catch(r);return}}typeof fetch=="function"?fetch(t,n).then(i).catch(r):At(t,n).then(i).catch(r)},ec=!1,kR=function(t,n,r,o){t.queryStringParams&&(n=Xi(n,t.queryStringParams));var i=Zl({},typeof t.customHeaders=="function"?t.customHeaders():t.customHeaders);typeof window>"u"&&typeof global<"u"&&typeof global.process<"u"&&global.process.versions&&global.process.versions.node&&(i["User-Agent"]="i18next-http-backend (node/".concat(global.process.version,"; ").concat(global.process.platform," ").concat(global.process.arch,")")),r&&(i["Content-Type"]="application/json");var s=typeof t.requestOptions=="function"?t.requestOptions(r):t.requestOptions,l=Zl({method:r?"POST":"GET",body:r?t.stringify(r):void 0,headers:i},ec?{}:s),c=typeof t.alternateFetch=="function"&&t.alternateFetch.length>=1?t.alternateFetch:void 0;try{Xl(n,l,o,c)}catch(u){if(!s||Object.keys(s).length===0||!u.message||u.message.indexOf("not implemented")<0)return o(u);try{Object.keys(s).forEach(function(f){delete l[f]}),Xl(n,l,o,c),ec=!0}catch(f){o(f)}}},LR=function(t,n,r,o){r&&Bt(r)==="object"&&(r=Xi("",r).slice(1)),t.queryStringParams&&(n=Xi(n,t.queryStringParams));try{var i=Bn?new Bn:new zr("MSXML2.XMLHTTP.3.0");i.open(r?"POST":"GET",n,1),t.crossDomain||i.setRequestHeader("X-Requested-With","XMLHttpRequest"),i.withCredentials=!!t.withCredentials,r&&i.setRequestHeader("Content-Type","application/x-www-form-urlencoded"),i.overrideMimeType&&i.overrideMimeType("application/json");var s=t.customHeaders;if(s=typeof s=="function"?s():s,s)for(var l in s)i.setRequestHeader(l,s[l]);i.onreadystatechange=function(){i.readyState>3&&o(i.status>=400?i.statusText:null,{status:i.status,data:i.responseText})},i.send(r)}catch(c){console&&console.log(c)}},MR=function(t,n,r,o){if(typeof r=="function"&&(o=r,r=void 0),o=o||function(){},At&&n.indexOf("file:")!==0)return kR(t,n,r,o);if(jp()||typeof ActiveXObject=="function")return LR(t,n,r,o);o(new Error("No fetch and no xhr implementation found!"))};function on(e){"@babel/helpers - typeof";return on=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},on(e)}function tc(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(o){return Object.getOwnPropertyDescriptor(e,o).enumerable})),n.push.apply(n,r)}return n}function ui(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?tc(Object(n),!0).forEach(function(r){Rp(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):tc(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function UR(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function nc(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,Fp(r.key),r)}}function VR(e,t,n){return t&&nc(e.prototype,t),n&&nc(e,n),Object.defineProperty(e,"prototype",{writable:!1}),e}function Rp(e,t,n){return(t=Fp(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Fp(e){var t=HR(e,"string");return on(t)=="symbol"?t:t+""}function HR(e,t){if(on(e)!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t||"default");if(on(r)!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var GR=function(){return{loadPath:"/locales/{{lng}}/{{ns}}.json",addPath:"/locales/add/{{lng}}/{{ns}}",parse:function(n){return JSON.parse(n)},stringify:JSON.stringify,parsePayload:function(n,r,o){return Rp({},r,o||"")},parseLoadPayload:function(n,r){},request:MR,reloadInterval:typeof window<"u"?!1:60*60*1e3,customHeaders:{},queryStringParams:{},crossDomain:!1,withCredentials:!1,overrideMimeType:!1,requestOptions:{mode:"cors",credentials:"same-origin",cache:"default"}}},Op=function(){function e(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};UR(this,e),this.services=t,this.options=n,this.allOptions=r,this.type="backend",this.init(t,n,r)}return VR(e,[{key:"init",value:function(n){var r=this,o=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},i=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};if(this.services=n,this.options=ui(ui(ui({},GR()),this.options||{}),o),this.allOptions=i,this.services&&this.options.reloadInterval){var s=setInterval(function(){return r.reload()},this.options.reloadInterval);on(s)==="object"&&typeof s.unref=="function"&&s.unref()}}},{key:"readMulti",value:function(n,r,o){this._readAny(n,n,r,r,o)}},{key:"read",value:function(n,r,o){this._readAny([n],n,[r],r,o)}},{key:"_readAny",value:function(n,r,o,i,s){var l=this,c=this.options.loadPath;typeof this.options.loadPath=="function"&&(c=this.options.loadPath(n,o)),c=NR(c),c.then(function(u){if(!u)return s(null,{});var f=l.services.interpolator.interpolate(u,{lng:n.join("+"),ns:o.join("+")});l.loadUrl(f,s,r,i)})}},{key:"loadUrl",value:function(n,r,o,i){var s=this,l=typeof o=="string"?[o]:o,c=typeof i=="string"?[i]:i,u=this.options.parseLoadPayload(l,c);this.options.request(this.options,n,u,function(f,d){if(d&&(d.status>=500&&d.status<600||!d.status))return r("failed loading "+n+"; status code: "+d.status,!0);if(d&&d.status>=400&&d.status<500)return r("failed loading "+n+"; status code: "+d.status,!1);if(!d&&f&&f.message){var p=f.message.toLowerCase(),h=["failed","fetch","network","load"].find(function(v){return p.indexOf(v)>-1});if(h)return r("failed loading "+n+": "+f.message,!0)}if(f)return r(f,!1);var g,m;try{typeof d.data=="string"?g=s.options.parse(d.data,o,i):g=d.data}catch{m="failed parsing "+n+" to json"}if(m)return r(m,!1);r(null,g)})}},{key:"create",value:function(n,r,o,i,s){var l=this;if(this.options.addPath){typeof n=="string"&&(n=[n]);var c=this.options.parsePayload(r,o,i),u=0,f=[],d=[];n.forEach(function(p){var h=l.options.addPath;typeof l.options.addPath=="function"&&(h=l.options.addPath(p,r));var g=l.services.interpolator.interpolate(h,{lng:p,ns:r});l.options.request(l.options,g,c,function(m,v){u+=1,f.push(m),d.push(v),u===n.length&&typeof s=="function"&&s(f,d)})})}}},{key:"reload",value:function(){var n=this,r=this.services,o=r.backendConnector,i=r.languageUtils,s=r.logger,l=o.language;if(!(l&&l.toLowerCase()==="cimode")){var c=[],u=function(d){var p=i.toResolveHierarchy(d);p.forEach(function(h){c.indexOf(h)<0&&c.push(h)})};u(l),this.allOptions.preload&&this.allOptions.preload.forEach(function(f){return u(f)}),c.forEach(function(f){n.allOptions.ns.forEach(function(d){o.read(f,d,"read",null,null,function(p,h){p&&s.warn("loading namespace ".concat(d," for language ").concat(f," failed"),p),!p&&h&&s.log("loaded namespace ".concat(d," for language ").concat(f),h),o.loaded("".concat(f,"|").concat(d),p,h)})})})}}}])}();Op.type="backend";const{slice:WR,forEach:zR}=[];function QR(e){return zR.call(WR.call(arguments,1),t=>{if(t)for(const n in t)e[n]===void 0&&(e[n]=t[n])}),e}const rc=/^[\u0009\u0020-\u007e\u0080-\u00ff]+$/,qR=function(e,t){const r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{path:"/"},o=encodeURIComponent(t);let i=`${e}=${o}`;if(r.maxAge>0){const s=r.maxAge-0;if(Number.isNaN(s))throw new Error("maxAge should be a Number");i+=`; Max-Age=${Math.floor(s)}`}if(r.domain){if(!rc.test(r.domain))throw new TypeError("option domain is invalid");i+=`; Domain=${r.domain}`}if(r.path){if(!rc.test(r.path))throw new TypeError("option path is invalid");i+=`; Path=${r.path}`}if(r.expires){if(typeof r.expires.toUTCString!="function")throw new TypeError("option expires is invalid");i+=`; Expires=${r.expires.toUTCString()}`}if(r.httpOnly&&(i+="; HttpOnly"),r.secure&&(i+="; Secure"),r.sameSite)switch(typeof r.sameSite=="string"?r.sameSite.toLowerCase():r.sameSite){case!0:i+="; SameSite=Strict";break;case"lax":i+="; SameSite=Lax";break;case"strict":i+="; SameSite=Strict";break;case"none":i+="; SameSite=None";break;default:throw new TypeError("option sameSite is invalid")}return i},oc={create(e,t,n,r){let o=arguments.length>4&&arguments[4]!==void 0?arguments[4]:{path:"/",sameSite:"strict"};n&&(o.expires=new Date,o.expires.setTime(o.expires.getTime()+n*60*1e3)),r&&(o.domain=r),document.cookie=qR(e,encodeURIComponent(t),o)},read(e){const t=`${e}=`,n=document.cookie.split(";");for(let r=0;r<n.length;r++){let o=n[r];for(;o.charAt(0)===" ";)o=o.substring(1,o.length);if(o.indexOf(t)===0)return o.substring(t.length,o.length)}return null},remove(e){this.create(e,"",-1)}};var KR={name:"cookie",lookup(e){let{lookupCookie:t}=e;if(t&&typeof document<"u")return oc.read(t)||void 0},cacheUserLanguage(e,t){let{lookupCookie:n,cookieMinutes:r,cookieDomain:o,cookieOptions:i}=t;n&&typeof document<"u"&&oc.create(n,e,r,o,i)}},YR={name:"querystring",lookup(e){var r;let{lookupQuerystring:t}=e,n;if(typeof window<"u"){let{search:o}=window.location;!window.location.search&&((r=window.location.hash)==null?void 0:r.indexOf("?"))>-1&&(o=window.location.hash.substring(window.location.hash.indexOf("?")));const s=o.substring(1).split("&");for(let l=0;l<s.length;l++){const c=s[l].indexOf("=");c>0&&s[l].substring(0,c)===t&&(n=s[l].substring(c+1))}}return n}};let xn=null;const ic=()=>{if(xn!==null)return xn;try{xn=window!=="undefined"&&window.localStorage!==null;const e="i18next.translate.boo";window.localStorage.setItem(e,"foo"),window.localStorage.removeItem(e)}catch{xn=!1}return xn};var JR={name:"localStorage",lookup(e){let{lookupLocalStorage:t}=e;if(ic()&&t)return window.localStorage.getItem(t)||void 0},cacheUserLanguage(e,t){let{lookupLocalStorage:n}=t;ic()&&n&&window.localStorage.setItem(n,e)}};let vn=null;const sc=()=>{if(vn!==null)return vn;try{vn=window!=="undefined"&&window.sessionStorage!==null;const e="i18next.translate.boo";window.sessionStorage.setItem(e,"foo"),window.sessionStorage.removeItem(e)}catch{vn=!1}return vn};var ZR={name:"sessionStorage",lookup(e){let{lookupSessionStorage:t}=e;if(t&&sc())return window.sessionStorage.getItem(t)||void 0},cacheUserLanguage(e,t){let{lookupSessionStorage:n}=t;n&&sc()&&window.sessionStorage.setItem(n,e)}},XR={name:"navigator",lookup(e){const t=[];if(typeof navigator<"u"){const{languages:n,userLanguage:r,language:o}=navigator;if(n)for(let i=0;i<n.length;i++)t.push(n[i]);r&&t.push(r),o&&t.push(o)}return t.length>0?t:void 0}},e1={name:"htmlTag",lookup(e){let{htmlTag:t}=e,n;const r=t||(typeof document<"u"?document.documentElement:null);return r&&typeof r.getAttribute=="function"&&(n=r.getAttribute("lang")),n}},t1={name:"path",lookup(e){var o;let{lookupFromPathIndex:t}=e;if(typeof window>"u")return;const n=window.location.pathname.match(/\/([a-zA-Z-]*)/g);return Array.isArray(n)?(o=n[typeof t=="number"?t:0])==null?void 0:o.replace("/",""):void 0}},n1={name:"subdomain",lookup(e){var o,i;let{lookupFromSubdomainIndex:t}=e;const n=typeof t=="number"?t+1:1,r=typeof window<"u"&&((i=(o=window.location)==null?void 0:o.hostname)==null?void 0:i.match(/^(\w{2,5})\.(([a-z0-9-]{1,63}\.[a-z]{2,6})|localhost)/i));if(r)return r[n]}};let Ep=!1;try{document.cookie,Ep=!0}catch{}const Ip=["querystring","cookie","localStorage","sessionStorage","navigator","htmlTag"];Ep||Ip.splice(1,1);const r1=()=>({order:Ip,lookupQuerystring:"lng",lookupCookie:"i18next",lookupLocalStorage:"i18nextLng",lookupSessionStorage:"i18nextLng",caches:["localStorage"],excludeCacheFor:["cimode"],convertDetectedLanguage:e=>e});class Np{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.type="languageDetector",this.detectors={},this.init(t,n)}init(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{languageUtils:{}},n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};this.services=t,this.options=QR(n,this.options||{},r1()),typeof this.options.convertDetectedLanguage=="string"&&this.options.convertDetectedLanguage.indexOf("15897")>-1&&(this.options.convertDetectedLanguage=o=>o.replace("-","_")),this.options.lookupFromUrlIndex&&(this.options.lookupFromPathIndex=this.options.lookupFromUrlIndex),this.i18nOptions=r,this.addDetector(KR),this.addDetector(YR),this.addDetector(JR),this.addDetector(ZR),this.addDetector(XR),this.addDetector(e1),this.addDetector(t1),this.addDetector(n1)}addDetector(t){return this.detectors[t.name]=t,this}detect(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:this.options.order,n=[];return t.forEach(r=>{if(this.detectors[r]){let o=this.detectors[r].lookup(this.options);o&&typeof o=="string"&&(o=[o]),o&&(n=n.concat(o))}}),n=n.map(r=>this.options.convertDetectedLanguage(r)),this.services&&this.services.languageUtils&&this.services.languageUtils.getBestMatchFromCodes?n:n.length>0?n[0]:null}cacheUserLanguage(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:this.options.caches;n&&(this.options.excludeCacheFor&&this.options.excludeCacheFor.indexOf(t)>-1||n.forEach(r=>{this.detectors[r]&&this.detectors[r].cacheUserLanguage(t,this.options)}))}}Np.type="languageDetector";ts.addDefaultLocale(Bp);const o1=new Pp;ve.use(Op).use(Fb).use(Np).init({detection:{htmlTag:window.document?window.document.head:void 0},fallbackLng:"en",interpolation:{escapeValue:!1},react:{useSuspense:!1},backend:{loadPath:"/static/corptools/i18n/{{lng}}/{{ns}}.json"}});function i1(){return a.jsx(H.StrictMode,{children:a.jsx(kp,{client:o1,children:a.jsx(Up,{children:a.jsxs(Vp,{children:[a.jsxs(W,{path:"audit/r/:characterID/",element:a.jsx(bS,{}),children:[a.jsx(W,{index:!0,element:a.jsx(Ro,{to:"account/overview",replace:!0})}),a.jsx(W,{path:"account/overview",element:a.jsx(qA,{})}),a.jsx(W,{path:"account/status",element:a.jsx(Yj,{})}),a.jsx(W,{path:"account/assets",element:a.jsx(Lb,{})}),a.jsx(W,{path:"account/listassets",element:a.jsx(Mb,{})}),a.jsx(W,{path:"account/pubdata",element:a.jsx(XA,{})}),a.jsx(W,{path:"account/clones",element:a.jsx(CS,{})}),a.jsx(W,{path:"account/roles",element:a.jsx(ej,{})}),a.jsx(W,{path:"account/wallet",element:a.jsx(Jj,{})}),a.jsx(W,{path:"account/mail",element:a.jsx(XS,{})}),a.jsx(W,{path:"account/mining",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is account/mining."})})}),a.jsx(W,{path:"account/lp",element:a.jsx(JS,{})}),a.jsx(W,{path:"account/walletactivity",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is account/walletactivity."})})}),a.jsx(W,{path:"account/notifications",element:a.jsx(tA,{})}),a.jsx(W,{path:"account/contact",element:a.jsx(SS,{})}),a.jsx(W,{path:"account/contract",element:a.jsx(FS,{})}),a.jsx(W,{path:"account/skills",element:a.jsx(zj,{})}),a.jsx(W,{path:"account/skillqueue",element:a.jsx(Vj,{})}),a.jsx(W,{path:"account/doctrines",element:a.jsx(YS,{})}),a.jsx(W,{path:"account/market",element:a.jsx(eA,{})}),a.jsx(W,{path:"account/standings",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is account/standings."})})}),a.jsx(W,{path:"account/list",element:a.jsx(Tb,{})})]}),a.jsxs(W,{path:"audit/r_beta/corp/",element:a.jsx(aR,{}),children:[a.jsx(W,{index:!0,element:a.jsx(Ro,{to:"glance",replace:!0})}),a.jsx(W,{path:"corporations",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is Corp List."})})}),a.jsx(W,{path:"glance",element:a.jsx(Xj,{})}),a.jsx(W,{path:"structures",element:a.jsx(fR,{})}),a.jsx(W,{path:"wallets",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is wallets."})})}),a.jsx(W,{path:"assetgroup",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is assetgroup."})})}),a.jsx(W,{path:"assetlist",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is assetlist."})})}),a.jsx(W,{path:"pocos",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is pocos."})})}),a.jsx(W,{path:"bridges",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is bridges."})})}),a.jsx(W,{path:"bridges",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is fuel."})})}),a.jsx(W,{path:"sov",element:a.jsx(D,{children:a.jsx(D.Body,{className:"text-center",children:"This is sov."})})})]}),a.jsx(W,{path:"*",element:a.jsx(Ro,{to:"audit/r/0",replace:!0})})]})})})})}var es={},ac=Lp;es.createRoot=ac.createRoot,es.hydrateRoot=ac.hydrateRoot;es.createRoot(document.getElementById("root")).render(a.jsx(H.StrictMode,{children:a.jsx(i1,{})}));
function __vite__mapDeps(indexes) {
  if (!__vite__mapDeps.viteFileDeps) {
    __vite__mapDeps.viteFileDeps = ["assets/browser-ponyfill-ToTdgQUL.js","assets/@libs-DsDdirnI.js"]
  }
  return indexes.map((i) => __vite__mapDeps.viteFileDeps[i])
}
//# sourceMappingURL=index-CVq_gsir.js.map
